{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Using CNN for Document Classification with Embeddings\n",
    "=====================================================\n",
    "\n",
    "The CBOW example used an Embedding layer to do simple classification. This example builds on that in three ways: \n",
    "\n",
    "- first by loading pretrained word embeddings, then \n",
    "- by finetuning these pretrained embeddings by classifying entire news articles, and \n",
    "- finally by using a convolutional neural network to capture the spatial relationships between words.\n",
    "\n",
    ":::{admonition} Transfer Learning\n",
    "In machine learning, using a model trained on one task as an initializer for another\n",
    "task is called *transfer learning*.\n",
    ":::\n",
    "\n",
    "In this example, we use the AG News dataset. To model the sequences of words in AG News, we introduce a variant of the `Vocabulary` class `SequenceVocabulary`, to bundle several tokens vital for modeling sequences. The `Vectorizer` demonstrates how to use this class.\n",
    "\n",
    "[Download GloVe Pretrained Embeddings - glove.6B.zip](https://nlp.stanford.edu/data/glove.6B.zip)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Imports"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {},
   "outputs": [],
   "source": [
    "import os\n",
    "from argparse import Namespace\n",
    "from collections import Counter\n",
    "import json\n",
    "import re\n",
    "import string\n",
    "\n",
    "import numpy as np\n",
    "import pandas as pd\n",
    "import torch\n",
    "import torch.nn as nn\n",
    "import torch.nn.functional as F\n",
    "import torch.optim as optim\n",
    "from torch.utils.data import Dataset, DataLoader\n",
    "from tqdm.notebook import tqdm"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Data Vectorization classes"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### The Standard `Vocabulary` Class\n",
    "\n",
    "A `Vocabulary` object is able to look up an index for a token and vice versa, useful for constructing a one-hot vector for each word. "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {},
   "outputs": [],
   "source": [
    "class Vocabulary(object):\n",
    "    \"\"\"Class to process text and extract vocabulary for mapping\"\"\"\n",
    "\n",
    "    def __init__(self, token_to_idx=None):\n",
    "        \"\"\"\n",
    "        Args:\n",
    "            token_to_idx (dict): a pre-existing map of tokens to indices\n",
    "        \"\"\"\n",
    "\n",
    "        if token_to_idx is None:\n",
    "            token_to_idx = {}\n",
    "        self._token_to_idx = token_to_idx\n",
    "\n",
    "        self._idx_to_token = {idx: token \n",
    "                              for token, idx in self._token_to_idx.items()}\n",
    "        \n",
    "    def to_serializable(self):\n",
    "        \"\"\" returns a dictionary that can be serialized \"\"\"\n",
    "        return {'token_to_idx': self._token_to_idx}\n",
    "\n",
    "    @classmethod\n",
    "    def from_serializable(cls, contents):\n",
    "        \"\"\" instantiates the Vocabulary from a serialized dictionary \"\"\"\n",
    "        return cls(**contents)\n",
    "\n",
    "    def add_token(self, token):\n",
    "        \"\"\"Update mapping dicts based on the token.\n",
    "\n",
    "        Args:\n",
    "            token (str): the item to add into the Vocabulary\n",
    "        Returns:\n",
    "            index (int): the integer corresponding to the token\n",
    "        \"\"\"\n",
    "        if token in self._token_to_idx:\n",
    "            index = self._token_to_idx[token]\n",
    "        else:\n",
    "            index = len(self._token_to_idx)\n",
    "            self._token_to_idx[token] = index\n",
    "            self._idx_to_token[index] = token\n",
    "        return index\n",
    "            \n",
    "    def add_many(self, tokens):\n",
    "        \"\"\"Add a list of tokens into the Vocabulary\n",
    "        \n",
    "        Args:\n",
    "            tokens (list): a list of string tokens\n",
    "        Returns:\n",
    "            indices (list): a list of indices corresponding to the tokens\n",
    "        \"\"\"\n",
    "        return [self.add_token(token) for token in tokens]\n",
    "\n",
    "    def lookup_token(self, token):\n",
    "        \"\"\"Retrieve the index associated with the token \n",
    "        \n",
    "        Args:\n",
    "            token (str): the token to look up \n",
    "        Returns:\n",
    "            index (int): the index corresponding to the token\n",
    "        \"\"\"\n",
    "        return self._token_to_idx[token]\n",
    "\n",
    "    def lookup_index(self, index):\n",
    "        \"\"\"Return the token associated with the index\n",
    "        \n",
    "        Args: \n",
    "            index (int): the index to look up\n",
    "        Returns:\n",
    "            token (str): the token corresponding to the index\n",
    "        Raises:\n",
    "            KeyError: if the index is not in the Vocabulary\n",
    "        \"\"\"\n",
    "        if index not in self._idx_to_token:\n",
    "            raise KeyError(\"the index (%d) is not in the Vocabulary\" % index)\n",
    "        return self._idx_to_token[index]\n",
    "\n",
    "    def __str__(self):\n",
    "        return \"<Vocabulary(size=%d)>\" % len(self)\n",
    "\n",
    "    def __len__(self):\n",
    "        return len(self._token_to_idx)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### SequenceVocabulary\n",
    "\n",
    "When we deal with a sequence of words, it is often useful to have four special tokens\n",
    "- the `UNK` token, \n",
    "- the `MASK` token, \n",
    "- the `BEGINOFSEQUENCE` token, and \n",
    "- the `ENDOFSEQUENCE` token. \n",
    "\n",
    "They serve three different purposes. \n",
    "- The `UNK` token (short for unknown), allows the model to learn a representation for rare words so that it can accommodate words that it has never seen at test time. \n",
    "- The `MASK` token serves as a sentinel for Embedding layers and loss calculations when we have sequences of variable length (padding in the context of sequence modelling). \n",
    "- Finally, the `BEGINOFSEQUENCE` and `ENDOFSEQUENCE` tokens give the neural network hints about the\n",
    "sequence boundaries.\n",
    "\n",
    "The figure below shows the result of using these special tokens in the broader vectorization pipeline.\n",
    "\n",
    "![SequenceVocabulary Class](../images/sequence_vocab.png)\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {},
   "outputs": [],
   "source": [
    "class SequenceVocabulary(Vocabulary):\n",
    "    def __init__(self, token_to_idx=None, unk_token=\"<UNK>\",\n",
    "                 mask_token=\"<MASK>\", begin_seq_token=\"<BEGIN>\",\n",
    "                 end_seq_token=\"<END>\"):\n",
    "\n",
    "        super(SequenceVocabulary, self).__init__(token_to_idx)\n",
    "\n",
    "        self._mask_token = mask_token\n",
    "        self._unk_token = unk_token\n",
    "        self._begin_seq_token = begin_seq_token\n",
    "        self._end_seq_token = end_seq_token\n",
    "\n",
    "        self.mask_index = self.add_token(self._mask_token)\n",
    "        self.unk_index = self.add_token(self._unk_token)\n",
    "        self.begin_seq_index = self.add_token(self._begin_seq_token)\n",
    "        self.end_seq_index = self.add_token(self._end_seq_token)\n",
    "\n",
    "    def to_serializable(self):\n",
    "        contents = super(SequenceVocabulary, self).to_serializable()\n",
    "        contents.update({'unk_token': self._unk_token,\n",
    "                         'mask_token': self._mask_token,\n",
    "                         'begin_seq_token': self._begin_seq_token,\n",
    "                         'end_seq_token': self._end_seq_token})\n",
    "        return contents\n",
    "\n",
    "    def lookup_token(self, token):\n",
    "        \"\"\"Retrieve the index associated with the token \n",
    "          or the UNK index if token isn't present.\n",
    "        \n",
    "        Args:\n",
    "            token (str): the token to look up \n",
    "        Returns:\n",
    "            index (int): the index corresponding to the token\n",
    "        Notes:\n",
    "            `unk_index` needs to be >=0 (having been added into the Vocabulary) \n",
    "              for the UNK functionality \n",
    "        \"\"\"\n",
    "        if self.unk_index >= 0:\n",
    "            return self._token_to_idx.get(token, self.unk_index)\n",
    "        else:\n",
    "            return self._token_to_idx[token]"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### The Vectorizer\n",
    "\n",
    "The `Vectorizer`, instantiates and encapsulates the use of the `SequenceVocabulary`. In this example, the Vectorizer follows the pattern we demonstrated before of restricting the total set of words allowed in the Vocabulary by counting and thresholding on a certain frequency (`cutoff`). The core purpose of this action is to improve the signal quality for the model and limit the memory model’s memory usage by removing noisy, lowfrequency words.\n",
    "\n",
    "After instantiation, the `Vectorizer`'s `vectorize()` method takes as input a news title and\n",
    "returns a vector that is as long as the longest title in the dataset. It has two key behaviors. \n",
    "\n",
    "- The first is that it stores the maximum sequence length locally. Normally, the dataset tracks the maximum sequence length, and at inference time, the length of the test sequence is taken as the length of the vector, for example in a Recurrent Neural Network (RNN) model. However, because we have a CNN model, it is important to maintain a static size even at inference time. \n",
    "\n",
    "- The second key behavior, it outputs a zeropadded vector of integers (indices), which represent the words in the sequence. \n",
    "\n",
    "- Additionally, this vector of integers has the integer for the BEGINOFSEQUENCE token prepended to the beginning and the integer for the ENDOFSEQUENCE token appended to the end. \n",
    "\n",
    "From the classifier's perspective, these special tokens provide evidence of the sequence boundaries, allowing it to react to words near the boundary differently than to words near the center."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {},
   "outputs": [],
   "source": [
    "class NewsVectorizer(object):\n",
    "    \"\"\" The Vectorizer which coordinates the Vocabularies and puts them to use\"\"\"    \n",
    "    def __init__(self, title_vocab, category_vocab):\n",
    "        self.title_vocab = title_vocab\n",
    "        self.category_vocab = category_vocab\n",
    "\n",
    "    def vectorize(self, title, vector_length=-1):\n",
    "        \"\"\"\n",
    "        Args:\n",
    "            title (str): the string of words separated by a space\n",
    "            vector_length (int): an argument for forcing the length of index vector\n",
    "        Returns:\n",
    "            the vetorized title (numpy.array)\n",
    "        \"\"\"\n",
    "        indices = [self.title_vocab.begin_seq_index]\n",
    "        indices.extend(self.title_vocab.lookup_token(token) \n",
    "                       for token in title.split(\" \"))\n",
    "        indices.append(self.title_vocab.end_seq_index)\n",
    "\n",
    "        if vector_length < 0:\n",
    "            vector_length = len(indices)\n",
    "\n",
    "        out_vector = np.zeros(vector_length, dtype=np.int64)\n",
    "        out_vector[:len(indices)] = indices\n",
    "        out_vector[len(indices):] = self.title_vocab.mask_index\n",
    "\n",
    "        return out_vector\n",
    "\n",
    "    @classmethod\n",
    "    def from_dataframe(cls, news_df, cutoff=25):\n",
    "        \"\"\"Instantiate the vectorizer from the dataset dataframe\n",
    "        \n",
    "        Args:\n",
    "            news_df (pandas.DataFrame): the target dataset\n",
    "            cutoff (int): frequency threshold for including in Vocabulary \n",
    "        Returns:\n",
    "            an instance of the NewsVectorizer\n",
    "        \"\"\"\n",
    "        category_vocab = Vocabulary()        \n",
    "        for category in sorted(set(news_df.category)):\n",
    "            category_vocab.add_token(category)\n",
    "\n",
    "        word_counts = Counter()\n",
    "        for title in news_df.title:\n",
    "            for token in title.split(\" \"):\n",
    "                if token not in string.punctuation:\n",
    "                    word_counts[token] += 1\n",
    "        \n",
    "        title_vocab = SequenceVocabulary()\n",
    "        for word, word_count in word_counts.items():\n",
    "            if word_count >= cutoff:\n",
    "                title_vocab.add_token(word)\n",
    "        \n",
    "        return cls(title_vocab, category_vocab)\n",
    "\n",
    "    @classmethod\n",
    "    def from_serializable(cls, contents):\n",
    "        title_vocab = \\\n",
    "            SequenceVocabulary.from_serializable(contents['title_vocab'])\n",
    "        category_vocab =  \\\n",
    "            Vocabulary.from_serializable(contents['category_vocab'])\n",
    "\n",
    "        return cls(title_vocab=title_vocab, category_vocab=category_vocab)\n",
    "\n",
    "    def to_serializable(self):\n",
    "        return {'title_vocab': self.title_vocab.to_serializable(),\n",
    "                'category_vocab': self.category_vocab.to_serializable()}"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### The Dataset"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {},
   "outputs": [],
   "source": [
    "class NewsDataset(Dataset):\n",
    "    def __init__(self, news_df, vectorizer):\n",
    "        \"\"\"\n",
    "        Args:\n",
    "            news_df (pandas.DataFrame): the dataset\n",
    "            vectorizer (NewsVectorizer): vectorizer instatiated from dataset\n",
    "        \"\"\"\n",
    "        self.news_df = news_df\n",
    "        self._vectorizer = vectorizer\n",
    "\n",
    "        # +1 if only using begin_seq, +2 if using both begin and end seq tokens\n",
    "        measure_len = lambda context: len(context.split(\" \"))\n",
    "        self._max_seq_length = max(map(measure_len, news_df.title)) + 2\n",
    "        \n",
    "\n",
    "        self.train_df = self.news_df[self.news_df.split=='train']\n",
    "        self.train_size = len(self.train_df)\n",
    "\n",
    "        self.val_df = self.news_df[self.news_df.split=='val']\n",
    "        self.validation_size = len(self.val_df)\n",
    "\n",
    "        self.test_df = self.news_df[self.news_df.split=='test']\n",
    "        self.test_size = len(self.test_df)\n",
    "\n",
    "        self._lookup_dict = {'train': (self.train_df, self.train_size),\n",
    "                             'val': (self.val_df, self.validation_size),\n",
    "                             'test': (self.test_df, self.test_size)}\n",
    "\n",
    "        self.set_split('train')\n",
    "\n",
    "        # Class weights\n",
    "        class_counts = news_df.category.value_counts().to_dict()\n",
    "        def sort_key(item):\n",
    "            return self._vectorizer.category_vocab.lookup_token(item[0])\n",
    "        sorted_counts = sorted(class_counts.items(), key=sort_key)\n",
    "        frequencies = [count for _, count in sorted_counts]\n",
    "        self.class_weights = 1.0 / torch.tensor(frequencies, dtype=torch.float32)\n",
    "        \n",
    "        \n",
    "    @classmethod\n",
    "    def load_dataset_and_make_vectorizer(cls, news_csv):\n",
    "        \"\"\"Load dataset and make a new vectorizer from scratch\n",
    "        \n",
    "        Args:\n",
    "            news_csv (str): location of the dataset\n",
    "        Returns:\n",
    "            an instance of NewsDataset\n",
    "        \"\"\"\n",
    "        news_df = pd.read_csv(news_csv)\n",
    "        train_news_df = news_df[news_df.split=='train']\n",
    "        return cls(news_df, NewsVectorizer.from_dataframe(train_news_df))\n",
    "\n",
    "    @classmethod\n",
    "    def load_dataset_and_load_vectorizer(cls, news_csv, vectorizer_filepath):\n",
    "        \"\"\"Load dataset and the corresponding vectorizer. \n",
    "        Used in the case in the vectorizer has been cached for re-use\n",
    "        \n",
    "        Args:\n",
    "            news_csv (str): location of the dataset\n",
    "            vectorizer_filepath (str): location of the saved vectorizer\n",
    "        Returns:\n",
    "            an instance of NewsDataset\n",
    "        \"\"\"\n",
    "        news_df = pd.read_csv(news_csv)\n",
    "        vectorizer = cls.load_vectorizer_only(vectorizer_filepath)\n",
    "        return cls(news_csv, vectorizer)\n",
    "\n",
    "    @staticmethod\n",
    "    def load_vectorizer_only(vectorizer_filepath):\n",
    "        \"\"\"a static method for loading the vectorizer from file\n",
    "        \n",
    "        Args:\n",
    "            vectorizer_filepath (str): the location of the serialized vectorizer\n",
    "        Returns:\n",
    "            an instance of NewsVectorizer\n",
    "        \"\"\"\n",
    "        with open(vectorizer_filepath) as fp:\n",
    "            return NewsVectorizer.from_serializable(json.load(fp))\n",
    "\n",
    "    def save_vectorizer(self, vectorizer_filepath):\n",
    "        \"\"\"saves the vectorizer to disk using json\n",
    "        \n",
    "        Args:\n",
    "            vectorizer_filepath (str): the location to save the vectorizer\n",
    "        \"\"\"\n",
    "        with open(vectorizer_filepath, \"w\") as fp:\n",
    "            json.dump(self._vectorizer.to_serializable(), fp)\n",
    "\n",
    "    def get_vectorizer(self):\n",
    "        \"\"\" returns the vectorizer \"\"\"\n",
    "        return self._vectorizer\n",
    "\n",
    "    def set_split(self, split=\"train\"):\n",
    "        \"\"\" selects the splits in the dataset using a column in the dataframe \"\"\"\n",
    "        self._target_split = split\n",
    "        self._target_df, self._target_size = self._lookup_dict[split]\n",
    "\n",
    "    def __len__(self):\n",
    "        return self._target_size\n",
    "\n",
    "    def __getitem__(self, index):\n",
    "        \"\"\"the primary entry point method for PyTorch datasets\n",
    "        \n",
    "        Args:\n",
    "            index (int): the index to the data point \n",
    "        Returns:\n",
    "            a dictionary holding the data point's features (x_data) and label (y_target)\n",
    "        \"\"\"\n",
    "        row = self._target_df.iloc[index]\n",
    "\n",
    "        title_vector = \\\n",
    "            self._vectorizer.vectorize(row.title, self._max_seq_length)\n",
    "\n",
    "        category_index = \\\n",
    "            self._vectorizer.category_vocab.lookup_token(row.category)\n",
    "\n",
    "        return {'x_data': title_vector,\n",
    "                'y_target': category_index}\n",
    "\n",
    "    def get_num_batches(self, batch_size):\n",
    "        \"\"\"Given a batch size, return the number of batches in the dataset\n",
    "        \n",
    "        Args:\n",
    "            batch_size (int)\n",
    "        Returns:\n",
    "            number of batches in the dataset\n",
    "        \"\"\"\n",
    "        return len(self) // batch_size\n",
    "\n",
    "def generate_batches(dataset, batch_size, shuffle=True,\n",
    "                     drop_last=True, device=\"cpu\"): \n",
    "    \"\"\"\n",
    "    A generator function which wraps the PyTorch DataLoader. It will \n",
    "      ensure each tensor is on the write device location.\n",
    "    \"\"\"\n",
    "    dataloader = DataLoader(dataset=dataset, batch_size=batch_size,\n",
    "                            shuffle=shuffle, drop_last=drop_last)\n",
    "\n",
    "    for data_dict in dataloader:\n",
    "        out_data_dict = {}\n",
    "        for name, tensor in data_dict.items():\n",
    "            out_data_dict[name] = data_dict[name].to(device)\n",
    "        yield out_data_dict"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 30,
   "metadata": {},
   "outputs": [],
   "source": [
    "dataset = NewsDataset.load_dataset_and_make_vectorizer(args.news_csv)\n",
    "#dataset.save_vectorizer(args.vectorizer_file)\n",
    "dataloader = DataLoader(dataset=dataset, batch_size=2,\n",
    "                            shuffle=True, drop_last=True)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 31,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "x_data\n",
      "tensor([[   2,  647,  721,    1,  148,  214,  142,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  507,   12, 1656,  426,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1597,    1,  273,   12, 1344,    9,  698, 1680,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1411,  183,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  854, 1463,  546, 2673, 3085, 1461,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2838,  429,   79, 2087, 2614,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2124,   45, 1687, 1022,    1, 3008,    1, 2424,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  835,    1,    1,  207,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1,  809,  696, 2692,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  796,  187,  208, 3096, 2565, 2119,  548, 1674,  671,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1445, 1421,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9, 1117, 1943,   61, 1812,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2308,  474,  693,   51, 2303,  914,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1,    1,   32,    1, 2161,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2658,   12, 1944,   98, 1580,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,    1, 1129,    1,   98,  114,  629,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   60, 1141,    1,  640,  119,  340,  951,   94,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,   37,  949, 2355, 1013, 2549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3194, 3195,   12,    1,   76,   37,  698,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2080, 2771,    1,  729,   32, 1090,  548,  287,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2269,    1,  754,  548, 3353, 2716,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1448,   12,  365,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3190, 1774,  608, 3194, 3195,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 550, 369,   1,  51,  92,   1,  37, 470, 741,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 105,   1,  45, 105,   1,  16,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  433, 1458,  131,    1,  861,  302,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3251,  972,   37,   18,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1352,  466, 1278,  418,    1,    1,   28,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,  391, 1036,    9, 1918,   32, 1081, 1002,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,  157,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  224, 1268,  756,   32,  829,   12,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1166,  544,  166, 2025,    1,  168,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2031,    1,    1,  856, 1905,  297, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3149,    1, 1243,   45, 1260,   98,   36,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2844,   32, 1094,    1,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 1118,    1,   45, 2176,  548, 3071,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  479,   85,    1,    1,   28,   32,  385,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994, 3348,  492, 1662,   13, 2572,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 2483, 2019,  315,    9, 2071, 1331,  769, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9, 1778,    1,    1,  884,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2998,   61,  105,  784,   79,    1,  202,  729,  140,   32, 2651,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  702,    1,  333,   45,  124,   37,  169,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32, 2646,  548, 2431,  267,    1, 3382,   57,    1,\n",
      "           37, 1910, 2646, 3346,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2936, 1260, 1251, 1851,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3369, 2774,  650, 1877,   37,    1, 1302,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1405,    1, 2174,  357,  439, 2060,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1, 1589,  116,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325,    1,    1, 2193,   13,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  744, 2364,   98, 2650,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  588,  432,   37, 1636,    1, 1208,  191,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  964,  267, 2095, 1450,   32,  531,  837,   10,   12, 1445,  863,\n",
      "          142,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   45,  507,   37,  221,    1,    1, 1429, 1499,   37,  273,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  220,  786, 2107, 1827,    1, 1990, 1948, 2369,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994, 1539, 2246,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2522,   37,    1,  103, 2420,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  686,  275,    1,    1,  202,  284, 1673, 2051,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1125,    1, 1310,   37, 1493, 1610, 1989, 1990, 2784,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1884, 2620,  640,    1,   98, 1282,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1920, 2853,  220,    1,    1,    1,  396,  365,  119,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2765,    1,   32,  365, 1928,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1053,  936,    1,   45,  261,   98, 2179,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  294,    8,  156,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1725, 1898,  973, 1211,  442,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1133, 1215,  115,    9,    1,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  592,  387,    1,  163,    1,   12,    1,   93,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,  986, 1354,   45,  962,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  303,  267, 1488, 1446,  261,  362,  954,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2909,    1, 3279, 2856, 3361,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1288,    1, 1288,  829,   12,    1,    1,  297,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  598,  191, 3172,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  251,  365, 3278,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,    1, 3118, 2751, 1980,   37,  498,   98,  861,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  487, 1938, 3197,   61,    1, 2645,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1033,    1, 1415, 2471,  220,  395,    1,  455,    1,   12,\n",
      "            1, 1447,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 801,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  37, 606, 361, 606, 193,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2239,    1,   37, 3161,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1631,  331,  813,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3319,  949,  709,  810,    1,    1,    1,    1,  480,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359, 2386,  864,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1122,   82,  387,  853,  538,   98,  617,  618,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884, 1333,  631,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1110, 3224,    1,  191,    1,  384,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 1260, 2414,   27, 2597,  501, 2060,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  231, 1107, 1863, 1553,  472, 1224,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  523,   61,  837,   45, 1938, 1723,  549,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  116,    1,  187,    1, 2095, 2549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  719,  388, 1407, 1149,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3330, 2954,  220,  247, 2059,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1936,  166, 1456, 2702,   37, 3064,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2, 328, 409,  25, 221, 417,  60, 338,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  64, 632,  36,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2160, 2049,   12, 2467,  167, 1694,   98, 1863,  220, 2534,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  651,  997,   98, 1520,  624,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2993, 2996, 2995,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,  754,  327,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2190, 2640,  315,  365,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1369,  256,    1, 1085,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,  967,  916,    9, 3252, 1844,  119,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2918,   37,    1,  906, 2539,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1176,  123,   37, 1140,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1340,  640, 1194, 2907,    1, 1110,  688, 3319,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3302,    1,    1,    1,  176, 3096, 1675,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1002, 1641,    9, 1759,  309, 2746,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   31,  338,  995,   32, 1169,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  439, 1110, 1844,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1, 2072,  105,  179,  180,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 105,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 696, 715,   1,  13, 151,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1451,    1,    1,  163,    1,   12,    1,    1,  244,   71,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1690,    1,  176,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2242,    1,    1,   98, 3152, 2967,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,  147,   37,  804,   98,  829,  400,  465, 1657,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111, 1904,  325, 3088,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1256,    1,  331,    1,    1,  737,  197,  418,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  854,  477,  411,  850,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,  442,    1, 1408,  677,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390,   27, 1686,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  232,    1, 1293,   98,   32, 2184,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1533,  917,  490,  187,    1,    1,    1,   45,  166,  404,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2972,  475, 1484,  460,  796,  548,  105,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1712,   37,    1, 1074, 1499, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  890,   37,   38, 1918,   37, 2789,   32, 1021,  452,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 1447,    1,   37,  395,  187, 2157,   37,  166,  104,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2652,    1,  506,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  537,  548,  236,   12,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   61,  590, 1665,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2729, 2547,  167, 1046,  134,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  709,    1,    1,  302, 1247,  928,   32,    1,  176,  166,  823,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  134,  972,   32,    1,  176,  845,   36, 1090,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3015, 3062, 2534,   12,  661,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  191,    1,    1,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2436, 1574,  361, 1300,  230,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2161, 2712,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  433,  102,   85,  191,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3102, 1089,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  632,   36, 1260,  251,    1,    1,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1,  904,    1, 1215, 2592, 2431, 2827,   32,  395, 2295,\n",
      "         2302,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2104, 2275, 1710,  335,  365, 1992,   37,  275,    8,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 1009,  682, 1322,   45, 3357,    1,  115,   45,  806,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  233,  958,    1,    9,   75, 2113,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1070,  342,  147,   37,  899,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1212,   12,    1,  315,   37,   47, 1056, 2152,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  171,    1,   98,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,    1, 2531,  439,    1,   46,   98,    1,  345,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   35, 1822,   26,  453,    1, 1232,  732,  733,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3146,   45, 2298,  220, 2018,  190,  335,  199, 2406,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   37,    1, 1772,  384,  183, 1410,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,   12, 2071, 1331,    1, 2007,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3378, 1380,  443,  147,   98,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  129,  975, 1258,  170,   46,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,  978,    1, 1355,    1, 1443,   98,  636,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  864,  967,  590,    1, 3107, 3366,  315,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294, 2771,  571,   37,  409,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 455, 729,   1, 384,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2774,  650,  738,  220, 1622,  957,   37, 2446, 2292,   32,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2816,  187,    1,   64, 1552,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  190,  606,   37, 1083,  142,   37,  726,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105, 2962,    1, 2199,    1,  187, 3312,  619,   81,   98,\n",
      "         1171,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1020,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171,   37, 2809,    1,  220,  149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2741,  804,   39, 3177,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2571, 2153,  588,  388,  617,  618,    1, 2910,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  183,    1, 2389,  852,  227,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398, 1369,   51,  606,    1,  147, 1250,   98,    1, 1469,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  985, 2432,    1,   55,  166,  311, 1265,  506,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2528,   45,  829,   12,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  116, 2264, 1210,  105, 1067,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1811, 1280,    5,    6,  881, 1812,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141, 1236,   37,   77, 3226, 1760,   39,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  690,  142,   37,  166,    1, 2771,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3230,   96,   28,    1,   32,    1, 1385,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3100,  695,  167,  288,  331,    1,   98,    1, 2515,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1539,    1, 1108,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1721, 1937,    1,  627,    9,    1, 2392,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  455, 2357,    1,  191, 2673, 2949,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2292,  187, 3363,    1, 2696,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1, 3358,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649, 1821,  232,   37, 2237, 2977,  475,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,  143,  187, 1547,  246,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,   32, 1817,    1, 1373,   37, 2816,  567,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,  284, 2334,    1,  663,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,  166,  104,  891,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  645,  469,    9,  844,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755, 1396, 1273, 2492,  918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3184, 1044,    1,   32, 3093,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  799, 1258,   37,    1, 1817,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2656,  778, 1359, 1586,   28,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1518,  132,  220,  104,    1,   98,    1,   45,  196,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1647,   98,    1,  477,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,    1,   12, 1821,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3382,   32, 1186, 1231,  220,    1, 2772,   45,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  667, 3060, 1924, 2764, 2765,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2158,   45, 2121,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2803, 3288,  444, 3142,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  871,  218,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 2102, 1107,  525,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  294,    1, 1432, 3207,  190,   77,  247,  671, 3126,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2592, 2411,    9,  132,   98,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1961, 2191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3200,    1, 2807,  750, 1564,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1109,    1,  912, 2285,    9,  517,  618,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  420,  267, 1718,   61,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  668, 2633,  680, 1260,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  935,   12, 1808,  437,    1, 1022, 2350,  793,   32,  430,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,  68,  69,  51, 245, 187, 104,   1, 504,   1, 496,  30,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1,  45, 741,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1269,   32,   91,    1,    1,  636,   45,   69,   28,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1367,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2993,    1,   39, 1270, 2069, 3056, 1117,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2362,    9,    1, 2203,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2224,  113,   46,   98, 2924,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2266, 1648,   37,  420, 3369, 2705,  499,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307,  884,    1,   37,  147,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1518,  297,  187,  218,  566,  430,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2765, 2153,    1,  528, 2018, 2678,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 1108,  476,  636,  423,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3207,  140,  810, 1425, 3208, 1684,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1465, 2519,   37,  815,    1,  279,   98, 2686,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1211, 1230,  764,  104, 1012,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  457,  963, 2981, 1539,   98,  429,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   65, 1564,  460,  547, 1500,   32,  105, 1559,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2546,  251,    1,   37, 2547,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  920,  166,    1,  565,   45, 2586,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  163,    1,   12,    1, 2547,  583,   32, 1966,  336,  298,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  565, 1107,   37,  119,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  354,    1,  159,  832,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1635,    1, 1682,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,   37, 1706, 1183, 2113,   32, 2948,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  305, 1027,  242,   98,   69,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066, 1564,    1, 2172,  865,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  315,    1,    9, 1751,  437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2889,    1, 2789, 1484,    9, 2024,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1110,    1, 3285,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1467,    1,    1,   59,   37,  875,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,  365,    1, 1976,   98, 2921,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386, 1083, 2326,    9, 3177,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2733,  776, 1268,   85,  680,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  729,    1, 2978,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   69, 1042,  885,  419,   37,  105,  106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3324,  140,    1, 3154,    1,    1, 1194,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2533,    1,    9,  683,  865,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100, 2587,    1, 2670,   98,    1,  769,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  355,   37,    1,   15,    1,   32,   91,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1920, 1492,    1,   32,    1,    1,    1,  600,    1,  226,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  195,   30,  270,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2615, 1120,   18,  166,  730, 2614,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  138,  168,  579,  460,    1,   37,  104,  361,  854,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1451,   45, 1204, 1844,    1,    9, 3051,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,  627,   45,  872,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  695, 2789,   12,  429,   98, 1021,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3369, 1988,   45, 2285,    1,  220, 3357,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  176, 2948,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2464,    1,    1,    1, 1348,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  246,   32,   98,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,   23, 1821, 2190,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1364, 1365,  116,    1, 1229,  193,    1,  191, 2226,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3365, 3150,  680, 1260,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1751,   39,    1, 3290,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  506,  486,    1, 1915,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   69,  102,  554,  530,  119,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  420,    1, 1958,   98,  166,  454,    9, 3167,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 3095, 1810, 1530,   32,  632,  851,  298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  938,    1,    1,   98,  941,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,   37,    1,    1,  985,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,  692,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,    1, 1053,  631,  876,  612,  111,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  437, 1261, 1089, 1675,    9, 2292,    1,  312,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141,  744,  449, 1034,    1,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2611,   37, 1865,  105, 2229,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  954,    1,  176,    1,  118,   32,  478,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2459,  361,  727,    1,  613,  630,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1763, 2572,   32, 3339, 2960,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  121, 3205, 2490,   37, 1334,   32,  593,  437,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 1798,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  437,  692,  658, 1766, 1767,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3147,  958, 3114, 2699,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2932,  774,  116, 2931,   61,    1,  763,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497, 1594,   37, 2967,   37,   81,   28, 2787,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  729, 3102,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  141,  142,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   25,  288,    9,  699,    1,   26,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  229,  440,  763,  749,   51, 1083,  985,  762,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2627,  872, 3280,    1,  612, 2347,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  812,  399,   45,    1, 2537,  220,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  487,  695,    1,   80,  293,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447, 1360,  612, 2192,   28, 2390, 2657,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1080,  176,    1, 1821,  656,  384,  666,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3351,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1680,    1, 1907, 2014,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3257, 2853,   32,  753,  548, 3230, 2195,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,    1,  864, 2673,  798,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,    1, 1377,    9, 3102,   12,  949,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  594,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788, 1625,   37,  726, 2826,  191,    1, 2591,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1167,    1,    1,    1,   12,   81, 1857, 1924,    1,\n",
      "          105,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1325,    1, 1294,    1,  187,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  734, 1660,  176,  639, 1167,    1,  573,  315,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  936,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  387,  244, 1473,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1523,    9, 1477, 1990,    1,    1,  176, 2916,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550, 2401, 1215,  115,    9,  460,  861,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  864,   37, 2199, 3107, 3366,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1353,  192, 2575,  220, 1085,    9,  465,  218,  361,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1492,   12, 1658,    1,    1, 3132,  248,  730, 2614,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 2979, 2869,   61,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 437,  37, 151, 944,   1,  50,   9,   1, 372, 328,   1,   3,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 707, 754,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   40, 1696, 1114,    9,  166,  350,  218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  176,  829,   12, 2019,   32, 1994, 2819, 2146, 3042,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  102, 1334,  242, 1010, 1622, 1345,    1,  417,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  438, 2122,    1,  441, 1604, 2444,   37,  837,  395,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1574,   98,  166,    1,  131,  195,  117,  112,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   63,  166,  862,    1,  418,    1,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2028,  868,   81,  176,  294, 2699,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37,  238,  361,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 1730,   51,  469,  388, 1450,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  577,  600,  166,  207,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1186,   37, 1816,  449, 2608,  931,  452,  593,  443,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2028, 2065,  442,  220,  104,  441,  528, 2782,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1785,  259, 2054,  162,   54, 1198,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374, 1094, 2072,    1, 2950,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3051, 1527, 1149,  820,  191, 3118, 2751,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1384, 1874, 2095, 3109,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   61, 1827,   32,    1,  191,  695,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3119, 2584,  872,  420, 1169,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  121, 1118, 1539,   45, 1821, 2190, 2640,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1536,  149,  951,    1,  989,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   10, 1380,    1,   98, 1428,   12, 2266,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  873,   45,  114,    1, 1608,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   12,  224, 1529, 1921,  220,  105,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  220,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  105, 2745,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1312, 2572,   32,  365, 2137,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3109,  176, 1785,    1,  776,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  613,    1,    1, 1106,  450, 1085,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2275, 1310,   37, 1594, 1708,  444,   10,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708, 3006,  114, 1056, 1957,   98, 2755, 1094,    1,  590,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,  288,   37,  439,    1,  187,  828,  741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3250,    1, 1408,    1, 1675,    1, 2424,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3039, 3040, 1089, 1090,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   73,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  178,    1,  325,    1,    9,    1,  131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2500, 1220,    1, 3024,   12,  109,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  964,  459,  625,   98,    1,    1,  378,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  581, 1023,  197,  418,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,  868,   28,    1, 2880,  613, 1017,    9, 3019,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  105,  593,   45,    1,    1, 1331,    1,  729,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3084, 2329,    1,   12,  365, 2180,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  693, 1067,    1,   29,   40, 1671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2751, 2856, 2548,    1,    1, 2782,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,  978,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   35,   37, 1083,  529,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,   32,  105,    1,  548,  484,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1087, 1042, 2336,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  818, 1055,  841, 1059,  162,  388,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  649,  217,   37,  693,  294, 1084,  931,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1560,    1,  565,  187, 1568,  187, 1089, 1675, 1160,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2360,   45,    1,  652,  967, 1752, 1463,   45, 2279,   12, 2179,\n",
      "            1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200,  845,  275,    1,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2917,  191,  447,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,  688, 3209,    1,  335, 2522,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1110,   37,  693, 1766, 1767, 2858,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3342,  290,   37, 2360, 1683, 1940,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  649, 2816, 3121,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2685,    1, 2884,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  547, 1693,  542,  619,  228,  356, 1760,    9,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2809,  104,    9, 1563,   98, 1094,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3216,    1, 3232,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968,  971,  221, 2070, 1559,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  297, 2095,  729,  105,    1,   98,  218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652, 1536, 1350,  149,  951,    1,  829,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3219, 1306, 1333,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1877,   37, 2122,    9, 1428,  142,  680, 1684,   45, 1789,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2899,   37,  168,    1,  176,  551,  612,  613, 1339,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1660,    1,  199,    9, 2851,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1228,  700,   37, 1636,    1, 1289,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1877,   37,   81, 2752,   32,  856,  444, 2834,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  741,    1,    1,    1,  342,    1, 1964,  361,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  852,   37,   92, 1662,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  365,   10,  117,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1,  325,    1,   37,    1,  111, 1107, 2575,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  213,   37,  786,  356,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   60, 1258,  453,    1,  276,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  967, 2411,    9,    1,  721,    1,    1,   82,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,  733, 1023,  453,  998,   32,   22,  447,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  957, 1822,  194, 1278,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  947,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2527, 2663,   51,   16,    1,  345,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  140,  449,  671, 3126,  176, 3292,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  105, 1183,    1,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2490,  958, 1920,  967, 2527,  164,    1,  581,  400,   32,  645,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 2272,   85,   98, 1465,  912, 2285,    1, 2819,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1834,    1, 3341,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2820, 2481,  729,  105, 2919,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1542,   37, 1948, 3191,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1973,  606,    1,  753,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885, 1077,   37,  877,  460, 1018,    1, 3258,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2111,    1,  187,    1, 1532,   37,  138,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2678, 1648,   98, 2730, 2086,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2227, 1443,  260,   28,   98,  166, 1222,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2110,   37, 1468, 3141,  810, 1292, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  872,    9,    1, 1013,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  510,    1,    1,    1,  313, 1750, 2028,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 1278, 1298,  199,  176, 2087,  433,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  903, 1296, 1660, 1194, 1843,    1,  156,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3282,    1, 2806, 1011,    9, 2112,    1,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  839, 2488,    1, 1347,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   12, 1594,   37,  335,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1268,  111, 1107,  525,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3154, 2126, 1849,   26,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1167,  460,   51,   52,  199,    9, 1084,   33,   37,   52,\n",
      "         1844,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  479,  353,   59,  197,   32,   72,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  909,  190, 1719,  443,  903, 1447,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2372, 2809, 1966,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2844,  176, 2592, 2472,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2151,    1,   37,   71,   37,  103,   32,  404,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273,   12, 1017,  884,  301,    1,  193,  160,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  220, 2615, 1919,    1, 2268, 2614,  661,  807,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  879,  822, 1942,   37, 1354, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,    1,    1,  112,    9,  342,    1,  131,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  388, 3079, 2844,   45, 3043, 2527,  164,  176, 2504,    1,  548,\n",
      "            1,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,  612,  717,   37,    1,    1, 1842,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,  943,   30,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3239, 2075,   81,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1905,   37, 1694,  548,    1,   79,  128,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3127,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  350,    1,  264, 2291, 2414,    1, 2803,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 3356, 2431, 1366,  190,  946, 3346,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,  327,   32,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39, 1114,    1, 3103, 1119, 1090,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  548, 3358,    1,  753,  361,  105,  389,    9,   91,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  501,    1,    9, 1517,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1957,   85, 1668,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 2924, 2625,    1,    1,    1,    1, 2856, 3375,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 2224,  738,  548,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  645,  224,  495,  402,   37, 2995,  315,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3166,    1,  590,    1,    1, 1022,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2733,  776, 2055,   85,  680,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,  787,   45,    1, 2518,    1, 1766, 1767,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1602, 1090,   61,  105,  628, 1523,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 1454,  443,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,  288,   37,   77,  215,  347,   98,  429,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  425,  426, 1564, 1705,   37,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2002, 3160, 1941,   32, 3349,  555,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2534,    1,  162, 2024, 2223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1224,   45,  163,    1,   12,    1, 1097,   93, 1784,   32, 1837,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  220,    1,  297,    1,    1,  167,   52, 1411,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,    1,    1,  460,   12,    1,    1,  460,   12,  105,\n",
      "          327, 1532,  415,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3238,   12, 3288,  190,    1, 1857,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,   25, 1758,    1,    1,  191,  487,  358,  361,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 422, 134,   1, 938, 361, 884, 674,  45, 941,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 896,   1,   1, 361,   1,  39,  45, 331,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  503,  765,   37, 1496,  103,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3198,    1, 3174,    1,   32,  310, 3282,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3198,    1, 3253,   37,  759, 2936, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  147, 1523,    9,  674,   45,  785,  786,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   72,  401,  197,  418,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3202,    1,  649, 2308, 1188,  388, 1604,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,   28,    1,  920,    1, 1146,  106,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1276,  951,  219,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2573,    1,    1, 1962, 1421,  517, 1017,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98, 1125,  644,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2523,   98,  837,   32,  878,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1684, 2789,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3233, 1415,    1,   32,  726,  297, 2685,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1228, 1825,   91,   12,  460,  954,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3129, 2594,  744, 2364,   98, 1913,  219, 1684,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  459,    1, 1116,  132,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,  857, 2568,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  952,   37,    1,  616,  297,  347,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1822,  140,    9, 3271,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,   61,  288,   37, 2303,  148,  647, 1523,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  829, 1539,  613,   29,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2924,    1,  810,   45, 3155,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1147, 3397, 1458, 2625,   98, 3155,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  693, 2774, 2198,  105,    1, 1243,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  487, 1109,   37,  151,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1061,    9, 1791,    1,    1,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2620, 1949, 1948, 3275,  176,  365,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1420, 1579,    1,    1, 2003,    1,  368,    1, 1437,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3354, 3006,    1, 1056,  649,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1966,   12, 1899, 1685, 2500,  663,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3016, 1935, 2146, 2034,  432,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  259,  260,    1,    1, 1159,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  542, 1882,   37, 1865,    1,    9, 1183,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280,    1,   79,   97,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1541,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2583,    8,    1,  304,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2349,    1,    1,  968, 1698,   45,  327, 2633,  506,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2319,  637,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 3111,    1, 3155,   12,  627,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,    1,    9,  365,  802,   32, 2322,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   83, 2609,    1, 1143,   98,    1, 1277,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3308,  488, 2637,    1,  297,   94,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  833,  612,    1,  245,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  780,    1,  587,   37,  943,  760, 1757,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1451, 1713,  440,  175,  220,  132,    9,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3225,  114,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2993,    1, 3056, 1117, 1525, 2706,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004, 2680, 1644, 1713,    1,  721,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1981, 2659, 2394, 1188,    9, 1131,   45, 1283,  542,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1266,  721, 2120,  475, 1213, 1432,    1,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1, 1608,  338,  995,  109,  997,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,  361, 2018,    1,  176,    1, 1815, 2024,  469,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1,  388, 3073,  361,  556,  777, 2165,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   69, 1293,   85,  187,  529,  408,  686,  954,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 2205,  297,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2977,    1,    1,    1, 1530,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117,    1,  843,  105,    1, 1159,  368,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2076,  417,  102,    1,  365, 2264,   77, 1273,  618, 1568,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,    1, 1822,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  967, 2505,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,  539,    1, 2315,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   12, 2800,    1,  193,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  646, 1353,    1,   32,  740,   86,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   89,   37, 1334,  187,  163,    1,   12,    1,  684, 2541,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358, 1536,    9,    1,    1,  467,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  105, 2305,    1,    1,  105,    1,    1,    1, 2548,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,   37,    1, 2301, 2671,    1,  855,    1,\n",
      "         2236,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  190, 1418,  176,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2016,   12,  872,  190,   52,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  395, 2201, 2003, 1950,  418,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  293,  437, 1082,   10,   37, 2653, 2972,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3129, 1385,   45,  963,   26, 2361, 2675,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965,    1,    1,    1,    1, 1534,   45,    1,  238,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   20,  721, 1579,  158, 1124,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  197,  418,    9, 1862,  425,  426,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1307,   37,  877,    1,   32,  854,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1058,   98,    1,   12,   69,   15,  343,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 2759,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  976,  162,  365, 1273,  618,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2835, 1625,    9,    4,   92,  187,  460,  459,  442,  132,  220,\n",
      "         1094,  361,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,    1, 2315, 2108, 2107,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1531,  952,  453,  248, 2223,   98,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   93,   32,  218,  332,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2605,    1,    1,  190,  166,  218,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481,    1,   32,  691,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158,   12,    1, 1465,  315,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485, 2404, 2682,  342,  828,    9,    1,  741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1051,  315,   37,    1,  365, 1607, 2575,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  542,    1,  297,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 158,   1, 919, 739, 159, 554, 328,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1, 191, 183,   1,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1292, 2593,    1,   55,    1,   45,  493,  361,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  650,  251,  241,  863,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1095, 1241,   28,  242,  197,    1,  852,    9, 1452, 1488,  572,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  795,  361, 1375, 1413,    1,  662,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  514,   45, 2089,  133,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3311, 1668,    1, 2920,    1, 3083,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2445, 1821, 2190,  967,    1,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294, 1940,    1, 3077,   32, 3134,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2523,    1,  724,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  191, 1394,  590, 2537,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3168,    1,    1,  759,   26,   12,  601, 1385,    1, 1041,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1050, 1740,  798, 3329,  631,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  449,  149,    1,  444,  116, 2650,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 1463,   95,  744,  365,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  607,   12,    1,    1,  994,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2307,  140, 1194,   73, 1090,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,   32,  674,  548, 3124, 1564,    1,  714,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    1, 1512,    1,   51, 1046,  996, 1686,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  281,  282,   51, 1046,  422,  522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,  105,    1,    1, 1216, 3164, 2236,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  420, 3294, 1216,   37, 2587, 2901,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107, 1009,  267, 2325,    1,   69,  102,  242,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  567,  510,  488,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  213,   37,  151,    1, 2203,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2567,   98,    1, 1151,    9,  618,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1422,  132,  326,   12,  205,    1, 1710,    1,  439,   45, 1018,\n",
      "         1015,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1183,  361,  166, 1139,   45,  460,   61, 1366,  565,  729,  119,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,  267,  854, 2108,    1,  792,    1,  792,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1110, 2712, 3319,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2477, 1401, 1948, 1779,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2087, 2614,    1, 3175,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1, 1064,   98,  166, 2354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  422,    1, 1783, 2600,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340, 1025,    1,  204, 2582,    1, 2644, 2901,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  590, 2012,    9,    1,  384, 2601,    1, 2741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,    1, 1564,  968,  105,  366,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  971,   37,   92,    1,   32,  730,    1,  333,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3199, 1086,  701,  220,    1,  726,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1613,  936,    1, 1766, 1767,  841,    9,    1,  612,  361,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3285,    1, 2563,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3194, 3195,   79,   37,  634,  698,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2452,  517,    1,   98,  166, 2747,    1, 1176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3350,  361,  475,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3355, 1042,    1,  798,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  754,    1,   37,    1,  626,  460, 2776,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  231, 2994,    1,  187, 2997, 2157,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  169,  794, 1597,    9,  111,   15,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   12,  872,  431,   59, 2328, 2223,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2317,    9, 1056,  537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2469,    1,    1,   37, 1140, 1090,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1094,  321,  612,    1, 2708,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2184,    1,   37,  151,   48,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3066, 2226,  416,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  519,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  193,   37,  142,    9, 1503,  129,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  768,  338,  526,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1854,  640, 1938, 2809,    1, 2087, 2614,  688, 3079,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1921,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  647,  721, 1728, 1114,    1,  148,   12,  142,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3333,    1,    9,  726,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  393,   22,  847,  716, 1797,  354,    9,   72,  401,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  737,  174,  418,  118,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2905,   37,  168,   37,  806,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3183,  729,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3190,   30,  453, 2558,   32, 3201,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  233,    1,  650,  952, 2532,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111,  819,    1,   37, 1561,   28, 2026,  126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1035,  776, 2221, 2356,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1512,  304,  384,  458,  187,    1, 1289,   37,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  567,  510, 2682, 1938,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3241,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2249,    1,  302,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  242,    1,  102, 2714,  666,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2064, 1844,    1,    9,    1, 1260,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    8, 2432,    9, 2851,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  386,  267,  388,  389,    6,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26, 1039,    1, 1998,    1,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1578,    1,  187, 3343,  863,    1, 1258,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   39,   45,  395,   26,   32,  449, 1385,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,  810,   45,    1, 2249, 1158, 2102, 1536,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1442,    1,    1, 2529,  176,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  359,  562,    1,  125,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437, 1877, 2966,   32, 2490,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  275,    1,  313,   37,   92,   72,  593, 2135,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   32, 1206,    1, 2103,  617, 1708,  117,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2974,  140, 2695, 2223,  191,    1, 1821,  105,  581,  199,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1528,   51,  875, 1405,    1,   43,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  405,    1,  167,  664,  671,  548, 1687, 1867, 1894,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  616,    1,    9,  241,  567,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1118,    1,   95,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   35,  476,   37,  792,  221,   98,  792,  548,  438,  662,\n",
      "         2443,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  932,   45, 1002,   98,    1,  297,  954,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  396,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2357,  297, 1133,  492,  673,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2095,  650, 1061,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  333,  193,   37,  686, 1537,  426,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  304,  297, 1792,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2967,    1,  166, 1497,    1,    1, 1748,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 2870,   32,    1,    1,  531, 1530,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,    1,    1, 1604,   98, 1059,  116,  105,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  108,  677,  626,  102,   37,  631,   37,  388,   31,   32,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056, 2700, 2632,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2551,    1,    1,    1,  808,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   25,  670,  187,  197,  937,  817,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  735,  441,  774,  957,  321,  612, 1753,  680,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,    1, 1337,    1,   98, 2203,   27,  463,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   44,   45, 3148,   32, 3118,    1, 3369, 2024,   46,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  215,  300, 2183, 1190,   37,  403, 1447,    9,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  104,  385,  389,   93,  143,  763,   76,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2853,   98,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2749,    1,    1,  787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1412,  161,    1,    1, 2066,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2972,  788,    1,    1,   32,  299,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  328, 2741, 1285, 2029, 2522,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  429,   27,   98,  531, 1665,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  449,   37,    1,  593, 2522, 3116,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1, 1411, 2273,  226, 1017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,   37,   47,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1040,    1,   98, 1017,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   10, 1133,    1,    1, 2489,    1,   32, 1966,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2096,  614,   98,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1985, 2764, 2765, 2985, 1061,   32, 2018,    9,  205, 1450,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  352,    1,   51,  606, 2644,  913,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3199,    1,    1,  267,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  268,  251,   37,  151, 1092,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 3081,   45,    1, 1891, 2325,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2733,  659,   37, 2560,  111,   19,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1485,  947, 2047,    1,    1,  443,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  921,  308,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  352,   51,    1,  531,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,    1,    1,   79, 1254, 2085,    1,  517,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  266,  353,  105,  354,   98,  134,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   45, 1737,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056, 3060, 1189, 2165,    1,    1,    9, 3385,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  392,    1,  384,  829, 2351,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 2967,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  550, 2165,    1, 1822,  860, 1889,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 3076,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147, 1800,  214,  142, 1787,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  240,    1, 1027,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    5,    6, 2175,    9, 1595,  174, 2377,    1,  112,    1,  267,\n",
      "          518,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2317, 2468, 3096, 1090,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283,    1,  140,    1,  628,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1962, 2522,    1,  167, 1389, 2322, 1080,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 3032, 1592,   81,   32,  864,   37, 1463, 2596,  396,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  572,  105, 1222,  662, 1009,   98, 2315, 2798,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   49, 1536,    9,  467,   32,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  566, 2235,  960,  333,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3231,  753,   37,  243, 2463, 2101,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1874,  221,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115,    1,    1, 3245, 2537,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  626,  919,    1,  374, 1276,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   79,   37,    1,  698,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1035,   12, 1135,    1,  191,  957,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1237, 1658, 1117, 1525,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  107,  497,  894,   28,  568,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  584,  103,  147,    1,   98,  735, 1280,  522,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1407,    1,  565,   81,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  819,    1,  951,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115,  554,   37,    1,  404, 1131, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    7, 1675,   32,  365, 2741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,  353,   59,  197,    9, 1913,  401,   98, 1084,   50,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  755,   37,  949,    1,  861, 2581,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,  438,    1,   35,  132,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2780,  529,  863,  133,  997,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1167,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2868,  108,   45,  388,  531, 1450,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  587,  588,    1,   45,    1, 1015, 1016,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2929, 1292, 1283,  765,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    8, 1174,   37, 2481,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  619, 1698, 2322,   98,  949,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   14, 1110, 2123,   32,   54,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  434, 2143,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  539, 1037,    1, 3166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  491,  167,   52,  837,    9, 2300,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 2269,  516,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  863,    1,  622,   32,  531,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2597, 2696,    1, 2950, 2414,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2410,  166, 2551,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,    1, 1684, 1948,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3364, 1484,    9,  439,   37, 3344, 2708,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1946,  191,    1,   15,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    4,  496,  410,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 2338,    1,  115,   45,  163,    1,   12,    1,   29,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 2452,  517,  105,  327,    1,    1,   37,  105,  282,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  921,  813,  551,    1,   98,  215,    1,   15,    1,    1,\n",
      "          267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  245,   32,  636,   45,   69,    1,  677,  109,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401, 3236,  608, 3266,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1186,   37,   44, 3382,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1331,   31,    1,  763,   76,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1117,    1,    1,   32,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2826,    1, 2297,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1425, 1283,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  381,  640,   81,  176, 1047,  220,  147,  221,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  387, 3356,  787,  187, 2876,    9, 3155,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1948,    9,  166, 1990,    1, 2408,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1186,    1,   12,    1, 2170,    1, 1140,    9,  264, 3184,  806,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  166, 1048,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  374,    1,  329,   71,  187,   68,  338,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1,   32,    1,  207,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  176,  613,  200, 2665, 1851, 2480,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715,    1,  686,    1,  297,  469,   37,  125,    1,    4,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  682,   98,  932,    1,  157,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035,  146,    1,  267,    1,  191,  104,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1283, 3161,  765,   28,    1, 3013,   32,  105, 1065, 3278, 1569,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   45,  166,  449, 1890,  361,    1,   12,  311, 1355,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056,  365,    1, 2080,    1, 1976,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1233, 1149,  741,  444,  477,  522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  433, 1579,  163,    1,   12,    1, 2968,  639,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,   37,    1,  735,   32, 1820,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  712,    9, 2764,    1, 1185,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3184,   12,    1,  261,   39,    1, 1031, 2682, 1186,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,    1, 1954,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3171,   98, 2579,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  409,  159,  526,  548, 2164,    1,   60,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1818,  147,    1,  544,  193, 1140,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2676,    1, 2136, 2905,    9,  736,  187, 2107, 2369,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  108,   45, 2025,  408,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2822, 2378, 1291, 1793,   67,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3252, 2151, 2614,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2999,   91, 1550, 1260,   98,    1, 1583,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,  978,   96,  501,  220, 1222, 2359,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116, 1089,  267, 1796, 1178, 2644,    1,    1,  580,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 2161, 3159,  463, 1447,    9,   72,   73,    1,  726,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,    1,    1, 2322,   98, 2378,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  668,    1,  251,   37,  130,  669,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2408,  416, 1176,  123,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2586,   32, 1327,  187, 3365, 1683,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37, 1252,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1292, 1681,    1,  271,   15,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   15,  120, 1198,  348,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3099, 1994,    1,  475,  939,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2754, 3102,   32,  531, 1484,    9, 2128, 2271,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2171, 3134, 2246,    1,    1, 2865,   79,  590,    1,  403,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283, 3318, 3326,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  999,    1,    1,  807,  315,    9,  326, 2759,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   38,    1, 2055,   32,    1,    1,  876,    1,   12, 2107,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,    1, 1817,    1, 1663,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  721, 2443,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  747,  353,  417,  156,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2408,    1,  220,  599,    1,  228,  356, 1281,    9,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2677, 2018,  753, 2620,  113,   79,    1, 3334, 1237,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  665,  247, 1509, 2380, 1836,   32, 1193,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3394, 1278, 1298,   98, 2095, 1450,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2295, 2757,    1,  787,  220,    1, 2530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1388,  297, 3080,    1, 1021, 2139,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2882,    1, 1625,  439,   32, 2674,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   12,    1,  861, 1896,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 1037,  275,    1,  608,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2669,  579,  272,    9,    1,    1,  458, 1160,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1658,  466,  777,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,  105,    1, 2409,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  523,  361,  104, 1864,  183,  399,  630,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  756,  757,   37,    1,  388,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  446, 1458,    1,    1,    1, 1760,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1303,  353, 1913, 1843,  197,  225, 1042,   98,  157,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2734, 2842,    1, 2582, 1509,    1,    1, 2804,  267,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1965, 2550, 1000, 1610,  365, 1534,   45,  608,  238,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,   45,    1,    1,  140,  166,  593,  297,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1566,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2104,  476,  249,    1,  193,    1,    1,   37, 2324, 3015,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788,  267, 1509,    1,   32,  142,   61,  787,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  220,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 2160, 2049,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  441,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1057, 2599,  865,   45, 1485, 3365,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,  465,  404, 1561, 2545,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1641,    9, 2427,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   34,  197,    1,  315,  388,  124,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3362,  729,  967,  808,   37, 1343,    9, 3349,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2103, 2727, 1991,   37, 1192, 1178,  105,  365,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  393,  475, 1889, 1108,  655, 2437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3274,  645, 1987,  167,   52, 1328,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  829, 3042,  161, 1992,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 2827,  297, 3379, 1260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3192,    1, 1564, 2218,  220, 1777, 2739,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 2834,  469,  738,  410, 2407,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   60, 1271,  187,  218, 1489,  303,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1352,  442,  910,  105,  119,    1,   28,   32,  339,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3064, 1917,    1,   32, 2033,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485,    1, 1542,    9, 1821, 2190,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  342, 3341,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  581,  401,  387,   71,   32, 2759,  983,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1212, 1478, 2274,    9,    1,  778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1184,  347,    1,    9,   72,   73,  339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    9, 3209,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2640, 1343,   37, 1832,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  883,  406,   28,   32,  385,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1570,  200, 1775, 1455, 1294,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2275,   10,    1,   37, 1722,  220,  166,  163,    1,  903,    1,\n",
      "          600,  531, 1160,    1,  150,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 1119,    1,  964, 1877, 1300,  290, 1159,   36,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1147,  861, 1414, 1539, 1450,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1, 1790,  872,   28,    9,  365,  777, 1085,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   93, 1071,   32,  705,  401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3226,    1,  405, 3291, 1285,   39, 3322,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,  688,  505,   32,  166, 1183, 1844,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779, 2622, 3064,   37,  759,    1, 3293,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3260,   37, 1330,    1,    1,    1,  951,    1,  931,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3190,   12,    1,  140, 3193,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1306, 1956,  593, 1990,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2459,   65,  883, 1279,  418,   37,    1,   32, 1352,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  295, 1807,  372,  354,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  531, 1450, 2856,    1, 1428, 3397,    1,   98,  890,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,    1,   26,    1,  105, 2847,   81,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  978, 2953, 1007,    1, 1159, 2933,   12,  103, 1569,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773, 2510,   15,  619,  227,  698,   32,  104,    1,  455,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1113,  338,  187,  156,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129, 3303, 1293,   39,   32, 1030,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  686, 1531,   12,    1,  845,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,    1, 2845,    7,  808,   32,  487, 2224,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2964, 1260, 3010, 2079,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  574,   11,  662,    1,    9,  152,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3407, 2153,  588,   37,    1,  997,  187, 2751, 2856, 1147, 2548,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2345, 2267,    1,    9, 2267,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  236, 1022,    1,   66,  526,  187,  195,  159,  817,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  293, 1489, 2623, 2624,  932,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401, 3290,  608, 3244,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422, 1564,  549,   45,  262,  263,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  476,    1, 2059,   37,   52, 1411, 1277,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2871, 3327,   12,  550,   51,    1,    1,  389, 1013,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  968,   12,  954, 1353,   32,  572,   98,  532,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,  515, 1994, 2650,  105,  160, 1046,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,   71,   37,    1,  220,    1,  449, 1023,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 2864,    1, 1856,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  359,  562,    6,   37, 1746,  393,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232, 2935, 1684,   32, 1619,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3096,   61,  105, 1020, 1176,  183,    9,  453,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2136,    1,  443,   98, 2095,  176,  186,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 3115, 2565,    1,    1,  928,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  551,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1214, 1478,  183, 2223,   32,    1,    1,    1,  384, 2916,   37,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  552,  551,  405,   37,  125,   28,   37,    1,    4,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3292, 2965, 1236,  709,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1786, 2358,    1,  361,   12,    1, 1117,    1, 1417,    1,    1,\n",
      "          503,  195,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,    1, 1965, 2582, 2738,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2470,    1,  409,    1,    1, 2789,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1662, 1235, 2689,    1,  884,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2201,    1,  887,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2746, 2825,   28,  388,  365, 2911,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  365, 2640, 1921,  176,  166, 1821, 2190,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1419,    1,  644,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    8,  480,    9,    1, 2687,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1935, 1863,  244,   85,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1477,    1, 1140,    9,    1,   98,    1,   45, 1990,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,  361, 2594,  810, 2277,  140,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1200,    1,  829,   37,    1, 1089,    1,  288,  921,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2932,  332, 2376, 2223,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,  166, 2084, 3009,   32, 1123,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861,    1, 2759,   37, 2123,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1741, 1228,    1,    1, 1876,   37,    1, 2549, 3004,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1889, 1944,  384,  647,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428,  108, 2170,   45,    1,  627,    1,    1,  460,   37,    1,\n",
      "            9, 2141,  199, 2596,  963, 2122,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118,  729, 2245,  187, 1428, 1757, 2202,   39,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,    1, 1114,    6,  570,    1,  159,  720,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2341,  412,   37,  466,  414,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2493, 2516,  966,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  889,  341,    1,   32,  539,    1,    1,   32,  404,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  335,   98,  460, 1085, 1110,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437, 1094,    1, 1663,  625,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  613,    9, 2466, 1209, 1074,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,   98, 1434,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 1106,    1, 1626,    1,    1,  777,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  868,    1,    9,  691,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  160, 1161, 1276,   98,  389,  509,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  510, 1414, 2807,    1, 3103,   37, 1343, 2675,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2826, 2962,  885, 3185, 2795,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  321,  612,    1,  888,    1,  338,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2475,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  166,  221,  176, 3258,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  654, 1419,  547,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  213,   37,  875,   32,    1,  149,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2300,   37,  151,   48,   32,    1,    9,  600,   54,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26,    1,  361,    1,  726, 1940,   12, 1660,  176,  104,   26,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   12,  507, 2593, 2210,  218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,  782, 1875,  809,   37,  665,  105,    1,   98,   69,  102,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,    1,    9,    1, 1013,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1450, 1056,  359,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1713,  730, 1777, 2274, 1659,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  580, 1133, 2082,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  219, 1385,   28,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1363,   32,  517,  345,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3283,    1,  548, 2596, 1665,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 1564,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2807, 3321,    1,    1,   32,  354,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1632,    1,  395,    1, 2702,   45, 2617,    1, 1881,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,    1,   32,  166,  104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3249,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1028,  310, 1211,  442,    1,  167, 1245,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1297,    1, 2734,    1, 2750,  517,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,  546,   28,  453,    1,  293,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302, 1712,   98,  103,    1,    1,   61,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 580, 312, 798,  32, 147,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 711, 369,   1,  37, 138,  28,  37, 105,   1, 105, 332,  32, 752,\n",
      "         328,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 3107,   37, 1348,    1, 1877,  864,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1759,  309,   12, 1557,  682,  388,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2018, 3109, 3384,  650,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,    1,   10,    1,   37, 1058,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,  326,  840,  453,  327,  112,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,  163,    1,  903,    1, 3365, 1683,   32, 3360,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1764, 1990, 2069,   37,  271,    1, 2078,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3061, 2549,    9, 1031,   32,  864,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3213, 1301, 1442, 3112,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260, 1210,    1,   81,    1,    1,   37,  335,  138,  125,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1629, 2767,  365,  286,  149,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2948,   45,    1,   32,    1, 1881,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2114,   12,  748,    9,  593, 2522, 3201,  565, 1637,  452,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878,    1, 2154,  161, 2607,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  957,   90,  667,  947, 1444, 1445,  193, 2556,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  954, 1754, 1533,  388,    4,  763,   76,   32, 1352,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1652, 1536,  885,  149,  444,  829,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1645,  876,  612,   51,  345,  621,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  176,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  361, 1363,  588,    1, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,   45,  517, 1089,    1, 1463,  218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  315,  342, 1437,   45, 2102, 1411,  339,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1962,  361,    1, 2527,    1, 1444, 1445,   32,   46,  297, 1273,\n",
      "           50,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,  951,    1,  829,    1, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  219,    1,   81,    1,    9,  397,  389,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2120,    1,  176,  136, 3217,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1821, 2728, 1830,   37, 1585,   79,    9, 2695, 2223,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1,  150,    1,  564,    9, 2492,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  386,  497,    1, 3357, 1523,   32,  404, 3114,  163,    1,  903,\n",
      "            1, 2924, 2347,  963, 2122,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 1466,  932,  103, 1470,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2753, 1056, 1310,  187,    1,    1,    1,   32, 3255,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2855, 1066,   98, 2103, 2727,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2184,    1,    1, 1012,  709,    1,  971,    1, 2533,  187, 2193,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  879, 1889,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1976,   32,    1,  829, 2549,   46,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  420,  841,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1013, 1299,   32,   91,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  288,    1,  943,    1,  176,  104,   26,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2733,  251,    1, 1211,  116,  259, 1484,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1844,    9, 2708, 1009,    1,  232,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,  846,   28,  617,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2658, 2269,    1,   98,    1,    1,    1,    1,  396,  420,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  420, 1245,   37, 1389,  388, 1206,    1, 2705,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,   61,    1,  384, 2807, 3321, 1728, 1114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2724,    1,    1,    1,   45,  547, 2273, 1123, 1841,    1,  928,\n",
      "          176,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37, 1539, 1313,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  768,  122, 1372,   37,    1,    1, 1718,  469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  335, 2709,   98, 1996,  858,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  381,   12,    1,  710,  269,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 2393,    9,  903,    1,  464, 2328, 1463,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2596,    1,    1,  880,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2179,    1,   45,  105,    1,  361,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1844, 1380,  365, 1546,  115,   37, 1334,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,    1,    1,    1, 1154,  311,   12,    1,  187,    1, 1125,\n",
      "           28,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  597,    1,   12, 1213,   37,  631,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1086,  537,   45,    1,  220, 1918,  297,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2127, 1001,    1, 2177, 2325,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1074,    1,  251,   28,    1, 2759,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1723,    1,  891,   32, 3311, 3310, 2930,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3297,   12,  750, 1240,   52,  921,    1,  176,  177,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  449, 1173,    1, 2480,  327, 1464,   37,    1,  327,  593,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  132, 1908,  517, 1523,  847,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  197,  418,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2546,  459,   28,  730,    1, 1718,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158, 2668,  220,  163,    1, 1774,   39, 1230, 2528,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2618, 2767,    9, 1821, 2328, 1539,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2993,  167, 1505, 1967,   45,  105,  224, 2995,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3302,   37,   92,    1, 2172,    9,  593, 1990,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   98,  486,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1885,   12,  332,   28,   98,  425,  426, 1184,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3318,    1, 1025,   39,    9,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186, 1544,  700,  187,  531, 3102,  513,    9, 1204,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  433, 2591,   37,  222,  365, 1600,  261,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,  852, 1159,  181, 1778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1753,  297,    1,  361,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  150, 1749,  220,    1,    9,    1, 1898,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 1821, 2107,   37, 1031,  166,  593,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,   32,  870,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  388,    1,  636,  418, 1999,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1584,  166, 2480, 1675, 1174,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3043, 2527,  164,  396, 2214,   12, 1204,   32,  451,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2090, 2161,   12, 3134,  872, 2257, 2017,   37,  688, 2468,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  882,  200, 1935,    1, 1167, 2489,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 2596, 1585,    1, 3343,  863, 2116,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1748, 1089, 1704,  858,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2966, 1450, 1999, 1316, 2490,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32, 3020,    1,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3015, 1669, 2316, 2923,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1244,    1,    1,  871,   15,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   69,  102, 1198,    1,   12,  737,  197,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1486,  207,  354,  703,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2848,   37,  579, 1018, 2452,  967,    1, 1846,  600, 3011,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,  388,   45, 1665,   37,  291,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1844, 2388,   12,  750,    1, 1923,   12,  472, 1090,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1116, 2896,    1,  928,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159,  729,    1,  191,  545,   12,  533,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,   22,  719,    6,   37,    1,  615,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1830,    9,  166, 1411,  537,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2489,  581,    1,   37, 3284,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,  267,  113, 2985,  330, 1479, 1450,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1918,    1,  191, 1530,   32,  669,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232,  103, 3231,   37,  726, 3235, 2522,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  491,    1,   98,    1, 1998, 1491,  138,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  787,   45, 1552,  997,    9,  453,  627,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1183, 1473,  986,   79,    9, 1497,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2605,   98, 1477, 1990,    1,  176,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2,  60, 682,   1,  69, 102, 832,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 211,  32, 326, 573, 400,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   71,    1, 2054, 1784,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1, 3229,    1, 2037,    1,   32,  726,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3339, 2271,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2924,  907,    1,    1,   32, 3391,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1422, 2144,  356, 1281,    9,  104,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1,    1,  162, 2025,  547,  427, 1281,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3117,    1, 3271,   37, 1066,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2638, 2930,  776,  891,   98, 1199, 3386, 2921,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1727,    9,  531, 3353,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789, 1949,  622,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  551, 1100,  872,   28,   98,    1, 2670,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1200,  315, 1107, 1089,  777, 1996,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  915,    1, 1462,  187,   22,  854, 2095,  776,    1,   85,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 2384, 2095, 3146,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1545,   51,  588, 1698,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  267, 2239,   51,  606,    1, 3012,  298,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1987, 1713,    1,    9,    1, 3141, 3083,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,    1, 2874,  469,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,  908,  469,   37,   77, 2924,   32,  531,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  635,  132,  881,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,    1,  104,  429,    1,   46,   98,   20,  296,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,   98,  917,  175,   45, 1171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  539,    1,  661,    1,  187,    1,   46,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2153,  543, 2024,   37, 3355,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,  407,  187,  166,  517,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,  105,    1,    1,  882, 1564, 2261, 1114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1548, 2411,   37,  480,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730,    1, 1445, 1421,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1936,   98, 1158,   12, 1107,  525,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2765,  345,   66,  187,  142,   37,    1, 2081,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  572,  105, 1370, 1051,   12,  678,    1,  176,  669,   12,  356,\n",
      "          813,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175,    1,    1,  759,  172,  399,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  225,    1,    1,   98,  776,    9,  133,    1,   61,    1,  187,\n",
      "          105,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1548,  387,  183,  745,  384,  365, 1522, 1597,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   10, 2659,   32,  166,  730,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,   37,  693,    1, 1718,  279,    1, 2168,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2843,   12, 2271,    1,    1,  628,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 3170,  193,    1, 2810,  202,  288,    9, 1463,  865,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2974, 1774, 1750, 1918,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  954,   37, 2370,  166,    1, 1601,   45, 1121,    1,  384,\n",
      "          395,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  936,    1, 1539,   45, 2798,    1, 2815,  361,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1653,  361,  850,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1950,   32,    1, 1101, 2817,  418,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2210,    1,  193, 2312,  227,    1,  342, 2409,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1479,  922, 1123,  571,   37,  316,    1, 2016,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2698,  894,    1, 1675, 2221,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1089, 1665,   37, 2856, 1428, 3365,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1877,   37,    1, 1824,    1,   45,  691, 2522,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,    1, 1617,  297,  448,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  313,  176,  845, 2146, 2826, 1009, 1733,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1290,  396,  720, 1196,  361,    1,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,   37,  125,    4,  187,  460,  392,   81, 1108,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  636,  418,    1,    1,  384,  487,  493,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2476,  565,  183,    1,   32, 2468,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  716,  506, 1718,  815, 1239,    1,  202,  320,   61, 1778,\n",
      "         2086,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129, 2871, 2885,    1,  193, 2843,    1,   30, 1529,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1903,  588,  439,   37, 2397, 1665,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,   82,  648,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1186,  261,   39,   46,  187, 3025,  513,    9, 1204,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2024, 2223, 2525,  384, 2170,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 591, 977, 959,   1,   1, 267,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 548,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   91,  300,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2797,    9,  730,    1,  276,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1076,  952, 1910,   37, 1377, 2015,  695,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  593,   98, 2393,  187,  297,    1, 2946, 1046,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,  315,  183, 1069,   45,  803,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3303, 3062,  119, 1194,  593, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  103, 2932, 1079,  777, 2264,   37, 1413, 2948, 1222,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1375, 2151,    1,  869,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  493,  640,  339,  845,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128, 1564,  460,  232,    1,    1,    1,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087, 1158,  956,  685,  365, 1230,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  223, 2577, 1465,    1,  356,  460, 1876,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2279,  140, 2318,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  341, 1374,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  203,   37,  877,  166,  917, 1140,   98,  617,  315,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  744, 1056, 2078,  187, 3211,  184,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  876,  612,    1, 1297,  195,  441, 1171,    1,  220,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2034, 1333,  176,  166, 1990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,  790,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  144,  145,  156,  664, 1515,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1895, 2043, 2639,  288,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2860,    1,    1, 2266,    1,    1,  443, 1924,  822,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962, 3117, 1493, 1194,    1,  726,   32,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1746, 2456,  176,   22,  298,  778, 1086,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,    1, 2684,   32, 3369,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585, 2668,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2305, 2391,  424, 1981,   61,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1880,    1,   42,  422,  400,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  382,   15,  276, 1548,  682,  332,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  230,  122, 2200, 1718, 1027,   32,  864,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1047,  615,    1,   37, 2857,  147, 2322, 1670,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3024,   37, 1937, 2300, 2923,   45,  166, 2918,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  618,  529, 1307,   12, 1560,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  438,   25,  301,  550,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1809, 1001,  384,    1,   12,  625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3215,   51,  193, 2274, 3177,   32, 2846, 1090,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,  443,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1169,   12,    1, 1729,  384,  455,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,   12,  590,  268,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  728, 1972, 1821,   95, 1017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  964,    1,   98,  531,  863, 2306,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 2962, 2920,  186,   37,  688, 1957,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  515, 2285, 2043,   37,  876,  612,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  228,  402,  631,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  864,    1,    1, 1094,  952,  163,    1,   12,    1,    1,\n",
      "         2909,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1756, 1552,  187, 3151, 2308,   24,  693, 2443,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  920,    1,    1,    1,    1, 2994,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1009,   37, 1982, 1064,    9,  365, 2113, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1962,    1,  517,  517, 1074,  881,   32, 2573,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  834, 1013, 2465,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1053,    1,   45,   22,  438, 1103,    1,  191,  218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  120,    1,  191, 1269,   32,   69,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1973,  132, 2619,   98, 2397, 2108, 2945,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,  155,  453,  156,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  177, 1125,   12,    1,   45,    1,  729,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 1774,   39,  365,  160,  623,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2059,  155, 1300, 2395,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  733,   48,   32, 1597,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,   12, 1482, 1596,    1,    1,  199,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3160, 2780,    1, 1204,   32,  531,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2477,  944,    1, 2977,    1, 2896,    1,  928,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  987,    1,  440,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  428,    1,    1,  876,  612,    1, 1590,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3361, 1096,  163,    1,   12,    1,    9, 2891,   45, 1763,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  220, 2021, 1017, 1758,    1,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1527, 2664, 1492,    1,    9, 3361,   61,    1, 1919,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1645,    1,  100,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755, 1328,  600,  861,    9,  105,  636,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   28,  663,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   59,    1, 2281,    1,  521,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2161,    1,    1,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2347, 3066,    6, 1139, 2172,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  193,  415,    1,  677,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3263,  619, 1055,  384, 3322,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  190, 1064,    1,  384, 3018,   12,  270,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1, 3034,  220, 1561, 1876,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  342, 1974,  104,  970,  909,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,    1,    1, 2695, 2071, 1331, 2403,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3095,  741,   37,  489,   39,   45, 3339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  715, 1273,  259,   37,    1, 1628,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  691,   12,  469,    9,    1, 2288,  861, 2060,    1,    1,  365,\n",
      "         2036,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  698, 2056,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158,   12, 1107,  112,  852,  388, 1620,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    8,  480,   45,    1, 2871,    1, 1129,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  256,    1, 1151,   37, 2261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    1, 1118,  818,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  425,  426, 1187,  166, 2871,  636,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 1994, 2650,   44,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  260,    9,    1, 2140,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2871, 2565,    1,    1,  600,    1, 2739, 2489,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  922,    1,    1, 1281,   98,    1,  873, 2308,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460, 1499,   37,  619,  105,   92,  384,  777, 1085,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1675,  835,    1, 2657,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523,  159, 2579, 3154,  631,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1713, 2923, 2055,   26, 1039,    1,  934,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 3345,  774,  957,  213,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  193,  166, 1411,  183, 1265, 3200,  125,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1308,   98,  800,    4,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  654, 1317,  220,    4, 2214,  166, 1868, 1172,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2077, 1893,    1,  104,   15, 1124,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  729,  387,   15,   28,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3188,   12, 1700,    1, 2035,  119, 1224,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   20,  927,  703,   37,  372,   24,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  756, 2690, 1372,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  779, 1084,  731,    9,  463,  691,  171,   37,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1435,  365, 1292,   37, 1636,   37, 1789,    1, 1053,   32,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  120,   98,  997,  297,  567,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2024,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,   52,  365, 1009,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622, 3279,    1, 2572,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3359,    1, 1384,   98, 1386, 3057,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  104,  358,  359,    1, 1903,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2254,   37,    1,   32,  215,  361,  447,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 2170,  691,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3144,    1, 1207,  365, 1287,   37,    1,  741,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2563,  664,   37, 1959,    1, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  314, 1974,   56,  297,  286,  927,   87,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   12,  856,   37,  166, 1838,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3350,    1,  220, 2874,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   97,   79,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3178,  190, 2303,   98, 1888,    1,   32, 2007,  199,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2720, 2796,    1,  730, 2614,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  288,   37, 2728, 2229, 2232,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  448,   61, 1176, 2738,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3238,  288,   37,    1, 2444,  105,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1464,   98,    1, 1560,    1,  267,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2070, 1537,  701,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  140,    1,  187,   69,  102, 1826,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   97,   98,    1,  297, 2210,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,   37,  130, 1074,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   20,  469, 1651,  142,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2780, 1173,    1,  548,    1,    1,   98, 2374,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1840, 1841,   37,  335, 1842,  633,  457,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,  313,    9,   56,  118, 1124,   32,   69,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  166, 2725,   61,  472,    1, 1681,    1, 1114,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  931, 2651, 1717,   32, 3201,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2823,    1,  877,  590,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1486,    1,  155,  197,  570,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  267,  204,  190,  815,   10,  736,   37,    1,    1,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  191,  354,    1, 1668, 2035,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1009,  546, 1583,  475,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2266,  267,  861, 1906, 1822,  100,  920,   98, 3118,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  352,  108,  444,    1,  693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  506, 1158,    1, 1128,  631,  327, 1889,    1, 1279,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 2767, 3107,    9, 3366,    1, 1428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2945,    1,   12,    1, 2334,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 1405,  232,  513,  514,   37,    1,  133,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2004, 2902, 2264,    1,    9,  787,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,    1, 1901,   45,  858,  207, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3335,  951, 3213,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2090,  425,  426,  353,    1,   71,   32, 1169,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087, 1614,    1,   37,  907,  112,  719,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2158,   45, 2121,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3228, 3103,  686, 1065,  199,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3092,    1, 1231,  297,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3202,  307, 1090,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1687, 1022,    1, 3008,    1,   51,   52,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  693,    1, 2880,    1,    1,    1,    1, 1285,  361,\n",
      "         1766, 1767,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785,    1,  107,    1, 1124,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  176,   38,   32, 1422, 2893,  776,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  975,  353,  417,  156,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  115,    9,    1, 1149,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974,  288,    9, 2507, 2073,   95, 1602,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   47,    1,   37,    1, 2936,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169, 1564,    1,  698,  176,  163,    1,   12,    1,   26,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  447, 1360,  612,  949, 3358,   12, 1983, 2078,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  442,  770,  958, 1211,  442,  695,   98,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  985, 2130,  195, 1396, 2169,  437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777,  108,  444, 1792,  861, 2215,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1120,   12,  105, 1173,  176, 2110,   12, 1841,   12,  441,    1,\n",
      "         2039,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  341,   12,  599,  176,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597, 2224, 1190, 2632,   28,   32,  314,  926,  287,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32,    1, 2774, 2625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1,  952,   37, 1865,  388, 2604, 1219,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  744,  365,  845,  109,  122,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,  332,    1,  756, 2690,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2503,  104,  220, 1056,  857,  569,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 2267,  559, 3000,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   98,  395,   12, 2401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3112,   51,  920,  483,    1,   37,  166, 3180, 1183, 2113,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,  764,    9,    1,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1683, 1428,    1, 1149,   32, 3360, 1173, 1836,   37,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  993,  652, 1176, 2056,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  389, 2493, 1018,    1, 2494,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  602,  498,   98, 1147,  734,  322,   79,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1343,   32,    1,  922,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  410,  439,   37, 1125,  605,  187,   69,  490,    1, 1608,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018, 1674,    1,   45, 1013,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  590, 1400,    1,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2924, 1388,  220,    1,   32, 1850,  531,    1, 1887, 1056,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 1877,   37,  981, 1994, 2095, 2471,  220, 2018,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2137, 2856,   98, 2835, 3101, 2735,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,  379,  588,  211,    9,  890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  459,   45,    1, 1976,   32,  395,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1581,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 2153, 1152,   45,  926,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2883,    1, 3365, 1058,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310,   25,  417,    1,  303,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2792, 3186,   85,  413, 3176,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,    1,   39,  388,  128,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  942,   37,  815,    1, 1001,    9,  501, 1017,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1850,    1,  593,   12, 2084,    1, 1512,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1874,   81, 1925, 1583,  862,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3163, 2954,  168, 1632,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  294,   37, 1463,    1, 1011,   15,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  213,   37,   59,    1, 1056,  356,   24,  220, 3231,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962,    1,  140,  449,  698,   32, 1700,  537,    9, 3271,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  633, 1885,  777, 2165,  686,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2037,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401, 2388,  608,    1,    1, 1159,    1, 3295,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2673,    1,    1, 2951, 3385, 1929,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2741,   12,  726, 1045,  640,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361, 1545,   32,  331,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  119,    1, 2885,    1,  115,   45, 3303,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1558, 1630, 1236,  485,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 2095, 3060,    1,  625,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1106, 1187,  193,    1,  224,  932,   37, 2635,  365, 1279,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  592,    1,    1,   98,  691,    1,  387,   93,  176,    1,  118,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1875,  992, 2029, 2024, 2284,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,  315, 2355, 1013, 2549,    9, 1158, 2261,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  166, 2056,    1,  364,  140, 3076, 1684,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  925,  315,   37, 1752,  786,  183, 1568, 1569,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1211, 1273,  861,  384,  468, 1362,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2491, 2980,   45,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3194, 3195,    1,  191, 1997,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,  936, 2128,    1,   32, 1815,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1840,    1, 1717,    1,   28,    9, 3235,  512,   45,  356,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2835,   12,    1, 1579,    1, 1140,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   45,    1,   12,    1,    9, 1970,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  647, 1707,  365,  148,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  597, 1009,   51,   52,  288,   37,    1,  915, 2529,  317,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2086,   32,  854,  408,  104,  331,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  606,  105,  873,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  746,    1,  747,   11,    1,    1,  150,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3403, 2414,  176,  177,   32, 3354, 3392,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 1473,   37, 1909,  220,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 3220,  550,  551, 2415, 1479,  922, 1123, 1203, 1628,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2095, 1665,   37,   52,    1,   32,  147,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2136,  387,  211,   32, 2259,   98,  776,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1652,    1, 1159, 1718,  218, 1396, 2738, 2798,   17,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203,  190, 2777,    1, 3115,    1,   37,  354,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  326, 2334,  744,  365,  846,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2638, 2931,  625,    1,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 104,  37,  44, 755, 220, 133,   1,   1,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3361, 1587,  187,   36,  356, 2055,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3117,  498,   37, 1145,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2734, 2372,    1,   37, 2502,  384, 1033,   37,   91,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  365, 1708,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  422,    1,    1, 1717,  938, 1659,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115, 2035, 2565,   12,   24,   56,  537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1907, 2134,  104, 2147, 2393,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 1447,  952,   37,    1,  903,    1, 1447, 1585,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  531, 1920, 3082,   37,   52, 1683,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1442,   37, 2929,    1,  150,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3352, 2856,    1, 2696,   45, 2597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   25,  439,   98,  242, 1318,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  108, 2617,   98,    1,  815,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2269,  267, 2602,   37, 1841,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1573,  166,    1, 1090,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  356, 1691,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  978, 3138,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3387, 2751,    1, 2024, 1625,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2066,  529,  408,    1,  293,   12, 1251,  672, 1699,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1142, 1143,   12,  797, 1924,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2464,    1,    1,  918,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  267, 3378,    1,  959,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2,  25,  66, 816, 115,  45,  69,   1, 646,  29,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 425, 426, 338, 419,  98, 570, 125,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  233,  522,  167,  771,    1,   37,   77,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,   37,  588,   10, 1876,   98,  517, 1964,  569,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2512,   37, 1706,   59,   32,  463, 1447,    1,  929,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  325,  647,    9,    1,  131,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2685,  688, 3209,   37,   26,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282,  183, 1008, 1758,   32,   26,    1, 3126, 2525,   39,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  694,  967,    1,   37, 1473,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973,  712,   79, 2963,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1660,    1,  199,    9, 2851,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885,  227, 3278,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  720,  187,    1,  102,  120,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481,   12,   54,   37,    1, 1384,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  312,  149,  855,  952,    1,    1,  516,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  614,  384,    1,   37, 2773,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968,    1,    1,  379,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 2275, 2250, 1520, 1523,  847,   98,  531,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106, 1013,  775,  892,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  105, 2962, 2857,  123,   98,    1, 2828,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2882,   60, 1426, 2335,  339,  845,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1523, 1364, 1365, 2817,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   92,   37,  238, 2152,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  297, 2851,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294, 1414, 2596,  778,   32, 3155,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,  936,  645, 1273, 1151,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,   66,  677,   69,  102,  470,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2226, 2518, 1230,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2095, 2985,    1,   32,  487,  147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 1615,  912, 1294,    6, 2759, 1208,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  677,  529,  408,  583,    1,   12,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,   37, 2164,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2869, 2979,  105,  686,   32,  455,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2862,    1, 1021, 1343,    1,  652, 1625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,    1,  395,    1,    1, 2179,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1127,  437,   37,  151,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  389,    1, 1335, 2693,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   61,  224,  166, 1411, 3028,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12,  138,    9, 1343, 1107,  778,  167,   52,  105,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1089,   37,  168, 1355, 1230,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  202, 1492,  321, 1154,    1,   12, 2728,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  619,  166,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  359,  474,  908, 1384,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3257,  967,   37, 1334,  838,   32,    1,   28,    9, 3230,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1289,  284,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1034,   45,  385, 1194,    1, 1370,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3052,  184,  754, 3023,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  422, 1536,  521,  134,   32,  702,  133,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2572,   32, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3385,  475,  267,  593, 1284,    1,  220,  903,    1, 1447,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,    1,    1,  361, 3327,  190,  335,  297,  389,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   97,  897,   98,    1, 1827,   37, 2192,   28, 1021,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2862,   37, 1348,    1,   37, 3093,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  492,    1,    1,   45,    1, 2791,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  217,    1,  612, 2123,   37, 1865,  388,    4,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  202,  105,    1, 2126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  805,   45, 2066,   69,  102, 2051,    1,  763,   32,   12,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  592,  213,   37,  211,   32,  734, 1197,  191,  208,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,  105, 2199,   37,    1,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2136,  967,    1, 1886,    9,   10,    1, 2676,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3342, 1924, 1769,   37, 2816,  463, 2170,   63, 2263,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  787,    1,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  708,    1,   32,  443,   98, 2819,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1366, 1445, 1415,   37,    1, 1433,  166, 2859,    1,  166, 2041,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1237,    1, 1897,  365,  973,  444, 3045,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   46, 1348,  548,  395, 3102, 1757, 2424,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2245,    1,  261,   39,  271,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1720,  166, 1656,    1,  334,   61, 1018,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  239,    1,   98,  148,   12,  647,  142,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 2968,  469, 1229,   37,    1,  853, 1294,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092,   37, 1753,  116,  912,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3087,  868,  455, 2144, 2347,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  932,    1,    1,  150,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,    1, 3029,   37, 1539,   32, 1056, 2119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1070,  845, 2442,  147,   37,  360,    1,  149,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1822,  606,    1, 1021,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186, 1301, 2018, 1708,  444, 2764, 2765,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,    1,  444, 1693,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035,  476, 1527,  220,  822, 1879,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  169,  159,  554,  187,    1,   34,   48,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2397,    1,    1,   98,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  971,   37,  698,    1,  297, 1144,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 2357,  104, 1650,   98,    1, 1196,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  640,  845,   98,  430, 1665,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  331,  469,  313,   37, 1154, 1206,    1,  171, 3001,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2124, 1494,   32,    1, 2023,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1985,  388, 1749, 1413,    1,  176, 1153,  625,  700,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1821,  927, 1464,   37,    1,  453,    1,  361, 2421,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  764,    9, 3118,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1717,   28, 1675,   32,  539,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2159,    1,    1,    1,  792,    1,  792,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  136,  744,    1, 2079, 1211,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1120, 1494,  166, 1361,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1778,  205,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2902,    1,    9,  787,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  146,  147, 1550,    1, 2322,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2640,  943,   45,  792,    1,  361,    1,  792,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   63,    1,    1,   33,   39,  166, 2780,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,  108,   98, 1633, 2027,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  297,  105,   59,    1,   81,  754,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1191,  207,  354,  703,    1, 1192,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   39, 2119,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2520,    1,  469,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  388, 2292, 1316,  531, 2414,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  793, 2151,  547,   74, 1981,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2018,   12, 3380,  267, 1926, 1927, 2793,    1,  202,    1,   39,\n",
      "            1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178,  782,    1, 2924, 2496,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1591, 1164,   32,  104,    1, 1638,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978,  343, 1667,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  811,  640,   39,  176, 1663, 1659,   12,    1,   32, 1811,  404,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1708,  914,    1, 1159, 1657,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  573,  639, 1660,  453,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1013,    1,    1,   98,  449,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1427,    9, 2379,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   12,  327,   50,  901, 1001,  384,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2476,   37,  335,   98,    1,   32, 1764, 1990, 3135,   32, 1657,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  441,   37,  771,  822,  912, 2434,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2202,   37,    1, 3358,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3345,    1,  487, 3102,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2911,   32, 1759,  309,   51, 2192, 1557, 2789,  453, 1354,    1,\n",
      "          452,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1083,  166, 2412,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1536,  388, 2819,  767,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,  764, 2264,    1,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2153,    1,  191, 2416, 1900, 2738,  361,  803,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   64,  632, 3071,   36,  187, 1763, 2816,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  947, 2856,  854,   12, 1354, 2556,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2755, 1306,  852,   37, 2035,  726, 1045,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777, 1008,  365, 1644,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  594,  341,  640,  104,  819,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1283,  830,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,    1,    1, 1876,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  668,  293,    1,  767,   98,  912, 2285,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1687, 1022,    1, 3008,   51,  335, 2119,   37,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2972,  788,    1,    1,   32,  299,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3392, 2596, 2414,   32, 2018,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  375, 1550, 2587, 1998,    1,  229,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  321,  612,  713,   37, 1343,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  644, 1285, 1415,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,    1,   37, 1844,    1, 3020,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428,  267, 2673, 2287,    1,  384,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2618,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  395, 1707, 1789,   46, 1377,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,   98,    1,  371,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,  551,    1,  579,  166, 2795,   61,  600,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,   81,   98, 1171,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1614, 1117, 1525,  861,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3317,    1,  845,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3198,  140, 2936, 3329, 3329, 1990, 1569,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,    1, 1866,   79,  140,    9, 2741,    1, 1327,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  420,   54, 1763,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2139,   37,    1,  220, 1939,   45, 1863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3141,  542, 1000, 2025,  861,  548, 2811,  187,    1, 3263,  726,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   39,  105,  365,  837,    1, 2698,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1120,    1,    1,  114,    1, 1171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  150,  325, 1739,  777,  861,  669,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3384, 2556,   32,    1,    1, 2572,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  320,  334, 1210,   37,   52,  105,    1,    1,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  786,  454,   37,  335, 1245,   79,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,  102,  245,  548,  227,  550,  384, 2046,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2275,    1,    1,  736, 1010,  119,   69,  102,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1,   61, 2281, 2295, 2302,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  677, 1230,  919,  810,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,    1, 2301,   39,  105, 2494,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1879,  729,    1,   45, 3220,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3216,   12,    1,    1, 3132,    1, 2317,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2615,    1, 1515,  631,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1284, 1658,  420,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1586,  597,  373,    1,  187,  395,  582,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  140,  458,   45,  507,    1,   24,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  403, 2926, 2503, 3158, 2748,   98,  915,  581, 2498,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 3045, 2572,   32,  531, 2292,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  675,  256,  365,    1,   37,  260, 3004,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3168,  884,  297,  187,  593, 2101,  786,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  438, 2832, 1314,  444,  822,    1,   45, 3153,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1999, 2572,  187, 3121,    1,    1,  455,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2425, 2489,   85,  861, 2454,   32,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1325,   81,   32,  557,  540,  637,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973, 2497, 3249,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  743,   12, 1690,  525,   15,   71,    1,  419,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  959, 1921,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,   12,    1, 1151, 2094, 2992, 1415,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   39,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  187, 3355, 1216,   37,    1,   45, 2282,  722,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  619,  105,  152,  384,  667,    1, 1501,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1013,   98,    9, 1938, 2607,  382, 2633,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,   12, 3359,  213,   37, 1064,   37,  717,    1,  458,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1818,  147, 1360,  612,  231, 2080,    1,  768, 2096,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1602, 1435,  650,   45,  166,    1,    9,    1, 1031,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1113,   67,  418,  699,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1415,    1,    1, 2744,    9, 3260,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  105, 2968,  853, 1821,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  840,    1,    9,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3244,    1,   28,    1, 1183, 2113,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,  166, 1509,   45,    1, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2843,   96,   32, 1509, 1385,  424,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  444,  342,  768,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1929, 1082,  531,   37,    1, 1557,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  385,   15,   71,    1,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,   25,  813,  199,  115,   45, 1002,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1, 1414,   39,   82,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2476,    1,  384,  691,  506,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2658, 2269,  190,  193,    1,  297,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101, 2224, 2424, 3339,  302,   63,    7,  741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,    1,   28,  116,  618,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1396,  229,    1,    1, 2172,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  249,    1,   37,    1, 1515,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1273,    1,    9,    1,  166, 1868, 1172,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  836,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1181,  200,    1, 1151,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  245,  548,    1, 1844,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2778, 1937,  682,   32,  715,  741,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  275,  389,  218,  729,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,   52, 2740,    9,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,  729,  327,   13,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  550,    1,    1,   37,    1, 1004,  297,  221,   37,  104,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  562,    1, 3170, 1774,   28,  247,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428,  475, 1008,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  491,    1, 2071,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2217,  446, 1082, 3072,    1, 1232, 1277, 2437,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3297,   51,   52,  166,  872,   37,  688,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  282,    1,  565, 2964,  920,    1,    9,  166,  282,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523,    1,    1,  332, 2579, 3154,  631,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1799,    1, 1184,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,   70,   51,  245,  496,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   60, 1276,  444, 1354, 1479,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 1739,  105,  331,    1,    1,    1,   32, 2138,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  121,  744,   49,  333,    1,    1,  163,    1,   12,    1,  695,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  164,  165,  109,  125,   32, 1023,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2868,    1,    1,   28,  395,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  566, 2943, 1499, 2223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3125,    1, 3025,  949,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282, 2779,  140, 3135,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   91,  121,   37,  130,  365, 2673, 2375,  675,  964,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1173, 1087,   12,    1,  535,  656, 2871,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    9,    1,    1,  105,    1,  365,    1,    1,  105,    1,  316,\n",
      "         2082,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1841,   45, 3101, 1891,  820,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   47,    9,    1,  182,  676,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1361,   61, 2841,    1,  220,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,    1, 1217,   37,    1, 1149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2297,  318,   45, 2928,    1,  150,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1247, 2590,    1,  865,   32,    1, 3135,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  954,    1,   79, 2066,   69,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2615,  565, 2934,  645,    1,  833,  612, 2394,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1640,    1, 3071,  650,    1,   37,   64,  947,  317,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 2170,  267, 3342, 1822, 2259,    1, 3058,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2107,    9,  541, 1159, 1821,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,  443, 2775,  140,  176, 1050, 1662,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   68,   69,  102,  701, 1315,  105,  106,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   56,  395,  945,  494,  946,    1,   37,  947,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,  729,    1,    1, 2751, 1537,  754,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  744,  114,   37, 2702,   32, 1313,  176, 1260,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2512,   37,    1, 1975,   32,  864,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1166,   37, 1173, 1720,  334, 1188,  105, 1734,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3305,  321, 1910, 3013, 2198, 2187,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1932,   37,  125,  541,   32, 1352,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1065, 1190,    1,  187,  792,    1,   94,  792,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 2106, 1458,  462,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  612,    1,   28,  100,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  729, 2793,    1,  267, 2068,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2190, 2640, 2405,  754,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 436,  45,  49,  37,  52,  53,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 113,  79,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,   29,    1, 1965, 1204, 1534,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3076,    1,    1,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  510, 1992,    1,   28,   69,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1157,    1, 2823, 2409,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  385, 1177, 1827,  773,  810,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115,    1,    1, 1159,    1,   81,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3177,    1,  168,   37,  443, 1763,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2929,    1,  150,   12,    1, 2677, 3167, 3220,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2476, 2587,  111,    1,  675,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273, 1036,    9, 1375,    1, 2771,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1, 2196,    1, 1841,  513,    9, 3102,   12,  949,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  249, 2572,   32, 1029,  851,  298,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,  105,  271,  384, 1663, 3096,  427,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  437,  396, 1147, 3365,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1808,   37,  693, 1821,  541,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  741, 2116,   32,    1, 3343, 1002, 1961,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2846,   92,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1185, 2501,    1,  105,    1,   32, 1053,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1414, 2856,  228, 3043, 3370,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,  810, 1167,   12, 1827,  187, 3251,  288,   37,\n",
      "         1910,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  951,    1, 2459,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  992,   28, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  370,  371,    1,  373,    1,   37, 1832,   28, 1043,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  211, 1149, 2430,   32, 1739, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  597,    1,  475,  640,    1,   45,    1, 2225,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  581,    1,  384,  166,  645,   32, 2171, 2800,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  430, 1665, 1702,   69,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1675, 2871,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  379,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   79, 2661,   32,  903,    1,  331,    1,    1,    1,    1,\n",
      "            1,   98,   32,    1,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   81,  533,    1, 2151,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 1831,  992,   85,  384,  621,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  191, 2330,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1988,   45,    1,    1,  152,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 236, 237, 288,  37, 670,  98,  69,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 305,  28,  98, 160,   1, 293,  29,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  691, 2783, 2522, 2872,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   45,  166, 2498,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1668,  475, 2037,  984,  238,   98,    1,  442,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  647, 1774,   39,  112, 2515, 3004,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,   12,  219, 2155,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  113,  682,   63,  303,    1,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1100,  387,  699,  417,   15,    9,  572,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1641, 1159,    1, 1006,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  619,    1, 1228,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144,   12,    1,  812,  652,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2834,  361,  166,  207,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,    1,   61,  166,    7,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  531, 2216,  104, 1572, 1414,    9, 1583, 2891,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437,  952,  474,  863, 1278,  927,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3175,  103,  105,   12,    1, 2935, 2764,  539, 1684,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 1707,  104, 1250,    1,   49, 1611,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1585,  176,  632, 2003, 2414,   32,  293,   12,  645,  139,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  978, 2953, 2334,  614,   98,  333,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  840,    1, 1778,  535,  656, 1228,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284,   45, 1123,   12, 2084, 1008, 2812,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453, 1441,  365,    1,  302,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100, 1419,  673, 2871,  769,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1594, 1658,  327, 1159,  105,  282,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,   37,  837,    9, 1411, 1778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2235,   69,  636,  921,    9,  449,  199,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1404,   45, 3102, 2827,   32,  531,  513,    9,  949,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   61,  166,    1,  604,  218, 1542,   37, 2155,  453,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,   26, 1039,   32,  854,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  121, 1458, 1839, 3037,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2879, 2946,  176,  629,  384,  218, 1414,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2005,  723, 2692,    1, 1294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37, 2225,  365,   82,   87,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1427,  515, 2828,  726,  297, 1985, 1178,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1002,   10, 2860, 1046, 1931,   98, 2834,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,  98,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 197, 418, 176, 974, 975,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1689, 2442, 2717,   16,    1, 2070, 1915,   64,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  304,    9,    1, 2813,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,    1,  342, 1350, 1250,    1,  453,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  483,    1,    9, 2125,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1138,  108,    1,  159,  686,  356,  340,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  953,   37, 2073,  548,  670,   45,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  370,    1,    1,  182, 1527,  132,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 3407, 3382,   61, 1229,   37, 2047, 2208,   32,  531,   51,\n",
      "           52, 1961,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428, 2924,   64,    1,    1,  274,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,   81,  384,  390,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2595, 1328, 1001,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 3071, 2070,  593,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 1912, 1273,  259,  400,   96, 1159,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,  726,    1, 1334, 2793,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1004, 2217,  522,   32,  312,    1,  400,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,    1,  131,   32,  156,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2797,    9, 2702,  298,   32,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 3020,    1,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3228,    1,   37, 1306, 1090,  220, 1497,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2906, 2871,    1,  515, 1285,   37, 2906,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,  121,    1, 2343,   12, 2375,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 1756,  176,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  864,  190,  843, 2390,    1,    1, 2694,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2474,   98, 1171,    9, 2918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2871,    1,    1,    1,    1,  590,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2514, 2226, 1360,  612,   52,  166,   81,    1,  424,  199,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   53,   98, 1102,  841,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1352, 1509,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  891,  453,   14,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3301,   12,    1, 3135,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3258,    1, 1294,    9, 1477, 1990, 1394,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947, 1939,   32, 1531, 1554, 1940, 1530,    1, 1941,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  245,    1, 1572,  191,  275, 2054,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2416, 1260,    1,   28,   69,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2828,  114,  228,   37, 2651, 3313,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  415,    1,  657,   61, 1809, 1732,    1,  833,  612, 1719, 1307,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  867, 2384,  552,  552, 2650,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  729,    1,    1,  204,  812,  730, 2614,  187,    1,  872,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  803, 3087,    1,    1,   32, 1676, 1633,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233, 2104,   37,  741,   98, 1412,  844,  302,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1941,   32, 2328, 1260,   32,    1, 2018,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1396,    1,  220,  192,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  709,    1,    1, 2352,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,   12, 3359,  213, 1064,   37,  717,    1,  458,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1956, 1463,   74, 1343, 2361,  548,  211,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1284,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3207,  744, 2364,   98, 2213, 3135,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1343,   79, 2034, 2885, 1909, 1918,   45,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3279,  187, 1966,    1, 2282,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826, 1676,    1, 2222,  619,  916,   37,  665,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98,    1,   12, 2225,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2489,   85,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3385,    1,   45,  845, 3373, 2249,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,    1, 1898,  191, 1333,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1601,   45, 2210,    1, 2377,    1,  342,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2433, 1412,  157,  902, 2054,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3181, 1949, 3306,   12,   24,  548,  195,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1492,  142,   37,  125,    1, 2705,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  336,   32, 1617,  946,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  365,    1,   37,  166,    1,   45, 1204,   98, 1965,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3322, 2368,   39,   45,  460,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  400,  444,  735,  293,   37, 1174,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1423, 1734,    1,   37,  439,  166,    1, 2494,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2954,  220,    1,   37, 2035, 1107, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  965, 1260, 1071,  531,   12,   69, 1069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2549,  199,    9,  829,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3239,  190,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,  475,    1,    1,    1,  267,  669,    1, 1176,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2511, 1749,  220,  829,    1,  199,  421,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  891, 2281,  927,   98,    1, 1603,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2372,   45,  851,  298,   32,    1,  384,  942,    1, 1186,    1,\n",
      "          691,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2250,  744,   28,    1,   32, 3123,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800,  321,    1, 1429,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,  267, 1801,    1,    1, 1511,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,  155,  347, 1114,    1,   37,    1,  361,  387,  590,    1,\n",
      "           37, 2446,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3062,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2144, 1095,    1, 2145,   37,  138, 1270,    1,   32,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  375,  894,  792,  664,  810,    1, 1232,  514,  792,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  389,  218,    1,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  716,  913, 1340,   81,  176,  656,   45,    1,  400,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545,  361,    1, 1758,  220, 3314,   12,  753, 2793,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   39,  176, 1094,   32, 1313,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  443,  488,    1, 2141,  270,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2222, 1631, 1632,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 1147,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307, 1631, 1159,  754,  861,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2889,    1,    1,    1, 2800,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,   28,   98,   49,  533,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,   12,    1, 1354, 2529, 1920,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2912,  653, 3277,    9, 1357,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  267, 2919, 2949, 1924,  649,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  393,  716,    1,  737,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2427,   37,  837,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  947, 2263, 2026,    1, 3060,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  166, 1264,  931,  175,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1633, 1765,  166,  449, 1597,  700,   37, 1413,  166,   26,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56,  332, 3116,  631,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,  839,    1,   37,    1, 3404,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 2371, 1657, 1194,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  190,    1,  424,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3168,  140,  449,  427,  176,  590,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  286,  927,  640,  754,   32, 2016, 2517,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2608, 2607,  533, 1192,    9,  575,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1,    1, 2759,  260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,    1, 3339, 1743,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 854,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 741,  32, 581,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1285,    1,  794,  365,    1,   45, 2798, 2706, 3004,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3281, 1587,   45,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3096,    1, 1380,    1,   81,   98, 3281,   12, 1046,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2526,  187, 2957, 2565,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,    1,  186,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1426,   59, 1649,  399,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1701,   37, 1753,  207,  668, 2852,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 3345,  949,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 398, 267, 829,  37, 138,  59, 428,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 938, 939, 187, 929,   1,  82, 361, 940,  45, 941, 234, 182,\n",
      "         235,   1,   1,   1, 234, 182, 235,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1362, 2627, 1107, 1863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   28,   98,  156,    1,   69,    1,  996,   29,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3172,  103, 2246,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1497, 2596,    1, 2827,  531, 2458,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  184,    9,  537,  297,  207, 3049,  506,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2334,  640,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,  720, 2762, 1965,  829,   12,  645,  328,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  544, 1444, 1847,  460,   12,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2970, 1089, 1675,  619, 1333, 1114,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   76,   37, 1343,  166, 2069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  968, 1550, 1284, 2673, 1017,  384, 2018,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1080,  677,  481,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  220,  104, 3009,   79,    1,  219, 2651,   61,   98,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  407,   98,  849,  548,  199,  421, 1042,  142,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1925, 1583,    1,   32, 2124,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302, 1712,    1,  220, 2819,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1157, 2751, 1207,   37,  439,    1, 1632,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3089, 3297, 1246,  167,  619,  885, 2240,  166,  567, 1090,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  686, 2466,    1,   32,  903,    1, 2926,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 1602, 2539,    1,    1,  105,    1,    1, 1816,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1029, 1557,  113,  480,  741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2753, 2572,   32, 1853, 1585,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 2180,    9,    7,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  197, 1936, 1702,   69,  102,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  537,  548,  166,    1,    1,    1, 1277,  162, 2100,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,   37, 2831,  453, 1863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1574, 2854,  511, 3201,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   37,    1,  750, 1414,   37,  856, 2834,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,    1,   50,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203,   37, 1343,  460,   73,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,    1,  359,  774, 1444, 1445,  123,   37,  105,  132,\n",
      "           98,  672,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61, 1658,  327, 2440,  384, 3002,  361, 2650,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2596, 1665,  991, 2936, 3283,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  221,    1, 1131,   37,  273,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2291, 2414, 1700,  487, 2548,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  310,    1,  219,  616, 1758,   69,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2746,    1,    1, 1523,    9,    1,  741,   32,  104, 2823,  863,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  459,  402,   37, 1954, 1798,   32,  531,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1256, 1256,    1,  195,  967, 2725,  505,  629,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  744,  949,    9,  792, 3018,  792, 1455, 1294,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  602,    1,  447, 1876, 1855,    1,   37,  342,    1,   46,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1292, 1021,   32, 2110,  729, 2669,  453,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2634,    1,    1,    1,  766, 1832,   98, 1395, 1069,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  992,   28,   97,  297,  375,  229,  396,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1042, 1705,    9, 3037,    1, 3036,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 1705,   37,  837, 2189,  557,   15,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,    1, 1560,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  405,   12, 1625,    9,    1,  439,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  602,    1,  593, 1990,    1,   32,  455,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2793,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3183, 2225,    1,  979, 3229,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  732, 1830,  365,    1, 1910,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,  199, 2292,    1, 1715,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   56, 2476, 2572,   32, 2597, 2137,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  429,   98,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2984, 2598,  608, 2662,   12, 2918, 2820,  892,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2533, 2331,   45,  683,  221,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,    1,  535, 2165,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,  492,  947, 2347,   32, 1994, 2095, 2625,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  952,  927,   45,   10, 3404, 1697,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3029, 3027, 1478,   98,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,   98,    1,   12, 1623,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   80,    1,    1,  187, 1766, 1767,  738,  207,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32, 2822,    1,    1,    1,    1,  506,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2736,  200,  161,  841,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  375,    1,   37,  151,    1,   32,  152,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,  953,   85,    1, 1638, 2337,    1, 2064, 2449,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  521,  663, 2104,   37,  713,   37, 2000,   10,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178,  163,    1,  857,    1,   32, 2250,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  565, 1211,   37,  289,   98, 3300,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2662,  927,   51, 2704,    7,   37, 1204,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   28,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,  544,  334,  774,   37, 1018,    1,    1, 1821,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   28,   98,    1,    1,   69,  441,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1059,   28, 3126, 2385,  612,  166, 2259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  318, 3365,   32,  531, 2562,   37,  437,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584,    1,    1,    1, 2249,    1,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1412, 2521,    1,  861,  441,    1,  384, 2047,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106, 2355, 1013, 1748, 2481,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2490,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  450,  104,   95,   37,  451,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  686,   81,  297,  427, 1336,  396,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3361, 2572,    1,  104, 2548, 1941,   32, 1656, 2596, 1260,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1631, 1998,    1,  220,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,    1,    1, 2095, 1450,  254, 1056,    1,    9,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2328,  140,  119, 1909,    1, 1185, 1624,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26, 1039, 2515, 2683,    1, 1419,    1,    1,   15,    1, 3031,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612,    1, 2191, 1314,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  615,    1,   45,   49, 2623,    1,    9,  987,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3281,    1, 1133, 2250,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2423,   32,  220,  166,   32, 2242,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  849,    1,  197,   28,   98,    1, 1869, 2057,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1046,    1,   32,    1, 2069,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  617,  618,  105, 1239, 2537,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  646,   93,  125,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3156,  176, 1021,  250,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1530,  176,   45, 1610,  985, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  535, 1682,    1,  191,  654,   12,  331,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3336,  738,    1, 1398,  612, 1079,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3303,  140, 1684,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  443, 2938,    1,   51,  335,  537,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3118,  105,  199, 2596, 1555,   37,    1, 2117,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2924,    1, 1354, 2556,    1, 2431,    1,  531,  716,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    9,  183, 1008,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585,  176, 2178, 2147,   32, 2197,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1236,    9,    1, 2819,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  500,  159,    1,   98, 1560, 1119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3155,   51,  193,  741,   32, 1147,  890,    1, 2877,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  702,  775, 1084,  841,   37,   92,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  123,  215, 2715,  661,  250,    1,    4,  901,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821,  927,  313,   37, 2809, 1159,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  344,    1,  297, 2702,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1487,    1,    1,    1, 1108,   37,  124,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  213,   37,   47, 1870, 2261,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,   69,  102,  245,   98,  197, 1936,  115,   45,  104,  863,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3339, 2129,  105, 1918, 3374,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2347,    1,  321,  612, 1838,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1022,    1, 2296,  162,   81,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1310,   37, 1594,   28, 1245,   32,  214,  142,   45,  647,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  765, 1836,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870,    1,   28,  365,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1775,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3301, 1558,  176,  584,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,  387,  682,  444,  166,   94,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  819,  260,   28,    9,  938, 1282,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2623,  176,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2596,  176,  854,    1,    1, 2414,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652, 1236,  829,  297,    1, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  187,  947,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   67, 1564,  803,  504,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2691,  619,  105,    1,  176, 2692, 1183,    1,    1,  775,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1283, 1292,   32, 2141, 1708,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2733,   81,   32,  147,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1449,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  191,    1,    1, 2141,    1, 1204,   32,  105, 2755, 2170,\n",
      "         1223,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  381,   37,  130,  449,  294,  458,   45, 1739,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035,  162,  365,  844, 2522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  619,  723,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3358,    1,  967, 1745, 1846, 1415, 3101, 2404,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764,    1,    1, 1748,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  915,  916,    9,  903,    1, 1973,  132,  187,  241,   46,   26,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  288,    9,  526,  698,    1,   29,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2967,   12,    1,    1,  408,  166, 1497,  105, 1090,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358, 1983, 1463,  782,  590, 1479,    1, 1190,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1630, 1063,    1, 2008,  609,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1381,    1,    1,  475,   12,    1, 2495,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1564, 1090, 2315, 2498, 1567,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1215,    1,   61, 2827,   32,    1,   32,    1,  290,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,  388,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1896, 1532,   37,  562, 1407, 1696,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3232,  321,  612,  686,   32, 2522,  354,   37, 2614,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169,  113,   79, 1645,    1,    1,   32, 2197,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1530,  187, 3121,    1, 2433,  455,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 3255,    1, 1938, 2809,  142,    1,  220,    1,  726,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1783,  744,    1, 1888,  693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388, 2458,  606,  116,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2073, 2151, 2451,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1151,   13,  353,    1,  401,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  506, 1744, 2527, 2946,  565,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1, 2196,    1,   37,  335,    1,  260,   98,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1773,  733,    1, 2510,    1,   32,  449, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3407,    1,  946, 2375,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3121,    1, 2414,   32,  451,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1,  640,  463, 1447,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1749,  220, 2573,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,   12, 1247,   37, 1248,  163,    1,   12,    1,   37,  125,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1979,    1, 1763, 2589,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  870, 1087,   37,    1,  331,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3076, 2886, 2572,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  310, 2153,   26, 1725, 2396,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   74,  786,    1,  335,  166, 1285,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175, 1144,   98,    1,    1,  276,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1,    1, 2971,   98,  166, 2918, 1821,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3350, 1373,   45,  622,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,  531,  852,   37,  593,    9,  432,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1159,  845,  275,  818,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1494,   37,  439,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  177, 1700,    1, 2548, 2572,   32,    1, 2517, 3279,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1309,   37, 1174, 1013,    9,  365, 1009,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,    1,  223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  506,   32,    1,  967,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196, 1419,  848, 1303,    1,  105,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  342, 2104,    1, 1786,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004, 2546,  354,  703,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  761,  267,    1,    1,  985, 2298, 1634,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  112,    1,  187,  104,  614,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1408, 1069,  837,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  150, 1749,  220,  613, 1605,  698,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 1542,   37,    1, 1232, 1377,  901,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2771,  193, 2181,    9,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  220, 3054,    1, 2977, 2850,    9,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  123,  410,   37, 1291, 1044, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  381,  884,   98,  657,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1705,  191,   10,   98, 1580,  640,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  140,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2839, 1554,  531, 1657,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2531,   32,  241, 1995,   98, 2095,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2104,  765,  444, 2650,    1,  207, 2086,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,   53,   79,   98,  104,  186,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  763, 2832, 1530,  187, 2504,  957, 2272,   85,   98,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1640, 2774,  475, 2753,    1, 2282,   32,  147,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299,    1,  116,  412,    5, 1281,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1548,  437,    1,    1,    1,   32,  942,  297,  114,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3276, 2712, 3247,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  657, 1913,  401,  983,    1,  131,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303,   69,  102,  590,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1112,  176, 1920, 1351,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,  200, 2340,    9, 2510, 2480,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  294,    1, 1408,  671, 3126, 2645,   37,    1,  384, 2616,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1,    1,    1,    1,  293, 1119,   37,  845,\n",
      "          275,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2, 176,   1,   1,   1,   1,   1,   1,   1,  45,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 575, 529, 658, 996,  93,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3383, 1414, 2341,  118,   45,  947,    1,    1,  104,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2362,   61,  792, 2527,   32,  166,   38,  792,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  296, 1450,  316,   12,  397, 1787,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1214,   12,  754,  209,  458,   51,    1,   39,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1645, 2404,   32,    1,  548,    1,   46,    1,    1,  191, 1484,\n",
      "            9,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707,  342,   46,    1,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,   28,   98,  105, 2312, 1938,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  364, 2257,   39, 1990, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1001,   39,   45,  105,  965,  994,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2628,  952, 1090, 1281,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3254,    1, 2777, 1710, 1584,    1,  168,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  359,  474,   37,    1,    1,    6,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  632, 3032, 1021, 2190, 2361, 1604,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  325, 1074,  861,  669,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1149,  548, 2174,  395,  132, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492, 1075,  896,    1,   12,  915, 1662,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2244,    1,    1,  155,  122,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358, 1216, 2958,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2446,   98,  166,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1326,    1, 2274,   37, 1706,  152,   32,  395, 1597,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    1,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  515,    1,   37, 2041, 2655, 1806,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3277,  251, 3177, 1148,   38,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746,    1,  829, 1508,  331,  116,  844,  132,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3311, 3310, 2930,  776,  852,  288,   37,  168,  115,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  502,  437,    1,  929, 2689,    1,    1,    1,    1,    1,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2662, 2918,   51,  606, 2378,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713,    1,   45, 2472,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1224,   45,  465, 1895,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  927, 2156,  297,    1,   45,  104,    1,   32, 3360,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3167,  972, 1360,  612,    1, 1340,    1, 3294,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   22,  847, 1830, 2240, 2092,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32, 3248,    1,  714,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1530,    1, 2249,  548,    1, 1308,   32,  395,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1249,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181, 2593,    1,  803, 1151,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  884,   28,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  710,    1,  648,   39,  166, 2009,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3123,    1,  619,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  896,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  460,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  456,   85,  667, 1325,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2104,  952,    1,  493, 1650,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2990, 1083, 2413,   45,    1,  341,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1678,   32,  166,  439,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1625,   71,    9,  439,   37,    1, 2299,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307,  919,  275,   25,  978,  769,  670,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1041,    1,    9,  915, 1090,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,   37,  151,    1,    9,   59,   32,  987,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2863, 1654, 2956, 1350,  400,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1613, 1614, 1615,  259,  220, 1616,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   63,  166,  862, 1303,  338,    1,  419,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  396,    1, 1383,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,  400,    9,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   63,  166,  862,    1, 1784,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,  737,  197,   28,  118,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2670,   37,  764,    1,    1,   45,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12, 1407,  269,  218,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  379, 1079,    1, 1675,  475,   37, 1334,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2919,   45,  166, 2710,    1, 1492, 1924,    1,  191,  166,  163,\n",
      "            1,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 1162,  108,    1,   37, 1306,  739,  159,  720,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   12,    1, 2331,   45,  105,    1, 2457,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1227,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2173,  720,  312,  400,  444, 3310,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   66,    1,   32,  395,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2789,    1,   32,  890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  166,    1,  384,  453,  124,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1420,    1, 2073, 1023,  207, 1660,   98,    1,  102,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018,    1, 2764, 2765, 1450,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  546,  518,  494,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  105, 1568,  225,  176, 1215,  156,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  845,  439, 1021, 2168,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  303,  108,   98,    1, 1665,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  927, 1549,   45, 1212,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3213,   37, 1421,   32, 1890,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2720, 2796,  130,    1,  987,  384,  978, 3138,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3089, 3205,    1,  171,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2954,   28,  220, 1181,   37, 1978,  166,  464,  218,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2041, 1463,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3300,    1,    1,  683,  384, 2347, 1638,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275,    1,  297, 1915, 1563,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12,    1,   37,    1, 2224,   98, 1602,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3199,    1,    1, 2940,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  396, 1254, 1465,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  513,  590,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  146,  147, 1968,    1, 2351,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3274,  744,    9, 2457,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   63,  166,  862,    1,    1,  262,  263,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   64,   23,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 2950, 3060, 1061,   32, 2018,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2860, 1027,  777, 1085,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,  365, 3092,  475, 1213,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 2419,  218,  631,  384, 1570,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,    1,    9, 3274,  361, 3169,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,  443,    1,  667, 2855,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3178, 1360,  612, 2303,   98, 1888,  920,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  963,  927, 1159,    1,  114,  891,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2792,    1,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   79,  147, 2712,  220,  331,  693,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1934,   12, 1021, 1031, 2900, 1057,  600, 1647, 1750,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  885,  649,    1,  700, 2317,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  640,  845,   98,  109,  509,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  967, 2588,   32,  449,  913,   32,    1,  463,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1009,    1,  176,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  476,  105,    1, 2297,   37,    1,  386,   12,  869,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1639,  384,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1251,    1,  407,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  358, 2361,    1, 1007,  541,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  455, 3121, 2900,    1,    1, 2817,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  705,    1,   32, 1117,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2024,   51,  920, 1734,  105,  916,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425, 2538,   26,   28,    1,   37, 1450,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2031,  777,  778,    1, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1097,   57,  245,    9, 2073,   73,  339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3236, 2871,    1, 1426,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2236,  577,  600, 1573, 1517,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3075,   12, 1645, 2237, 1554,  734,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1355,  294,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147,  947, 1237, 2646, 3346,    1, 2263,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3059, 2761,    1,    1,  220, 3265, 1987,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3175,    1,    1,  140, 2764, 3212,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2944,   12,  695,    1, 2789,    1,  446,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  857,    1,  477,  515, 3181,  726,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  702,  176,  365,  845,  636,  837,  969,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  947,  820, 3060,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503,  338,  548,  790,  776,    1, 1324,   98,  749,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3115, 1403,   81,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 2708, 1333, 1530, 3095, 1687, 1013, 2456,   32,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  952,   37,    1,    1,  220,  327,  333,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106, 1107,  256,  388,  219, 2610,  124,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 1021,   45,  869,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 2065,  365, 1461, 1294,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,  443,    1,  193,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,   37, 1073, 3339,    1,  539,  458,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1200,  132,  515,  829, 2927, 1159, 1842,  844,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,    1, 1919, 3374, 1098,   32, 3140, 1010,    1,    9,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  608,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1674,  671, 2806,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  220,    1,  164,   32,  649,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  990, 1536,  449,  961,   43,  444, 2650,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1879, 1285, 1159, 2941,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2278, 1586,   28,   13,   45, 2815, 2043,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  187,  104, 2924, 1285, 1415,    1, 1147, 3382,  980, 1004,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 2982,  190,    1, 1965,    9, 1700,  388,  257,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3066,  546, 2741,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708, 2153,   37,  791, 3358, 2005,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 3276,  167,  168,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2648, 2801,   12,  517, 1116,  640,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1547,    1, 1245,  187,   69,  102,  686,  119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,  868, 3057,  132,  220, 1384,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1799,    6, 2253,    1,  223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3364, 1564, 2507, 2708, 2237,   37, 3140,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2578, 1654, 1881,   45, 3324,  176,    1,  628,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1,  434, 2355, 1013,    1,  388,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1128, 1137,   37,   56,  356, 1653,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,  968,   12,  954,    1,  166,    1,   61,   32,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  393,   37,  125,  494,    1, 1149,  138,  191,  419,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  171,   45, 1193,  548,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  166, 2745,  168,    1,  903,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978, 3138, 3252, 3224,    1, 2615,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1082,  865,   37, 2756,   32,  557,  540,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3393, 1450,    1, 2024,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  683,    1,  197,   28,   98,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   29, 2483,  677,    1,  408,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3257, 2682, 1990, 2462,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111, 1611,   37,  693,  105,  784,   45, 2295,   37,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,  831,  187,   68,   69,  102,  720,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1662,  293, 1536, 1994, 2086,  767,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2493, 1176, 1133,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3397,  531,  890,   37,    1,   98,  199,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2698,  865,   37, 2288,   12, 1285,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1236,  777,  778,    1,  297, 2819,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   37, 1075,   98, 1275,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043,   28,  786,  118,    1,    1,  407,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1934, 1419,  388, 3080,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1867,  912, 2285,  210,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2960,  898, 2083, 1785,  458,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  301,    5,  302,  630, 2011,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1693, 3092,    1, 1313,  297,  966,   45,  938, 2308,   32, 2468,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  338,  384,  187,   68,   25,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1010, 1523,  220,  148,    1,  647,  546,  453,  475,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  445,    1,  600,    1,    1,  614,  111,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  547,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  506,  267,  105, 2673,  864, 1710, 1527,  388, 2095,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1617, 1216,  448, 1347,  254,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178, 2921,  686,  191, 3038, 2164,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  683,    1, 3174,   32, 2069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,  140, 1361, 2255, 2351,  400,    1,  476,   54,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   32,    1,    1,   10,   12,    1,    1,  105,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   28, 2462,  105,  638,  221,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  534,  986,  105, 2391,  845,  331,    9, 1524,    1,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504,  446,  953,    1,    1,   98,  368,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  220,    1,  176,    1, 1247,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 1090, 1829, 2307,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1485,  446, 2356,   45,    1,   37,    1,  398,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3128,  267,  104,  580, 1463,   45,    1,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  681,   37,  151,    1,    9,    1,  372,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1235,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1359,   45, 1163,   37,   38,   79,  389,   37,  105,  365,  475,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3160,    1,   37,  531,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3170,    1,    1,  202, 1625, 1173,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3191,   37,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  156, 1253,   32,   72,  401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  417,  187,    1,  485,  246,   98,  374,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1084,    1,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169,    1,    1,   37,  759,  316, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1586,  475,   39,   45, 2514, 1505,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  941, 1663,   12,  149,  444,  938,   61,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3358,  928,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1, 2894,   37,    1,  517, 2474,  259, 2146,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,  108,   45,  525, 1073,   79,    9,    1, 2102,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187,    1, 3212,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1465, 1466,   37,  130,    1,   32,   59,  810,  987,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129,  922, 1090, 1829, 1834,  176,  365, 1788,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2384,    1, 1522,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2846,  665,    1,   32,    1,    9,    1, 1867,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1751,    1,    1,    1,    1,    1,  928,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,   17,  619, 1658,    1,   98,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1, 365, 963, 663,   1, 101,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 259,  50,  32, 395, 967,  71,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2596, 2716,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,  294, 1983,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2004,  755,  459,   28,    9,    1, 1225, 2549,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  792,  593,   45,    1,  775, 1332,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3129,    1, 2885, 1401, 1548, 3154,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   26,   28,  548,  594,    4,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3129,    1, 1086,  547,  356,  713,    9, 1684,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,  156,  304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1390, 1746,  469,    1,  548,  810, 2539,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485,  957,   12, 1300,  693,   45,    1,  159,   37, 1844, 1352,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2004,  829, 2373, 2229,  327,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  371,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   20,  156, 1253,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596,    1, 1359,    1, 1130,  972,   37,   52, 1041,  680,  422,\n",
      "         1259,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2226, 1847, 2226,  321,  688, 1005,  220,  166,  917, 1656,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2463, 1249, 1245,   32,    1, 3135,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1898,  220,  455, 2913, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  802, 2195,   37,  829, 2194, 1705,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1046,  134,   32,  854,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  469,  818,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1808, 1273,  328,  640,  159, 2013,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    7, 1726,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1680,  163,    1,   12,    1,  112,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2094,  365,    1,   37, 2142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    9, 2176,    1, 1158,  251, 1442, 2452,  517,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56,  709, 2379,    1,    1,  493,  239, 1231,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  148, 1117,    1, 1248, 2716, 2465,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  527,  952,  885,  372, 1251,  745,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3113,  479,  484, 1924,    1, 1632,  166,  985,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  523,  162, 1451,    1,  384,  422,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  828, 1079,  422,   37,  927,  622,  574,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550, 2610,    1,    1, 2304, 3005,    1, 1704, 2492,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1247,  686, 2177,   32,  865,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1173,  176, 2823,  806,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2913,  593, 1587,   45,  829,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099,    1,  281, 1083,  209, 1650,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  321,  334,  774,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  546, 3181, 1918,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  795,   22,   82,  796,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1082,  342,   37,    1, 2673,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1128,  952,   37,  860, 1085, 1632, 1876,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  972,   37,   26,    9,    1,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   14,   15,  670,   98,  382,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2789, 1774,   98,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  361, 1051,  872,   28,   98,  861,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3187, 2800, 1218,    1,  288,    9,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1408,    1,  331,  671,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310,   25,  245,  187,   69, 2405,    9, 1194,    1,  504,  848,\n",
      "         1042,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 550, 369,   1, 104, 221, 706,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 503, 251,   1, 105,   1, 132,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   20,   50,   37,   47,    1,   22,  798,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  702, 1342, 1751,  365,   82,    1, 1009,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  147,    1,  768,  695,  444,   13,   45,   40,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  770,  361, 2895,   45, 2691,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,    1,    1,   28,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98, 3358,   76,   32,  105, 1875, 1890,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  716, 1390,  459,  132,  220, 1327,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233,   51,    1, 2730,  302,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2217, 1489,  365, 1277,   12,  865,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2948,  166, 3024,    1, 2984,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  107,   37,  163,    1,   12,    1,  815, 1193,   69, 1356,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,    1, 2017,  384,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3096, 2671, 1532,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1,   37, 2192,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1011,    1,  804, 2493,   37,   52,  105,  183,    1,    9, 1031,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321,    1,  877,  196,  917,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1100,  775, 2071, 1331,    1, 2403,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2827,  297, 3038,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3144,   12,    1, 1484,    9, 1407,  764,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  814,   50,   37, 2123,    1,    1, 1539,  853,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  388, 2529,  294,    1,  884,  297,    1,   45,    1,  963,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1388,   37, 1838,   98, 2020,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2075,   81,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2452,  517,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947,  927,    1,    1,  396,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 2346,    1,   45, 1125,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,   50, 1355,  224,    1,  440, 1013, 2165,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1933,  467,  105, 1641,   37,  258,  954,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  782,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  293, 1077,   37,  726,  297,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2222,    1,  105, 1656, 1167,   46,   81,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1247,    1,  220,  386, 2191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,  830,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 218,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 746,   1, 829, 477, 331, 844, 132,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3227,  501, 2420,    1, 2308,   45,  166, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3113,   12, 2545, 2658, 1654, 1684, 1277,    1, 2059,  920,   66,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  649,  214,   45, 2550,  578,  439,   45, 1186,   12, 1728,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   93, 1071,    1,   15, 1269,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  359,  360,  104,   22,   12,  365,  693,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275, 1187,  103, 1985,   98,    1,   16,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,   37, 1706,   59,   32,  854,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273,  772,    1,  983,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  761,  267,    1,   12,  762,    1,  763,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2685,  729, 2934,   37, 1054, 3237,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158,  775,    1, 1456,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437,   45, 1312,  476,  388,   69,  568,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  459, 1228, 2718,   37,    1, 2639,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  361,    1,  191, 1936, 2936,   26,  631,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2377,   45, 2752, 3365,   32,  531,    1,    9,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,    1,  565,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1028,    1,    1,  105,  365,    1,   32,  166, 2299,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  636,   45, 1738,  163,    1,   12,    1,  433,  418,    1,  419,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1279,  977,  321,   52,  638, 2549,    9,  803,  615,    1,  202,\n",
      "         1543,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  335,    1,  176,  657,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,    1,  527,  317,   72,  401,  390,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,   12, 2339,  156, 1522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  439,    1,  417,   98,  749,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280, 1542,   37, 1664,  183, 1158,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,  315,  219,  117,    1,   37,    1, 2102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2841,  683,   37, 1046, 3333,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  275,  159,  123,  242,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  119,    1, 2903, 3250,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3116,  922,    1, 2857,  921,  453,  437,  548, 2250,  176, 3176,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579, 1411,    9, 2977,    1,  405,    1, 1554,   32,  227,    1,\n",
      "            1,  202,  639, 2126, 2245, 1821,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1019, 1676,    1, 1737,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 2828,  877, 2177, 1604,   45, 1990,  726,  297,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3229,  967,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   37, 1539, 2693,    1, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  905, 2166,   34,  572,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1126,  680, 1665, 2007,   37,    1,   45, 1077,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   72, 2132,    1, 3079,  190, 1046, 2142,  171,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,   37,  119,  340,  951,   94,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,   37,   92, 2101,   45,  541,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  480,    1, 2937, 1658,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1,    1,  868,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12, 2849,  217,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1976,   32, 2468,   66,  187,  915,  345,   37,  638,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2592,  459, 1259,    9, 1725,  442,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  150,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401, 1957,  608, 3219,   32, 2138,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1056,    1, 1114,   32,  365,    1,    1,    1,  193,  424,  199,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,  155,  207,  197,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  573,  639,  475,  997,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1723,  261,    1,  187, 1056, 1450,    9,  286,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2826, 2497, 2786,   45, 3021,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,  367,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2962, 3188,  140, 3212, 1523,  187, 3244,  688, 2807,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1091,  920,    1, 1465,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  640, 2255,    9,  617,  618,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147, 2417,  193, 2810,    9,  777,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2386, 1700,  220,    1, 1443,  777, 2165,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  381,   37,  151,  449,  294,  458,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1652, 1419, 1718, 2355,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  550,   61,   26, 1039, 2366,  550,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  469,    9,  667, 1437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  952,  119,   45, 3024,  651,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,  938, 1282, 2453,  187,  501,    1,   55, 1393,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   98, 2569, 2735,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  548,  914,   32,    1,    1,  938,    1,  753,   37,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  147, 1707,   49, 2509,    1,  398,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1583, 1360,  612,  138,  419,   45,  352,  302,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  711,  475,   37, 1910,   63,   24, 1086,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  348,  387,    1,   93,   45,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3194, 3195, 1008, 3276, 2731,    1,    1,    1,  187,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    9, 2676,  361, 2136,    1, 1896,   37,  860,   98,  166,  440,\n",
      "          736,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181,   79,   37,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  281,   12,    1,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  852,   55,    1,   37, 2565,  208,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  220,  424, 1705,    1, 1444, 1445, 2505,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  957,    1,    9,  844,   12,    1, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2144,    1,   32,    1,  195,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 2024,  475,  108,   45,  388, 2292,  548,    1, 2891,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2468,  297, 1690,  312, 2220,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 1758, 1750, 2646, 3346,    1,  844,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  137,   37,  138,  119,  139,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2747, 1128,   12,  883,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  632,   36, 3071,  105,    1,   12, 2775,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  204,  105,    1,  484,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   20, 2744, 1202,   32, 1913,  401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    5,  302,    1, 1698,   45, 1631,    1, 2424,  233,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  560,  347,  973,  242,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1834, 1383,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2094, 1766, 1767,   85,  384,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1600,  625,    1,   61, 2177,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1582,   30, 1647,    1,    1,   32,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,  997, 1018,    1,  863,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2884,    9, 1537,    1,   12,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1386,  972,   37,  125,   69, 1607,    1,  232,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  422, 2677,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  249, 2572,   32,  216,   32,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  743,   12,    1,    1,  862,  187,   82,    1,  580, 1463,   32,\n",
      "           91,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1086,    1,   45,  104, 1350,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  147, 2037,   39, 1739, 2162, 1175,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3272,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1584, 1428,  475,  619,   98,  220,  389, 1861,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1938, 2607,  382, 2206, 2989,   61, 2970,    1,    1, 1090,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2954, 2253,    1,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2898, 1658, 2819,   61,  105, 2537,    1, 2898, 1114,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2004,  342,   12,    1,   46,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2715,   45,    1, 2058,   79,  892,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  584, 1625,   37,  619,  460,  917,   32,    1, 2661,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878, 2458,  361,    1, 1753,  829,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1053,  190,  193, 1031,  792,  786,  395,  792, 1563,  446,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2682,   32, 1537,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  441, 1753,  388, 1465, 2264,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1,   22,  721, 1830,   37,  741,   98, 1656, 1649,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,  125,    4,  187,  408,    1,    1,    1, 1528,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,  950,    1,  273,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   49,  952,  104,  467,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   39, 2355,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2438,  224, 1658, 2177, 1027,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  268,  251,   37, 1083,  142,    9, 1092,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  275,    1,   98, 1171,    9,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  282, 2539,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2679, 1263, 1401,   37,    1,   12, 2772,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2090, 3096, 1218,  884,    1,    1,   32,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1610, 1039,   45,    1, 2796, 1976, 1821,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479, 2094,   81,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2687,    1, 1242,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1147,    1, 2572,  191, 1656, 2596,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3043,    1, 2827,   32, 2018,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  155, 1537, 1625,   45,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  179,    1,  176,  612,  875, 1084,  625,    1,  396,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,   98, 3155, 2414,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1178,    1,  548, 2144,    1, 2572,   32,  395,   36,    1, 1260,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2921,   32, 1242,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 547,   1, 243, 636,   1, 906,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 957, 108,  45, 207,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1082, 1488,    1, 1639,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   32,   46,   37,   47,  453,  327,  112,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2170,  361,  453, 1763,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110, 1575,   37,  726,  297, 3271,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  416, 1994, 2390,    1,    1,    1,  193,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,  566, 1952,  745,   45,    1,   54,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1773, 2510, 1510, 2821,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,  199,   98, 3173,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1181,   37,    1,  182, 1159, 1286, 1069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1015,   45, 2494,  872,    1,   32, 2890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  189,   37,    1,    1, 2089,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  819, 1284, 1159,  166,  818,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   25, 1594,   28,  187, 1158,  919, 1017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3360, 3347, 3340,  191,    1,    1,  193, 3370,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1264,    1,  387,  572,    1, 1698,  356,  390,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  952,  764,   32,  250,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3101,    1,    1,  350,   32, 3339, 3133,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1321, 2544,    9,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  697,    9,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3315,  920,  581,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1167,    1, 2881, 1718,    1,   32, 1698,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160,    1,  407,  191,    1,  118,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3043,    1,  114, 2414,   32, 1771,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  976, 1064,   37,    1,   37,    1, 1429,    9,  909,  686,   69,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,   12, 2648, 2801,  387,   91,    1,    1,  275, 1273,  618,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  634,   32,  365, 2731,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  799, 1414, 3228, 3103,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  884,   98, 2355, 1013,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3113, 1761, 1326,  132,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,  362,    9,   20,   32,  296,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  730, 2614,    1, 1211,  639,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3121,  431,  409, 1312, 1530,    1,    1,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1380,    1,   98, 2056, 1151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  176,  177, 2335, 2572,  191,  567,  510,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1, 1705,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  872, 2770, 2977, 2978,  210,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2069,   74, 2094,   39,  183, 2242,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2227,    1,  105,    1,  105,    1,    1,  220,    1,   45, 2910,\n",
      "          361, 1346,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  315, 2102,    9,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1, 2549,    9,  434,  829, 2515,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,    1, 2016, 1867,    9,  730, 1571,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3064,    1,    1,  439,  914,  220, 2540,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196,    1,    1,  613, 2123,  548,    1,  915,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3363,    1, 2784,   37, 3343,  787,  548, 2328,  640,   27, 2585,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1364, 1365,  267,    1, 2843,    1,    1, 2024,  142,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,    1, 1604,   98,    1, 2515,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3020,  187, 1373,  191,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1053,   22,  744,    1,  372,   20, 1250,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1572, 1414,    1, 2029, 1619, 3391,    1,   22,  868,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,   37, 1174, 3339,  797,  589,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1204,   61,  227,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  803, 2983,    1, 1204, 1159, 1691, 2813,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,   12, 1675, 2494,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3226,    1,   37, 1306,   56,   37, 1700, 2119,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2225,  190,  713,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2050, 1114,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2626, 2623,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3204, 3145,   37, 2410,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1538, 1140,   79,  477, 1969,  630,  220, 1386,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  942,    1,  453,  164,  165, 1563,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3203, 1610,   32,  449, 1385,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1922,  320,  653, 1412, 1204,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1003,    9,    1, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2197, 2331,  460,  321,  726,  142,    9,  478, 2826,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1733,   37, 1734,  700,   98,    1,   60,    1,  176, 1319,  187,\n",
      "          395, 1310,   37,    1,  954,  101,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,  109,    1,  155, 2326,   32,   49, 2426,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3219, 1589, 2317,  786, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,  63, 166, 862,   1, 338,   1, 419,   1,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  25,  66, 526, 176,  26,  69,   1,  28,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1585,  640, 1850,  531,  965,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973, 1173,   37,  103, 2388,  171,   98,    1,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1639, 1803,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  816,    1,  107,   76,   37,  125,  109,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   39,    9, 1056, 2119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2102,    1,    1, 1230, 2610, 2544,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,  632,    1,    1,    1,    1,   32,  245,  176,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  274, 2629,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  328, 3187, 2250,  176, 3328,    1,  902,  439, 1044, 1844,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  957,   37, 1694,   32, 1405,  133,  776,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 208,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 727,   1, 166,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  310,  225,  616,  123,  410,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1755, 1499,   51,  193,  764,  176,  810,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,  160,  620,  293,   37,  686,  131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2171, 3134, 2962, 2628, 1249,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  190,  211,  284,  626,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593, 2522,    1,  206,  920,  105,  183, 2773,   32,  273,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   56, 1530,   32,    1,    1, 2950,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1707, 2362,    1,    1,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  738,  220, 2224,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  601,  671,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  695, 2141,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2368,   39,   45,  460,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2809,    1, 1330,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  151, 1842,  669,   32,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  170,    1,   14, 1110,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  393,  267,  460,  190,  125,  388,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3251,  221,    1,  105, 1633, 1516,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2792,  288,   37,  877, 2236,  512,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2565, 2562,  199,   37,  619, 3308,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   72,  401,  197,  338,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1151,   15,   28,    1,  118,   32, 1352,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428,    1, 1248,    1,  191, 3147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1717,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  874, 1774,   39, 2798, 1412,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  794, 2102,  413,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2492,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,  659,   61, 2812,    9, 1718, 2264,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  116,    5,    1,  991,  299,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1640,  828, 1248,  147, 1398,  612, 1211,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2945, 2874,   45, 1023, 1204,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  572, 1347,   98,  166,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1116,   32,    1,    1,  554,   98,   40,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1542,    9,    1,    1, 2699, 1821,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3099,   12,    1,    1,  140, 2376, 2024, 2223,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1716,  155,  327,  157,    1,  392,  570,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1625,    1,  187, 2308,    1,  154,  360,  315,   37,  439, 1756,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2179, 3080,  949,  105,  822,    1,    1,  267, 3371,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1980,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32, 1656, 2909,   32, 1850,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  896,    1, 1308,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433, 2107,   96,    1,   32, 1440,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  449, 1173,  803,  112, 2089, 2515,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3080, 1284, 1515,   74,    1,  202,    1,   32,  147,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3376, 3345,  949,  547, 1428, 1149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043,  980,    1,  417,   69,  102,  764,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  326, 1353,    1, 2575,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3322,    1,    1,   39,  569,    1,  979,  220,  705,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  398, 1360,  612,  222,  386,  573,  315,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1341,    1,  187,  855,   45,    1, 3154,    1,   45,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  136,    1, 2759, 2515,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,    1,   28,  116, 2542,  218,  332,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3192, 2236, 1321,  384, 3334, 3273,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1993, 1836,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2225,   37,  168,   98,  810,    1,  124,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1533,    1,    1,    1,   51,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1292,  493,   85,   98, 2211,  269,  108,   45,  467,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1083,   32, 2212,  861, 1639,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1442,    1,   98, 2292,  444, 2161, 2770, 3369,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3303, 2660,  119, 2674,  427, 1343, 1684,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  924,    1,  193,    1,    9,    1, 2162,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  529,  102,   37, 1251,  793,  293,   28,   37,   54,  424,\n",
      "          356,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,  267, 1360,  612,   52, 1532,   37,  439, 3107, 3366,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,  404,   37,   52,  786,  872, 1131,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  811,  361,    1,   37,  907,  220,  964,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1577,  765, 1750, 2516,    1, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1906,    1, 1839, 3037,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,  551,  552,    1,  731,   98,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  288,    9,    1,  865,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3241,    1, 2644,   37, 2611,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,  395,   12,    1,   37, 1786,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  147,    1,   98, 1842,  207,  412,  804,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2779,  901,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,   12,    1,  590,  469,   37,  319,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  361,    1,    9,  275, 1149,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1584, 1094,    1,    1, 1000, 1515,  248, 2024,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2031,  515,   28,   98, 1718, 2606,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2278,  884, 2759,    1,    9,  105,  559,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428,  663,  475,  267, 3369,    1,  249,   45, 3118,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  764,  634, 1537,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,    1,   37,   10, 2681,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2580, 2851, 1757,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  331,  551,   12,  267,  752, 1220,  198,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790, 1579,    1, 1983, 2078, 1151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,  705,    1,    1,   98,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463,  464,  437, 1877, 2154,  477,  297, 1384,  652,  302,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1, 2366, 3004,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275, 1112, 2466,   51,    1,  938, 2591,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 342,   1,  37, 829, 199, 421,   1, 132,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  37, 130,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  997,   45, 1066,   32,    1,  437,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3402,    1,   61, 1231,  297,    1,    1,   37, 2856,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  691,   12,    1,    1,   37,  125,    1,    4,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,    1, 2902,    1,  207,    1,  347,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  291,   37,    1,  365,  280,    1,    1, 2359, 1135,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2803, 3265,   98, 2069, 1343,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1176,  445,    1,    1,  193, 2398,    1, 3000,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1920, 1236, 3227, 3178,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3242, 2270,   37, 2904,  792, 1264,  792, 3177,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  972,   37,  665,  448,    1,   98, 2378,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  241, 2292,  640,  531, 1633,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3194, 3195, 3272, 2513, 2132, 1252,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3129, 3210,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  220,    1,  640,  105,  340,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   79,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106, 1518, 1013, 1522, 1017, 2677,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    9,    1, 2891,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  244, 1285,   28,  187,   15,  664,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  107,    6,   69, 1069,   37,  429,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 1771,  171,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1837,    1, 2802,  140,    1,  705,    1,  633,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  638,    1,   37,  439,  104,   26,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2107, 1750,    1,  436,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280,    1,   37, 2107,   32,    1, 2472,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1405,   37,  138,   59,   32,  869,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3326,    1, 1061,    9,    1,    1,  440,  134,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  388,  389,    6,  972,  176,  294,  295,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220, 1340,    1,    9, 2218,    1,  824,    1, 1752,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1271,    1,  552,  551,  517,  490,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,    1,   28,  365,    1,    1,    1, 2348,  259,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1321,  384, 1764, 1990,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  291,  675, 2373,  810,   32,  786, 2706, 2639,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  884,  522,  444, 1407,  217,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2231,   37,  720, 2930,   44,  444, 3311, 3310,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,    1, 2483,    1,   45,  247,  442,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  590, 1161,   32, 3128,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  105, 1298, 2724,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,   12,  484,    1, 2353,  627,    9,  647,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  794, 2333,  676,  117,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2942,   98,  454,   37,  638,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1100,   30,   79, 2071, 1331,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1284, 1159,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  845,  275,  661,   37,  764,    1, 1731,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  768,  400,  444,  848,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2702,  298, 2886, 2582, 1056,  357,  547,    1,   37, 2446,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340,  640,  590,    1,   32, 1110,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  103, 2635,    1, 1627,    1,    1,    1,  401, 3179,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1021,    1,  326,   12, 1718, 1851, 2232,  260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  111,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3266, 2651, 2615,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  927,   45,  590,   16,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1945, 1727,  187,    1, 1008, 2224,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1287,   37,  688,    1, 1564, 3295,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2305,    1,    9, 3154,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3263,  726,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 2751, 2596, 2597,    1,    1,  686,   69, 2054,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  942,  147,  261, 1230,    1, 2189,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3158, 3297,  852,   55,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2414,  103, 3374,  650,   32, 3140,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  485,    1,  737,  156,  245,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3066, 1631, 1159, 1092,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  750,   25, 1253,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  755,    1,  758, 1289,  365, 2194, 2043,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  295,  162, 1084,  260,   92,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3064,  683, 1249,    1,   37,  759,  581, 1385,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,    1,  387,  388, 2690,   98,  627, 1975,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1505,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1174, 2208,   32, 1422,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  691,    1,    1,    1,    1,    9,  854, 2579,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1082,    1,   37,    1,   37,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,    1,    1, 2468,  297, 2702, 2909,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190, 1343,   32,    1,  669,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2603, 1781,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2321,  429,   98,    9,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,  951, 1547,  187,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  542,    1,  176,  439,   45,  593, 2522, 2769,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1965,  927, 2797,   98, 1338,   45,  977,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2317,    9,    1,   45,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 1376,   98,  109,  509,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2423, 1338, 2463,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2206, 2207, 3183,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  598,   37, 1343,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  992, 1159,  166, 1551,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1189,    1,  741,    9, 1855,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2977,  582,  992,   85,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3069,  113,    7,   46,  220, 1094,  361, 1891,   78,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  162,  764,  384,    1,    1,  326,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,  165,   30, 1677,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3141,  571,   37,    1,    1,  664, 3201,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,  672,  388,  763,    1, 1354,   32, 1037,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2658,    1,  356, 1691,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3045,  686, 2597, 1606,  220, 1957,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1700, 2827,  548, 3379, 2950,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3083, 1734,   32,  454,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2867, 2226, 2969,  618,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,  162, 1425,  861, 2298,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1307,   12,  645, 1775,  515,  105,    1, 1470,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1668,    1,  444,  449, 1891,  872,   32, 3308,  427,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  709,  391,   76,   37,  726, 2823,  863,   32, 1081,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311,  733,  331,    1,  176,  105,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1965,    1, 2382,   12,    1,  661,   32,  166, 2391,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715, 2095, 2985,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1118,   95,   45,    1,  880,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503, 2257,    1,  195,   79,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  187,  526,    1,    1,    1, 2105,    1,    1,  997,    1, 1160,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1674,    1,   74,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  294,    1, 2889,    9, 1204,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,  588,    1,   45, 1204,   32,    1,  176, 1965,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2226,  331, 2059,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  893,   81, 2266,  220,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,   98, 2764, 2765, 2985,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   82,  738, 1537, 1065, 1190,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1701,  260,   28, 2072,    1,  365,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2266, 1484,    9,    1,  522,   32, 3369,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  744, 2841,   81,   98, 1434,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  132,  431,   98,  531,  734,  322,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  691,   12, 1312,    1,  590,  315,   37,   47,   48,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785, 2044,   12,  449,   26,  776,   45,    1,    1,  191,  398,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  236,  237,    1, 2819,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384,  121,  220,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  754,  102,  729, 2066,    1,    1,  774,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  208,  884, 3134,  671,    1,  104,   42,    9, 3077,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  680,    1,    9, 1890,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2188,  864, 2673, 2118,  548,  365, 2945,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  963, 2102, 1107,  525, 1961,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1477, 1990,  542, 2149,   37,  335, 2621,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  742, 1268,   46,  220, 1973,  187,  386,  542,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1675,    1, 1816,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,   32,  166, 2301, 2012,  203,  786, 1841, 1287,   37,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1515, 1530,    1,  187,    1,  187, 1515,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1454, 1111,  517, 1992,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2528,    1, 2957,   12,  365,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,  983,   28,  118,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2695, 1284, 1778,  535, 1863,  328,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2279,   12,  142,   37,    1,  942,  223,  100,    1,  176,  915,\n",
      "            1,    1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2801,  640,    1,  613,   29,    1,   32,  517, 1867,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1128,  794,    1, 2695,  361, 2695, 1917,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1411, 2842,   32,    1, 2359,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1759,  309, 1802, 2122,  267,  249,  729, 1210, 1698, 3093,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 2924, 2155, 2708,  220, 2596,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,   28,    1,  338,   66, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,  812,  121,  651, 1259,  221,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,  434, 1411, 2273, 1821, 2328,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1937,  388,  495,    1, 1633, 1278,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2171, 3134, 2628,    1, 2570,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1509,  151,  315,   37,   47,  176,  551,  612,   80, 1108,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2202,    1, 1425, 3132,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3348, 2042,  610,   37,  611,    9, 2189,  112,    1,  220,  976,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  198, 2409,    9,  397,  389,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,   61, 1229,   37,   52,  123,   37,    1,  142,  191,  148,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2126, 1976,   32, 1013,    9,    1,  770,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  552,    1, 1117,    1, 2226,    1,    1,    1,  162, 1217,   37,\n",
      "         1289,    1,   32,  501,    1, 1255,  963, 2122,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 978, 769, 245, 187, 331, 932,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 552, 551, 405,  37,   1,  28,  37,   1,   4,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3233,  726, 1114,    1,    1,   37, 2941, 1625,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870, 2344,   81,   37,  466, 2910,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  331,    1,  612,    1,  105,    1,    1,   59,   98,    1, 1600,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3010,   12,    1,  952,    1,   32, 1002,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1363, 1660,  339,  158,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 3185,    1, 1564,  460, 2177,   37,    1,    1,   61,\n",
      "         1805,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  596, 1793,    1, 2822,   37,   69,    1,  493,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390,    1,    1,    4, 2402,    1,  580, 1251,    6,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1013, 1522, 1912, 2436,  361,    1,    1, 1101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162,   45, 2333, 2527, 1554,  627, 2353,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2838,  498,   37,  786,  356,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  449,    1,  872, 1524,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326, 2753,  182,   32,    1, 1495,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398, 1004,  658,  522,   98, 1147, 1038,  966,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  978,  769,  439,  417,    1,  425,  426,  246,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  218,    1,  115,  548, 2761, 2094,    1,   37,  439,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   98,  736,   12,    1,    1,    1,    1, 1263, 2928,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  223, 2420, 1275,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2646,  105, 1918,    9, 2325,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1884,    1,    1,    1, 2856,   32,  395,   12,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1965, 1456,  387, 1803,   32,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903, 3085,    1,    1, 1463, 1558,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,  640,  339,  340,  951, 1547,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178,    1,    1,   36, 1763,   32,  403,  404,  395,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  614, 1183,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422, 1093,  574,    1, 1822,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  342, 1484,   98, 1094,   37,  439,    1,   98, 1850, 3339,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   47,   79,  636,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,    1,    1,    1, 1640, 2784,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12, 1698,  846,  115,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275, 1388,   98,  171,   45,  954,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 3030, 2770,    1, 1585,  778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2328, 1260, 2414, 1147,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1807,  389,    1,   37,  712,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  667,   60,  418,   63, 1619,  458, 2696,   12, 1819,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,   37,  166,  311,  994,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,  459,  116,    5,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,   12,  587, 1046,  365,  686,   37,  138,    1,  869,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2176, 1648,   37,    1,  985, 1580,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   12,  365,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2004,  112,    1,   37,    1,  326, 2043,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 2178, 2179, 2778, 1505,  129, 3057,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2776,  863,   37,    1, 1016,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123, 2246, 3271,  877, 1354,   45, 1573,   32, 2295,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2615,  688,   28,  730, 2614,    1,    1,  631,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1816, 1099, 1453,  733,    1,  131,   32, 1879,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3184,   12,  449, 1920,    1, 1484,    9, 1945,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1012,    1,   37,  169,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2990,   51, 1188,  377,    1,  763, 2112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   12,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2638, 2931, 1665,   37,    1,  778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2098,   85,  166, 2954,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 3146,    1,    1, 2129,  384, 1430,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178, 1634,   37,  903,    1, 1256,    1,  876,    1,  267,  204,\n",
      "           12,   73,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2226,    1,   45, 2310,  248,  895,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  208, 2652, 2494,  872,   12,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1585, 2783, 2764,  404,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  220,    1,   32, 3376,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  173,  424, 1230,    1,    1, 2261,  187,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,   37,  130, 1074,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  651, 1031, 1621,    1,  596,    1,    1,  716,  774,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2424,  632, 1463,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,  32,  95, 617, 618,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 288,  37, 865, 951,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   15, 1021,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1204,    1, 2518,  361,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1712,    1,  191, 1718,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,  783, 1519,    9,  449,  199,   32,   56,  257,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1258,   37,  184, 2198, 2347, 2942,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228,  365,    1,  384, 2159,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1492,  614, 1221,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2645,   37,   81, 2009,    1,  202,  822,    1,    1,    1, 2018,\n",
      "          967,  365, 1065,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2753,  187,    1,  688,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2710, 2774, 1439,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  858, 1991,  191,  118,   45,  111,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311,  725,  333, 1086,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   32,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1937, 2854, 2856, 1914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2360,  166, 2855,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  726, 2034,    1,  449, 1394,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  396, 1383,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   37, 1075,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  419,   98,  195,  776, 1578,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479, 2422,   77,  650,    1,  176,  827,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  398,    1,    1,    1, 2638, 2931,    1,  625,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,   74,    1, 1517,    1, 1169,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  314,  551, 1692,  570,    1,    1,  225, 1226,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1031,   98,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  104,  819,  973,   60,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  683, 1086, 1705,   37,   47, 1021,  112,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2801,  603,    9,  196,  132,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   89,    1,  247,  198,   60,  143,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3103,  130, 2761, 2477,  384, 3247,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1449,  613,   37,  151,  963,  413,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1,  321, 1403,  183,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  669,    1,  777,   37,  844, 1089, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  967,    1,    9, 3227,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3249,  726, 1238, 1684, 3010, 1804,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  487, 1325, 1914,    1,  908,  214,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1917,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3325,  162, 2174,   32, 2809,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2971, 2896,    1,    1,  193,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1877,    1, 1511,  220, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 1158,   12, 2102,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1458,  535, 1860,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    6,  570,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  627,   12,    1,    9,    1,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228, 1574,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  242,   98,   69,  636,  591,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  960,   32, 1081,    1,   85,  548, 1665,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1089,   30,    1,   45, 3365,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3285,    1,  726,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1663,    1, 2286,   37,  439, 3144, 1512,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2057,  580,    1,  230,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  744, 1056, 2078,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 2656,  104,    1,  342,   32, 2589,  220, 3374,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2028, 1679, 2674, 1156,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  898,   37,  665,  453,  327,  112,   28,    9,  333,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1698,    1, 2145,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  440,    1,  807, 1239,  448,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   71,  361,  245,   45,   69,  102, 1578,   32,  105,  410,  570,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  108, 2751,   37, 1598, 1450,   32, 3118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  420, 1082,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  475, 1229,   37,   52,  103,    1,    9, 1007,    1,   12,\n",
      "            1,  163,    1,  389,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  361, 1051,   32, 2798,  861, 1832,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  849,  967,    1,  315,    9, 2831,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 3160, 2399,   37,  764, 2764, 2765,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2954,  220, 1955,   98, 1067,    1, 1656,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1380,  438,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  144,  145,    1,  159,    1, 1010,    1,   46,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,  417,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965,    1,    1,   51,   52, 1578,   45,  238,  522,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  491,    1,  492,  493,  112,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2384,  365,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1707,   97,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1956,   57,    1,   45, 1529,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 1447,    1, 3107,  123,   37,    1, 2596,  529,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   69,   92,   37, 1656,  627,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  304,    1,  236,  237,  186,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,  879, 1193,   32,    1,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1123, 2246, 2633,  489,  166, 3260,   73,   81,   37, 3024,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671,    1, 2525,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  197,   79,  176, 1256,    1,  552,    1,  485,  605,    1,  187,\n",
      "          800, 1569,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  602,   12,    1,  353,  572,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  848,   12, 1352, 2050,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1209, 1268,  187,    1,    1, 2639,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1755,    1,  632,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   37,    1,  822,  522,  444, 1617,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1013, 1381,    1,   37, 1089,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3094, 1061,   32,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1411, 2273,  632,    1, 2030,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1778,  443,   45, 1886,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   65, 1680,   67,  191,  401,  402,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090, 1380, 2308,   32, 2275,   12, 3072,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3177,  729,  967,  247, 2364,   98,  922, 1684,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  216, 2856,   56,    1,    1,   32,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   63,  166,  862,  348,    1, 1170,  670,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  655, 1061,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  282, 1675,  193,  183,   32,  455,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 3341,    1,   37, 2276,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1, 581,  32, 247, 865, 754,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 550, 271,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1,    1,    1,  815,   45,   23,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,   98,  105, 2365,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3108,    1, 2017, 2615,    1,    1, 1724,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1651, 2456,    1,   32, 3387, 2985,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  818, 2791,   53,  176, 1611,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203,  166,  487, 3222, 1924,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2447, 2471, 2522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1334,    1,  795, 1131,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3302,  637,   39,    1,   37,    1, 2308,    1,  361,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  542,    1,  386,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1748,   45, 2662, 2704,    1,    1, 2607,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  272,   39,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1094, 1542,   37,  470,    1,  548, 3358,  928,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973, 2422,   37,  360,  742,   12,  331, 1178,  163,  142,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1485,  449,    1,  294,    1,  581,   32,    1, 2472,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790,    1,  267,    1, 1961,  749,  506, 1167, 1976,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,   37,    1, 1023,   45, 2571, 2699,   32, 3118,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,   37,   84,   28,  443,   98, 3006,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1076,  952,   37,  151,  671, 1078,   32,    1,  131,  132,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1009, 1216, 1255,   32,    1, 1512,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  305,  186,    1,  685,  686, 1034,  687,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  565,  410,  187,   69,  102, 1473,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3270,  140, 3313,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  723, 1362,   41,   37, 1306,  572,   15,  739,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  506,    1,    1,   32,    1,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384, 2780,   37, 3045,    1,   12, 1354,    1,   28, 1886, 2535,\n",
      "          166,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  793,  662,    1,   32,  147,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1,  537,   45,    1,   32, 1675,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,  531,  191, 1428, 2108,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1617, 2357,  104,  221,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  715,  650,    1,  632, 2638,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433, 2591,   37, 1496,  543,  384, 2559,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977,  475,    1,  405,    1,  939,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  773,  818,   15,   71,  425,  426,    1, 2072,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3128,  536, 1479,  531,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3207,   12, 2840,  894,   52,    9, 1674,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  251,   37,  151, 2326,   32,  455,   12,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1926, 1927,  729,  176, 2738,  537,  548,  104, 1450,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  667, 2416, 3060,    1,  580,  104,  622,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2693,    1,  187, 1104, 1117, 1525,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  696,   32,    1,    1,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275,  147, 2911,   32,  365, 1212,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1454,  657,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3102,    1, 2491,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1399,    1,   12,  724,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,   12,    1,  200, 1938, 3057,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1295, 2449, 3156,   32,    1,  493, 2960,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,  613,  733,    1, 2665, 1671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  613,    1, 2054, 1401,  166,  454,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163, 1442, 2581, 1230,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3230,    1,  683,    1,  384, 1674, 3282,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189, 1654,  600,   59,  104,   32,   72,  401,    1, 1023, 2007,\n",
      "           37,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1017,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1, 2196,    1,    1, 1973, 2153, 2243, 2024, 1907,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  992,   28, 1462,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999,   91, 1994,  934,    1,  923,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2617,    1,    1, 2632,   32,  596,  861,  777,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  733,  403,  294,  960,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1662,  442,  437, 1536, 1994, 2086,  767,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2217,   12,  365, 1277, 1921,   32,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2764,    1,   32,   12, 1447,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,  446,  744,   39,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  579,   12, 2249,   32,  829, 2997,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3087, 2478, 3097,  590, 3307,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3167, 2110,    1, 1834,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2046, 2404,  884, 2024, 1263,   37,    1, 3079,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,  25,  28, 615,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 183, 132,  32,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1237, 1739,  616,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2959, 1586, 2882,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  920,    1,    9, 1658,  327,  282, 2367, 2695,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1716,  155,  327,   93, 1470,    1,  392,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1427,  591,    9,    1,  187,  896,    1,  796,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1085,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 1834,    1, 3341,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3102, 2068,  640,   39,  297,  947, 2625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3151,  154,    1,  474,   37,  907, 1411, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2090,    1,  975,  716,  242,  572,  156,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3333,  683,  227,  427,   28,    9, 2841,    1, 1628,    9,  284,\n",
      "           32,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947, 1761, 3403,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1, 2860, 1313, 2266,  798,   98,  531,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111, 1959, 1688, 1167,    1, 2534,    1, 1205,    9,  133,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2523,   37, 1348,    1,   45,    1, 1090,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1090, 2677,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 2373,    1,  272,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2162,  927, 2156,   32, 2379,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564, 2895, 1604,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393, 1149,    1,  220,  591,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  691,  335,  631,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2144, 2095, 2985, 1231,   32, 1186,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 1992, 1010,  430,  555,  997,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,    1,   32,    1,   54,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3252, 1478, 1383,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307, 2776,    1,   37,    1, 1871,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2855, 1620,   79,   98,  275,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3310,  776,  891,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3402, 3408, 2322,    1,   32,  602,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   37,    1,  978, 2953, 2334, 3004,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  457, 2328, 2728, 1478,   32,  878,  548,   95,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,   27,  687,  548,  800,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3250,    1, 3290,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1,    1,    9,  622, 2673, 1604,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  678,   89,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,    1,  389,    6,   98, 1171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  572,    1,    1,  861,    1, 1294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 1641,   37, 2723, 2724,    1,    1, 1458, 3016, 1935,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1, 1976,   98,  581,  851,   32,  121,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974,  614,    9, 1411,   95,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1009, 3090,    1, 2564,   98,  247, 1204,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,  103,   32, 1306,  593,    1,  140,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2919,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  764,    1, 2657,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  224,    1,  785,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1173,   37,    1,   85,   98,    1,  195,  815,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  876,  612,  288,   37,  877,   69,    1,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1, 1273, 1140, 2587,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597, 3101, 1583,  475,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2149, 2250,   98,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 3345,    1,    1,   98,  163,    1,   12,    1, 2860,   32,\n",
      "          531,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1039,    1,   37, 2192,   28,  163,    1,   12,    1,  442,  317,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2649,  571,  759,  786,   59, 1428,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3361, 1399,   45,    1,  176,    1,  778,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700, 2572,   32, 1815, 2292,    1,  947,  271,   28, 2357,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,    1,    1,  590,    1, 1739,  105,  331,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   93,   67,   45,  954,    1,  242,  297,  478,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  503,    6,  388,    4,  187,  156,  276,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1060,  420, 1075, 1638, 1916,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 197,   1,   1, 305,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  61,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,   28,   32,  166, 1089, 1090,  293,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,   59, 2695, 2223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   26,   85,    1,   69,   28,    1, 1138,  108,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230,    1,  220,    1,  548,  537,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  239,  297,    1,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1461, 2414, 3374, 3384,   32, 3339,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3263, 2565, 1247,  571,   37,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 1405,  232,  513,  514,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  551,    1,  730, 2393,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1630,  792, 1469,  792,  384,  137,  105,  311, 2502,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1949,   59, 1126,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  734,  591,    9,  531,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1033, 2211, 1726,  943,  442,    1, 2832, 1523,  220,  947,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2095,    1,   12,  667,  315,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3332, 1564, 1245,  714,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  292,  365, 2043,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  361,  342,  851,   46,  168,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  180,    1,    9,  166, 3154,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  172,    1, 1335,  514,   32,  927,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  747,    1,  746,    1,   37,  349,    1,    1,  150,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3066, 1820,    9, 2839, 1388,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1107,  441, 1753,    1,  297, 2733,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  160, 1161, 1556,  388,  763,   76,   32, 1352,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2862,    1,  854,   37, 1421, 2532,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  140,    1, 1918,  297,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2774,  650,  776,    1, 1159, 1803, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  828,  221, 1750,  132,   98,   64, 1527,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  284,    1,  844,    1,    1, 1699,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 1447, 1536,    1,   98,    1, 2485,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,  614, 1273,  220, 1013,  361, 1748,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2179, 2344,  972,   37,    1,    1,  157,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,  361,  864,  123,   37, 2673,  529,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129, 2948,    1, 2104, 1082, 2977,   37, 1539, 3033,   37,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  347,  606,    1,    1,  267,  787,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  551,  903, 2058, 2017,    1, 1045,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  305, 1269,  202,  840,    1, 1071,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,  459,    1,    9,  784,    1, 1069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1326,   12,    1,    1,   37,   52,  166,    1, 1736,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  566,  187,  567,  431, 1549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1891, 3146,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1016,    1, 1248,  531, 2128,  741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  944,    1,  733,    1,   50,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 2414,   32, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3358,   37, 2354,   37,  447,    9, 1983,  351,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1084,  841,    1, 1083,  183,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1570, 2192,  357,  335,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  132,    1,  460, 1159,  593,  218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1687, 1022, 3008,    1,   32,  104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  114,  629, 2134,   22,    1,  480,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,  477,  522,  640, 1853,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,    1,   39,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2596, 1585,   32,  336, 2414, 1056,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2279,  267,   10,    1, 1590,  590,  315,    9, 1821,  279, 2375,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1089, 1090, 2407,  792, 2692,  792,  105,    1,    1, 1167,    1,\n",
      "         2853,   28,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 1239,  315,    1,   12,    1, 1904,  315,  183,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   37, 2819,    1,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  515,  104,  358,  562,   37,  125, 1149,  138,  191,  118,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1364, 1365,  688, 2018,   32,    1, 1463,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1660,  158,    1, 1353,  752,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  852,  115,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545,  162,   81,   37, 2315, 1262,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  617,  618, 1167,  544,  460,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  485, 1948, 1644,    1,    1,  939,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,    1, 2531,   37,  943, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035,  146,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,  155, 1184,  347,    9,  449,  199,   32,  537,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1811, 1280,   61,    1,    1,   45, 2643,    5,    6,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3016, 1935,  437, 2023,    1,   50,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2149,    1,    1,    1, 1240, 1343, 1632,  888,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2845,  317,  187, 3092,  475, 1213,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1426,    1, 2390,  132,  220,  342,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2844,  548, 1997, 1061,   32, 2490,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2238,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3143,    1,  191,    1,   12, 2339, 1928,   45,  215, 2658,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,   81,  754,  548, 2133, 2456,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,  636,  332,    1,  631,    1,  187, 3337,  361,    1,\n",
      "         1306,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  656,   61, 2067,   55,  105, 3252, 1114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1100,   12,    1,    1,  191,  829,   12,  784, 1118,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1791,   32,  597,  702,  494,  400,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2881,  246,   32,   98, 1778,  951,    1, 1718,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2013,    1,  400,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2859,    1,    1,  164,  165,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783,  879,    1,   24,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2700, 1865,    1, 2655,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1607,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2737,    1,    1, 2556,  797,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1008,   32,  166, 1090,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1200,  315, 1107, 1089,  777, 1996,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766,   12, 1935,  967,  460, 2487, 1262,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  570,  125,  191, 1721,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2538,  698,  388, 2205,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  163,    1,   12,    1, 2548, 2572,   32, 3343, 1345,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,    9,  388,  230,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1527, 1149,    1,  187, 2292,    1,   32, 3118,  176,  177,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,    1,  729,   32,  915,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163, 1230,   37,    1, 1378,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  571,   37,    1, 2741,   81, 1559,  444,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1123,  892,  428,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  353,  417,  572,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  225,  269, 1337,  605,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  212,    1, 2417,  402,   37,    1,    4,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2896,    1, 1520, 1584, 2723, 2724, 1343,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  700, 1713,   26, 1039, 2657,    1,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1984, 1484,   80,    1,  440,    8,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1428,  531,  861,   23,   37,  582,   39, 1411,  339,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1149,  176, 2618,    1,  250,   37, 1313,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190, 1628,  550,   52, 1628,    9,   10,   32,  863,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,   28,  453,  750, 1058,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 1407, 1190,  577,   98,  403, 1447, 2673,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3349, 2617,    1, 2198,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  213,   37,  151,    1,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  200,    1, 1542,  288,  103, 1510,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1729,    1,  606, 1752,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977, 2415,  284, 1647,   32, 1809,    1, 2219,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  778,   61,  282,    1,   45, 1158,  802,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2582,  166,  917,   37,  125, 1021,  176,  433,   45,\n",
      "            1,    1,    1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,   45,    1,    1, 1071,  649, 2003, 1746,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 3400, 2055, 1204,   32,  455,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707, 2424,    1, 2690, 1511,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  912, 1294,  967, 1183, 2041,   37, 1778,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  608, 2551,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,    1,    1,   32,  955,  662,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  460, 1924,  105, 1628,  221,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1652, 1380, 2355, 1718,   37, 1604,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1723,  261,    1, 1450,  254, 1056,    1,    1,   51,    1, 2695,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   96,   85,    1,   54,    1,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141,  435, 1936, 1675,   37,  395,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  138, 1146, 1470,  983,   34,    1,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,  170,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2881,   98,  861,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2546,   37,  693, 1467,  116, 2943,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1545, 1249, 3187,   37, 2035, 1045,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  462, 1353,  453,   69,  112,    1,   37,  151,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,    1, 1857,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1,  365, 1013, 1522, 2043,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,    1,  741,    9,  365, 1984,  872,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1433,    1,   12,  151,   61,  227,  550,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  846,  261,  176, 2689,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  892,   12, 1090,  469,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2080,  517,  726, 1380, 2802,   32,    1, 1218,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,  102, 1150,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  398,    1,   59, 1634,   37,    5,    1,    1,   37, 2617,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  354,   61,  105, 2771,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,  387,  638,  916,    9,    1, 2708,  171,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  502,  770,    1, 1994, 3036,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,   37,  151,    1,    9,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3202,    1,  571,   37,  395,   37, 3141,    1, 1090,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  223, 1229,   37,   52,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  632,    1, 1377,   37, 2751,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,   28,   98,  169,  132,    1,  202,  682,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2107,  290,  640, 2205,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2765,  396, 1260,   98,  104,    1,   32,    1, 2606,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1393,    1,  150,   37,    1,   59,   32, 1799,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,    1, 1201,    1,  267,   37,  125,    1,    4,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3236, 3237,  162,    1, 1624,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1785,    1,    1,   81, 3088,  443,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  903,    1,  531,    1, 1386,    1,  812, 3391,  270,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3345, 2253,   37, 2856,  649,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  350,    1,    1,    1,    1,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  987,  384,  166,  608,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,   12,    1, 1890, 1240,   52,    1,    1,  191,  889,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  253,   37,  907,  187,  669,  246, 1610,  251,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1212,    1,  455, 1421, 1211,  442,  630,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612,  619,    1,  191,   33,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2847, 2566,    1,   45, 1922, 2721,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  657, 1419,    1, 1151,   37,  410, 2407,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2988, 2690,    9, 2987, 2762,  820,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,   12,  606,  889,   37,    1,  857,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299,    1,    1,    1,    1, 1879,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  340, 1021,  613, 2146,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   63,  166,  862,    1,    1,  189,   85,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2754, 3102, 1683,   32,  531, 1621,   32,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343,  147,    1, 1178,   37, 2162,    9, 2772,   45, 1407,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  219, 2005, 1587,   45,  388,  670, 1680,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1194, 2132, 1037, 2622,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3151, 1384, 2096,    1,    1, 1316,  163,    1,   12,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2662,    1, 2424,    1, 1463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  161,  544,  334, 2595, 1847, 1492,   12,   19,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3104, 2417,   16, 2139,  297,  395,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3215, 1877,   37,    1,  706,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  197,  418,    9,  758,  455,  778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3343,  806,  264,  528, 1508,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1033,  884, 1003,  176, 2189,    1,  442,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2789,  488,   37,    1, 3101,  876,  612,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1778,    1, 1188, 2786, 2432,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2789,   37, 1140,    9, 2024,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,  159, 1285,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  932, 1291,   98,    1,   32,  207,  197,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  119,    1, 2800,    1,  619, 1090, 1760,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  321,  612, 2446, 2701, 1021,  384,    1, 1684,   45,  593,\n",
      "           12,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358, 2617, 1373,   37,  211, 2895, 2162, 1867,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1935, 2294,  443, 1618,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2576,  361, 2070,  325,   81,  331,  159,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   63,  166,  862,    1,    1,    1,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2692,    1,    1,  166,  116,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  941, 1663,   37,    1,  400,  444,    1,  938,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458, 1408, 1184,  347,   98,  429,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  469,    1, 1186,   12,  502, 1525,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  500,    1, 1191,   37, 1835, 1651, 1607,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  968,   61,  593,    1, 1633,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,   37,  125,    1,  388,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  818,    1,  920,   98,    1,   12, 1638,   45,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1084,    1,   37,  221,   37,  786, 1589, 2225,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  198, 2164,  686,    1, 2921,    1,  455,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2484,  794, 1961,  517, 1108, 2013,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  485,    1,    1,  498, 1651, 1597,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523,   32,  590,    1,  548,  247, 2220,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  224, 1236,    1,    1,  297,    1,  133,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  786, 1494,   37,  750,   98,    1,    1,   74,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,   37,   36,   11,  640,   14,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 2336,  220,  365, 1778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  183,  802,    1, 1046,   45,    1,  293,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   12,  857, 1567, 2903,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  388, 1645, 2924,  565, 1866,   37,  557,  540,  187, 2292,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,    1,    1,  191, 1101, 2817,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  572,   12,    1,    1,  448,  703,   37,  119,    1,  372,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384,    1,   37,  135, 3009,  166,    1,   45,  255, 1833,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  376,  854,   12,   93,  570,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596,   32, 1850, 2597, 2414,  228,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  438,   12, 2674,   67, 1124,   32,    1,  166,  915,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  251,  192, 1085,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  882, 1401,  219,   25,  417,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965, 2982, 1937,  238, 1634,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1151,    1,  997,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403,  464, 2237,   37,  395,  792, 1894,    1,    1,  792,  463,\n",
      "         1447,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   42,  220, 1629,    1,  422,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1,  657, 1413, 1414,   98, 2894,  618,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1082,    1,  290,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,  155, 1184,   67,   37,    1,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  560,    1,   93, 1071,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2714,  865,   37, 1505,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  186,  187,   69, 1042,  185,  198,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2144,  947,   37, 1734,  776,    9,  517, 2292,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2647,  433,  102,   32, 2792,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974,  105,   95, 2017,  384,  331, 2223,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  339,  191,  339,    1,  105, 1199, 2214,   12, 2177, 1360, 2097,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2175, 1371,    1,   98, 1658, 1339,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3380,   37, 2346,   79,  622,    1,  191,  356,  439,  104,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   28,   37,  228,  671,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2, 350,   1,   1, 952,  67, 423,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,  39, 734,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  396, 1254, 2334, 1684,    9,  920,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1762,  698,    9,  447,   32,    1, 1990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  744,  818, 2975,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1, 1564,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1730, 1665, 1380, 1081,   98,  845, 2393,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2839,  193,   37, 1418, 2924,  384,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 365,   1, 496, 428,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 719,   1, 384,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   69, 1631,  104,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,   12, 1691,   91,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  126,    1,  384, 2693,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2041, 2784, 1086,   98,    1, 1318, 3214,  614,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1517,   12, 2925, 3210,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2313,    1,  335,   37, 2501, 2095,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 3247,    1,   45, 1796, 3372,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1818,  147, 1392, 1393,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3255,  474,    1,  729, 2040,   45,  865,   37,  522,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  307,  125,  176,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3215,   12,  311,    1,  967, 3242,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  364,  593,   12,    1,  388,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1, 2018, 1542,   37,  943,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3188,    1,  421,   32, 1022, 2163,  698,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,   28,  419,    1,  159,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2288,   45,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273,  274, 1900, 1542,   37,  693,  591,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,  548,    1, 1464,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422, 1360,  612,    1,  596,    1, 1359,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  683,  190, 2449,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  345,   37, 1116,    1,  506,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  682, 1298,  220,  726,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,   12,  391,  477,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  191,  166, 2015,    1,    1,   12,    1,  288,   37,  123,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  760,  197,   28,    1,  159,  245,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2661,    1, 1654,  863,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1136,  986,  331,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  369,    1,  159, 1253,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 538,   1,   1, 539, 540, 541,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 353,  72, 401, 354,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1252, 2503,  511,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994, 2749,   28,  777, 2995,  593,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  547, 1634,   37, 2397, 1156,   32, 2883,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1057,  297, 3349,   12, 1786, 1294,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1035,    1,   37,  168,   37, 1038,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   25,   26,  417,  187,   69, 1552,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 3141, 3009,    1,   37,  166,    1,   63,    1, 1617,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3132,    1,  167, 1306, 1694,   45,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1932,   37, 1237,    1,    9,    1, 1933,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713,    1, 1638,   45, 1463,  810,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  288,   98, 3229,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,    1, 2835, 2434, 3080,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   98,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2931,    1,  981,    1,  220, 2693,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1870,   12,  737,  354, 1052,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  381,    1, 1047, 2811,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3361, 1982,    1,  863, 1010, 2292,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 2548,  792, 2572,   32, 3339, 1585,  792,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  176,  177, 1530,  187, 1656, 2909,    1,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  874,  792, 2798, 1412,    1,  792, 2202, 1778, 1273,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,  105,    1, 1427,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325,    1,   12,  382,  112,    9,  105,    1,   59,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3300, 1737, 1090,    1,   28, 3079,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   51,  720,  647,  142,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,  766, 2177, 1027, 2776,    1, 1017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1065, 1190,    1, 3371, 2007,   32,  854,  892,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  411,    1,    9, 1989, 1990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777,  710,  884, 1361,   37, 2082,   98,   26, 1039,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  864,  774, 3385, 3146, 2179,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  227,    9,  224,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  321,    1,  460,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1211,   45,  888,    1,    1, 2188,  247, 1473,   32, 2788,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  232, 2411,   37, 1540,  297,  287,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   28,  528,  160, 1161,  550,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2596, 1665,  304, 1924,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  996, 1424, 1924, 2051,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1623,  729,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  121,  600,   37, 1046,  447,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3316,    1,  405,    1,    1,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3168, 1141,  608,    1,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1384, 2153,  588,   37,    1,    1,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1529,   45, 2618,   12,    1,  952,    1,   32, 1377,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  300, 2924,   37,  764, 1157, 2785,  591,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 1117,    1, 1417,    1,   61, 1229,   37,    1,  225,\n",
      "         1402,  191,  183,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2297,  187, 2741, 3164,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  199,  421,   27,  755,  399,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  645,    1, 1523, 1103, 1960,  166,  856,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2571,  474, 1082, 3369,    1, 2751,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181,  884,  631,   32, 2038,  922,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1203, 2686, 2687,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1833,    1,  973,   32, 2170,  313,   37,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3257,    1,   32, 2110,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,   98,    9,  613,   29,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2266, 1877,   37, 1496,  163,    1,  903,    1, 1346,  384, 1450,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835,  476, 3127, 1419,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1710,  334, 1012,  105, 2888,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2802, 1564, 2218,  220,  885,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  560, 1274, 1672,  915, 1034,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267, 3057,   46,  167,   52,    1,   32, 1890,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,  361, 2275, 1174,  736,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230,  951,    1, 3204,   32, 2490,   26, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 683,   1, 887, 991, 990,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 829, 200, 272,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  321,  204,   52,   55,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68, 1426,  885,  119,    1,    1,   27,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2526,  854,    1, 1536,   43,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233,  420,  267,    1, 1360,  612,  125,    1,    1, 2191,  460,\n",
      "          408, 2588,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101,  844,  267, 3358,  223,  967,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  466,  275, 2972,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1169,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,  958, 2073,  400,   45, 2623, 2624,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2980, 1450, 2894, 1273,  618,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,   37,  289,   98,    1,  652,  176, 1320,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  129,    1, 1268,  365,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1604,   23,  191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  198,  751,   37,  331,  551,   12,  752,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2898,   63,  334,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1759,  309,    1,  774, 2602,    9,    1,    1, 1002,  264,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3240,  267,  204, 2556,  199,   79,    9, 1841,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2252, 1026,  170,  167,   52, 1641,    9,  787,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  513,  193,  514,   37, 1995,  134,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147,  446,  267,  890, 1822,  168,  115,  215, 2488,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2226, 2233,    1, 2741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  147,  991,  454,    9, 3398, 1377,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  387,    1,  327,   93,  115,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2987, 2693, 1976,    1, 1704, 2492,  210,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3361,    1,  163,    1,   12,    1,  379,  907,   32, 2024,  142,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2721,  335,   95,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   42,  768, 2096,  297,    1, 1463,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1648,   37,  360,  104, 2304, 1228, 2351,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  492,   84,   28, 3348, 1942,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2405,    1,  439,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1139, 2113,   67,   70,  866,   98,    4,   29,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2452,  517,  199,    1,   45,  166, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1790,    1,    1,    1,    1, 2558,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602, 1042,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  726, 3246, 1684, 1114,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2693, 2865,   39, 1440,    1,  675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   68,  102,  288,  903,    1,  904,    1,  119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3075,    8,  365, 1377,    9, 2024,   32,  531,    1, 3388,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  217,  469, 2522,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2592,    1, 2084, 1064,   32,  537,    9, 1674, 1675,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2886,    1,    1,  459,    9,  730, 1571,    9,  914,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2496,  565, 1976,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2974, 2652,  449,   95,   32, 2695, 2223,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596,    1,  159,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1037,  275, 2748,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2565,  765,   98,  548, 1936, 3190,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  902,    1, 3331,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 1796, 1940,  610,    9,   29, 2607,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1676,   22,   23,  475, 2526,  548,    1,  650,  928,   32,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2072,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,   37,    1, 3358,   37,  168,   37,    1, 2611,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  342,   37, 2192, 1903,   98,   20,  296,    1, 1559,\n",
      "          388,  199,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  129,  975,   37,   92, 1607,  949,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3144,  563,    1,    1,    1,  759, 1567,  813,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1107, 1229,   37, 2234,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 1586,    1, 1539,  778,    9,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   32, 1876,   45, 1211, 1819,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  177,  228, 1530,   32,  121, 2003, 1585,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2974,    1, 1821, 1697,  627,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1231,  548, 1656,  298,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1, 2254,  221, 1836,  548,   59,  399,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2514,   12, 2146,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3129,    1,  877,  227, 1219,    9, 2715,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  295,    1,  541,   37, 1022,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  845,  147,  261,  444,   22,  438,   35, 1832,   28,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,    1,  609,  162,  257, 1038,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  882,  733,   48,   32, 1486,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1936,  166,  829,    1, 1463,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  706,    1, 2892, 2905,    9,  163,    1,   12,    1, 1117, 2208,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2208, 2055,   32,    1, 2823, 1844,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   12,  551,  552,   51, 1083, 1883, 1228,  748,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  365,  872,  190,  771,    9,    1,   98, 2190,    1,\n",
      "         3052,  774,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  667,  957,  315,   37,   92, 1994, 2095, 1506,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  292, 1222, 2359,   37,   26,   16,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1934, 1638,    1,  215,  441,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2817, 2856,   32,  395,    1,  590, 1584,   28,   32, 1881,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3128,  108,   98, 2968, 1296,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3059, 1822,  713,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,  884,  297,    1,    1,  384, 3069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2668,  167,  429,  411,    1,   45, 1204,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1106, 1107,  951, 2102,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1936,    1,   45,    1,   41,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,    1,    1,  163,    1,   12,    1,  112,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3298, 2055,  449, 1742, 1938, 3197,   32,    1, 2027,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  479,   37,  693, 1170,  538,  187, 1018, 1144,   32,  388, 1975,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492,   37, 1539,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  727,  613, 1360,  612,    1,  180,    1, 2434,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2965,    1,    1,   37, 2162,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   20,    1,  166,  856,   37,  296,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1484, 1157,  650,    1,    1, 2471,  528,  531, 3102,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3178,  167,    1,  590,    1, 2788,  424, 1034,  176,    1, 2445,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   45,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1699, 2558,  321,  612,    1, 1377,   45, 2968,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,  525, 2753,  220,  786,    1, 1851,   15,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2374,  113,   79, 1436,    9, 1517,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965, 2550,  782,    1, 2668,  361,  388,  459,   45,  238,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,  443,   98,  531, 2189,  386,  497, 2541, 2266,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1631,  248,  593,  813,   32,   81,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1270,    1, 3343, 3396, 1421,   28,   37,  741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  786, 1680, 1443,  220,  593,   12,  449,    1,    1, 1732,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1256, 1256,  505,  629,   32,    1,  195,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1658,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  718,  459,    1,    1,    9,  356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  179,  190,    1, 2492,    1,    1, 1876,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  374,  375,   61, 1229,   37,  498,   37,  105,  132,   37,  151,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3018,  315,  125, 1139,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388, 1942, 1648,    9, 2333,    1,  176, 1261,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  800, 1220, 1401,  224,   37,  417,  453, 2364,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  338,   98,  459,   45,  677,   68,  109,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   25,  504,  187,   69,  338,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1362,    1, 1363,   32,  613, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2615,    1,  220,  454, 1090, 1924, 2052,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  989,  267,  214,  142,    1,  187,    1, 1765,  103,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1576,    1, 1981,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  925,    1,  967,   37, 2394,  204,   12,  642,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1889,  120,  176,    1,  425,  426, 2410,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  387, 1610, 1450,   32,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,  839, 3038,   22, 2421,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2292,   32, 3360,  396, 1312, 2853,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2997, 1560,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,    1, 1817,    1,    1,    9,  411, 2591,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  215,   37, 1539,    1,  290, 1159,  627, 1117, 2208,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  421, 1401, 1110,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3227,  184, 2487, 2621,   45,  166,  260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169,    1,  202,  140,    1, 3201,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 1376,  530, 1714,    1,  123,   32,   98,  119, 1653,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,    1,  939,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 1415,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1824,   32, 2047,  187,    1, 1450, 1687,   32, 2490,   12,\n",
      "          463,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1530,   32, 2597,  218, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  395, 1419,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3108,  726, 1194,   73,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,   12,  590,    1,    1, 2390,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  160, 1161,  338,   32,  367,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178,  610,   32, 2607,   45,    1,   12, 2608,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  176,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1157, 2785, 1950,  640,    1, 2986, 2884,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  549,    1, 1159, 2178,  851,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1621,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  311, 3159,    1,  220,  581, 1023, 1567,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1877, 2086, 1995,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  297,  301,    5, 1064,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  384, 1035,   12,  550, 1929,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1564, 2069,   95,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1839,   46,  187,  651, 2396,  891,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  990, 1070,  147,   37, 2199,  105, 2650, 2456,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  782,  808,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 1466,   37,  125,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  657, 1426,  660,  846, 2010,  176,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  203,   37,    1,    1, 2645,   37, 1515, 1842,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777,  614,  548,    1,  220,    1,  956,    1,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  187,    1,    7, 2943,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  215,   60,  140,    1,    1,   29,  246,   98, 1547,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61, 1167,  105,  535,  656,  327,  357, 1018,  439, 2601,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,  166, 2769, 1086, 2198,  607,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,    1, 3358,   37,  319,  187, 2708,  475,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  168,  457,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1691,  593, 1765,  105, 1298,    1,    1,  111,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428,  927, 1458,  864, 2673,  798,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,  251, 1876,   37, 3025,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,  868,  885, 2673,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1794,    1,    1,   12, 2585,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  790, 2104, 1458,  195,  384,  700,   37,   52,    1,  191,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537,  650, 1685, 2263,  796,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  116,    1,    1, 2161,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821,   95, 2896,  536,    1,  792, 3033,  792,   32,  537,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2672,  321,  612,  429,   98,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275, 1564,    1, 2179,  584, 2237,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1674, 2246,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  603,    9,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2024,  872, 1082, 3356,   37, 1140,   79,    1, 3357,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,  627,   32, 1658,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,    1,    1,  228,  365,  937,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2696,  335,  522,   98, 1089, 1675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1028,    1, 2531, 2024,  142, 2202, 1159,    1,  238,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056, 1429,  217,  875,  220,  422,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1902,  900,  159,  186,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  597, 2226,    1,  704,    1,   12,    1, 1576,  728, 2317,\n",
      "            9,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1723,    1, 1260, 1924, 1056,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  506,  460,  389,  218,   61,  729,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1249,   39,    1,  187, 3103, 3229,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2871,    1,  261,  204,  321, 2303,   98, 2322,  146,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 2572,   32, 1882,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2420,    1,   74,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800,    1, 2226, 2233,  168,   32, 2330, 2027,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  103, 2308, 1188,  388, 1694,    1,  267, 3242,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 1905,   32,    1, 2024,   46,  548,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  854,    1, 2018,  774, 1188,  388,   46,   98, 1815,  336,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3228,  750,  884,  105,  686, 1056,    1,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,    1, 2018,   37,    1,    7,    1,  345,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2689,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,   51,   52,    1,  365,  647,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  446,  261,   39, 2025, 2924,    9,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1447,   37,    1, 1377,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3253,   81,   98, 1171,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  424, 2385,  612,  166, 1838,  260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 2055,  105, 1108,   37, 1527,  111,  825,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2838,    1,    1, 1173,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1, 1097,   37, 1251,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  136,    1,  708,    1,    9,   82,  389,    1, 1118,  136,  593,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2881,  267, 1230, 2264,  565,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 1680, 1429,   32,    1, 1228,  973,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  986,    1,   37,  163,    1,   12,    1, 2924,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 1268,    1,   98, 2359, 1021,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158, 2102,   37,    1,  365, 2880, 1527, 2210,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  570,  155, 1057, 1151, 1220,    1,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1123,  593,    1,  542,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,    1, 3360,   37,    1,    1,  861,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  560,  347,    1, 1128,  480,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1794, 3350, 2145,   81,   37,  215,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  167, 2923, 1403,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2578, 1401, 2588,  105,    1,    1,   32, 1447,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  790,    1,    1,    1,  351,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2156,   98,  649, 2949,   12,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 2067, 1245,  384,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2095,  722,  176, 2388,  845,   36,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1955, 2654,   32, 1656, 1819,    1,    1, 1294,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2752,   46, 1625,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1147, 2751, 1910, 2646, 3346,    1,   38,   32, 2375,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,    1,  156,  720,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  820,  187,   26, 1039,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764,    1,    1, 1928,   45,    1, 1527, 2664,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  213,   37,  151,    1,    9,    1,  131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3335, 2315,    1, 1675,  220, 1545,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  291, 1258, 1108,    1,    1,  973,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  743,   12,  244,   32,  260,  220,  308,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1744,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1369,  251,   37,  138, 1370,   45,   78,  396,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3385,    1,   76,   32,  968,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 2024,  132, 1822, 1664,  608,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  848,   37, 1539,  999, 1892,    1, 1893,    1,  420,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1435,  691,   12,    1,   98,  887, 2290,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2983,   51,  335, 1400,   37, 1505,  763,    1, 2112,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3385,  475,   32, 2470,    9, 2673,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  868,  671,    1,  244,    1,  408,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1, 1976,   32,    1,   12,  770,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1861,   37,  973,    9,  465,  404, 2024,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1079,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453,  159,  720,  419,    1,   32, 1890,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  160,  102,   28,    1,  118,   32,  367,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3052,  688, 3151,  593, 3009,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1076,   12,    1,  214,  142, 2070,  147, 1787,   32,  463,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  845,  275, 2322,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1749,  220,  326,   98, 1766, 1767, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2726,  220,  401, 2069,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1273,  259,   15,   28, 1307,  682,  218,  332,  918,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,   77,    1, 2440,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,    1, 3338,   32,  531,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1163,  197,   28,   98,  198,  163,    1,   12,    1, 1220,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964, 1921,   32,    1,   98, 2567, 2237,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2183,  342,  232,    1, 3363,   98,    1, 1918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1941, 2922, 1554, 2498,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2551,    1, 3252,  683,  515, 1531,  183, 1198,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496,  460,  389,   93,   98, 1121, 1171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,    1,  326,    1,  361,  766, 2704,  388,  315,    9,  617,\n",
      "         1151,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3340,    1, 2572,   32, 3360, 1142,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,    9, 2936, 3329, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2871,    1, 1558,  187, 3233,  512,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1824,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  356,  191,  356, 2153,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1976, 2793,   32,    1,  548,   64,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  151, 2576,  581,  293,  887,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  391, 2216, 1038,  966,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1,  608,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1056,  632, 1202,  298,    1, 2834,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2437,  384, 3141,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1313,  362,    6,   32, 2743,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  365,    1,    9,  112, 1749,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977,  475,  405,    1,   51,   52,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1419,  365, 1872, 1228, 3031,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1296,   85,   32,  340, 1251, 2054,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  907,  220,  501,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,  245,  548,   69,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1175,    9,    1, 2387,  625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 1251,   45, 2693, 1942,  418,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  208,   37, 1664,    5,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  395, 3067,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1898,  597,  844,  512,    1, 2343,   12, 2059,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3324, 1293,   98,  103,  548, 1194,    1, 1684,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,   76,   37, 2709,  993,  302,  424,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 121,  12, 818,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 328, 657,   6, 983, 157, 225, 948,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3238,  729,   51, 1330,    9,  273,  444,  365, 1788,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,  102,    1,  810,  199,  845,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  140, 1229,   37,   52,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  716, 1022,  156,  452,  170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3038, 3121,  640,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,    1, 1211,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2735,    1, 2172,  765,   27, 1212,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2006, 2572,   32, 3101,  336, 3389,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  305,  186,  187,  389, 1931,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3200,    1,  705,  191, 2125,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1841,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1391,  310,   25,   69,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  103, 2132, 2570,  113,   79, 2963,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  169,  361,  702,  498,   37, 2123,   32,  131,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2697,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2445, 2095, 1313, 1908,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2978,  865,   37,   95, 1961,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2980,    1, 2894,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1468,  691,   12,  365, 2080, 3255,  872,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  517,    1,   32,  460,    9, 1244,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228, 2323,    1, 1095,   12, 2464,  111, 1197, 1108,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   26,  914,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  765,    1, 1159,  160,  623,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2175,   37,  105, 2171,   27,  334, 1085, 2948,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3297,   12,  472, 1458,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  293, 1004,    9,  388,    1,    1, 2221,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2781,   32, 2741, 3129,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   49,  580,    5, 1197, 1757,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 2331,   45,  365, 2978,  529,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2754,  446,  859,  531, 2128,    6,    1,  198,  954,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   37, 1816,    1,  932, 2675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1024, 1024,  197,   28,   98,  195,   15,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2263,  388, 3384, 2985,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  939,  187, 2049,  512,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2971,  458,   37, 2155,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1187, 1658, 1656,  606,  105, 2968,   32,  166, 1522,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  566,  647,  187,    1,   98,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  292, 1677,   45, 2103,  617, 1116,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305, 1285,   85,  187,   69, 2338,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,  361, 2466,  777, 2165, 1673,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,  885, 1333,  176,    1, 1133,  750,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1327,    1,    1, 3030,   37, 2000,  645, 2189,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1326,   37,  877, 1736, 1975,   32,  395,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1516, 1554,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  515,    1, 1333,  176, 2545,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1366,  606,  590, 2047,   45, 3123,    1, 3281, 2167,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296,  361,   20, 1822, 1911,  397,  400,    1,  447,   12,    1,\n",
      "          267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2800, 2741,   37, 1046, 2846,   32,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  247,  114,  729,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3045, 1539, 1450,  444,  947,    1,   32,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1903,  588,  439,   37, 2397, 1665,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  166, 1254,   32,  166, 1054,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2464,   37,  599,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  251,  331,    9,    1, 2049,  280,   32, 1912,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,  421,  858,  149,  801,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1539, 2995,    9, 1778, 1273,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  679,   69, 1220, 1391,  636,  423,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1785, 2044,  765,   37,  125, 1069,  115,   45,  107, 1953,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296, 1550, 1322,  829,   32,  342,  400,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 657,   8,   1, 304, 600, 116,  12, 627,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 447, 267, 460, 190, 193,   1, 582,   1, 625,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1796, 3222, 2726,    1,   98, 3121,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3051,    1,    1,   32, 3118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1918, 1518, 3188, 2771,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230, 1258,   37,   16,  247,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  112,  783,  640,  356,  845,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  242,   98,  720,   32, 1290,  396,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614, 2872,    1,   37,  726,  449, 2545,  452,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  529,    1,    1, 1795,    1,  584, 1539,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  571,   37,  166, 3225,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 2800,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  720,   98,   69,    1, 1115,  954,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739,    1, 1022, 3026,  424,  356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  811, 1564, 2507,  976, 2784,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1241,   28,    1,   60,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2828,  856,   81,    9,  105,  402,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363, 1867,  649, 1273,  259,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  386,  288,   37,  720,  573,  315,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  919, 1940,   12, 3208,  872,  671,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  321, 3068, 2449,  388,  763, 1211,  259,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  848,  361, 1234,    1, 2444,  176,  915,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1528,  917,    9, 1477,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  142,   37,    1,  365,   12, 2170,  868,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  425,  426,  744,  131,  332,    1,  469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3247, 2712,    1,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1209,  861, 1553, 1735,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  337,    1,    1,    1,    1, 1210,  365,  961,    1, 2616,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   39, 1030,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  108,   98,  102,    1,  408,    1, 1913, 1843,  207,\n",
      "           28,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  206,   12,    1, 2888,  162, 2335,  537,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3241,  664,  601,   73,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1543,    1,  187,  365, 1065, 1190,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,   52,  176,  166, 1542,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3358,    1,  247, 2840,  361,  166,  627,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  672,   81,  166, 1603,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3358, 3137, 1519,    1,    1,  729,  105, 2919,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1,  396,  987,    1, 1975, 1810,    1, 1639,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1207, 1745,   37,  865,   37,   64,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,    1,  359,   37, 1195,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  326,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,  936, 1243,   45,    1,    6,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  661,   98, 2325,    1,   12,  142,   37,    1,  962,    1,  167,\n",
      "          619,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  741, 2177,   37, 1399,  203,  460,  190, 1594,   39,\n",
      "         1160,    1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1667,   12, 2772,  400,    1,   32,  856,  297,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1143,    1,   83,    1,    1,   32,  654,  149,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  861, 1906, 2770,    1, 3114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1509,  151, 1205,    9,    1,   79,  575,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  107, 1009,  267, 1663,   69,  102,  190,  720, 1371,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3138, 2712, 2379,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2018,  668,    1, 2960, 2414,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,  764,    1, 2500,  195,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  477,  105,    1, 1318,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087,  433,   21,  816,  996,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3308, 1990, 3186, 3158, 1844, 1086,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1771,  729,    1,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 458,  45, 507,  37, 125,   1, 388,   4,  88,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 420, 596, 327, 218, 288,  37, 554,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1463,  758,   12, 2194, 1017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  626,   37,  151,    1,    9,    1,  182,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  358, 2520,  199,    1,    9, 1610,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  764, 2391, 3164, 1154,  166,   74,    1,  726,    1, 3011,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  403, 2926,  171, 2097,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   91,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  593, 3105, 1174, 2024,    1,   32, 1853,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3315,    1,   37,    1,  219,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1203,    1,    1,  517, 1871,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 1411, 1282,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1095, 2870,   37,    1,  453, 2293,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  129,  922,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 166,   1, 327, 884, 453, 913,  32, 166,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 944,   1, 840, 382, 436,  50,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3064,    1,    1, 2963,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1431, 1268,  704,  551,  705, 2363,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1502, 1544,  700,   98,  214,  142,    9, 1503,  129,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,    1,    1,   45, 2571,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1024,   81,   32,  180, 1684, 2107,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  884,  671,  176,  166,    1, 2826,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  523,   61,  837,   45, 1938, 1723,  549,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1,    1, 2740, 1509,   32,  455,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1586,  361,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3286,    1, 1224,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  647, 1607,  710,    1,   82,   39,  166, 2009,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2218,    1,    9, 2741,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,    1, 1749,  693,    1,   45,  617, 1151,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  108,  864,   45, 1328,    1,   98, 2673,  315,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  374,   37,   47,   48,   32, 1597,   37,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2685, 1787,    1, 3237,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  778, 1288,   37,    1, 1210,  378,    9,  334,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  551,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   12,  552, 1426,  317,  845,  402,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,  288,   37,   38,    1, 2765, 3060,   37, 2468,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2932, 1569, 2580, 2851,  861,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,    1, 1821, 1827,  191, 1888,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2741,  167,  606,    1, 3302,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1035, 1627, 1038,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1971,    1,  325,    1,   12,    1, 2101,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  265,   45,    1,   12,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  384,  117, 2960, 1441,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   98,    1,    1,  237,    1, 3375,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1780,    9,   98,   22, 2769, 1042, 3199,   39,   45,  449,  913,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  225, 1144,  804,  211, 2806,  916,    9, 2324,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1016,  953,   37,   72,  913,   32,  215, 1002,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2723, 2724, 2636,   37, 1876,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1785,  992,   28,    1,    1, 1897,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  461,    1, 2227, 1522, 2436, 1604,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1009, 1579,  535,  625,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2069,    1,  288,   98, 2170,  638,    1, 2024,  469,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2144,    1, 3047,   32,    1,    1, 2517,  947,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  379,   81,  976, 2108, 3368,  439,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  105, 1298,  227,  550,    9,    1, 3103,    1,  140, 1442, 2954,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,   37, 1937, 3358,  528, 1404,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2685, 2895, 2143, 2385,  612,    1,  320,   73,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  792,    1,  632, 3065,  792,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  409,  269,  315, 1053,    1,  895,    1,    1,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2573,   12, 3398, 2331,   45, 2559,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  271,   32,  176,    1,   51,  606,    1,   29,   45,    1,   59,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,  980,  845,  846, 1074,  261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  705, 2796,  688, 3079,   37, 1911,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,  155,  347,    9,   72,  199,  424,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1562, 2523, 3325,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1834, 2297,   72, 1354, 2342,  787,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1039,  342,  355, 1350,  132,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  612,  613,   37,  693, 1107, 3049,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 2004, 1473,   81,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,   61,  501,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2573,   12,    1,    1,  296, 1202,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,  251,  203,   37, 1243,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  282, 2367, 2695,    1,   45,  166, 1034,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3226, 2811,  220,  542, 1897, 3263, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    9, 2523,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  794,  365, 2842,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428,  861, 1906,   37, 2000, 3369,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2399,   37,    1,    1, 1009,   12, 3150,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3192,   97,    1,   98,  438,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25, 1253,  548,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    7,  808,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  459,   59,  132,  220, 3175,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  305, 1826,    1,  685,  686,  241, 1653,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2676,   37,  631,  104,    1,   37, 3360,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1018,    1,  105,   74,  227,    1,    9, 1744,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1567,  353,   18, 1159, 1343,  176,    1,    1,  717,    1,\n",
      "         1037,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  683,    1, 1371,   98,  105, 1102,  841,   27,  334,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1818,  147,   37, 2303, 1842,  116,  400,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1251,   45, 2301, 1124,   61,  553,   32,   56,  537,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  743,   12,   15,  973,  453,  225,   37,  356,  845,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,  794,  885,  927, 1159,  829,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,  105,  148,   12,    1, 2523,   98, 2019,    1,    1, 2168,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  669,  852,   37,  877,    1,    1,   32, 2840,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3084, 1057,   98,    1,  931,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1081, 1707, 1727,  191, 2095, 3060,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219, 2122,  231,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 1990,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1002, 1001, 1132,    1,   98,   25,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,  493,  102,    1,   28,  191,   69,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 3006,  288,  365, 1757,    9, 1428, 3365,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,  868, 2649, 2791,    1, 1887, 1056,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  477,   61,    1,  191,  132,  220,  487,  358,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,   28,  187,  163,    1,   12,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  348, 2506,  297,    1,    9,  597,  475,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2496, 1976,   32, 3383,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,  297,  187, 2584, 2565,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  840,  783,  166,    1,  841,  293,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2275,   12,    1,    1, 2275,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1233,   37,  125,    1,    4,  176,  250,   32, 1619, 2741,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 3081,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,   37,    1,  597, 3289,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1158,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  612,    1,    1, 2582, 2313,   93,    1,    1, 2700,  774,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283,   32,  870, 1056, 1171,  593, 2078,  288,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  391,    1,  353,  197,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  251,   37, 1504, 1792, 1778, 2580,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3157,  774, 1398,  612, 2898, 3006,  429, 1428, 3365,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3167,    1,    1,    9,  547, 1739,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 3096,  427,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1, 1438,   45, 2992,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  228, 1439,   32,  449, 1405,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481, 1544,  191,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 1380, 2785, 1950,  176,    1,  187,    1,  914, 1086,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  923,    1, 3042,  161,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1021,  282,  517,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,   37, 1334,   32,  531,  548,    1,    1,    1, 2893,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428, 2673,  475,    1,    1, 2088,  297, 1338,   45, 1647,   98,\n",
      "          403, 1447,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3279, 2535,  557,  540,  957,    1, 2756,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3343,  195,    1,   37,   16,  183,   71, 3355,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 3102, 2399,   37,  836, 3026,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1183,    1,    1, 1976,   32,  395,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  682,    1,  202,  193,  220, 2482, 2911,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3184,  147,  267,    1,  514,   32, 2282,  722, 2108,  132,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  276,  981,    1,  528,    1,  567,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1641,   28,  965,   32,  403,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2953,    1,   96,    1, 1159,    1,  506,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2476,  973,    1, 1159, 3155,  947,   32, 3383,  664,  674,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,  213,   37,  151,    1, 1201,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1641,    9,  842,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  941,  256,    1,  482,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  597,    1, 2226,    1, 2275, 1708,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 2227,    1, 1007,    1, 1564,    1,  402,   32, 1573,\n",
      "          191,  166,  825,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 1414,  597, 2548,  384, 3362,  754,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299, 1579, 2933,  302,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2510,  313,   37, 2589, 2691,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112, 1625,   10,  190,    1,    5,  652,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  102,   85,    9,  166, 1034,  187,  109, 1665,  980,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  169,  332,  682,   92, 2054,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1724,  885, 1918, 2866,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2743, 2576, 1856,   45,  236,   12,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2868,  104,  190, 1527, 2708,  890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1583,    1,  352,  589,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  323, 2747,  166,    1,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1, 1631,    1,    1, 2770,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3270,  140, 1088, 1938, 3197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,  225, 1279,    1,    1, 1010, 1021,  595,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,    1,  357,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,  476,    1,   37,    1,    1,    1,   37,  429,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3102,    1, 2226, 1398,  612, 1210,   37, 2844,   55, 3025,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178,    1,    1,   98, 3386, 2930,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  812,  487,  484,   37,    1, 2924,   37,    1, 2060,   32,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  231,  297, 3143, 1313,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  758, 2612,  365, 1273,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129,    1, 3254, 1401,    1,  219, 3329,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,    1, 2174,   32,    1,  769,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 2055,   32,  878,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2386,  375,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,   12,    1,    1,    1,   32,  449, 1385,   45,  395,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1107,  293,    1,   85,   98, 2441,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  183,  861, 2538,   32, 1718,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  592,  582,  387,  590,    1,   98, 1220,  191,  594, 2064,    9,\n",
      "          105,    1, 1067,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2982, 1000,  238, 1634,    1,    1, 1937,    1,  361, 2599,   98,\n",
      "         1965,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1181,  387, 1151,   93, 1115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  391, 1329,  197, 1042,  187,  408,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035, 1070,   37, 1174, 1175,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2920,  606,  105,  183, 2539,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1133,   98,  258,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1723,    1,   37, 1174,   32, 3311, 3310, 2930,  776,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  105, 2537,    9,  531,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  245, 1270,   37, 1315,  105,  106,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1444, 2233,   18,   39,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1948, 1924,   98,  810,  478,  920,  460,   12,  105, 1530, 1245,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  603,    9, 2966,  444, 3326,    1,  166, 3115,  619,  284,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  242,  529,  408,  979,   37,  686,  575,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  957,    1,  441, 1152,   45, 2786,  148, 2558,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3021, 1408,  671,    1,   51, 1046, 1281,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   42, 1350,  134,  220, 1652,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  256,  365, 1021,    1, 2232, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 2924,    1, 3045,  856, 1425, 1147, 2774,  787,   45, 3155,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9, 2377,   45,    1,    1,  166,  856,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   45,    1,    1,   61, 1530,  176,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  476,   37,    1,    1,  497,  734,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  397, 1542,    9,  163,    1,   12,    1,  909,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2890, 1518, 1674,  478, 1675,  220,    1,  361,  591,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,   37,  470, 2375,  970, 1281,    1,    1,  622,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  992,   85,  384,  287,  686,  314,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,  246,    1, 2915,    9,   46,  220, 2707,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233,  929, 1061,   32, 3349,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  191, 2215,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,  584,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1663, 1821, 2190, 1323,  420,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  391,    1,  515, 2266,  579,  453, 1009, 1484,  741,   45,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1294,   51,  193,  764, 2155,  923,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3326,   81, 1764,   39,   28,   37, 2119,  220, 3265, 1987,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2683,  593,  594,  497,   98, 1030,  260,   45, 1465, 1681,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   39,   45, 2826,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3094, 2347,   32, 1855,    1,  114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,    1,    1,   32, 1815, 1585,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1647, 1228,    1,  298,  361,    1,  166, 1868, 1172,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1423, 1310,   37,  619,  215, 3102,   12,  949,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2334,  656,  162,  365,  590,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  961, 1482,  155,    1,  105, 1194,  199,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3192, 3184, 2579,  168,  115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2384, 1768,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 3358,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746,   32,  132,  220,  829,   37,  843,  844,   98,  845,  846,\n",
      "          847,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    1,  331,   32, 1405,   43,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  991,   22,  297,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2648, 2801,    1,    1, 1403, 2226, 2969,   37,   91,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3102,    1, 1220,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977,   12,    1, 1625,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2177,    1,   32,   36,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2668, 2433, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  952,    1,   46,  220, 1815, 2104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1127,  437,   37,  151,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9, 2127, 1220,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2023, 1116,  956,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1159, 1089, 1675,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  754,   15,  670,   32,  871,    1, 1224,  729,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1033, 1874,    1,    1,  811,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2275,  315,   37,    1,   37,   10, 1819,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1958, 1355, 1983,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1128, 1625, 1876,    1,  190,  860, 1108, 2568,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1976,   32,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2994,    1, 2188, 1184,   32,  166, 2995,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3313, 2097,    1,    1,  614,   37,  103,   45, 2601,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428, 2500,  663,  475, 1082,  463, 1447,   37,    1,  861,  625,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  166, 1034, 2155,  361,  429,  538, 1699,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1965,    1,    1,    1,    1, 1534,   45,    1,  238,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,   96,   37,    1,    9,  764,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,   12, 3356, 1685, 2069, 2074,  957,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 3102,    1,   32,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  345,   37,  985, 1450,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169,  801,   37,  104,   26,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1853,  387, 2843, 1397,   28,   32,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   51, 1121, 1811,  823,    1,  504,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1474,  267,    1,    1,   39,   45, 3127,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1929, 3210,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  539, 1037, 1249, 3166,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  631,  787,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3325,  459,   98,  187, 1046,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115, 1173,   81,    1,  193,  115,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  950,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1074, 1822,  335, 1134,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,    1, 2902,  125,  102,   98,  116,   19,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  691, 2638, 2931, 3109,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  634, 3324,  113,    1, 1333,  631,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,  957,   37, 2000,    1, 1839,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  455, 3121, 2414, 1056,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640, 1505,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  557,  540, 2756, 2961,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  597, 2696,  820,  384,  611,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1321,  247,    1,  361, 1441, 3364,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,    1,   32,  430,    9, 2024,   46,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1718,    1,  191, 1164,   45,  861, 2538,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2114, 1283,  207,   37,    1,    1, 1675,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  447,    1,  593,   12, 1637,  826,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  675,    1,  244,    1,  191,  104,  886,    1,  296,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   94, 1137,  187,   99,  475, 1454,   67,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  590, 1462,  444, 1778,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,  683, 1566, 1610,  865,   37, 2748,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  828,  360,  531,  881,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1024, 2659,   79,  888,    1, 2479,  922,  631,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   12,  103, 3407, 3382,  571,  754,  187, 1345,    1,   32,\n",
      "         2646,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1, 361,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 491,  37,   1,   1, 721,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  623,    1,    1,  156,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  225,  953,  187,  365,  159,  686,  218, 2928,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  483,    1,  793,  267,  467, 2092, 1610,   32,   27, 2113,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3308, 1990,    1, 2282,    1,  913,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,  649,    1, 1497,    1,  220,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  955, 1675,   45, 3032,    1,   32,  864,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  251,  388,  199,   37, 1463, 2580, 1108, 1779,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  990,  952,  599,  444,  544,  193, 1140, 1638,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2144,   37,    1,   32, 2235,  147,   98, 2095,  722,  134,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,  475,  387,  591,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  475, 1213,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  708,    1,  187, 1411,   82,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2646, 3279,  187, 1302,   46, 1980,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2006,  583,   32, 1585,   32, 2018,   12,    1,  844,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1090,  891,  176,  446,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  960,  980,   39,   82,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  310,  159,  417,   98,  156,    1, 1448,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2881,   12,  310, 2348,  304,  288,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1498, 1152,  600,    1, 1317,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  997,    9,  627,   45,  638,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1789,  251, 1358,   98,  450,  395, 1898,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  815, 1017,   37, 1527,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  273, 2171,  729, 1670,  453, 2608,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2994,  884,   98,  116, 2542,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 1065, 1190,    1, 2133, 2456,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  108,   45,  417,    1,    1,  197,   98,  104,  560,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2620,   32,  273, 1666, 3216, 3132, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  619,  365, 3372,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  915,   45,    1, 3033,    1,    1,  944,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1600,  261,  168,   32, 1601, 1602,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321,  544,  457, 1821,  441,  288,    1,    9,  627,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  361,    1, 1810,  166, 1354,    1,    1,   37,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783, 1114, 1666,  572,  156,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2777,    1,    1, 3115,   32, 1133, 1569,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144, 3372, 2424,  469,   37,    1,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1224, 2631,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 2630,   32,  525,    9, 2826,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  613,   37, 1027,  116,   93,    1,  275, 2153,  774,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343,    1,   12,    1, 2134, 2292,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1227, 2869,  535,    1,   37, 2728,  465,   86,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  434,    1,  176,    1, 1325,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   65,   12,    1,  267,  954,  729,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,   37, 2884,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 3315,    1,   61,  297,  548,  594,  698,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  863,  289, 2095,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1433,  303,   61,    1,  166, 1434,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3269,  697,    9,  247,  183,  484,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3336,   12,  199,    1,  220, 1668,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,  942, 1149,  686,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2325, 2487, 2621,  661,    1,  593,   69,  102,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   64, 2414,    1, 2249,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  641,  158,    1,  752,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3039,  116, 1090,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977,  313,    9,   51, 2978, 1539,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 2471, 1260,   32, 1785, 2044,   37, 1147,  890,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  108,   45,  861, 2558,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1238,   22,  437,  197,   28,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  163,    1,   12,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,  891,    1, 1557, 2778,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  393,  840, 2144, 1202,   37,   58,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,  566, 1429,    1,   32,  121,  446,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1728,  730,    1,    1,    1,  501,   61,  105, 2773,    1,  202,\n",
      "          176,  754,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,    1,  187,  861, 2762,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  183,    1,    1,   37, 1399,  810,  176, 2220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  220, 1973,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1998, 1011,  108,   98,  572,    1,  572,  244,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1523,    9, 1811, 3024, 2373,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977,   37, 2354, 1114,   32,   51,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275,  335,   98,  954,    1,  531,   32, 1384,   74,\n",
      "         1287,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  481, 1017,  575,   37,  664,   32, 1935, 2461,  443,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 2635,    1,    1,  590,    1, 2635,    1,  801,   37, 3293,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  148, 1426,  214,  132,  220,  647, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  437,  267, 2414,  581,  163,    1,   12,    1, 3102,  844,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2176, 1822,  764,   32,  856,  444,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  619, 1018, 1952,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 112,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 393, 566,   1, 359, 132,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1039,   45, 2868,   12,  864,  993,  680,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  439,   45,  166,  260,    9, 1087,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,   37,   77,   37,    1,    1, 1563, 1603,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  510,    1,  567,    1,  384, 1515,    1,   98,  166, 1549,  540,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 2036,   12,    1,    1, 2587,  667,  458, 1852,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  585, 1253,  698,  495,   32, 1352,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1110, 1428,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550, 2997,   32,  241,  861,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3343, 3006,  774,   37,  429,   46,   98, 1428, 3365,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 2764, 2765,    1, 2572,   32, 2018,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  755, 2369,  861,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  794,  163, 1230,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2634, 1680,  845,  439, 2759,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447, 1360,  612,    1, 3358, 1983, 2078,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361, 2319, 1434,   98, 2336,  315, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384,    1,   45,    1,  579,   12, 1568,    1,  579,   12,  193,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  199,  421, 1830,    9,  399,  220,  331, 1482,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1094,  894,    1, 3339, 2271,  220, 3375,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2694,  443,   98, 1158,   12, 1230,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  108,   45, 1133,  157,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   56, 2260,    9, 1022,  548, 2410, 1385,   45,    1, 3023,   45,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,    1,  134,   45,  312,  966,  191, 1346,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 1795,   37,  125,  572,  156,   98,  149,  354,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  647,  170,  459,  361,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2685,    1,    1,  901,    9,  914,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1040, 2770, 3113, 2565,  298, 2986,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453, 1229,   27, 1633,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  365, 1788, 1407,  269,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   67, 1564,  803,  504,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1302, 1813, 2751,    1, 1622,  957,    1, 1905,   37,   52,  998,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   85,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  729,   39,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  166, 1521,   45,  166,  475, 1213,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  845,  689,  105,  365, 2067,  176, 3010,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,   39,   12,    1, 1447, 2128,  125,\n",
      "         2191,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307,   96,   28,  166, 1245,   98,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676,    1,  650,  928,   32,    1,  298,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1,   37,   47,   56,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2777, 1408,  289, 1010,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1634,   37,  227,  223,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2328,  114,    1,  186,    9, 3363,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1, 1316,  395,   37,  813,  455, 1260,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  446,  254,    1, 2862,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1817,    1,    1, 1236,  597,    1,  940,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2183,  379, 1910, 3104,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3339, 3352, 2572,  187, 3359, 1877,   37,    1, 2625,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,  267,  411,  890,  565,  105, 2179,  361,  996, 2124,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3188,    1,  421,  176, 3284,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3342,    1,  600, 2059,   12, 2263,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2425,  361, 1883,   37, 2123,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1084,    1,   37,    1, 1501,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  217,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,    1,  108,   45, 1147,  521,  443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  105, 3292,    1, 1550, 1534,   45, 3185,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  560,  347, 1180,  242,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1773,    6,  636,   98, 1090, 1667, 1758, 1294,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118,   12, 3396, 1046,  537,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  542, 1306,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2024, 2699,   32, 2646, 2597, 1585, 2414,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1186,  556,  195,  700,  384,    1,  164,  165,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 1242,  187,    1,  796,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1800,  971, 1665, 1167, 1656,   50, 1240,  168,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  446,  890,   37,  168,  115,  187,  205,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2979, 1588, 2091,    1, 1216,  848,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1957,    1,    1,  384, 2347, 1638,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2745,  220,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  123, 1140,    1, 2619,    1,  233, 1311,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   34,    1,  613, 2027,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1,  829, 1542, 2210, 1421,   98,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,    1,  600,  549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  621,  251,   37, 1066,  104,    1,  132,  220,   20,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2186,    1, 2928,    1,  150,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3168, 2788, 2420,    1,   32, 1294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1717,    1,  716,  449,  400,   45,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284,  773, 2582,    1, 1981,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  656,    1, 2547,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3124,  921,    1,   32,    1, 3329,    9,  247,  449,  726,   45,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  610,   37,  537,    9, 2772,    9, 1012,  722,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  267, 1732,  218,   37, 1121,    1,  332,   37,   71,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  187, 2995,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1712, 2182,   39,  810,    1, 1412,  535,  315,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2390,    1,    1, 2297,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1118, 2568,   45, 1151,    9,    1, 2105,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  348,   37,  151,  238,  351,  669,    9,    1,  131,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3207,  162,   37,   77,  671, 3126,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  729, 1509,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  585, 1910, 1797,  996,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  291, 2767, 2706, 2232, 1907,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 1009, 1581,  649, 1462, 1190,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  686,  365,  845,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2959,  949,    1,    1, 1056, 1130,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2707, 2095, 3060,  108,   45, 1450,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159,  120,   98,    1,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3232,  759,  132,  220, 1277,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 2886, 2572,   32,    1,  186, 2514,   32, 2835,   12,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  502,    1,   32,  214,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  884,   98, 2815,  218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,   96,  297,  365,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2317,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2307,    1, 1959,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2078,    1,  357, 2395,  166,  974,  215,    1,  267, 2971,\n",
      "            1, 2896,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3262,  865,  193,  311, 1144,    9, 3215,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2479,  631,   32, 2480,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  632,    1, 3198,    1,   32, 2106, 1990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  391,    1,  156,   28,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   26, 1039,    1,  335,   98,  342,  768, 1816,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 2767, 3019, 2304,  973,    9,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1165, 1278,  640,  810,  199,  845,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2796,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2954,   37,    1,    9, 3243,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433, 1458,  131, 1278,  302,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  113,   79,    1,   37, 1758,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,   12,  340, 1251,  777, 1671, 1396, 2065,  593,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   61, 2213,  187,  166, 2242,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,    1,    1,  792,    1,  792,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,  638, 1849,   26,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  120,   32,  156,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3359,    1, 1986,    9,    1,  356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,  650,  859, 2024,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1081,  958, 1056, 2161, 3365, 2644,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,   98,  103,  115,   45,    1, 1209,    1,  528,  531,    1,\n",
      "          996,  533,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1147, 1009,    1, 1583,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1,  744,    1, 1281,   37, 1154, 1149, 1458,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3140, 1454,  453,  808,   32, 1430,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428, 2967,  729,    1, 2024,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    9,  166, 1110,    1,  459,   45, 2024,  565, 2626,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  186,  187,   69,  102,  720,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1204, 2198, 1397,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  221,  242,  187,   69,  102,  720,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3231,  914,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  150, 1355, 1051,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1310,   37,    1, 3012, 2604,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1487,  794,  449,   45,  792, 1107, 2008,  792,    9,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  567,  799,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2612,  593, 1659, 1222,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  130,    1,  223,  315,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973,  566,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 2523,   32, 2589,  220, 1687,    1,  631,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  361,    1,  777, 2657,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3248,    1, 2966,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2314,    1, 1079,  584,    1,   37,    1,  131, 1280,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  528, 2647,  596,  954,    1, 1726,  729, 1046,    1,    8,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  856,   98,  147, 1813, 3263,  361, 3226, 1401,   37,    1, 2811,\n",
      "           32,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3121,    1, 2414,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1464,   37, 2155,   28,   37,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1170,  614,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   35, 1394,   37,  577,  157,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  233,  321, 2010,   10,  315, 2295, 2302,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  267,  460,  967,    1,  955, 1461,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  864, 1337,    7, 2673, 1604,   37, 1911,  909,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  491,    1,  605,  459,  493,  109,  132,  220,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1127, 1310,   37, 1237,  104,  218,  220,    1,  349,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1164,   45, 1568,  365, 1675,    1,  191, 2086,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,  861,    1,   98, 2784,   37, 1966,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 1726,  907,  297,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1228,    1,  693,  764,  361,    1, 1112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,  267,  864,   61,    1, 1428,  522,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1205,  297, 1662, 2086,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,  155,  207,  197,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,   37,    1,   81, 2924,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,  884,  985,  384,   65,   12,  577,  996,  157,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,   12,  365,  210, 2937, 2177, 1825,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 1466,  353,    1,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1818,  147, 1392, 2096,  297,    1, 1393,   15,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,   47,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1300,    1,   37,  531,  443,  176,  119,    1, 1002,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2317,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2977,  313,    9,   51, 1821, 2978, 1539,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2828, 2857,    1, 3181,  361,    1, 2857,   77, 1762, 2078,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3342,   12,    1, 1223,  776, 2052,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   59, 1754,    1,  110,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1818,  220,  627, 2261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2677, 3170,  865,  256, 2025,    1,   37,   72, 1463,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2822,   78,  498,  803,  992,   37, 1121,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  387, 2012,    9,    1,    1,   32, 2090,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 2036,    1, 2390,    1,   37,    1,  854,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1,  782,    1, 1241, 1425, 3022,    1, 3009,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  531, 1585, 2162, 1950,  418,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   81,   37, 1505,    9, 1477, 1463,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   89,  163,    1,   12,    1, 1458,    1,  734,  591,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2602,   61,  166,    1, 1357,    9, 1861,   98,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  575,  865,   32,   86,    1, 1278,   28,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,  670,  361,    1,   32,  105,    1,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,    1, 1725,  498,   37,  439,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  693,    1,   37, 3237,    1,    1,    1, 1700, 1130,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1704,    1,   26, 1039,  535, 1863,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622, 2924,   37, 1910,    9, 2117, 2699,   32, 3118,   98, 1602,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  590, 1665,   37,  296,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3108,  785,   61,  590,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  464,  361, 1796,  259, 1091,  726,  496,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2206, 2989, 2606,  328,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1110, 2198, 3245,    1, 3200,  619,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1285, 1367,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2, 305, 670, 548,  14, 420,  88,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 425, 426,  12,   1,   1, 478,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1962, 2418,   28,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  432,    9,    1,    1,  195,  251,    1,  591,    9,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1676,    1, 1000,    1,  356, 1691,    1,    1,   32,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105,    1,   61,  590,    1, 2494,   32,  709,  404,  602,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2865,   39,    1,   32,  581, 1385,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   72,   45,  593,   12,    1,   98, 1285,   45,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2499,  325,  493,    1,  384,    1,    1,  491, 1597,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  233, 2104, 1118,    1,  100,  741, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1341,    1,  361,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3115,    1,  167, 1306,  284,  199,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  703,    1,  631,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3129,    1, 2578,    1,  754,  542,  220,    1, 1918,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  990,    1,   98, 2650,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  325, 1541,  384,  196,    1,  218,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 1550, 2336, 1031, 1251,  460,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  488,  531,  863,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   61, 1542,   37,    1,  535, 1863,    9,  342,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2672,  726,   89, 2771,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550, 1663,   37,    1, 1056,    1,   45,    1,    4,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1000,  155, 1574,  600,    1, 2990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2909,    1,   32, 2490,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3096, 3242,  261, 3304,   39,   45,  311,  472,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  497,    1,  187,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1899,    1,   98,  458,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3194, 3195,    1, 3190,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1, 2196,    1,  957,   37, 2035,  547,  356,   24,  220,\n",
      "          829,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175, 2709,    1, 1463,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  506, 1527,    9,  594,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  590,  427,    9,  539, 1037,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2411,   37,  764, 1154, 3102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  927,    1, 1159, 1676,    1,  298,    1, 2565,   12,  608,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  603, 1836,   37,    1,   32,  365, 1788,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,    1,    9,  949,   45, 3073,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  311,  856,   81,   37,  688, 3312,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  177,    1,  476,   37, 1343, 1120,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 2224, 2297,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1, 2018,  469,   37, 1348, 2024,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2528,    1, 1762, 1236,  224,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  952,    1,   37,    1,    1,   32,   95,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3202,  884, 2565,   98, 2784,   85, 1102,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  936,  469,    9, 2128,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,   93, 1509,   32,  547,  537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,    1,    1, 1212,  852,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1178,    1,  230,  127,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3205,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3123,   37,  335,   98, 3176,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  166, 1510,  197,  490,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3191,    1,    1,  105,  631,  220,  726,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1, 2414,    1, 1746, 1604,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  424, 1034,   32,  535,  656,  550,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  606, 1846, 2463,  444,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1167,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579, 1710, 2214,    1, 2898,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2041,    1,  153,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 2572,   32, 2504, 2292,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  197,  418,    1,  419,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3320, 3262,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2307,   12,    1,    1, 2748,   12,  750,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1591, 1536,    9, 1126,  220,  422,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1158,    1, 1778,  798,  794, 2355, 1681,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,   37,  328,    1, 2043,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1934,    1, 1679,  103,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358, 2431,  396,  204,   61,  193,   32,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1,    1, 1871,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1560,    9,  491,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  409, 1285,    1, 2094, 2691,    1,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1769,   37,    1,  466, 2471,   37,  105,   12,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3102,    1,  884, 1950,   98, 1841,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  861, 1906, 1310,   37, 2446,    1,    1,   32, 1430,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,   25,    1, 1441,  604,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  919,  163,    1,   12,    1,   32, 2161,   12, 3096, 2069,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2525,  565,  365, 2640,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1, 1229,  193,    1, 3369, 3396,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2004,  612, 1273,  256,  861,    1,   37, 1568, 1669,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3204,   61,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2965,    1,    1,  191,    1,   32,  365,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1373, 1099, 1453,   37,    1, 2488,   32,    1,  927,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  224, 2384,  365, 1116, 2549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  295,  936, 1108,    6,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3181,  664,  361,    1, 2445,  720,   39,  528, 1918,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1920,    1,    1, 2356,   32, 1212,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  189,  392,    1,  469,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2991, 2744,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  196, 1408,  284,  176,  551,  612,  494,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  295,   37,  125,   28,   37,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  317,    1,    1,  941,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129,    1,  884,  411,  631,   32,  219, 3329,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1123, 2671, 1340,    1, 2587,    1,    1,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,    1,   28,    1,  118,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2962,    1, 2202,  297, 3227,  187, 1110,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3352,    1, 1147,  358, 1612,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 2606,    1,  389,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,    1,  918,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3027,  384, 3012, 1821,  927, 2421,   32, 3013,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2229,    1, 2192,    1,  105,   38,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  245,    1,   12,    1, 1292,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  104,    1,   98,    1,  384,  395,    1,  451,   51,  764,\n",
      "          104,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2835,  267,  460,  967, 1061,  228, 1634,   37, 3393, 2095, 1450,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311,    1,    1, 1516,  444,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2882,  140, 1684,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1020,    1, 1380, 1526,   98,  163,    1,   12,    1, 3001,   25,\n",
      "            1,  506,  267,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  572,  197,  388,  763,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  775, 2355, 1013, 2549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  538,    1,  710, 1713, 1100,  721,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  464, 1228,   13, 1713,  310, 1718,  437,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2050,    1,    1,  490,   37,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994, 2673,    1,  928,  187, 2702,    6,   79, 3078,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3045,   37,   38,  297, 2375,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3196, 1103,    1,   37,  439,  754, 1223,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,   37,    1,  529,   25,   37,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   45, 2388,  385,  783,  338,   37,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2570,  171, 2681, 1554,  872,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006, 2286,   37,    1, 1891,    1, 2292,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3151, 2308,    1,  105,  118, 2389,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,   45, 2869,  535, 2308,    1,    1,  176, 2473,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,    1,   45,  163,    1,   12,    1,  315,   45,  388, 2673,\n",
      "         2109,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  952, 1370,   32,    1,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3134,  163,    1,   12,    1, 2161,  726, 1114,    1, 1617,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,   37,  817,    1,  535, 1863,  384, 1778,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 3222, 1757,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1667,    1,  162,  698,    9, 3260,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3161,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  702,    1,  365,   82,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  936, 2071, 1331,    1, 2403,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1675,    1, 2206, 2989,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  754, 2264,  619,    7, 1778,  328,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3244, 1173,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1282, 2539, 2800,    1,  434,    9, 3201,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   98,    1,    1,    1,  987,    1,    1,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  155,    1,   98,  459,  403, 1447,  315, 1461, 1463,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  111,    1,  681,  588, 2075,  384,  286,  293,  287,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 1447, 1484,    9,    1,   45, 2673,   46,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,    1,   37,  151,    1,   45,    1,    1,  458,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2161,    1,  220,    1, 1119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   37, 1304, 2498,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  162,  537,  611,    9, 3058, 2282,  722,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  420, 1082,    1,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   82,  267,   51, 1066,  669,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2316, 2545,    1,  190,   52,    1, 2311,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   47,    1,   32,  978,    1,   37,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  379,    1, 1167, 2343,   61,   98, 3136,  477,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,    1, 2115,    9,  987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  901, 2591,   32,  903,    1,  331,    1,  105,    1, 2775,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  750,    1, 1879,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2080,    1,  288,   37,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3315,    1, 2414,    1, 1625,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746, 1268,   28, 1766, 1767,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2416,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1476,  574,   42,    1,  400,    9,   59,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   81,   37, 1772,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384,  105, 2229, 2849,    1,    1,   45, 2095,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 2946,   45,    1,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1072,   12, 1178, 3340,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  442,   46, 1174, 1010,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  458,  520,  413, 2362,    9, 1178, 1179,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777,  190,   77, 1718,  218,  631,  297, 1652,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081, 1259,  162,    1, 1876,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3332,   12,  764, 1245,  184, 3206,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1769,   37,    1,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  458,   30,  197, 2485,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984,   12,  449, 2820,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  726,  220,  105, 1480, 1838,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,  318,  796,   32, 1094, 1559,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   12, 2692, 1089, 1090,    1,   98,  116,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1068, 2578, 3102,   37,  163,    1,   12,    1,  903,    1, 1447,\n",
      "         2471,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1436,    1,  885,    1,  726, 1517,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3168, 1625,   37,    1,  103, 1569,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  811,  413,    1,  162, 1645, 2789,   92,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2976, 2786, 2580,    1, 2762,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  293,    1, 1470,    1,  187,    1,   32,  141,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   12,  365, 1992,    1,  166, 1690, 1691, 1438,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  202, 1628,  209,    1,  115,   45, 2462,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2427,   98,  103,  202,  854,   16,  856,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  411,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428,  597,  584, 2565,    1, 3301,   37, 2628,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1625,    9,  183,    1,  220,  803, 1825,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  765, 1850, 2142,   85, 3106,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3247,  454,   37, 2069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,  730, 2614,  288,   37,    1, 1246,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2925, 2385,    1, 2368,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   61, 1509,    1,  166,  786, 1167,  272,    9,  334,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  179,   32,   46,   37,  151,  180,    9,  372,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2297,   37, 1796, 2224,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1004,  791,   45,    1,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  996,   29,    1, 1797,   60,  186,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  518, 1476,  977,    1,  824,  361, 2613,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  211,   37, 3076,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2142,   37,  619, 1542,    9,    1,  593,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,  582,   45, 2656,  267,    1, 1861,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,  453, 2966,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2757, 1572, 3386,   12, 1305,   32,  312,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219, 2981, 1627, 3048, 2818,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1046,  786,  356,  863, 1856,    1,  191, 1677,    1,    1,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1375,   22,   37,  125,    4,    1,  108,   98,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  487,    1,  321,   52,    1,   37,  104,    1,  398,  261,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  700,  140,    1,    9,    1, 2131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3075, 1141, 1632,  350,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117, 1525,  161, 2567,  437,  456,   85, 2198,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1879,    9,   32,    1,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  323,   32,  166, 2822,    1,    1,   98, 1793,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1972, 1821,  293, 2137,   79,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,    1, 1323,   45,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3306,   12,    1,  195, 1463, 2536,  191, 1863,   12,  474,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116, 2931,    1,  763,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275,    1,  562,  547,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321, 2492,    1, 1159, 2858, 1107,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1334,   45, 3026,  357,  365,    1,   98, 1204,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1009,  928,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  113,   98,  187,  914, 1426,  105,    1,  439,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 1218,   37, 1343,   32,    1, 1417,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,  155,    1, 1816,  220,  395,  420,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  103,  379,  380,  381,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2445,   98,  166,    1,    1,  121,   12,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2474,  777, 1064,  593,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 1639,   45,  166,  365, 2994, 2995,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1855,    1, 2886,    1, 1147, 1976, 1530,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12,  395,    1,  572,  983,  418,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  741,    1,  680,  454,   32, 3343,  863,    1, 3363,   76,   37,\n",
      "          726,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2206, 2207,    1, 1710,  606,    1, 2757,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,  116, 1108,    1,   11,    1,  111,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3198,    1,   39,   45, 1022,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1454,  395,  333,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3391, 1345,    1, 1527, 3150, 2443,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1408,  547,  402,  631,   98, 2275,   88, 1002,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  665,    1, 1661,   32, 2210, 1151,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1661,  207,  197,  418,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1106, 2355, 1013,   61,    1, 3085,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 1450, 2856,   32, 2835,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  942, 1321,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1548,   37, 1155,    1,   32, 2637,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  925, 2783,    1,  404, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2996,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  501,    1,    1, 1210,    1, 2545,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    4,  200, 1158,   12, 2528, 1230,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3147, 2253, 3114, 2874,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2153,  870, 2778,   98,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  968,   12,    1,  535,    1, 1426,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  315, 1821, 2190, 1539,   98, 1893,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  233, 2104,   37,  288,    1,   98,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1877,   37,  856, 2141,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  437,  396,   37, 2856, 1485, 3365,   32,  531,    1,  202,   98,\n",
      "          777,  778,  193,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0],\n",
      "        [   2,  220,  195,    1,  608,    1, 1875, 1171, 2078,  245,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  393, 2598, 1750, 2599,   45, 2240,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  215,  719,   56,   67,  641,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3405,   37,  168,  115,  220,  557,  540, 2237,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  132, 1380,  324,   98,  596, 1267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  267,  199,  472,   39,    9,  864,   37,    1,  220, 2673,\n",
      "         1004,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 1684, 1625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2475, 1508, 1211, 2878,    1,    1,    1,    1,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1107,  293, 1268,  365, 1030,  444, 2733,   32,  691,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3377,    1,    1,    9, 1922, 1204,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1120,   18,  166,  398,    1,   12,  105,    1, 2025, 1160,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1658,  224, 1013,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585,   32, 3339,  754,   45, 3374, 1178, 2414,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  342, 1414, 2707,   37,    1,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2987, 2762,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1369,  716,    1,  182,  354,    1,  202,  267,  460,   12,   81,\n",
      "           98, 1171,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  361,  195,  230, 2001,  576,  159,  417,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  691,  581,  617,  697,    9, 1081, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  200,  340,  439, 1021,  282,    1, 1614,    1, 2625,  361,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  370,    1,   37, 2446,    1,  844,    1,    1,  289,   98,  999,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,  115,   45, 1104,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1272,    9, 2218,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2748,    1, 2489,    1, 3135,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  777,  778,  267, 3381,  437, 2414,  294, 3102,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2505, 2841, 3126,    9,    1, 3046,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2, 195, 506,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1, 531, 132, 973,  28, 104, 159,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  515, 2462,   45, 3075,   12, 1411, 2784,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2680,   12, 2980,    1, 2485,  162, 2683,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   15,    1,  244,    1,   71,    9,  273, 1609,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2073,  567,    1, 2766,   32,    1,  584,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  223,   34,  197,  327,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3014,  251, 1211, 2079,    9, 1718,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  447,  952,    1,  163,    1,  903,    1,   23,   32, 3114,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,  361, 2608, 1085,    7,    9, 1652,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2680,  794,    1, 1117, 1525,  861, 1108,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1076,   12,  693,    9,  671, 1078, 1380,    1,  170,   32, 1820,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  891, 1604,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2142,    1,    1,    1, 2748,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  328, 1795,  140,    1,  372,  104,  853,  934,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111,    1,  700,  267, 2733, 1044, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  116,  412,    1,    1,  384,  530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2895,  506,   30, 1433, 2966,   61,  363,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  393,  225,   28,  548,  359,  132, 2011,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1629,    1,  119,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   77, 1171,   45,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  761,   12, 1646,    1,    1,  985,  629, 1634,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  437,  510,    1, 1549,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1584,    1,  311,   79,  166, 2904,  267,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  138, 1658,  962,    1,    1, 3102, 1373,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,  992,   28,  453,  104, 1208,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2977, 2937, 3012,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200,    1,  613, 1499,    1,  861, 1228,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2077, 1455,  197,  418,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   28,  388,    1,   32,  284, 1451,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2863, 1654, 1385,  444, 2956,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2914, 1199, 1480, 2873,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2885,  744, 1001,  119,  220,    1,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  418,    1,   32,  385,    1,  143,  763,   76,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,    1,  781, 1812,  191,    1, 3011,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,  991,  148,  214,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  336,    1, 2729, 1149, 2421,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596,   32,  531, 2414,    1, 2766,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3155, 3045,  856,  104, 3111,    9,  581,   74,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  233, 2104, 2591,   37,    1,  365, 2138,  261,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  546,  176, 1219,   32,    1,    1,    1, 1531, 1910, 1530,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2914,    1,    1,  777,    1, 1294,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1367,    1, 3218,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,   47,    1,   37,    1, 1633,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  726, 1678,    1,    1, 2911,   98, 1300,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  386, 1445,  459,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1308,    1,    1,  195, 2797,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1676,  336,    1, 1086,  220,  946,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203,  166,  821,  293,   61, 1997,    1,  191, 1089, 1675,  424,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,   25,   71,  187,   69,  980,    1,  185,  120,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  763,    1, 1530,   32, 3349,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,   37, 2678,   98, 2500,    1, 1010, 1239,    1,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2578,   12, 1161,    1,   32, 1922, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2658, 2269,   37,  764, 2638, 2930, 2566,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,    1,  359,  588,    1, 1737,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3191, 1293,  103,   32, 1485, 3096,    1, 1401,   32,  447,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  418,   37,  119,    9, 1194,   74,   98,    1, 1057,  815,\n",
      "          407,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  449,   37,   52, 2399,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  627, 2178,  650, 1484,    9,  129, 1945,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1147,  653,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1230,   37,  168, 2627,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1509,  151,  737,  197,  407,  419,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1660,  983,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,   22, 1225,  788,   61,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  147,    1,  209,  126, 1080, 1624,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  729, 1551,    9,  730,    1,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2723, 2724,    1, 1851, 2294,   37,   52,    1,  411,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  579,    1, 2438, 1827,   98,  166, 2918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2235,  147,  288,   37,  804,    1,    1, 3382,   37, 1046,  134,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2162,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  816,  530,  105,  106,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  219,    1,  908,  365, 1984,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  835,    1,    9, 1263,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 121, 396, 917,  37, 477, 449,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 506,   1,   1, 606, 388, 805,  98,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3112,  453, 2315, 2258, 1167,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1503,    1,  214,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  102,  554,   98,  720,   32,  679,   69,  109,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12, 1009, 1733,    1,    1,  187,  622,  475,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2843,  665,   37,  166, 1477, 1990, 1787,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1211,  111,  822, 1108, 1781,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  233, 2104, 1579, 2650,  361,  613, 2387, 1879,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671,  953,   39,   45,  759,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  121,   12,    1,  140, 2161,   12, 1333,  665,  294,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1010,  997,   45, 3057,   12,    1,    1, 2944,  267,  460,  190,\n",
      "          211,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3092,   37,   33,    1, 2001,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  476, 3140, 2532,   32, 1046,   45,  163,    1,   12,    1,\n",
      "           97,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  112,    1,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  544, 1366,  606,  105,  132,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3213, 1458,    1,    9,  602,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 2303,   32,   51,   98, 2579, 2689,  447,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1500,    1,  102,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1628, 2539,    1,    1, 2741, 1673,  384, 1902,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1047, 1236,  104,  458,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  868, 2764, 3381, 1074, 1530,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3210,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1199,    1,   12,   74,   32,  166, 1361,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1695,    1,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  528,    1,    1,    1,    1, 2647,    1,   45, 1986,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 2553,   39, 1708,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1788,  936,  365, 1294,   37,  226, 2377, 1670,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  506,    1, 2636, 2668,   98,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2298,    1,   32,  863, 1294,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1378,  863,  844, 1442,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2166, 1008,  365, 1455,  475,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1821,  420,  590,    1, 1352,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  952,    1,  764,   32, 2137,  927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,   33,  402, 1228,  572,  197,   28,    1,  387,  388,   93,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  491, 1536,  149,   37,  222,   69, 1149,   32,  430,  477,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1705,   37, 2035,    5,    6,  682, 1737,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2787,   12,  865,    1, 1497,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  379, 1599,  230,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468, 1008,  453, 1764, 1990,  872,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  531, 2751,  856,   81,  187,  104, 2909, 3155,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2190, 3033, 1373,   37,    1, 1011,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   68,  418,   98,  531,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3078, 1987, 2865,    1,   39,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,    1,  191,   22,  298,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187, 3243, 2917,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3129,  833,  612, 1188,  105,    1, 1294,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3208,  121,  315,  103, 1722, 1313,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3024,   12,    1,    1,  384,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,   98, 1935, 1160,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,    1, 1841,    1,    1,  372,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,  108,   69,  109,    6,  110,    9,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1802,    1,  949,  384,    1,    1,   98,    1,  132,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  288,   37,  103,  121,  395,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  112,   36,    1,   39,   40,   41,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98, 3388, 2024,  226, 2198, 3358,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,  200, 2069,  647,  693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2526,  342,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  845,  275,    1, 1950, 1294, 2222, 1781,   32,  602,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1794, 1310,   37,  439, 3106,  444, 1973,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  449,  992, 1750, 2024,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3332, 1554,    1,  220,  105,    1,   32, 1245,   12,  726,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2548, 2377, 1399,   45, 1406,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2427,    1,  713,   37, 1046,  938, 2032,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  819, 2192,  169,    1,  702,  170,  410, 2407,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  146,   37,  810,    1,   32,  365,  825,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  365,    1, 1108,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3319, 2712, 3231,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2597, 2137, 2856, 3128, 2770,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,    1,    1,    1,  753,    9, 2507, 2823,  863,  726,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1059, 1067,   37, 1089, 1675,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  623,  572,  156, 1124,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,   69,    1,    1,  498,   98,  182,  493,  965,  132,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700,    1,    1,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  108,   45, 2786, 2987, 2762,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1925, 1583, 1685,    1, 1523,  424,  818,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  220, 1035,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   76,   37,  245,   98, 1162,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1545, 2422,   32,  447, 3273,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  957,  267,    1,  220, 2997,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2536, 1530,   32, 2702,    1,   32, 1850, 2140,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,  298, 1159,    1, 2414,  810,   98,  721,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1576,  588, 1031,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  315,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,  413,    9,  372,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  434,    1,  786, 1539,  176,  105,  199, 1821,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  626,   70,  102, 1376,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1260,   45,  166,  538,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2352,  142,   37,    1,  787, 2771,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  612,  613,    1, 1107, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  758, 1660, 1117, 1525, 2759, 1650,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602, 3109, 1194, 3060,   32, 2877,  722,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  306,  794,  105,  777, 1013, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2551,    1,    1,  683,  307, 1090,   32, 1959,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1327, 1550,    1,    1,    9, 3365,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2625, 2759, 1294,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  147,  884,   98, 2360,   45,    1, 1054,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3385,    1, 1428,   45, 2249,  531, 3373,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 688, 902,   1, 428,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 105,   1, 227, 356,   9, 166,   1,   1,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1591,    1,  387,  159,   71, 1022,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2862, 1419, 3080,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  856, 2251,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1,  176, 1273,  275,   16,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  439,   28,    1,    1,  191,  185,    1,   69,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  622, 2377, 1456,  284,  531, 1931,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1476,  977,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 1583,   79,    1, 2705,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  758,  197,  388,  763,    1, 2645,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61, 1988,   45,  312,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,  81,  98, 166,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 326, 244, 686, 191, 331, 869, 399,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1891, 3146,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1397,    1, 2374,  384,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2500,  663,  437, 1236, 3128,    9, 1791,  443, 2938,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1188,  193, 2047,  854,  361,  395,  302, 1712,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  536, 3364, 2315, 2708,  890,  844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2206, 2207,   12,    1, 2757,   37,   52, 3390,   32,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  997,    1,  102,  554,  187, 2782, 2369,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3112,  476,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1809,    1,   98,  411, 3024,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3005,    1,    1, 1952,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1970,   12, 3141, 1829,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310, 2476,  856, 2829,    1,   32,  104,  890,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1676,  851, 1478,   32, 1423,   32,  581, 2596, 2393,   32,  547,\n",
      "         1890,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2479,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2718, 2653,    1,    1,    1,  176,  613,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1933,    1, 1635,  283,  655,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 1343,   32, 1107,  787, 2771,   32,    1,    1,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 2436,    1,    1,    1,    1,  220,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  107, 1082,  163,    1,   12,    1,   37,  815, 1193,   69, 1356,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  454,   32, 3155,    9, 3348,  591,  639,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3302,   37,  518,    1,  593, 1990, 2789,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1683,  384, 3127, 1054,   32,  754,  611,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   64, 2414, 3094,   32, 3349,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796,   25,  417,  187,  217, 2338,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 2249, 1811,  404,   10,    1, 2275,    1, 3101, 2708, 2299,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2266, 2357, 3155, 1560,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2932, 1604,   98,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1647,   61,    1,   32,  903,    1, 1423, 2024,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275,   98, 1816,   45,  195,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1127,    1,  143,   60,  817,   98,   94,  159,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359, 1004, 3140, 1598, 3006,   63,   46,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3399, 2390,    1, 2644,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  183,  228,  288, 1515, 2364,   98, 1273,  844,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,  453,    1,    9,  964,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1186, 1974, 2234,    9,  164,  165,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2110, 3272,  590,    1, 3110,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  311,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  359, 1406,    1, 1767,  542,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  813, 2410,   45, 1147, 2179, 1929,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 1090, 2677,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1956, 2548,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  200, 2452,  517,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1652,    1,  929,    1,    1, 1554,  669,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2307,  515,  365, 2234, 1017,  105, 1463, 1027,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1837,    1, 2322,  288,    9,  148,  647,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  398,    8,    1, 1250,   98,   49,   50, 1611,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3300, 1285, 2584,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3239,    1,    1, 1061,   98,  195,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  519,  193, 2587, 2966,  951,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1304, 1025, 1426,  630,  220,  422,   98,  133,  549,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3231, 1822,  665,    1,   98, 2378, 1110,  729, 2793,    9, 3235,\n",
      "          539,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  776, 2306,  288,    9,  667, 1988,   45,    1,  487,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1457,  770,  183,  681,    1, 2298,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  120,   98,   10,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  220,  378,    1,   37,    1,    1,  441,  661,  365, 1262,   37,\n",
      "          619,   39,  166, 1263,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,  705,    1, 1417,    1,  386,  335,    1, 1684,  297, 2570,\n",
      "          787,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3095,    1, 3375, 1807, 2922,   37,    1,   10, 1563,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1028, 1298,  753,    9, 1815,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2193, 2884, 2830,    1,  622,   79, 1515, 1054,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  460,   51,   47,   48,   32, 2002,  671, 2003,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  443, 2281, 1268,  342,    1,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999,   91,    1, 1994, 2819, 3050,  384, 2606,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2173, 1114, 2625,   49,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  773,    1,  938, 1282,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1290,  396,  720,    9, 1913,   73, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1013,  361,    1,    1, 1000,    1,    1,    1,  326,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1326,   12, 2073, 1843,  197,    1,   98, 1547,    1, 1501,  701,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1827,  730,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  959,    1,  967,  105, 2854,   32,  424,  856,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1433,  166, 2047,    1, 2202,  220,  166, 1779,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  743,   12,   82, 1554,   37,  856,  505,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  693, 1358,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1436, 2602,    9,    1,    1, 2800,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584,  105,  331, 2565,    1, 1360,  612,  619,  881,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3045, 2856,  228,   32,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1360,  612,    1,  163,    1,   12,    1, 1437,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,   65,   12,    1,  577,   98,  104,  954,    1, 1349,   98,\n",
      "         1278,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  231, 1773, 2510,  105,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  593,  896,    1,  884, 1894, 1992,   37,    1, 1463,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260, 2712, 3232,   32,    1, 1090,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3342,   12, 2059, 1231,   32, 2282,  722,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2394,    1,    1, 2700,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2583,   12, 1280,  100,    1,    1, 1483,  176,  915,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523,  917,   98, 1434,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  928,  176,  823,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  813, 1448,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3262, 2800, 1218, 1831,    1,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   31,   67,   32,   33,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  338,  202,    1, 2598, 2029, 3303,  114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  732,  851,    1,  548,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1209,    1,  171,   45, 2821, 1017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  369,    1, 1564, 1299,  973,    9, 3019, 1151,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,   12,    1,  929, 2437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  704,    1, 1494, 1480,   32,  666,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  609,   12, 1623,    1,   32,  700,  637,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1427,  344, 3389, 2856,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,   12, 1016, 1268,  454,    9,  662,  220, 3359,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129, 2246, 2885, 1401, 2523,    1,  123,   37,  103, 1569,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   10, 1625, 2095, 1263,    1,   32,  903,    1, 1256,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  950,  574, 1132, 1493,  388,  763,  152,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  979,  304, 1638,   98, 2429,   37,  725,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,  104, 3164,    1, 2347,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2388, 2726, 2206, 2207,  171,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  708,  709,  355,  710,  187,   82,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  113,  176,    1,    1,    9,  889,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1886,   51, 2010,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   61, 1509,   98,   74,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1887,   45, 3102,    1, 2516, 1521,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1147, 2751, 2253, 1796, 3102,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273,   21, 2048,  176,  730, 2614,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3167, 2295, 2087, 2614,    1, 1739,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2710,  437,  353, 1791, 2455,   45,    1, 3047,   32,  531,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  413,    9, 1084,  841, 2153,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,  475,  387,  388,    1,   32, 1437,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  446, 1921,   32, 1966,    9, 1319, 2396,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1498,   51,    1, 1099, 1453, 1499,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 2623, 2624,    1,    1,  729,    1,  612,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510, 2097, 2732,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  891, 1107, 2610,  778,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,  186,    9, 1212, 2823,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1128,  387,  218,  682,  220,  365,    1, 2168,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  361, 1790, 2274,    9, 3049,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3101,    1,  546, 1461, 1159, 3339, 3133,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,  418,  995,    1,  159,   28,  419,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1185, 2685,  583, 3117,   32,  105, 1090, 1444,  110,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510, 1774, 2029, 2028,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 1258,    1,    1, 1737,    1,  444,    1, 1396,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,   82,  460,   61, 1176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1,    9, 1222, 2759, 1708,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   98, 1220, 1089, 1090, 1085,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2732,   12,  947,    1,  939,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,  108,   69,  109,    6,  110,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,  361, 1861,    1,  386, 1030,   98,  365,  916,    9, 3388,\n",
      "         2024,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,    1, 1750,    1,  163,    1,   12,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,    1,    1,   32, 1802,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1,  437, 1679, 1147, 2548,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1247,    1,   37,  877,  449,  221,   32,  331,    1,  142, 1523,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572, 1897,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,  459,  302,   37,   77,  957,  707,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2618,    1, 1919,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3157, 1114, 2035, 1757,    9, 1428, 3365,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  396, 1254, 2334,   98,  166, 3022,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2837, 2816, 2732,  115,   45,  567,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 1566,    1,   68,   69,    1,  667,  716,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1545, 2331,    1,  562,    9, 1178, 1179,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,  225,  616, 1046,    1,  238,  297,  365, 2089,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 197, 277, 191,   1,   1, 962,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 753,   1, 186, 321,   1, 166,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1287, 3200,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  836,    1, 1645,    1, 2237, 1094,  187, 1994,    1,  418,  176,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2181,  220,  777, 1085,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  920,   12,  193,  199,   37, 1198,  347,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2719,    1, 1187,    1,    1, 1176,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,    1,  187, 1094, 1830,    9,  247, 2162,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,    1,  176,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1380,  453,  327,  112,   28,    9,  333,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 2537,  653,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1433,  753,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2885,    1, 3258, 1863,   45,  356,  191,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 2981, 2436, 2896,    1,  928,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,   25,  288,    9,  699,    1,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647, 1082,  779,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  864, 1112,  176, 2673,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1139, 1105, 2900, 1585,   32, 2018,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2902, 1413,   98,  613,   80,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3076,    1,   28,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,  37, 168,   1,  32,  54, 142,   9, 667, 413,   1,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 491,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1071,  342,  751,   32, 3369,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106,  744,  668, 1215,   98, 2474,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  479,  157,    1,   25,  242,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   61,  786,    9,  166, 1772,    1,  380,  284,  220, 2609,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  566,  856,   98, 3356,  754,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9, 1064,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2334, 1631,  846,  119,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  861,  662, 1082,  961,  522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1039, 2321,    1,   37, 1421, 3229, 2719,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3198,    1, 3169,   32, 2197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3024,   12, 2604, 1294,    1,  191,    1,  220, 1292,    1,    1,\n",
      "          774,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   66,  143,   69,    1,   60,  817,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,    1,  297, 1994, 3036, 3037,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  313,   37, 1296,   28,  166,  526,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  129,    1,  890,  288,    9,  740,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  794, 2102, 1107,  525,   32,  942,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  185,  321,  612, 1000,    1,    1, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 1940,   12,  810, 1425, 3208, 2630,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,  113,  682,  548,  163,    1,   12,    1, 1097,   29,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162, 1950,   32,  395, 2003, 1585, 1426,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361,   37, 2365,   39, 1211, 2366, 2367,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128, 1380, 1361,   32,    1,   98, 2232,  332,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  905,   10,  777,  412, 1825, 2017,  104, 2911,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479, 1564,   56,  356,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1547,  418,  444,   60,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1829,    1, 2175,    1,  763,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1087,  494,  109,  524,    1, 1250,    1,  583,  163,    1,   12,\n",
      "            1,  572,  932, 1379,   12,  112,  499,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  809,  884, 1381,  548,  758,  932,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,  484, 1724,   98,    1,   45, 2924,   32,  531, 1861,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1,    1, 1789,    1,  616,  123,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  727,   37, 1155,  365,    1,    1, 1074,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1070, 1462,  475,   37, 1334,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 1479,  170,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1840,    1,   37,  151, 1840, 1300,   48,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2421,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,  504,  284,    1, 2012,  220, 2872,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2518,   45, 2948,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  389,  682,   32,  171,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1788, 1688,   37,  433,    1,    1, 3096,  437,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190, 1343,  584,  171,   32,    1, 2771,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,  974,    1,  361, 1977,  202,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613, 1766, 1767,  841,  105,  449, 1173,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  116, 2542, 2226,  331,  380,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3167,  193,  972,   37,    1,    1, 2264,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  749,    1, 1409, 1008,  228,  388,    1,  229,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232,  168,   81,   37,   81,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2802,  515,  365, 1173, 1423,    1, 1639,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1, 2414,   32,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   47, 1023,   45, 2912,  675,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181,  103,  548, 3143,  429, 1545,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2026,    1, 1976,   98,  166,  116,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  477,  943, 1618,   28,  187, 2322,   98,  104,  358, 1384, 1495,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   97,   98, 2689, 1717,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1854,  387,  193,  320,  363,  572,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   56, 1530,  548, 1260,   98,    1, 1178,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962, 3260,  335,  631,   32, 1264,  841, 2107,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,  176,  177, 1700,  257,  548, 1827, 3078, 1857,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,   32, 3101,    1,  698, 3136,  477,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  161,  931,   37, 1427,  163,    1, 2196,    1,    1, 1469,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1554, 3236, 3186, 1090,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2974,  288,   37,  335, 2695, 2223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2734,  256,   37,    1,   32,    1, 2674,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   20, 2645,  296,    9,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  813,    1,    1,   26, 2943,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3111,  361,  105,  517,    1, 2226,    1,  565, 2572,   32,\n",
      "            1, 1450,   32,  531,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2381,    1,  973,   28, 2053,  636,  232,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  267,  388, 1147,  947,  565,  110,  187,\n",
      "         1450, 1348,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  785,  786, 1831,    1, 1936,  822,  522,  444,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,    1,   94,  361, 1547,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1770, 1433,  455,    1,  612,    1,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1212,   12,  700,  267,   69,  636,   37, 2449,  845,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1,  547,  257,   98,  389,    1,    1, 1513,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  449,  219,    1, 1627, 3048, 2818,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640,   81,  176,    1, 1663,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  798, 1918,  176, 1261,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  295, 1352,   50,  983,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1937, 3002,    1,    1,  187,  103,  861, 1787,    9,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1194,  593, 2522, 1684,    1,    9, 1022,    1, 2296,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3376, 1585, 1924, 2083,  163,    1,   12,    1, 2147,    1,  590,\n",
      "          163,    1,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066, 2726,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3250,    1,   37, 1306, 2119,  220, 3288, 1987,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1757,    9, 3026,   45, 1796, 3102, 2424,  220,  590,  550,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  376, 1952,  197,  570,   98,  636,    6,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2016,  386, 1544,    1,    1, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3115,    1,    1,   32, 1656, 2291,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2737,    1,   12,    1, 2411,    9, 1197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1711,   45, 1140,  656,    4,   37,  168, 2311,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1285,   85,    1,  119,   68,  246,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2142,   12,    1,  193,    1,  449,    1,   45, 1044,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1880,    1,    1,   32,   46,   98, 1610,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  437,  929,   37,  930,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  977,  881,   45, 1965, 2982, 2699,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  112,  550,    9, 1017, 2153, 2077,    1,  971,  872,   28,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91, 1648,   37,    1,  971,  975,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   96,  460, 1425,  176,    1, 3154,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2839,   37,  125,  531, 2924,   32,  411,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2614,  894,  726,  460,  810,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,   12,    1, 2498, 1463, 2483,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  539, 1037,    1,   37,    1, 2771, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  527,  162,   74,  881,   45,  147,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087, 1380,    1,  429,   98, 2693,    1, 1607,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1751,   39,   37, 2230, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3358, 3090, 1585,   32, 3339,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3196, 1401,  461,  786, 1056,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1507,  541,   37, 1186,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,    1,    1,   10,   12,    1,    1,  105,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  597,    1,  475, 2145, 2827,   32,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1474,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,    1, 2968,   36,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,  794, 1180,    1, 2400,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1330,    9, 1273, 2913,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  155,  453,  731,   98,  393,  159,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   64,    1,  608,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  620,    1, 1464,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,   37, 2728,    1,  220,  861, 1151,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   12,    1,    1, 3186,   39,   45,   91,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   10, 1921,   32,  942,    9,  449, 1267,   45,  593,    1, 2731,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2920,  764,    1,  612,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1319, 1320,   45,  518,  519,    1,  808,   45,  876,  612,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 1830,    9, 1442,  956,  220,  342,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1028,  190,    1,    1,   39, 2102,    1, 3011,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118,  132,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3354,  379,    1,    1, 1606, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  551,  244,  688,  739,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1447,  744, 2915,    9,  454,   46,   37, 1195,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,  437,  952,    1, 2024,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2616,  696, 1403,  395,    1,   37, 2998,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353, 1124,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2725, 1001, 2758,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2126,   45,    1,   55, 2946, 1976,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1748,   45, 2820,   16,  411, 3024,   55, 2915,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2107, 2369, 1340, 3299,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,   71, 1114,  297,   49,  997,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2104, 2591,   37, 2856,   20,   22,   23,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1771,  171, 1874,  885,  549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3244,    1, 3200,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2977,  475,   61,    1,  548,  537,    1,  379,  774,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870, 1353,  327,    1,  809,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  558,   11,    1, 1258,  220,   54,  215,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141,   12, 1349,   61, 2516,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 1253,  548,  104,  716,  417, 1588,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 1940, 1156,    9,    1,  310,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  961,  147,   37, 1709,  829, 1377,   45,  116, 2542,  400,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  200,    1, 2581,    9, 1021, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,   37,  687,    1,   94,    1, 1547,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1024,  696,  705, 1458,  439, 2335, 1090,  832,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  510,    1,  539, 2028,  361,    1, 1159, 1549,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2174,    9,    1,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1, 1119,  680,  166,  433,   45, 1099, 1453,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   12,  572,  244,   28,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1712, 1713,  316,  317,  624,    1,  187,  940,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  335,    1, 2610, 2545,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1899,  580,    5,  134,   32, 1966,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  954,  353,    1,   93,   32,  581,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3123,    1, 1818,  297,  311,   12,    1, 3009,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  117,  700, 2783,  142,    9,  163,    1,   12,    1,  413,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  291, 1419,    1,    1,   26, 1039,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,    1,    1,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,   32,  166, 2826,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,  551,  105,  829,   12, 1718,    1, 2279,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   26, 1039,  226, 2232,  288,    9,  949,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973,    1, 1492,    1, 1675, 2356,   45,  966,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3306,  267, 2602,   37, 3181,  542,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  803, 1244,   51,  619,  271,   98,  618,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1713, 3108,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713, 2912,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  726,  919,    1, 1684,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3335,    1,    1,    1,   12,  714,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,  695,   76, 1282,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3278,    1, 3013, 2126,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,   39,    9,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  491,  640, 3392,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,  387,  803,  916,   45, 1428,  996,  909,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676,    1,   32, 3344,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1236,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3070, 1207,   37,  665, 2774,   98,  776,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,   39,  365,    1,  280,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  934,   51,   52, 1634,   37, 2164,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1111,  600, 3238,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  852,   37, 1888,  548,  104,   26,  354,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  536, 2873, 2960,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  315, 3019,   55, 1589,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   89,  267,  198,   60,   61,   32,  507,   12, 1184,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  327, 2054,  333,  191,  326, 1710,    1, 1031, 2928,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2976,  861, 2762,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117,    1,  163,    1,  700,  839,  274,  700,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   20,  927,  167,    1,  413, 2039,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  446,    1,  884,  411,  631,   32, 2823, 2107,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1361,  729, 2781,    9,  148,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  636,  105, 1057,    9,  104,  954,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  977,    1,  138,  331, 2021,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1,    1,  891,  424,  339,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,   12, 2355, 1013,   61,    1,    1, 1724,    1, 3000,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1470, 3105,    1,  507,  361, 1094,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101,  477, 2414,  547,    1, 3006,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2067,  384,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3173,    1, 2779,    1,   63, 2069, 1798,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,    1,    9, 1018,  411, 1463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  751,    1,   98,    1,    1,    1,    1, 2727,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1133,  688,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1707,  903,    1, 1447, 2915,    9, 2673,\n",
      "           46,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  811, 1877, 2848,  956,  220,  976,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2414, 1312,    1, 2766,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  572,  244,  565,   85,    1,  202,   15, 1473,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1190,    1,  600,    1,  549,   37,    1, 1984,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  261,  105,    1,   61,  193,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2275,  140,  542,    1,  220,  596, 1793,  469,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  140,    1,  622, 1967,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3175,    1,  105,   12,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2463, 2712, 1245,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2925, 2489, 1628,    1,  951,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  829,   12,  535,  656, 1542,    9, 1065,  199,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,  114,  187, 2427,    1,   98,  166, 2202,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967,    1,   85,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 2494,  872,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1602,   12,  103, 3210,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  786,    1, 2679,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3115, 1376,    1,  440, 2715,   45,    1,   32, 2205,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3199,  140,    1, 2107,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1235,  102,  317, 2050,  367,  720,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,  387,    1,  100,    1,  187,    7, 1567,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  952,    1,   32,  581, 1370,   45, 2031,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  803, 1585, 2668, 2757,   12,  756,   32,  447,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1396,    1,  249,    9,  777, 1704,  844,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2595, 1568,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2738,    1,  903,    1,  182,    1, 1603,    1, 1518,    1,    1,\n",
      "            1,  176,  177,  249,   39,   45, 1604,  963, 2122,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1520, 1042,    1,  384,  104,   14,  218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1450,    1, 2849,  297, 1645,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 1178, 1924,  105,    1,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  391,  613, 1017, 1268,   28,  365, 1262,    9,  327, 2264,   37,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1297, 2264,    1, 2381,    1, 2165,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1,  696, 1563,   65,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3269,   61,  105,  183,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,  682,  590,  104, 1527,   37, 1876,   60,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1363,   37,  151,   81,  388,  159,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  430, 3369, 2292, 1702, 2024,   46,   79, 1171,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3139,  476,   37,  168,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 1372,   37,  619,  705, 2796,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2999,   91,  456,   85,  792,  166, 2518,  792,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  546,   82, 1492,    1,  148,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  506, 1087,   61,  593,   12,  103, 1151,  607,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303,  954,    1,    1,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,  193, 1724,    1,  671, 1078,  963,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  275,  494, 1986,   61,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3181,  606,    1, 2349,    1,    1, 3306,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1290,  396,   71,   98,  585,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3177,  566, 3116,  922, 2494,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1,  464, 1068,  568,   93, 1226,   37, 2335,  339,  340,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1237, 1658, 1117, 1525,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545,   81,   98, 1171,  220,  365,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  223,  325,  449,  223,  437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,   37, 2122,   98,  651, 1031,    1, 1787,   10,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  786,   37, 2162,    1,   37,  611,   98, 2095,  134,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2036,  936,    1,   37, 1155, 1898,  220, 1725,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  251,    1,   37, 1156, 3139,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,  338,  187,  408,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  774,  140, 2505, 3126, 2072, 2942,  176, 1139, 1434,  593,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  980,  187,  679,   69,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  822, 2195,    9, 1107,  293,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2963,  176,    1, 2072, 1427,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  632,   21,  741,   98, 1839, 3037,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1236,  787,   45,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1087,   30,  365,    1,    1, 2686, 2687,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2451,  546, 2565,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  420, 1550,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2577,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  581, 2960, 2668,    1,  501, 2060,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204, 1249, 3230,   37,  726, 2490,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  920,    1,  758, 1013,   98, 1273,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2297,   37,  631,    1,  861,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 1874,    1,  432,   45,    1,    1,  776,  469,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1786,   45, 2024,   98,  776, 1550,    1,    1,    1,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  492,    1, 1492,    1,    1,   61, 1919,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3176,  168,  547, 1394, 1048,   32, 2792,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  190, 1317,  704,  104,  606, 2745, 2063,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437, 1261, 1117, 2208, 2298,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3374,  650,    1,    1,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2183, 1499, 1176,    1,  220,  414,  861,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  702,   11,  169,   32,  131,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,    1,  602,   37,  864,  899, 2673,  210,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  667, 2702,    1,    1,    1,   32,    1,  171,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  166, 3252,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   32,  395,    1, 2830, 1384, 2321, 1176,  445,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999,  251, 2819, 2232, 1260,  210,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3349, 3395,    1, 1976,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1166,  565,   69,  102, 1036,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1821, 2190, 2640,  891,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1113,    1,   69,  550,   77,   25,  410,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2353, 1623,    9,   12,    1, 2170,   12, 1110,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597, 2548,  498,   37, 1910, 3362,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 2996,    1, 2232,    1, 2762,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283,  757, 1564,  105,  955, 1343,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  622, 2120, 2862,  650,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1695, 2209,    1, 1976,   32,  511,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453,  894,    1, 1772,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  365,    1, 1199,    1, 1976, 1425, 2662,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2615,    1, 2720, 2796,  894,    1, 1090,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2753,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158,    1,  608,  166,   59, 2102,  813,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1,    1,  403,  455,    1,  898, 1530,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2745,   32, 1958,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1089, 1294, 2806,    1, 1565, 2973, 1764,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  391,   12,  572,  197, 1042,  118,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  971,    1,  479,  125, 1069,  163,    1,   12,    1,   15,  245,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1255,   98,  845,    1, 2393, 1969,  365,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2871,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  575,    1,   14,   15,   37,  105,  119,    1,  131,   32,  367,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  741,    1,  891, 1890,  548, 3343, 2823,  863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  374,  267,  590,    1,   32, 2656,    1,  420,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1206,    1,   37, 1468,    1,    1,  333, 2085,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   45, 2472,    1,  361,    1, 1940,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1412,    1,  810,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,    1,    1, 1965,    1,  608,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3228, 1188,  140,   37,  427, 3276,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,   12,    1, 1299,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2, 657,   1, 600, 818,  15,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 155, 197, 157,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,  613,  567, 1402,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2403,  769,   32,  657,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2232, 2815,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2076,  572, 2232, 1828,   28,   98, 1361,    1, 1128, 1565,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,  105, 1198,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1203,    1,  331,    1,    9, 2323,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2573,   12, 3398, 1654,  142,   37, 1198, 2179, 1281,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  737,  207,  174,  418,  419,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  550, 1039, 1092,   37, 1753, 2232, 1182, 2072,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,  640,  743,   12,  220,    1,    1,   43,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1087, 1412,  973,  313,    9, 2301, 2012,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3068,    1, 1962,   37, 2904,   28,    1,   80,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3207,  140,  810, 1425, 3208, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649,    1, 1380,  455,   98,  730, 2393,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1162,    1, 1420,    1,   37,   47,  159,   32,    1,    1, 1126,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1464,  229, 1463,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1712,    1,  294, 1194,  356,   32,  105, 1559,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  475,    1,  297, 2001,   98,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  829,  288,  103, 1510, 1542,   37, 2365,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,   37, 3319,   32,  442,    9, 1183,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1083,  997,   45,  968, 2162, 3273,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1109,  156,  115,   45,  570,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  865,   37,   64,    1, 1219,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1017,  696,   91,  619,   37,  166, 2918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3096,    1,    1,   98, 3177,  791,   37, 1178, 1179,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  388, 2690,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2073, 1385,   45,   46,   98, 3118,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1744,    1,   45, 3009, 1821,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,   25,  504,  159,   45,  381,    1,  458,   45,  507, 1758,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810,    9,  786,    1,  267,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  649,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3402,    1, 2726, 3040, 2564,   32, 3339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  503,   12,  749,  533,  817,   98,   25,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1345, 2897,   32,  539, 3369,  528,  895,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  614,    9, 2848,    1,  949,  220, 1023, 1204,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  142,   37, 1154,    5,    1,    9,  166,  594,   61,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  684,  356, 2415,  429,  123,   37,    1,  845,    9,  581, 1034,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  160,  102,  120,    1,  118,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2492, 3005,    1, 1632, 2987, 2454,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3189,    1,    1, 3227,    1,  951,    1, 1110,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2685,    1, 1348,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,    1, 3119,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   26,  699,  242,  187,   69,  980,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 2310,  917,    1,    1,    1,   37, 2310, 1827,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  398, 1042,  400,  444,  366,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 2089, 1294,    1,  105,  356,  857,    1,  431,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3143, 1454,    1,    1,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3332,  140,  754,  714,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,    1,    1, 1877,  590, 1796, 2129,  548,    1,   12,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1186,   12, 1016, 2789, 1141,   37, 1119, 1929,  289,  384,  531,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 2170,    1, 3079,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2759,    1, 2511,   37, 1876, 2487, 3016, 1935,  361, 2723, 2724,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   39,   45, 3220,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  890,    1, 2789,   45, 2002, 1009,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,   98,  446,   37,    1,   37,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  987, 1564,  284,  822, 2298,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,    1, 1787,   32,  691,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2468, 2936,  361, 3313, 2487,  726,  361,    1, 1515,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2685,  103,  730, 2614,   32,  693,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2255, 2524,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,    1,    1,  356, 1490,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  861,    7,   32, 1081,  741,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1226,    1, 1547,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3188, 1494,   28, 1139,   45,    1,   12,  813,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1749,  220,    1,    1,  950,  551, 1130,   37,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,   12, 1407, 1356,  686,  119,  845,   32,  367,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  493,  102,  720,  187,   68,   69,  109,  418,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3319,    1,   28, 2685,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  750, 2554, 1959,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3321,    1,    1,    1,  220,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  460, 1278,   37, 1192, 1411,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1778, 2264, 1210,  932,    1,  193, 2881, 1288,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  947, 2360, 1243,   45,  854, 2690, 2607,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   12, 1065, 1190,    1,  104,  622,   32, 2891,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   56, 3375, 2572,   32, 3339,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,   22,    1,  901,   59,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1290,  396,  276,  995,  915, 1034,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2802,    1,  202,  193,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 1983,  159,  720,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035,  624,    1, 1635,    1,   37, 1865,  844,   16,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  528, 1393,  390,    1,    1,   12,  207,  418,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  140, 2024, 2223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1785,    1, 1464,   37, 1267,  350, 2357,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,  102,  245,  528, 1450,   98,  531,  965,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  405,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  361,    1,    1, 2992,  662,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  506, 2196,  377,  275,    4,  452,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504, 2038, 2770, 2705, 1223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2445,    1,   37, 2669, 3373,   98, 2487,  632, 1497,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  458,  582,   37, 1910,   32, 1014,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  176,  915,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3173,    1, 2779, 1758,   37,  395,   26, 3295,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  829,   12,   72,   26, 1228,  934,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,    1,    9,    1,  374,  375,  213,   37,  151,    1,  172,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1499,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 1908,   98, 2997, 2762,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1817,    1, 2321,    1,   45,  510, 1530,   32,  163,    1,   12,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3211,    1, 2882,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3198,    6, 1139, 3257,   12,  356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1966, 1564, 2069,  695, 1899,  321, 1734,  776,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,  810,    1,  187,    1,  338,  411,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  197, 1137,   98,  242,    1,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  366,    1, 1269, 1114,   32, 1352,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  168,  168,    1,   51,  606,  277, 3224, 1492,  416, 1333,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  952,  399,   45,  573,   43,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1831,  101,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  619, 1542,    9, 2069, 1385,   45,  449,  450, 2823,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3102, 2572,   32, 2018, 1746,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  500,  952,   93,    1,  193,  197,    1,  159, 1374,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  463, 1447, 2652,  531,    1,   45,    1, 2924,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  335,  104,   37, 1965,    1,    1,  872,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3168,    1,    1,  759,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1, 3034, 2988,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  159,  245,  548,    1, 1869,  304,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  880,    1,    1,  232, 2421,   32, 1440,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  251,    1,  131,    9,  989,    1,  195,   13,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545,    1,  460,    9, 1022,  611,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3352, 2856,  947,   32, 1450,   32, 2433,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,    1,  267, 1228,  190,   52, 1370,   45,    1,   37,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  688, 1178,    1,  787,   37,    1,  910,  220,  103,   56,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  654,  737,  197,  418,  419,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3060,  928,   32, 2018,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1778, 2432, 2493,    1, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2916,    1,    1,    9,  453,  264, 1477, 1990,  288,   28,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3349,  597, 2774,  582,  598,   45, 2772,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  311,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,  727,  744,   28,    1,  754,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2762,   30,  454,   32,   37, 2026, 1450,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1224,   37, 2288,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3097,  446,    1,    1, 2757, 1523,    9,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116, 2542, 1654,  388,  218,  332, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  641,  505, 1665,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1480,  845,   98, 1816, 1125, 1708,    1,    1, 1210,    1,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1249, 3257,    1,  515, 2637,  631,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1140,    9,  522,  297,  133,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2940,   39,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,  942,   37,  151, 1266, 1497,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2615,   51,  619, 1024,  187,  802, 1348,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2910,  220,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,  200,  453,  645, 2452,    1,  257,  857,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,  707,   37, 1289, 1100,    1,   37, 1607,  260,   82,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1943,  786, 2202,   39,   45,  987,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  936, 1013,  132,  220, 1312, 1410,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   61,    1,  166, 2498,   32,  166, 1194,  667,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1973, 2024,   46,  439, 2198, 2666,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  994, 1638,  967, 1354,    1, 2085,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1378,    1,    9, 1989, 1990,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,    1, 2900,   45, 2095,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1287,   98,    4, 1397,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3399,  864, 3107, 2096,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1173,   37,    1,    1,   98, 3079,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1013,  361,    1, 2699,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1427,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1290, 1397, 1124, 1114,   32,  602,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  374,  375,   61, 1229,   37,  498,   37,  105,  132,   37,  151,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1203,   32,    1, 1871,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  261,    1,  400,   37,  335,  913,   32,   26,  147,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1536, 2281, 2118,  444,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1189,    1, 2729, 3365, 1683, 2572,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2642,  186, 1071, 1717,   12, 1027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2822,    1,   51,   26, 2728,    1,    1,  202,  762,  845,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2919,   45, 1920,   12,  770,   32, 3155,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  108,  395,  460,   51,    1, 1650,   98,    1, 1196,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1902,  900,   12,  667,    1,  574, 1536,    9,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151,   37,    1,   39, 2308, 2283,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  395, 2003, 1585, 2414,   32, 1194,    1,   32,  257,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1118,  215,  858, 2365,   39, 2013,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  512,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2357,  297, 3343, 1021, 1559,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1789,    1,   79,    1,  650,   12, 2081,   45,  166, 2921,   12,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1888, 1724,    9, 3253,    1,  267, 1404,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3144,   12, 3372, 1268, 2198,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2042, 1900,    1, 2376,  712,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  864, 1710,  193,  690, 1183, 2113, 2836,   45, 2673,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3378,  872,  588, 2199,   37,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327, 1066,  297, 3365, 1944,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2345,  166,  917,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3183,  168,    9, 2333,  726,  914,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3172,  400,  590, 1406,    9, 3327,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2122,  231,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1233,  333,    1, 2154, 1184,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2907,    1,  191, 2868,  371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  761,   12, 1646,  919,  985, 1260,  629,   32,  776,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1, 2708,    1, 3374,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1789, 1286,  157, 1111,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092,   12,  786,  477, 1563, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275,    1,  953,   32,    1, 1002,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  352,  353,  354,   98,    1,   44,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1964,   28,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 2343,    1, 1061,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2442, 1583,    1,  738,  166,    1,  866,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  846,   28, 2343,   12,  776,    1, 2877,   90,  147,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1346, 2344,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1009, 1008, 1065, 1190,   37,  582,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428,    1,    1,   37, 3358,   12,  223,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1486,    1,    1,  686,  191, 1629,  927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  405,    1,    1,   32,    1, 2577,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715, 2735,  947, 1439,  297, 3051, 2162,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2844,   32, 1815, 3279,  187, 1190, 2770,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2932, 1248,    1,    1,  261,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1802, 2746, 1207,   37,  856,    9,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2563,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1369,  330,   37,  322,   85,  259, 1541,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053, 1564,  183, 1250,    1,  113,   79,   98, 1117,   12,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  691, 1625,   37, 1421,  365,  861, 1259,  220, 1081,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  108,   45,  800,  401,    1,   82,  939,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 2237, 3079,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1536,    9,  331, 1126,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  437,  812,    1,   12,    1, 1896,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12,    1,   37,  151,  388,   45,    1, 1017,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2741,  691,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136, 1419,  613,    1, 1499, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2666, 2403, 1215,  658,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,  159,  176,  339,  845,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3100, 2622,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1398,  612,    1,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  200,    1,  187,    1,  891,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092,    1,    1,    1,  387,    1,   45,  443,   32, 3118,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  196,  898,   37,   52,  123,   37, 2801,  956,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,  438, 2935,  786,   74, 2522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3134, 1214,   64,  140,    1, 3179,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247, 2940,   45,    1,    9, 3025,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1147, 1580,  232, 2572,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2755, 3010,    1, 2142,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  506,  267,  105, 2673,  864, 1710, 1527,\n",
      "          388, 2095,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  693,    9,  129,  975,   61,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  671,   32, 3292,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485,  398, 1268, 1047,  133,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2608, 2325,   61,  105,    1,  357,    1,  105,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,   25, 1758,  187,    1,   34,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  973,  444,    1, 1781,   32, 2170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2919, 2072,  166,    1,   45,    1, 2796,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3369,  459, 1422, 3118,  802,  220, 2751,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107, 1009, 1082,  104,   37, 1978,   69, 1356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3102,    1,  166,  487,   37,    1, 2924,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3222,   46,   81,   98,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  440,    1, 1501,  875,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  411,    1,    1,  163,    1,   12,    1, 2304,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1640, 3352, 2833,  947, 2190,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  595,    1, 1479, 2195,    9, 3101,  993,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  324,  958,  887,   46,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,    1,    1, 3167,   61,   81,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2333,    1, 1752,  593,   12,  581, 1354,    1, 1656,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1268,  166, 2009,   37,  105, 1400,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  189,   37,  508,   79,    1, 1346,  481,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,  936,  315,    9, 1821, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3181,    1,   32, 2410,  427,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,    1,  479, 1810,  681, 1997,    1,    9,  573, 1251, 2089,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2307,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1359,  875,  422,   12,  396,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  433, 1579,  131, 1278,  302,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  315,   37, 1539,  853,  191,   51,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,   29,    1, 2840,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1458,  942,   98, 1787,   45,  104,    1,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3294,   37,  865,   37, 2615, 2087, 2614,    1,  331,    1, 2737,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1570,   37, 1289, 1718, 2367,   37, 2575,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3168, 3205,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  619, 1718,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1087,  323,    1, 2336,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3147,  488,   37, 1260, 2751,   32, 3114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1291,   61,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   26,  176,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1117, 1525, 2208, 2134,  861,  122,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,  857,  605, 1976,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  294,  361, 3347, 1046,    1,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   98, 1220, 1089, 1090, 1085,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,    9,  166,    1, 1659,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  198, 2164,  640, 2433,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3241,   77,  460, 2444,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2178,  947,   37,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2092, 1243,    1,    9, 1138,  494,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  581,    1, 1821, 2699,   32,  395,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,  140, 2161,   12,  680, 3096, 1684,  104,   61,   72,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2619,   28,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1317,  704,  104,    1,   37,  572,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1, 1230,   32,  183, 1607,  973,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2158,  332, 3116, 2579,  631,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  632, 2122,  812, 2779,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1024, 1024,  197,   28,   98,  195,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  395, 1877,    1,    1,    9,  777, 2931,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  686, 3339,  399,    1, 1920, 2572,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   30, 3016, 1935, 1863,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,    1,  365,  111,  834,  778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 1771,  171, 1993,    1,   98,  915,  581,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,    1,    1,    1, 1061,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  453,  193,    9,  166, 1001,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  716,  449, 2085,  197,    1,    1,  604,   15,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  531,   12,    1, 2726, 3040,    1, 2263,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1,   61,    1, 1463, 1558,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1028, 1720,   65,  267, 1253,    1,  615, 1079,  203,  845,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  891,  350, 1069,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1238,   22,  456, 2916, 1967,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1401, 3258, 3275,   36,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  449, 1023,  111,  117, 1278, 1137,    1,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1445, 1421,    1, 3108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  709, 1189, 1009,  267,  864,  967, 3162,  220,    1,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   27, 1653,    1,  430, 1665,  980,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 2628,  921,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 1292,    1,  609,  162,  537,   32, 1038,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1524,  671,    1, 1909, 3126,    9, 2942,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169, 1426, 2069,   98, 1183, 2921,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2160, 2049, 1494,   28, 1139, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1325,  861, 1654, 2596,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,    1, 1211,  442,  274,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1477,    1,   16,  104, 1822, 1031, 1434,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1712,  459,  132,   98, 1228,    9,  166,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1895,  787, 1904, 1606, 1149,  477,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1932,  295,  431,   59,  132,    9, 1933,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,  547,    1,    1,   39,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2459, 1353, 1211,  613,  777,  412, 2060,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  657,   26,   28, 3044, 2232,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2741,    1, 3066, 2726, 3092,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1187, 1658,    1, 1173, 1792,   37,  166, 1013,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   28,    1,  548, 2315,    1,   48,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  912,  767,  444,  923,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1583,   12,    1,  967,    1,    1,   81,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596,    1, 1359, 2726,  422,  134,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3052, 1838,    1,  220,    1, 1990, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2110,  920,   32,  674,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  317, 3070,  121,  852,   37,  104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1256,    1, 1417,    1,    1, 1690,  525,   15,   71,  419,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1012,    1,   32,  854,    1, 1365,    9,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9, 3240,    1,  892,   12,    1,    1,    1,  537, 1490,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   21,   37, 1343,  444, 2672,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1355, 2102,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3221,    1, 2689, 1717,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,   12,    1, 2277,  410,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  560, 1274, 1556,  915, 1034,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596,    1, 1420,    1,  353,  119,  207,  197,  187, 1220, 1137,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  403, 1447,  108,   45, 2673, 2108, 2107,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  532,  119,  590,   45, 1273,  618,  384,  740,   37,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  177, 2572,   32, 2490, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3110, 2682, 3166,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1236,  422,  297,  721,  804,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196,  132,  140,   75, 1322,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  215, 2924,   32,  531,  221,  403,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3079,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3021, 1408, 1674,  671, 1010, 2795,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  282, 2264, 1046, 2333, 1665,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  215, 1774,   39,  365,   80, 1397,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187, 3312, 2565,  939,   37,   52,   27,    1, 1404,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   65,  155,  453,    7,   67,   37,    1,  239, 1807,  885,  423,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2676,  738,  220, 2924,   32, 3360,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  505,  888,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1, 2254,  875, 2255,   43,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,    1,  220,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2027,    1,    1,  460,  884,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3118, 2751,  815, 2500,    1, 3369,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 3026,   45,  166, 2213, 1667,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1697,    1,  335,   98,  103, 2165,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,   37,  774, 2283, 1232, 3118, 2705,  565, 3148,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  186,    1,  179,  180,  943,  696,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1, 2974,  872,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   84, 1159, 1381,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1627,  111, 1107,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  943,   61,  824, 1720, 2587,  116, 1183,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181, 1660,    1, 1102,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  108,   45, 1450,   32, 1081,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   37,    1,   59,  164, 1333,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   75, 1566,  617,  259,  815,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  163,    1,   12,    1, 3111, 2572,   32,  531,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,    8,  449, 2432,    9, 1778, 2580, 1108, 1779,  918,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  559,   98,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  398, 1297,  104,  358,  815,  876,  612,  209,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   28,  528,   69,    1,  105,  106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1712,  951,    1,    4,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105,  289,    9, 3401,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,  28, 590, 388,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  25, 245,   1,   1, 191,  69, 361, 303,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3233, 2415, 3233, 1413, 2884,    9, 3171,  166, 2615,  361,  730,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2343,    1,    1,  786,  356, 2248,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3319,  130,    1,  384, 3251,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1936,  166,    1,  789,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  865,   45, 1018, 1691,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   82, 2964, 1284,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  381,   61, 1205,  297, 1791,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  858,  388, 1021,   37,  334,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962,    1,  919, 3117,  297, 3260,  548,    1, 2022,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2692,    1,    1,  207,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2854,    1,   61,    1,  176, 2099,   45, 2227,    1,  705,    1,\n",
      "          105,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  244,  176,    1,    1,  554,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1390,  587,    1,  176,  389,    6,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1,  598,   45,    1,  903,    1, 2288, 3001,  506,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3359, 3057,   32,    1,  548,  354,   32,  673,  741,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  138,  920,    1,    1, 2248,  994,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,  335,  674,   45, 2764, 1264,  841, 2107,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  695,   98, 1502,   12, 1503,  142, 2007, 1411, 1034,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  506, 2859, 2955,    1, 1460,    1,  910,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  879, 2651,    1,    1,  297,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1796,    1, 1666,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1778, 2580, 2264,  894, 2610, 1108, 1779,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 2122,   98,  220, 1718, 1605,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2037,   56,  388,    1,   32, 2513, 1918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2206,    1,  476, 1211,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299,   51,  100,   98,  116, 2086,  302,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 1169,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  591,    9,   94,  654, 1355,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  800, 1838,    1, 2551,    1,  698,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  661,    1, 2789, 2012, 1021,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2153,  321,  402,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  611,    9, 1674,    1, 1253,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  125,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   26,  855, 3174, 1141, 1159,    1,  176,  395,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  228,  365,    1,    9, 3022,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  409,   25,  417,   60,   28,  444, 1547,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1086, 1211,  157,  412,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  921,    1,  679,  109,  105, 1057,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1656, 3389, 2856, 3361,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  613,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1072, 1635,  365, 1009,    9,  453,  104,  550,  437,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187,  388,    1,    1,    1,  861, 1900,    1,    9, 2987, 1260,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  163, 1741,    1,   12,    1,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  872,  831,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  262,  263,  353,  207,  354,  548,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2955, 2876,    1,   37, 1228,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  190,  184, 1107,  218,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,  163,    1,   12,    1,  427,   76,   37,  288,  119,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2275,    1,    1, 2103,  617, 1116,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  853, 1539,  166,    1,   32,  608,  537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  865,   45,  166,  183,  234, 3041,  235,    1,  234, 3041,\n",
      "          235,    1,  612,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964, 2386,  539,    1, 3149, 2774, 1877,  388, 1450,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  688, 3313,    1, 2828,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  365,  454,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  344, 3403, 2414,   32, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  625, 2151, 2707,  176,  342, 1712,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1774,   98,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   81,   32,    1, 1505,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1698,    1,   45, 1081,  139,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2660, 3262,  221,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1663, 1821, 2190, 1323,  420,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   24,    1,  365,  943,   98,  654,  389,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2025,  987,    9, 2080,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1091,    1,    1,    1,  297,    1,    1,  384,    1, 1638,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   32, 2197,    9,   46,    1, 1277,    1,    1,   98, 1147,  890,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220,  673,  288,    1, 2977,  315, 1411,  221,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  565,  410,  187,   69,  102,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  861,  187, 3363,    1, 1010,    1, 2292,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  997,    9,    1,  187,    1,  565,    1,   37, 2856, 1114,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2292,    1,  176,  111,  772,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  877,  815,   45,  829, 2690,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2212,    1,    1,    1,   98, 2639,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   75,  261,   37,  771,  858, 1704, 1021,  847,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426, 1408,   15, 1470,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  603,    9,  105, 1421,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  104,    1,    1,  864,   12, 2673,  210,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2711,  774, 1394, 1780, 1176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808, 1627,  111, 1107,  112, 3031,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  338, 1315,   37, 1034,  340,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260, 3224,    1, 3330,  140,  119, 1909,    1, 1185, 1624,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2479,  166,  671,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 1417,    1, 1022,    1, 2151, 1481,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  395, 1728, 1114,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3281, 2331,  297,  477, 2422,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1627,  111, 1107,  218,  220,  552, 3049,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  200,    1,   45,  160,  280, 3011,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3372,    1,  590, 1400,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3244, 2807, 1510,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,   61, 1958, 1183, 2320,  613, 1151,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2016,   12,  872,  190,   52,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  438,    1,  559,   79,  167,    1,  454,    9,  365,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  304,   45, 1479,    1,  460,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1808,   12, 1411,    1, 1821,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  267,  460,   12,    1,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3124,    1,  361,  166, 2397, 1822, 2487,  690,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  500,   82,  347,  268,    1,  306, 2429,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  921, 1010,  531,  109,  509,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  134,  444, 3142,    1, 2917,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,   72,  401,  156,    1,  983,   71,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790, 1627,  754, 1089,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2971, 1028,  167,    1,  557,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   32, 1151,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2871,    1, 2711,   37,    1,  600,  851,  298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220,  192,    1,  301, 1240, 1564,  917,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1492,  735, 3037,   37, 1752,  625,   32, 1890,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   37,   26,  417,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1013, 2043,    1, 1107, 1729,  361, 1117, 1525,    1,    1, 2310,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1,    1, 1255, 1587,   45,  539,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1778, 2580,  861,  328, 1961,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  273,   12,    1,    1, 1600,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  161,    1,  140, 1479,  104,  164,  165,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  850,  460,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  460,   12, 2675,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103,  469,   37, 1435,    1, 2409,    1,  729,  103,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3161,   12,    1,   45, 1739,    1,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192, 3170,   32,    1,    9,  449, 1463,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  374,  375,   37,  151,    1,    9,  152,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1295, 3156,   32,  395,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  294, 1456, 1913,  401,  207,  418,   98, 1697,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,    1, 2942, 1321,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  275,    1, 2495,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  128,    1,    1,  434,   32, 1687, 1022,    1, 3008,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2463, 2589,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  267,    1,    1, 2208,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1794,  132,   51, 1865,  388,  172, 2298,    9, 1783,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282, 3230,    1, 3169,    1,    1,  361, 3204,   37,   52, 2249,\n",
      "          384,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 1447, 1070,   10,   37,  289,   98,  903,    1, 1447,\n",
      "         2673, 1512,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1109,  438,   51,  420,   71,   32, 1022, 1843,  197,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3177,  443,  431,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  178,  848,    1,    1,    1,   32,   46,   98,  365,  912, 2285,\n",
      "         1597,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  708,  615,    9,  786,  131, 2097,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  872,  854,  162,  166,    1, 2589,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2400, 1698,   45,  365,    1, 2713,  384,    1,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1974,  531,  285,  548,  940, 3047,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  815, 1307,  618,   32,  613, 2247,  776,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3176,    1,   39,  202, 3308, 1990, 1569,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  429, 2073, 1463,   32,    1,  187, 1103,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 2572,   32,    1, 2137,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  166, 1889,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3141,    1, 1044,   37, 1488, 2954,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  422,  839,  589,   37,  573,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1248,   10,   37,    1,  531, 1563,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  647,    1,  365,  728,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  475,    1,    9,  389,  176, 3089,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  949,   37,  860, 2835, 1094, 2471,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    9,  715, 3096,  872,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1591, 1137,   98, 1022,   74,    1,    1, 1625, 1198,  159,   28,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523, 1045, 1086,  187, 1509, 1863,   32, 3129,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,   96,   37,    1,    9, 1580, 2541,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  410,  578,    1,  186,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1380,  164,  165, 1867,   98,  429,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3108,   77,  104, 1625, 2793,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,   52,  166,  580,   45,  889, 1675,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1519,  861,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1290,  396,   71,   98,   81,   45,  567,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  381,   12,    1,   90,  455,  828,  204, 2233, 2324,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2921, 1178,    1,  384,    1,    1, 2679,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1183,  245,    9, 1474, 1292,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2843, 2523, 2471,  166,    1,   32, 2304,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  811,    1,  884,  518,  389,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  558,  325,    1,    9,    1,  182,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  200,    1, 2071, 1331, 1273, 1151,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3330, 1542,   37,  877, 2218,    9, 3260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1818,  147,   37, 1709,    1,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3343,    1,    1,  183,  861,  231,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2116,    1,   98,  166,  168,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3375, 1980,  449,  317, 3358, 1513, 1463,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755, 1360,  612,  815,  829, 1994, 2819, 2146,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1720,  102,    1,  138, 1398,  612, 1289,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2137,    1,  484,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  885, 3246,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  399, 2011,   32,  131,    1,  605,  149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  316, 2681,  936,  865,   37,  147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676,    1, 1740,  565, 1231,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  729,  176,    1, 1340, 1908,  410, 2242,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2855,  686, 1460, 2482,   78,   45, 1771,  361,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  795,  295,   37,  480,   95,  473,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2924, 1334,   32, 2589,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  773,  420,   15,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  510,    1,    1, 2797,    9,  163,    1,   12,    1, 2705,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1527,    1,  548,  304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2529, 2164, 2803,  187,  455,    1,    9,  166,  183,  786,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  424, 1034,   12, 2462,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121, 2414,   32,  455,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  434,  105, 1488, 2707, 1632, 2244,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2441, 2126,  166, 1690,  994,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  487, 3102,  513,    9,  247, 1204,  187,  104,  379,  804,   39,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,  775,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 105, 787,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 386, 111, 244,  28,   1,  37, 151,   1, 111,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2445,  997, 1056,  388,  344, 3035,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   28,  967,  365,    1,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2902, 1660,  453, 1001,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 1033,    1,  176,    1,  238, 1512,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3101,    1, 1414,    1, 1763,    1,    1, 1478,   32, 3046,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,   37, 1124,   69, 1069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   42,  220, 2206, 2207, 1630,   32,  269,    9,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2448,  386, 1631,    1, 2315, 1045,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  431,  632,  103, 1569,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1842,  551,  613,   37,  125,  388,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,   12,  964,  288,    9, 1422, 2237,   37, 2707,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 1009, 1118, 2784,   37,  447,  297, 3102, 1512,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2932,    1,  436,   45,  166, 2955,   45,  105,    1,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1187, 1965,    1,    1, 1204,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  585,  254, 1515,  248, 2491,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885,  356,  343,    9,    1,   12,  531, 2579,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  942, 1249,    1,   32,   56,  497, 1990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  439,    1, 3142, 2213,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  220, 3304,    1,  193, 2565,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,    1, 1089, 1090, 1429,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  502,  458,    1, 2411,   37, 1616,    1,    1,   37, 1876,    1,\n",
      "            1,    1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  501,   12, 2809,  919, 1007,    1,  105,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2279,   12,  789,    9,  705,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764,    1, 1484,    9,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  912, 2285, 1074,    1,    1,  166,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984,  123,   28,   98, 2820,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2974,   61,  199,   12,    1,   45,  166,  356,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790,  113,   79,  432,   45,  365,  503,  195,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3339, 1763,  664,   32, 1675,  444,  311,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  153, 2415, 2967, 2934,   37, 1046, 2295,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2743,    1,  602,    1, 1352,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,   37,    1,    1,    1,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  191,  166,  336,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2058,   79, 2501,  861,    1,  339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3141,  892,  428,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,   32,    1,    1,  442,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1190,    1,  190,  720,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1721,    1, 1158,   98,    1,    1,    1, 3011,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  342,   12,    1,  193,   37,    1,  872,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708,    1,  690, 3358, 1677,   37, 2324,  957,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,   21,   15,    1,   37, 1403,    1,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092, 1236,    1,  777,  778,  154,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1543,  105,    1,  384,  166,  489,   85,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  185,  321,  612, 1000,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  137,    1,    9,    1,  666,  390,   12,  551,  552,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2621,   37, 3276,  270,  724,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 848,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,  37,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  612,  111,  155,  157,  548, 1488,  763,   76,  932,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,    9,  683,   37,   33,  247,    1, 1159,  105,    1, 2750,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  275,   34,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,  716,  995,  242,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359,  288,   37,  439,  339, 1860,   45, 2708, 1513,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1652, 1718, 2355,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  334,  321,  612,  221,    9, 2355, 2937,   39, 1221,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1036,   37,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  292,   26, 1039,  221,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2925,    9, 2954,    1, 1262,   37, 2315,   32, 1600,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,   51, 1083,  748,   98,    1,  369,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  311, 1917, 3312, 1388,   45,  166,   85,  361,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  119,    1,    1,  726,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  195,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2709, 2100, 1658, 1412, 1107,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2134,    1,    1, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2103,  617, 1116,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1110,  469,   37,    1, 1340,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  913,    1,   98, 2347, 1638,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  657, 1898,   28,  220, 2894,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  397,  958,  183,  442, 2005,  342,    1,  104, 1822,    1,    1,\n",
      "            1,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1128,  361,  882, 1508,   59,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3173,    1, 1159,   26, 2033,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   49,    6,  395,  129,    1,   12,   69, 1588,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  225,   70,   71,  548,  646,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1542,   37,    1, 1232,  342, 1377,  901,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3154, 2579, 1774,   98,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 1117,    1, 1417,    1,  108,  294,  269,  379,   45,\n",
      "          521,  134,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  726,   26, 1940,   12, 1660,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3096, 3308,   44,    1,  297,    1, 2292,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3299,  583, 2295,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1500,  158,    1,  387,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1762,  913,    9,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2214,    1, 1937, 1443, 1936,  377,  618,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,    1,  163,    1,  903,    1,    1,    1, 3051,    1, 1207,\n",
      "           37,  439,  443,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,  512,    1, 2317,    9,  786, 1090,    1, 1041,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  191,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1257, 1862,  600,  627,    9,    1,  669,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1602, 2539,  105, 1460, 1090,    9, 2487, 2954,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,  361, 3230,  470, 1159, 2490, 1286, 3179,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3359,    1, 3339, 2271,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  754,   15,  894, 1269,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1630, 1205,   32,  142,    1,  290,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2526,    1,  361,  920, 1444, 1445,   81, 1160,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3079,  664, 1090,    1, 1056,  810, 3009,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081, 1830,    9,  890,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2214,    1,  384,    1, 2804,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2910,    1,  191, 2650,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3014,  251, 1211, 2079,    9, 1718,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  811, 1625, 2237,    1,  956,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    9,  166,  730, 2614,    1,    1,   61,  105,    1,  193,    1,\n",
      "          176,  810,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1932, 1077,  331,    9, 1933, 1541,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  565,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2936, 2137,  548, 3387,  304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  854,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  246,    1, 1903,  220,   91,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2596,  176, 2018, 3407, 3392, 2414,   56,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 3012, 2961, 3027,  113,  227, 2948,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2275,    1,  996,    1,    1,  191,    1,  806,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267, 1404, 1924,    1,  837,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,   26,  417,  104,   60,   85,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  580, 1407, 1355,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  403, 2926,    1,  590,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425,    1, 1883, 1025,   32,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2752, 1557, 1484,    9, 1302,   37,  439, 2782,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  365,  469,  640,    1,  225,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1932, 2319, 1262,  680,  365,  475, 1213,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  386,  837,    1,   37, 1334,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,  550,  864, 2673, 1021,   37, 1752,    1,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  364, 1586,   28,    1,  176, 3076, 2577,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3282, 1918,    9, 3257,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  664,   32,  915,   56,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   47,  975,    1,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  190, 1012,  388, 1346,  176, 1537,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2178,  947,    1, 1312,  249,   98, 2095, 1898,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  787,   12, 1084,    1,    1,  191,  103,  639,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  144,  145,  376, 1396,    1,   34, 1278,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1760,    1, 1185,    9, 1204,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1417,    1, 2208, 1294,  967, 1744,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  487,  883,  686,  191,  242,  408,    1, 1115, 1220,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232,  726,    1, 2236, 2034,  885,  119,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2069, 1145,    1,   98,    1,  895,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1396,    1,  218,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  593,  442,  288,   37, 1192,  191,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  571,  754,   37,    1, 2714,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   98, 2103, 2727,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,  220,   81, 1987,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  594, 1385, 1554, 3303,   28,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3200, 3245,    1,    9, 1517,   12, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,    1,    1,  522,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   55, 2742,    1,   55, 2059,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3226,  190,   52, 1231,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2850,   37,  631, 3116, 2579, 2630,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2004, 1722,   37,  151,  179,   12,    1,   28,  112,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2490,   37,   52, 2491,    1,  191,   69,  636,  120,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,  251,   37,    1,  590, 2596, 1563,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1185, 2711,  804,   32,  892,   12,    1, 2514,  922,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1024, 1385,  191, 1385,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3178,  921, 3064,   37,  877,   26, 2033,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1497, 2139, 1728,  388,  444,    1,  872,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1277,    1,    1, 1156, 2042,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  879,  338,    1,  109,  997,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1415,    1,  908,  331,  132,  220, 3079,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2699, 2747,  166,    1, 2060,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  993, 1659,  852,  176,    1, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   91,   12,    1,   66,  979,  242, 2013,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2457,    9,    1, 2806,  726,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1850, 1423, 2778,  429, 1021, 2285,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1416,   45,    1,  155,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  647,  313,   37,   77, 2664,    1,  845,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   37, 1878,  166,    1,    1,  314, 1822, 2535, 1629,   12,  631,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,   60,  188,  444,   94,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,    1,  746, 1776, 1766, 1767, 2285,  630,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  780,   37,    1,    1,    1, 1273, 1074,   98,    1,\n",
      "           45,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2659,    1,    1, 2216, 1330,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  864,    1,    1, 2298,    9,  163,    1,   12,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  188,   37,  119,  340,  444,   94,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,   12,    1, 2694,  590, 2518,    9,  730, 1777,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  913,    9,  166,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,   37, 1377,  444,  397,  695,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1412,    1,  167,   52,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3067,  721,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 1107,   37, 1753,  111, 2633,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  102, 1027,   28,   31,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178,  163,    1,    1,   32, 3092, 1990, 1913, 1385,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  352,  353,  354,   98,    1,   44,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,  354, 2900,    1, 2298,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   50, 2572, 1147,    1, 2688,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  410,   37,  961,  133, 2872,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1514,  770,    1,   32, 1796, 3102, 1512,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1, 1408, 2637,   32,  593,  437,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3075,  146,    9,  531, 3365, 1645,    1,   37,  753,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  880,    1,    1,    1,    1,   32, 1056,    1,  927,  958,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  770,   45,    1,    1, 1976,   32, 3360,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 2962,    1,    1,  187, 3115, 2651, 2551,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   68, 1784,   81,  530,   32, 1033,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1072, 1635,  365, 1009,    9,  453,  163,    1,   12,    1,  550,\n",
      "          437,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1702,   37,  439,  296, 1527,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  986,   79,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  388,  533,   39,  539,    9, 1367,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118, 2791, 2625,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3176, 2590,  453,  449,  354,   45,  166,  914,  444,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  698,   28,   37,  815,    1,   37, 1155, 1488,  769,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1,   45, 1476,  977,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401, 1957,  608, 3219,   32, 2138,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1985, 3365,    1,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3172, 1090, 1829, 2486,  176, 2748,  584,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2614,    1, 1515,    1,  220,  251,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3297,  140, 1684,  202,  193,  786,  460, 2556,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1447,  387,    1,  443, 2124,    1, 2682,  104,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2978,  529,    1,  894,  193, 2346,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1477,  872,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649, 1513,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1712,  292, 1228, 2463,   37,  125,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1306, 1545,   12,    1,  220, 3181,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2425,   37,  151, 1883,    9,    1,  131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  640,  409,   98,  442, 2699,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  619, 1542,  220,  166, 1411,    1, 1700,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3061, 1152,   45, 1610, 2930,   45, 2734, 2986,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1085, 2188,    1,   24,  256, 2798,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  602, 1458, 2707,   32,  342,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3401, 1564,  166,  125,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  412,  936,    1, 1273, 2943,    1,    1,  361,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510,  288,   37, 1403,  633,    1,   37, 1549,   45, 1212,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  398, 2917,  166,  873,   98,  424,  786,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1923, 1022,    1,    1,  590,    1, 1037,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3015,    1,  176,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3172, 1090, 1829,    1,  176, 2160, 2049,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  936,    1, 2725, 1001,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  721, 1268,   28,   37,  148,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3289,   61,  628,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2321,    1, 1515,  454,   37,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1855,  669, 1337,  285,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  154,  469, 3243,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  326,  396, 2545,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  341,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  361, 1608, 1221,  254,  547,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3123,  456,   39,  413,  311, 2936,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  615,  774,  829, 1013,  321,  612, 1285,   39,  224,  361,  758,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  754, 2264,    1,  777,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2469,  459,  786,  356,  132,   37, 2449,   32, 1214,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  499,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,  118,   71,   32,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  190, 2564,   37, 1539,  105, 2978,   32,  465,   51,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 225,  70, 402,  37, 417, 218,  26,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  25,  27, 526, 187,  69, 980, 981,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  665,    1,   32,  492, 2565,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1518,  225, 1996,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  954, 1574,    1,   60,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387,  737,  197,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  147,  261,  444,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  844, 1559,  488,  691, 1867,    1,  108,  854,   12, 3192,  721,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1545,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1465, 2264,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  715,    1, 1848,   37,  138,   59,   60, 1350,  599,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2719,   10,  778,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  485,    1,    9, 1305, 3310,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  121,    1,  447,  123,   32,   98,   65, 1990, 2069,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2170,   12,  183,  469,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,  764,    1,    1,  664,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  968,  952,  793,  734, 1197,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2206, 2435,  261,  167, 2412,    1,  384,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1892,  636,  125,    1,    1, 2975,  483,  125,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3018,    1,  444, 2607,  191, 1230,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1821, 2190, 2640,    1, 2069,    1,   45, 2699,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1654,  671,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   26,   28,  590,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220,  786, 1204,   37, 1824,    1,  166,  730, 2614, 1210,  460,\n",
      "          920,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3258, 2579,   12, 1218,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1971,    1,  476,   37,    1,  183,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  622,  267,  531,   12,    1, 3371,  729, 2793,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  989,    1,    1,    1,  214,  693,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3272,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3228,  862,   39,    9,  176,  177, 1056, 2119,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  968,    1,  967,  638,    1,    9,  594,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,  650,   37,   52, 3390,   32,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  493,  847,   32, 1186,   37,   52,   53,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  200,  340, 1251,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  761,   37,  335,  152,    1,   44,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2276,   33,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1214,    1,    1,    1,  213,   37,  786,  356,   24,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 3345,    1, 1757,  881,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,   98, 1610, 1796,  909,  444,  403, 1447,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2159,  794,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2980,    1,    1,   98,  777, 1446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  195,   51,  222,    1,   12,    1, 2700,  774,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,  645, 3316,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  355,    1,    6,  156,  570,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  931, 1021,  454,   37, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  957, 1268,  449, 1405,  776,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3129,    1, 2523,    1, 2498,    9,  449,  455, 2579,  726,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2594,   61, 1558,   28,   37,    1, 1505,   37, 1531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,   37,    1,    1, 1410,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 1924,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  294,  716,   59,   72,  401,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2335, 2572,  187,    1, 1583,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  635,   12,  614,   81,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1414,  335,  522,   32,    1,    1,  191,\n",
      "         1147, 3045,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  711,  936,   82,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974, 2767,    9,  152, 2695, 2223,   95,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  395, 1680,  347,    1, 1022,   32,    1,    1, 1173,    9,\n",
      "          388,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  787,    1,  195,   44,  444, 3142, 1292,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 2995, 1681,  565,   81,    1,    1,   37, 3028,   12, 1359,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204, 3090, 3253, 2457,   37,  759, 3293,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1465, 1090,    1, 3039, 3040,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 1365, 2024,  142,  176, 2786,  340, 2046, 3397,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2841,  550, 2074,   74,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2438,    1,  365,    1, 1294,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   69, 1042,  885,  419,   37, 1034,  340,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2395,    1, 1584, 2719,  544,  460,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  793,  293,   66, 1044,   28,   37,  104,  182,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  341, 2134, 1031,    9, 3010,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  620,    1, 1240,  193,    1,   28,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1009,   37,   26,    1, 2611,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  518, 1190,  267,  448,   61,    1,  176, 1417,    1,  372,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707, 1707, 2081,   98,    1,  469,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2685,  943,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,    1, 1876,   37,    1, 2104,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3375,  491, 3339,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,   32,  105, 1569,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  638,  259,    1, 2260,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1727,    9, 1876,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  487,  294,  735,  737,  197,  418,   98,  887,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2447,  244,   71,  528,  198, 2497,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  422, 1236,    1,    1,   32,  574,  605,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,    1,  746,   32, 1766, 1767,  132,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 105,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 810,  78, 317, 466, 174,  93,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1167,  193,  320,    1,    1,   32,  166,  604,  218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1273, 2943,  221,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3233,    1, 3296,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  716,  572,   15,    1,  156,  682,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3352, 2833, 1056, 2476,    1, 3347,   32, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  446,  108,   45,    1,  996,  139,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 166,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  25, 439, 526, 657,   1, 548, 862,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  616,  240,  578,  384,   65,   98, 1524,  104,   67,   71,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884, 3077,    9,  691,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   12,    1, 2581,   45, 2580,  190, 2365,   39,   37,  854,\n",
      "          361,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  756,    1,    1, 2232,  279, 2515, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1861,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2289, 1360,  612, 2192,   28,   98, 1590,  187, 1183,  187,\n",
      "         2289, 1908,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1157,  646,  418,    1,  118,   32,   72,  401,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092, 1236,  297,  754,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3118, 2571, 2153,  444, 1407,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12, 1733,  884, 1583,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 1079, 3063, 2243, 2355, 1013, 2043, 3000,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2911,   51, 1031, 1206,    1,    1,    1,    1,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3182,  130, 2469,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  195,    1, 2763,    1,   37,    1,  661,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  531, 2751,  477,   63,  104, 1260,   98, 3391,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  590,    1,    1, 2885,    1,   28, 1030, 2335,    1, 2850,\n",
      "          176,  862,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2990,  606,  377,    1,  763,    1, 2112,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  777,  279, 2549,  696, 2911, 1000,  806,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3336,  387, 1022,  317,    1,  199,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3168, 1494,   28, 1139,    1, 3169,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   98, 2746,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  938,  551,    1,  572, 2034,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   17,   37,  619,    1,   32, 1657,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   18,  103, 1114,   32,   36,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   37, 2446,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   65,   37, 1083,  104,  347,   37,    1,  816,   93,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    6,    1,    4,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2719,    1,  444, 3182,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,  778, 2455, 2528, 1230,    9, 2063,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  593,   22, 1697, 1258,  471,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    7,  539,    1,    1,    1,    1, 1380,    1,   98,  453, 2789,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  803,  851, 2421,   32,  395,    1, 1887,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  751,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  165,  277,    1,  319,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  964, 1494,   39,    9, 2071,    1, 1813,  121,  361,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1695,  331,    1,  705,    1,    1,  176,    1, 2147,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2302,   37, 2446,    1,    9, 1050, 2829, 1603,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3386,  312,    1,    1, 1700, 1439,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  326,  840,  466, 1465,   50,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,    1,  238,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275, 2877,   12,  335,   98,  531,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1789,   26,  442,   46,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  476,    1,    1,    9, 1839,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  794, 1222, 2359,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3294, 1484,    1, 1977, 1328,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1352,  365,  754,   15,   71,    1,   37,    1,   59,   67,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1932,   37,  125,  541,  258,  805,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2833, 1928,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1936,   91,    9,  105, 1747,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1071,   85,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1607,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  418,   32,  218,  714,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  389,    6,   32,  275, 2054,  554,    1,  420,  782,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1128,   12,   82, 1707,  166,    1,   45,   11,  326,   12,  327,\n",
      "          112,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  542, 1882,   37, 1865,    1,    9,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  330,  854, 1437,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1788, 2685, 1012, 1056,  388, 1442,    1,   32, 1030,  756,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1092, 2329, 1935, 1151, 1091,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  224,   71,   63,  166,  862,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   32, 1739,    1,  105, 2519,  321, 2856,  105,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2516,    1, 1628,    1,  884, 1940,   12, 2107,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,  852,  760,  183, 2247, 1495,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1222,    1,   37, 1539,  669,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  952,    1,   45,    1,   45,   24,  396,   32, 2031,  400,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993,  951,    1,  829,  166, 1868, 1172,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 739, 433, 636, 245,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 968,   1,   1, 167,  52, 651,   1,  88,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1720,  460, 1494,   37, 1778,    1,    1,  911,  565,   26,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3347,   61, 1333, 1530,   32, 1785, 2044,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2612, 2873, 1167,    1,   98,  238,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1759,  309,   12,  709,    1,    1,  297,  487,    1,  221,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3310, 1141,  202, 2920,  729,  688, 2959,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,    1,    1,  917,    9,  854,  187,    1,    1, 1098,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  331,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    6,  453, 1126,  636, 2320,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   64, 2162, 1950,  921,    1,   32, 3349,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1239,  388, 2947,   32,  273,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  251,    1,  182,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1839,    1,    1,  632,    1, 2404,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  927, 1781, 1159, 3372,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 2587,    1, 2465,  297, 3144,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2913,   37,    1,   32,  467,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,    1, 2344,  153,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  472, 1090,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2680,  313,   37,    1,    1,   45, 2693,  361, 2819,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 388, 763, 786, 686,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  69, 338,  37, 339, 340,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3144,  313,   37,  674,    1,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3326,    1,  519,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2072,  166, 3102, 1512,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  562,   12,  927,   45,   36, 2705,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  420, 1528,   27,  132,   98, 1405, 2039,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510, 2414,   32,    1,    1, 2405,  539,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1151, 2549,   57,  245,   32,  367,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1,  163,    1,  903,    1, 2673, 1063,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1845, 1238, 1054, 2434,  155,    1,  997,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2310,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   12, 1447,    1,  297, 2390, 1867,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,    1, 2903, 2853,  361, 1001,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,  720,   32,  572,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3200, 3182, 1090,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   75,  952, 1021,  297,   80,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123,  892,  428,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 107,   1, 104, 764,  37,  62,  69, 218,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 499,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3084,   57, 2180,  290,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2466, 2153, 1260,  531, 1563,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3370,  361, 3343, 1414, 1388,    1, 2006, 1530,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9, 3322,    1, 1675,   85,    1,   37,  168,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2318,  176,  105,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    4,   93,  143,  763,   76,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1186,   37,  288, 1211, 1407, 2095, 3060,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1075, 1166,   37, 1937,  245,   12,    1, 3152,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  590,    1,    1, 1217,  614,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3348, 2153,    1,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3134, 2451, 2308,  167, 1046,  134,  548, 2811,  220,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169, 1825,  754,  247,  865,  402,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  261,  444,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  214,    1,    1,  635,  225,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2865,    1,   85, 1215,   32, 1913, 1385,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1100,  769,   32,    9, 2869, 1089, 2308,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523,    1,    1,  332,  631,  176, 1062,  458,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    6,  389,   93,  570,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3351,    1,   37,   52, 2827,    9,  885,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3130,   61,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2332, 1976,   32, 2170, 1334,   32,    1, 2135,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  534,  140,  562,   37, 1119,  550,  369,    1,   37,  104,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2144,    1, 3047,   32,    1,    1, 2517,  947,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2628,  696, 2629,    1,  229,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1408,  163,    1,   12,    1, 3158,   32, 2841,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773, 2351,    7,    1,  111,  772, 2524,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  183, 1994,    1, 1708,  205,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  500,    1,   98, 1172,  538,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  199,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  245, 1270,   37, 1315,  105,  106,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  297, 1485, 3365,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2203, 3246,   61,  264, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1235,   12,  225,  338,  118,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   37,   47,  327, 2054,   37,  649,  700,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  151,    1,   12,    1, 1842, 1294,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,    1, 1117, 1525,  441, 1753,  923,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2362, 1710,    1,    1,  721,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497, 3245,    1,    9, 1517,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  878, 1236,    1,    1,    1,  626,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  315,  228,   74, 1821, 2699,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   79,  166, 2904,    9,    1,  948,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,  225,   28,  548,  359,  132, 2011,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  342, 2707,  132,    1,  187,  105,  826,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,   37,  804,   98, 1334,   45,  342,  909,  444,  829,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3382,  176, 3358,   12,    1, 1897, 2069,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2246, 3312, 1342,    1,    1,  187, 2565,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  750,  302, 1710,    1,  182,   20,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1876, 1718, 2146, 1967, 2973, 1764,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  420, 2994,  682,  118,   32, 1169,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  199,  421,   76,   37,  138,  422,   59,   37,  875,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  364,  140, 1383,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1774,   39, 2528, 1616, 1230,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,    1,    1, 1018, 1147,    1,   12,    1, 1204,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1004, 1018,  439,   37,   67,  418,  187,   93,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,    1,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  542,    1,  187,    1,  837, 1693,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1461, 1025, 2414, 3374, 3384,  650,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1082,  163,    1,   12,    1,   37, 2446,  840, 2108,   37,\n",
      "         1789,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3121,    1,    1, 2755,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  581,  477,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1081, 1953, 1082,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3117, 3224, 2275,    1, 1654, 1377,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1123,    1,  640,    1,    1,    1, 3271,   37, 2613,  726,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  321,   77, 1021, 2062,  379,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3303,    1, 1056, 1333,  631,  176,    1,  294, 1456,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,    1, 2143, 1515,  566,    1,  361,  166,    1, 2962,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  487,  947, 2263,   56,   32, 2095, 2596,  722,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2258, 1366,  321, 1807,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  790, 2576,    1,  220, 1056,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3243,  154, 2040,    9, 2227,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,   85, 3146,   98, 3369,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  178,  179,    1,  180,  181,   32,   98,  182,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  375,    1,  437,  190,  130,    1, 1885,    1,  365, 1788,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  348,   50,  315,    1,  131,  349,   45,  350,    1,  279,  238,\n",
      "          351,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1800,  170, 1801,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984,  200, 2455,   45, 2662,   12, 2918,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3211,   37, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1414, 1539, 1995,   98, 1147, 2751,   32,\n",
      "         3383,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  990, 1536,  400,  444, 2650, 2985,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548, 2457,    1,    1,    9,  104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  880,   37,    1,  548, 2596, 2716,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1,    1, 1750, 1789,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2546,   37,  693,    1, 1107,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 2476,   51,  606,    1, 1895,    1,  537, 1490,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2910,  187,    1,    1,    1,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  639, 1121,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  159,  245,   98,  304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  391, 1926, 1927,  972,    1,   57,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2911, 1210, 3359,   37,    1, 3057, 1002,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2246, 3266, 2202,  227, 1851,    9, 1066,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2373,  593,  449, 2627,  327,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1561,   28,    1, 1268,    1,   37, 2026, 1450,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2868, 2386,    1,   45, 2065, 2673, 2375,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  617, 2403, 2030,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094, 1702, 1159, 3339, 2831,    1, 1887,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1,   64,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2607,    1,   98,    1,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1245, 2753, 2304, 1394,  176,  754,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3364,  516,   37,    1,  297,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228, 1873,   51,  987,   32,   98, 2763,  656, 2351,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2735,    1,  469, 2030,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   65,  190,   52,    1,    1,   69,  640,   93,    1,    1,\n",
      "          267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  874,    1,    1,    1, 1778, 1273,    1, 2261,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1353, 2229,    1,    9,  112, 1749,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 1466,   37,  138,  599,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,    1,   98,    1,  220,  631,   32, 2522,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1,  342, 2390,   46,    1,    1,  590, 2666,   66,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3230,  921, 3001,   32,    1,  427,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,    9,  163,    1,  903,    1, 1929,   98, 2095,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  282, 2264,  619, 1227,  756, 2851,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962, 3319, 2709, 1110,  528, 1340, 2907,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2485,  696, 2685, 2712, 1110,   32,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  367, 1151,   15,   93, 1071,   98,  845,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  742,   12,  248, 1567,  176, 1178,  163,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  166, 1551,    1,    1, 2151,    1,   32,  547,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2, 398, 261,   9, 148,  32, 647, 142,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 963,   1, 877,   7,   1,   1,  88,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3274,  801,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1013, 1522,    1, 1488,    1,  202,  729,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3072,  884,   79,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790, 1564,  754,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  746,    1,  179,  477,    1,  895,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2677, 3228,  951,    1, 1110,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   92,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1988,   45,    1, 2819,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3279, 1316, 1853,  548,  186, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1047, 1236,  597,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 3102,    1, 1211, 1763,    1, 2161,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  613,  618,    1,   37, 2018,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3330,   37, 1306,  698,  220, 2693,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2573,   12, 3398,    1, 1683,  384, 1038,   98, 2069, 1377,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 3383,    1,    1, 1708,    1,  444, 1147, 1414,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2865,   81,  829, 1994, 2819,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 1696,    1,    1,    1,    1,  361,    1,   32,    1, 1002,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1043,   28,    1,    1,   11,   32,   70,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2860, 1398,  612, 1210, 3069,   32, 3360,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2348, 1523,  847,    1,   32, 2819, 1681,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  921,  453,  156,  689,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  190,   52, 2644, 2100,   98,  810,    8,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2805,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  987,    1,  590, 1090,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2506,  297, 3153,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  754,   37,    1, 1568, 1569,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1851,    1,    1,  149,    1,  920, 2812,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056, 2754, 2548, 1530,    1,  228, 2347,   32,  531,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035,  716,   37,  611,   37, 1174, 1175,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1957, 2075,   81,    1,  688, 2584,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2615, 1083,  636,   45, 1509, 1510,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  681,   37,  317,  195,   29,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   81, 1640,  285,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  972,   37, 1048,  148,  132, 1039,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  211,  167,   52,    1,  105,    1,   45, 2074,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3286, 1258,   44,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1658,  248,    1,   98,  810, 1658,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,    1,    1,   45, 1434,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1290,  396, 1269,    1,  427,  739,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   45,  507,   12,  289,   98,  197,    1,  389,    6,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2962,    1,    1, 2907,   32, 1194,  187, 3108, 1285, 2838,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  947, 2263,  249,   32, 2625,   98,    1, 3175,    1, 1218,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2780,    1,   32,  166,    1,    9, 1658, 1299,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   45, 1147, 3392,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3096, 1452, 1232, 1759,  309,  696,    1,  395,   12,  593,   51,\n",
      "          439,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,   82,   45,  395,  945,   69, 1053,  571,   37, 1053,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  197,    1, 1666,  156,  420,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947,    1,  215, 2702,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  510,    1,    1,    1, 2414,  176,  177,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1303,    1,  649,    1, 1074, 1437,  132, 1960,  104,  331,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  566,  388, 1904,  960,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,    1,   98, 3036, 1281,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  415,    9, 2181,    1,   25,    1,  506,  782,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  450,  741,   32, 1759,  309,    1,  395,   90,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1043,  697,   37,  245,    9, 1194,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  177, 1530,    1, 2249,   32,  395, 1177,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1987, 1086,  252,    1,   12,  914,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  787,  456,   81,  827,  818,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051, 1353,    1, 2575,  220,    1,  151,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2433,    1,  289,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 1268,   28, 2436,   45,  453, 3044, 2168,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284,  379, 1670, 1119,  384,  869,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 1745, 2768,  460, 1488,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 2235,  669,    1, 2049,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,   37,  619,  331, 1193,  209,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1983,    1,   37,   52, 2812,  111,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1243,  365,    1, 2043,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,  920,    1,   37,    1,  661, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  506, 1898,    1,    1,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   37, 1539,  453,  449, 1234, 2177,  988, 1107, 1863, 3011,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1781,  191, 2977,   37, 1173,    9,    1,  938,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826, 2789,    1, 2789,    1, 2789, 1617,   12,    1, 1055,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  716,   98, 3358,   12, 3137,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1581,  331, 1084,  260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  242,   98,  645,  646,    1,    1,  417,   69,  102,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  639, 1236,  780,  297,  573, 1563,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  114,    1,  597, 1794, 2949,   98,  454,   37,  365, 1914,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3333,    1,  683,   37,    1,    1, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2470,   90,   45, 1463,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,    1, 3077,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1117, 2208, 1089, 2940,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1628,  750,    1,    1,    9,  519,  356,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3115,  606,    1,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3317, 1288,    1, 2457,  384, 2961, 2380,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  213,   37,   47,  104,    1,   50,   37,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  700,  997,   93,  967, 2582,  453,  769,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 1731,  108,   45, 3155,  762,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2786, 2997, 2432,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2041,   37, 3018,  162, 1400,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  764,  260,    1,  105,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   39,   45,  581, 1463,  187, 1103,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1232, 2647,    1, 3173,  894,  726, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1631,    1,  104,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,  942,   12,    1, 1947,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2266,  590, 1161,  741,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  612,   12,    1,  388,  763,  415,  105,    1, 1705,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  754,  804,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  385,   15,  176,  837,  124,  688,   14, 1738,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  472,    7,   37, 2500, 3020,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236, 1022,   66,  979,  242,  187,   69,  636, 1042,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  545,    1,  166, 1575,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37,   52, 2399,   32, 1450,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 3020,  190,   52,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  327,   61,    1,  415,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2962,    1,  696, 3276, 1493, 1022,    1,  726,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1707,  342, 1167,    1,    1,    1, 1281,   61,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3003,  891,  365, 1385,   45,  912, 2285, 2039,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   69,  102,   71,   98,  679,   69,  122,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2142, 1355,  590,    1, 2160, 2049,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162, 1950,   28,  187,    1,    1,  436,   45, 1033,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  620,   29, 1426, 1259,  220, 1794,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  371,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,    1,  548,   65,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  565,  105,    1,  321,    1,  860, 2588,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3261,  729,    1,  600,    1, 2053,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1712,  176,    1,    1,   98, 1116,    1, 2311,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  654,   12,  193,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,  489,   39,    1, 2299,   32,  166,    1,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  649, 3102, 1512,  640,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  457, 2328, 1426, 1821,    9,  581,  199,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  123,  526,  548,  166,   65,   67,  423,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1019,    1,    1,    1,   28,   27, 2890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1035,    1,   37, 1642, 2113,  920,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2550,    1,    1,  187, 1965,    1,  384, 2072, 1361,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  743,   12,  614,    9,  671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  244, 2557,  640,  159,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1363,  794,  517, 1085,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,   28,   98,  160,    1,  293,   29,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1829, 1510,  342, 2153, 1421, 3341,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  172,  304,    1,   98, 1099, 1453,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  919, 3211,   37,    1,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2608, 2607,  533, 1192,    9,  575,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2137,   32, 2597,  837, 1056,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160,  643,  441,  288,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  636, 1056,   79, 1224,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089,   30,  215, 3102,   12, 1727,    9, 1204,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2405,  810,  632, 2069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117,  741, 2323,    1,   10, 2300,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  978,    1,    1,   37,  670,  608,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151, 1081,  493,  384,    1,    9,  403,  507,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1181, 2914,  845, 1208, 2474,  841, 1151,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   12,  197,  490,   98, 1565,   45,    1, 1178,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   58,   34,  197,  570,    1,  225,  407,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925,    1,  614, 1514,    9, 3326,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3129, 2246,    1, 1401,  191, 1056,   32,    1,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  845,  147,   37, 1709, 1377,   98, 1107,    1,    1, 2730,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1847, 1492, 2233,  726,  166, 1684,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1414, 2856, 1056, 3375,   32, 3339,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  963, 2700,    1,    1,    1, 2598,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  669,  794, 3039, 3040, 1090,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2733,  580,    1,   32, 2730,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1659, 1425,  545, 1035,   12, 1038,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1294,  288,    1,  202, 1931, 2449,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1716, 2480,   15, 1348,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  398,  108,  104,  957,   37,  846,   28, 3402, 3408,  927,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1285,  115,   45,  163,    1,   12,    1, 2161,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   63,  166,  862,    1, 1042,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1412,    1,    1, 1691,    1,   79,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1120, 1494,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,  810,  112,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,  590,    1,    5,  423,    9,    1,    1,  422,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  358,  475, 1216,  669,  416,  460, 1514,  297, 1346,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1663,    1,   37,    1, 1354, 1147,  734,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  132,   37,  130, 2211,  269,   61,   76,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1366, 1188, 1161,   92,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974,    1,    1,    1,    1,    1, 2181,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1790, 1310,   37,    1, 1412, 2382,  218,  220,  365,  912, 2146,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,    1, 2979,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3382,   12, 3404, 3340, 3091,  190,   52, 1683,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2160,   28, 1140,   98,  651, 1031,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,  953,   98,  800,  455,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,   82,    1, 1454, 1513,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3375, 2572,   32, 3101,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,   12,    1,  267,  140,  444,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018,    1,  854,   37,    1,   32,  626,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,  546, 2565,   45,  129,    1,  872,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   17,  606,  901, 1021,    1,  167,  915, 2119,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,    1,    1,   12,    1, 1013, 1017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  342,    1,  297, 1859,   37,  644,  441,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,  588,    1,    9,  863,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3391,  686,  191,  241,   22,  868,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  911,  565,  434,  501,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  647, 1830,    9, 1574,  176,    1,   16,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1744,    1, 1338,  105,   56,  356,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  203,    1, 2161, 1532, 1940,  166, 1134, 1444,  565,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  477, 2478,   68,   69,  408,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2594,    1,    1, 2469, 2977,   95,  940,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,  187, 2752, 3071,    1, 1633,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  502,  551, 1361,  662,   37,  221,    4,   37,  854,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1166,   12,  166,  218,    9, 1361,   12,  138,  187,  334,  168,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3167, 2415, 3108,  103,    1,    1,   26, 1090,  631,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3216, 2935,  581,   73, 2941,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1,   45, 3185,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179, 1308,  131, 1159,  613, 1074,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1181,  200,  365, 1616,  781,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676,    1,    1,  542, 1388,  548,  427,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  733,    1,    1,  112,   37, 2578, 1771,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 1560,   61, 1762,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  189,  267, 1913, 1843,  983,  190,  245,  384, 2073, 1843,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2963,  600, 1148,   10, 1911,  443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2668, 2597,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3339, 3352, 3353, 2183, 2708,  232,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  287, 1618, 1568,    1,   32,  455,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   45,  853,  538,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1684, 1604,   37,  544,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260, 1173,   37,  489,   32, 1452,   32, 1090,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  198, 1322,  176,  449,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    8,    1,  304,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  647,   12, 1889,  533,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  587,   32,   46,  297, 1233, 1641,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  871,  160,  102,  720,    1,  626,  188,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,    1,    1,    1,    1, 2558,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  590,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3228, 2871, 1090,   98, 1690,  199,    1, 1690,  913,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1419, 2432,   37, 2324, 2558,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1420,    1,   37, 1636,    1,  285,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  980,  187, 1588,    1,  889,  997,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  720, 2024, 2909,   98, 3105,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,  443,  147,    1,  449,  400,   37,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  198, 1998,  191,    1, 1519, 3141, 1625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1117, 1525, 1108, 1554, 1778,    9, 1718,  327,  593,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,   98,  486, 2785,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  550,  215,  947, 1816,    1, 2980, 2393,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,  171,   37, 1124, 2339,  947, 2005,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  375, 2526,  548,    1,  698,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,  859,   37,    1,    1, 3101, 3339, 2731,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3303,  884, 1333,  631,  176,  294, 1456,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 2505, 1710,  877, 3207, 2213,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3187, 1734,  700,  297,    1, 1077,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,   12,  449,    1, 1607, 1433,  460,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1464,   37,  335,    1,   45,    1, 2250,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  147,  261,   98,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2178,    1,    1, 2504, 3105,    1, 1065, 1190,  267,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,  435,  142,    9,  179,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1627,  822,    1,  220, 1652,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  267,  903,    1, 1447, 1585, 1372,   37,  606, 1846, 2673,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  207,  261,   37, 1125,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  197,    1,  159,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1880,  325, 2241,   48,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550, 2680, 2706, 2262,  282, 2264,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,   27,  687,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,  933, 2189,    1, 1816,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2528,   45,  596, 2691, 1388,    9,  987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  397, 1458, 1705,    1,  176,  104,  625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1349, 2239,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187,  166,  957, 2694,  105,  547,   74, 3336,    1,    1,  354,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  886,  251,   59,    9, 1151,    1,  700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,  469, 2204,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  613, 1597,  967,  657,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3358,   12, 1628,  356,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  387, 2034,  176,  103,  439,   45,  570,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  695, 1458,    1,   67,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2948,    1, 1581, 1624,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,  396, 2983,  631, 2970, 1204,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  577,   20,  919,  197,  739,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1343,  198, 2125, 1090,   32, 1918,  297,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3285, 2225,    1,  590,    1, 3229,    1,    1,   39,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105,    1,  182,  361, 1417,   32, 1844,   28,   37,  736,\n",
      "            4,    1,    4,  361,    4,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2276,  844,  680,  114,   32,    1, 1969,  183, 2068,  344,  142,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,   61,  193,    1, 1488,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,   37, 1930,    1,    1,  612,    1,    1,  275,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   37, 1075,   98,  367,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  162,   24,  881,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3262, 2800, 1218,  661, 1485,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,   93,  816,   32,  401,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   22,  359,   37,  741,   98,  138,  125, 2362,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  150,  353,    1,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1,  849, 1662,    1,    9,    1,  182,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  533,    9, 1965, 2550,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  140,    1, 2560,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  667, 1386,   12,  233,  726, 1268,  711,  333,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1, 1123,   12,    1, 2457,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3323, 1247, 1631,  247, 3078,    1,   76,   37, 1306,   56, 1675,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390,    1,   95,  473,  498,   98, 1460,  895,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,  572,  354,  187,  983, 1042,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2322,   37,    1,  548, 3141,  267,  460, 1360,  612,  588,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3380,    1, 1232,  204, 2233, 1334, 1583,  475,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  742, 1380,  386,   32, 1343,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  750,    1,  590,    1,  872,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602, 1707, 1801, 1167,  531, 1563,   51, 1031,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1626,  659,   45,  829, 1013,  614,   39, 2283,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232,   16, 1515, 1021,  220, 3299,  444, 3231,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  296,   15,   37,    1,   20,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1431, 1310,    1,   98,    9, 2293,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2378, 2701,  914,   51,   52,  901,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  633,    1,   32,  395, 1482,  619, 1766, 1767,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3274,  645, 1987,  167,   52, 1328,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   37,  125,    1,  191,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1079, 3063,  361, 2999, 1237,  166, 1013, 1522,    1, 2498,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3060,   32,    1, 2891, 1061,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1420,  315,   28,   37,  105,    1,    1,  752,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2707, 2321,  354, 2595, 2731,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1178,  513,  514,   32, 2154, 1084,    1, 2607,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1753,    9, 1107,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1853,    1,  191,   72,  477,  548, 3038,    1, 1260,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  915,    1,  270,   98,  166, 2041,    9, 2551,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428,    1, 2752,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,   12, 3019,    1,  220,  810, 1766, 1767, 2461,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  902,  429,   98,   37,  688,  166, 3263,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2283,   12,    1,   32,  531,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  326, 1203, 2871, 1021, 1129,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116,   12,  846,  641,  187,  460,   96,  537, 1691,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1107,  293,  388,  176,  629,   32, 2086,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 119, 845,  69, 102, 686, 310, 616,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 375,  37, 151,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,   37,  588, 1461,    1,  176,   46,  220,  903,    1, 1447,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3243, 2306,  321,   52,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  151,  361,   47,    1,   37,    1,  361,   53,   39,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3379, 1585,    1,   12,    1,  471,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  157,  384,  303, 1464,   37,    1, 1744,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1683,  187, 2774, 3382,    1,  105,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2,  98, 166,   1, 166, 104, 719,  37,  16, 284,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 853, 538,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,    1, 1317,  704,  104, 1344,  819,  220,    1,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,   74,  167,  606, 1846, 1452,    1,    9, 2551,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  582, 1360,  612,    1, 2024,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1, 1778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1007, 1008,  813,    1,  187, 1009,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1467,   37,    1,   12, 2463, 2800, 2565,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,  25,  28,   1,  69, 636, 470, 515, 591,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 328,   1, 716, 417, 244,  98, 887,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2273,  969,  220,  116,  897,   28,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,  353,  197,    1,  387,   15,   93,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1022, 1023,  207,  197,  640,    1,  182,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3296,    1,  193,   37, 1421,    1,    9, 1194,  356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101,  446, 1654,    7,  673,  741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2272,   32, 2673,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  108,  365,  872,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 2237,    1,  365,    1,  220,  163,    1,   12,    1,    1,\n",
      "          220, 2179,  629,    9, 2279,  963, 2122,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   32, 1430,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1448,   37,  138, 1427,    9, 2201, 1411,  356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2894,  267,    1,   51,  193,   52,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2072, 1104,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2942,   12, 2721,  907,  193,  320, 1628,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187,  829,   96,  166,    1,    1, 2489,   98, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1059,   81,  753,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092,  724, 1287,  384,  601,   37,  726,  176, 1092, 2578,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  121,    1,    1, 3107,  384,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1654,  391,  371, 1448,  109,   24,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  461, 2951,   32, 1742,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12, 1509,   37,   77,    1,  384,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3228,    1,   39,  220,    1, 1987,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2433, 1920,   12,  770, 1976,   32, 3155,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3358,    1,   79, 1787,  297, 1511,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1439,    1,    1, 1368, 2337,  204, 1489,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1352, 1757,    9,  487, 3222,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3296,    1,  742,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  615,  335,  105,  818,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1818,  147, 2411,   37,    1,   32,  912,    1, 2096,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1362,  325,  275, 2211,   37, 1636,   32, 1033, 2211,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  556, 1230, 2528,  384, 2546, 1076,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,   25,  218, 1276,  187,   69,  418,  361,  224, 2781,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1538,    1,    1,  410,  751,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3358,   32,    1, 2135,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  166,  439,    1,    9,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2145,  259,  708,   37,   77, 2518, 2638, 2339,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1855, 3372, 1464,   37, 2709, 1511,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2144,  709,    1,  675,  494, 2430,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,   61,   45,  166,    1,   32,  424,  645, 1385,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612, 2612,   32, 1074,  861,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3029,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3033, 2760,    1,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1235, 1236,  405,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2168,    1,   37,    1,   45, 1108, 1450,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1,  297,    1,  455,    1, 1554, 1530,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  581, 3185, 1463,   98, 1973,  855,    1,    1, 1894,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  197,   28,    1,  155,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  593,  793,  390,   27,  131,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708, 3352, 3353, 1072, 1235,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158, 2630,  167, 1403, 1230,  550,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968,    1,  967,  638,    1,    9,  594,    1,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2, 647,  51,   1, 148, 142,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 382, 770, 524,  42, 133, 149,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3363, 1103,  115,   32, 3343,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1433,  776, 1578, 1924,  105,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  105, 1832,   37, 2844,    9,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1938, 2607,  382, 2206, 2989,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2183, 3091, 2572,   32, 1850, 1853,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 2067,  599,  187,  204,  614,    9,  985,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1, 2192,  386,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3403, 2414,  176, 2445,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,    1,  907,  548, 3038, 3279,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3388,    1,  903,    1, 2170, 2095,  304,  288,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3112, 1820,    9,    1, 1388,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1816, 1908,  410, 1944,  384,  441,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2571, 2153,  360, 1407,    1,   32, 3118, 2299,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 2685,  600,   37,  619, 3269,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,   12,    1,    1,   37,  619,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  191, 1206,    1,  477,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1203, 2686, 2687,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2594,  140,  219, 3329,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  631,   37, 1056, 2936, 3109,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676,  947,    1,    1,  336,   27, 2890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2987,   45, 2162,   96,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  124,    1,   15,    1,  548,    1, 1981, 1160,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1536,  397,  400,  951,  342,    9,  296, 1859,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,    1,  463,  464, 1611,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 275,  25, 504,  98,  69, 636,   1, 647,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 169, 546, 475,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1375,   37, 1174, 2247,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,    1,  356,  207,  197,   28, 1146, 1703,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2016,  386, 3062,  119, 1194,    1, 1990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,    1, 1564,  105, 2457,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2466, 2639,  858,  361,  704,  705,    5,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  385,    1, 2849,  297,  104, 2823,  863,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2315, 2457,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3378, 1576, 1335,   37,  319,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,   12, 2789, 2591,   37,    1, 1384,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2377,   45,  487, 2372,   37,    1,   86,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,    1,  191,  105, 2847,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2379,    1, 2065,   32, 2211,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  191,  786, 1167,  416, 2017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3006,    1,  297,  946,   45, 3346,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   28,  384,    1,    9,  553, 1211,  442,   32,  593,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3207,    1,    1,  930,  384, 2161,   12, 3096,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1328, 2298, 1976,  191, 1498,  176, 1099, 1453,    1,    1,  422,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  671, 1078,    1,   28,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579, 2768, 1099, 1453,   12,  650, 1847,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035, 1142, 2356,   98,    1,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   82,    1, 1744, 1149,  619,  138,  125,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,   12,  311, 1246,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1241,   28,  242,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  388,  249, 1530,   32, 3339, 1345,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  295, 2145,   37,    1,   29,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  307,  308,    1,  159, 1374,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2693,    1,  187, 1104, 1117, 1525,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1200,  936,    1,  829,  844, 1228,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,   37,  125,    4,   32, 2741,    1,  447,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1645, 2611,  267, 3358,   12, 3137,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  315,  786, 2446, 2943,    1,    9, 1273,  725,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  338,   37,  339,  340,   98,    1,  341,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1013,    1,   37,  166, 2355,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1530,   32, 3339, 2831, 1345,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777, 1376,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 2686,  801,   37,  449, 1125,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  475,  741,   27,   98,  218, 2678,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  487, 3102,   32,  531,  513,    9,  764,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  160,  783,   28,   32, 1657,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2546,  733,   59,    1,  452,  636,  125,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3010,  162,  166, 1631,   37,  429,   79,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  515,  103, 2576,   37, 2890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,    1,    1,   32, 1194,    1,  726,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,    1,  489,   39,  802,  105, 1427, 1641,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  461,  449,  361,  915,   32, 3275,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2994,   28,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2801,   37, 1539,  365,  517,    1,  617,  259,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  709,  502,    1,   32, 1381,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 3397, 3369,  167, 1937,    1, 2304,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1861,   37,  606, 1983,    1,   98,  985,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2120,    1,  176,  136, 3217,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3198, 1159, 2197, 2069,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3313, 2712, 1554, 3316,  228, 1394, 1048,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2227,  551,  552,  162,  331,  104,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1484,    9,  741,   98, 3251,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1013, 1522,    1,    9, 2780,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1758, 1159, 2835,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1181,    1,  449,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523,  852,   98,  837,    9,  865,   37, 2315, 1262,   32,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1479, 1918,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151,    1,   61, 2740,  914,   61,   32,    1,  297,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 954, 366, 440,   1, 187, 942,  37, 631, 517,  32, 234, 182,\n",
      "         235,   1,   1,   1, 234, 182, 235,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 786,  84,  32,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2548,  726,  917,   37,  487,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  941, 1663,  967,    1,    1,   59,   98,  938,  927,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  891,  905, 1069,   45,    1,    1,    1,  376,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   12,    1, 1564,    1,  693,    9,    1, 1201,    1, 1010,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  113,   79,   98, 3229, 1140,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  551,  365, 2036,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  814,    6,  605, 1469, 1114,    1,  225,   79,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  446,   37, 2237, 1815, 2791,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1230,  384, 1158,  113, 2945,  361, 1107,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  374, 1276,    1,  329,   28,   32,  713,    9,   65,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1133,  401,    9, 1105,  787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2801,  200,    1, 1362,  529,  617,    9,  517,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  151,  105,  971, 1656,  176,  920,    1,  619,  166, 1690,  132,\n",
      "           32,  537,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  669, 1203,  749,    1,  195,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1,   61,  193,  415,  885, 2480, 1671,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1918,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  681,    1,    9,    1,   45,   22,   23,   24,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9, 1879, 1090,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158, 2408, 2165, 2438,  220,  943,   45, 2528, 1542, 1230,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2003, 2960, 2414,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  428, 1327,  251, 1358,   98, 3036,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   70,  616,  771, 1009, 2107,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1663, 2888, 1551,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2001,   98, 2371,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1370,   45,  166,    1,  550, 1074,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3254, 2257, 2017,    1,  140,    1,  628,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    9,   82,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1287,   37, 1917,  873,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2095, 2985,    1,   32, 3360,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3320,  439, 3309,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2993, 2994,  166,    1,   12, 2995,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  275,  387,  572,  354,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   32, 3099,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3392, 2950, 1965,    1,   45,  863, 1708,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3349,  597, 2548, 2833, 3362,   12, 1691,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   46, 1348,  548,  395, 3102, 1757, 2424,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,   33,  625, 1308,   33,    1, 2760,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   66,    1,   32,    1,    1,    9,  920, 1721,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,   12, 1043, 1738,    1,    1, 1758, 1326,    1,    1,  504,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  361,  829,    1,   98,  854,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  307,   39,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1951,  700, 1077,    1,   54,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1585, 2668, 1855,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220,  764,    1, 2288,    1,  186,   37,  836,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,  936,  654, 2723, 2724, 1876,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1502,   37,  125,    1,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1935,    1,  844,   32,    1, 2107,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  261,   39,  271,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2039,    1,  191,  713, 1346,  297, 1804,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  961, 1498, 1000, 2298,  176,  183,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   51,  606, 2572, 1021,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128, 1203, 2048,   45,    1,    1, 2871, 1129,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  453,  449,    1, 1009,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,    1,  359,   37, 1195,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,    1,    1, 1980,   37,  759,  442,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2972,  475,  939,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 122, 600, 889, 973,  69,  37, 119,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  69,  27,  98, 430,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  766,  744,  119,  220,  365,    1,    1, 1017,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676,    1, 1867, 1894,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  217, 1173,   37,  104,    1,    9,  244,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  713,  105,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   99, 1554, 1184,  347,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280,    1,  191,  595,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1631, 2380,   32,  104,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327, 2749,  166, 1438,    9,  166, 1674,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3257, 2622,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 1268,  220,  726,  297,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1304,   37,  138,   59,   32,  133,  927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1178,  163,   12,    1,  665,   98,   56, 1292,   30,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   28, 1228,  669,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,   81,  548, 2170, 2128, 1207,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  640, 1198, 2838,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    5, 1084,  797,  431,  331,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  519, 3318, 1090,  167,   52,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2798, 1013, 2718,  661,    1,  616, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  413, 2776, 1926, 1927,  117,   37, 1260,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,   37,  151,  552,    1,    9,  600,   59,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  831,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,  511,  275,    1,    1, 1022,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3285,  132, 3310,    9,  485,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1693, 3192,  872, 1921,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2668, 2755, 2490,   98,    1,   45,  446, 2237,    1, 1941,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492,  186,  444,  362,    6,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 159, 686, 191, 156,   1,  60, 338,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1, 928, 176,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2026,   51,  606,  686,  224, 2264,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1019,    1, 1199, 2990, 2346,  365, 1125,   98, 3020,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1087,  551,  657,  872,   28,   98, 2168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503,  159, 1374,  959, 2335, 1146, 1703,  548,  420,  460, 2582,\n",
      "          749,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2571,  474, 3369, 1414,    1, 3118, 2649, 2791,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2050,  720,  104,    1,  102,   61,  410,  550,    9,  954,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1341,  155,    1,  102,  191,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,    1,    1,  943, 1394,   79,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2197,    1,    9, 1158,   12, 1135,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707,    1,    1,    1,  187, 2507,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428,  864,  420, 2827,   28,  187, 2390, 1806,   46,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2713, 2692,  640,    1, 2165,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3363,  810,  202,    1,   45, 3343,  863, 2241,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314, 1268,  331,  574,   37,    1,    1, 1629,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3219, 1473,   32,  539,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1584,  166, 1675,  361, 2778,    1, 1174,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   28,   71,   32,  156,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 2572,   98, 1314,   37, 2646,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  342, 1236, 2743,  297, 1471,  625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3061, 1406,  863,  652,   51,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094, 2414,  388,    1, 1763,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  198, 1220, 1702,  212,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3226,   37, 1377,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  688,  166, 3083,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2700,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089,    1,  163,    1,   12,    1, 3102, 3395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,   98,  112,  226, 1499,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,    1,  321,  333, 2260,   37, 1839,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  567, 1408, 2885,  384, 1423, 2784,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  361,    1, 2654,  792,    1,  792, 1766, 1767, 1228,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3067,  163,    1,   12,    1,    9,  443,   98, 2095,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2137,  135,  218,   32, 3144, 1633,    1,  583,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158, 2373,  282, 2367, 2695,  328,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2659,    1,  237, 2502,  187,    1, 2354,   32,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  191,    1,   32,    1,    1,  162,  166,  542, 1876,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043,   66, 1782, 1298,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1340, 2126,    1,   45,    1,  202, 1110,  729,  726,  183,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26, 1039,    1,    1,  162, 1597, 1799,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3298,  754,  361,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2686, 2135,  244,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1100,   46,   28, 1736, 1101, 1102, 2436,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  408,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  270,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9, 2691,    1,  105,    1,  713,   32,  260,    9, 2692,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  183,  460,  802,    1, 1044, 2230,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  335, 1090,  631,  297, 3175,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  105, 1950,   98, 3375,    1, 3101, 1583,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1, 1994, 2095,  582,  476,  388,  993, 2285,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  907, 1176,    1,  724,  220,    1,  751,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,    1, 1067,    1,   37,    1,  111,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2916, 2672,  442,    1, 2922,   37, 1214, 3323,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359, 2329,   37, 1154,  957,  384, 1686,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   96,    1,   98,  247,  248,  249,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  965,    1,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1919,  492,    1,   61,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  794, 1106,    1,    1, 2549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 267, 460, 719, 241, 394,  37,  77, 605, 328,   1,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  25, 800, 156,   1, 104, 332, 102,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2692,    1,  689,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,  958,   83,   37, 1910,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1451, 1713,  730, 2614,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1564, 1938, 2022,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,   12, 1354, 2556,    1, 1333, 1530,   32,  947,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1993, 3202,   32, 1388,   45,  166, 1110,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  574,    1,   37,  875,    1,  138,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1585, 2766,  176, 3099, 1325,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  938,   37,  319,  941, 1201,  792, 1387, 1890,  792,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3037, 2109,  442,   32,  388, 2342,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  321, 1198, 3262,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  991, 3192,  872,   37, 1174, 1853, 2579,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  755,  496,  782, 1219,    1,    1,   37,  111, 2429,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  633,    1, 1536,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1378,    1,    1, 2952, 1183,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2197, 1218,  765,   37,  322,   79,  531,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  506,  852,  176,    1,    1,  938,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9, 3358,    1,    1,    1,  874,   45,  753,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3356, 1484,    9, 2646, 2756,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649, 2681,    1,    1,  125,  384,    1, 2959,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  247, 1194, 1462,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1746, 1705,    9,  963, 2949, 1781,   79, 1973,  540,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1764,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,  125,  985, 2130,  629,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2027,   61,    1,    1,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  925,   65,  716,    1, 1121,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  147, 1707,  205,   22,  365, 2036,   35,  662,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181, 1831,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,    1,    1,  453, 1545,   37,  335,   98,  224,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1, 3077, 3126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3166,   12, 2558,   16,   32,  354,   37, 3161, 1022,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,   85,   32,  367,    1,    1,  468,  729,  198,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2204,  804,   51, 1031,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613, 1702,   39, 1615,  328,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  422,    1, 2252,    1,  607,  907,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1159,  166,  207,    1, 1632,  166,    1,  236,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2201, 2003, 2960,   32, 1619,  395, 2414,    1, 1554, 3156,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  461,    1, 2227, 1522, 2436, 1604,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2695,  105, 3054,    1,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2518,  427,  297,    9, 3169,  361, 3274,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37,    1, 1009,  384,  166, 1645,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  711,   12,   59,  332,  151,   81,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1870,    1, 1455,  197,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1319, 1702,    9, 1211,  442,   92,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  739,  433,  636,  720,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3189,  256,   37,  247, 2671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1022,    1, 2838,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,  361, 1821,    1, 1353, 2575, 1728, 1114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  912,    1,  400,  782, 1678,   32,  147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2208,    1,  680,  123, 1075,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1656, 2596, 2960,   32, 2597, 2414,  228,  631,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  815,   45,  457, 1325,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1751,  361,    1,    1,  220,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1670,    1, 3258, 2579,  726,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  539,    1,  726,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169, 1249,    1,   37,  335, 1913, 1684,   45,  914,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  993,    1,  365, 1928,    1,   37, 1926, 1927,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401, 3231,   37,  726,  297, 3232,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  279,  669,    1,    1, 1294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1972,  541,   32,  537,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  510, 1782,    1, 1813, 2028,    1, 1212,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1360,    1,  202, 2746, 2360, 1771,  741,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  884,  845, 2041,    9,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3199,    1,  384,  103, 1569,   32, 3076,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  398,  908,  104,  358,  469,   37,  125,  138,  191,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117,   67,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  454,  116,  259,    1,    9,  424,  339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  361, 2018,  288,   37,    1,  846,  443,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  861,  760,    1, 1699, 2928,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1475, 1126,    1,  422,  562,   76,  892,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1024,  551, 1024,   37,  151, 1026,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  102,    1, 2084, 1253,  452,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  766,   37,  815,    1,    1,   32,  365, 1825,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   72,  401,  197,  407,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2275,  155,  331,    9, 2746,   32,  903,    1,  904,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,   12,    1,    1, 2732,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  173, 1762, 2826,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789, 1009,  315, 2579,   45, 2211, 2860,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  603,    9,    1,   37,  100,  444,  864,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3184,  147,    1,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,   46,  220,  359, 1686,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  459,  220, 3190,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3375,  193,    1, 2398,    1,  267, 3359,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2814,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1668,  517,    1,    1,  967,   38, 1857,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3349,   32, 2300,    1,  548,   64,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1661,  156, 1253,   98, 1251,  745,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   60,  640,  885,  340,  444,   94,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,  186,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973,    1,   15,  701,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1, 1022,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1920, 2572,   32, 1260,   98, 3339,  399,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  193,  320, 2056,    1, 2104,   57,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 2491,  400,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1708, 2290,  884, 1963,   37,  463,  584,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   59,  214, 1523,    9, 1178, 1179,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  674,  167, 1154, 2548, 2853,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2401,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3101, 3162,  686, 2708,    1,   32, 3339,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1, 1273,  259,  218,  332,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1930, 2317,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3183,    1, 3229,    1,  877,  132, 2925, 2246,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2226, 2632,  334,  603,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1,  104,  498,   37,    1, 1196,   45,  284,  294,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  591, 3150,    1,   81,  384, 3155,  730, 1731,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  200, 1778, 2580, 1455, 1294,    9,  854,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3147,    1, 3114, 2004,    1,  178,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  469,   37, 2785,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,  645, 3278,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1691, 1434,   32,  680,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2,  60,  28, 699, 951,   1,  94,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 891,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  255, 2332,    1, 1488,  763,  105,  224,  627,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3157,  820,  384,    1,  827,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,    1,  191,    1, 1593,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978,    1,    1,  725,  384, 2650,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2497, 3322,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178,  947,    1, 1312,  249,   98, 2095, 1898,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2881, 1450, 1718,   98,  768, 1030,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,  335, 1090,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  551,    1, 2614,  460,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   42,  786, 1405,  149,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,  365, 1916,   98,    1,  223,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 2764, 3212,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2957,  794,  593,   12, 1254, 2334,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  575,  442,   32,  754,  618,    9, 1273,  361,  777,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3402,    1, 1988,   45,    1, 2772,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785, 2292, 1702,   69,  102,  242,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1326, 1564,  119,  449, 1023,  197,   45,  131, 1547,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2311,  615,   51,  349,  131,   45,  395,   12, 1628,  734,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2853,   98,   32,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2924, 1000,  388, 2496,   32, 3383,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1137,  530, 1130,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2055,  365, 1204,   32,  455,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 1252,  113,   79,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1864,    1, 2825,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  845,    1,  484,    9, 3317,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  854,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,   37,    1, 1013,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3302,  315,   16,   37, 2460,   79,  593, 1990,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3188,    1,  228,    1,   32,  449, 1023,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,    1,  326,   37,  877,    1,    9, 2530,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   28,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   26, 3173,  288,   37,    1, 1381,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,   37, 1174,    1, 2432,  949,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,   46, 1897, 3371,   12, 2237,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  835, 1717,    1, 2244,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537,  700,    1,  468,  220,    4, 1437,   32,  903, 1423,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2297,  187,    1, 2565,  463,    1,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1268, 1718,  656,   32,  968,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  413, 2473,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,   12,    1,   51,   52,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3187,  576, 3177,    1,   37, 2170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  116,  412,  176,    1, 1300, 1410,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2487,    1,    1,    1,   72,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  353,  304,    9,    1,    1,    1,   78,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,  63, 166, 862, 262, 263, 159, 720,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 111, 325,  48,  32,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1061,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2077, 1205,  297, 1656, 1311, 1987,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1861, 1229,   37,  588,  365,  651, 1259,  220,   10,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  176, 1034,  340,  187,  109,  997,  470,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  224, 1126, 1258,  528,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1841,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1429,  437,  155,  142,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,  297, 3151,    1,  453, 2308,  606,    1, 1977,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,  105,   74,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1005, 2737,  193,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2241, 1458,    1,   12, 2381, 2169,  627,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 3087,  640,  455, 1114,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3282, 3204,  992,   39,   45, 1764, 1990,  427,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3320,  688, 3262,   37, 1734,   72,  176,  166, 2601,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  669,   37,  836,  134,  187,  561,  837,    7,  494,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1062,    1,  251,   54,   37,  151,   81,  612,  111,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  519,  168,   98,  166, 2731,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2490, 1585,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  148, 1114,  879,  693,    9,  647,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1035, 1765,  961,    1,  590,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2, 848, 123,  37,   1, 849,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 388, 861, 509,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   49, 1644,   90,  147,   45, 2429,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,  900,  580,  104,    1, 2357,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1866,  754,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593, 1030,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2297, 1354, 2342,  787,   32,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1874,    1,  132,    1,  159,  554,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 2806,  934, 2232, 1643,  345,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1840, 2094,   80, 1108,   37,  388, 2458,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3369,  459,    7, 2024,  802,  220, 2751,  187, 3118, 1512,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  354,   98,  983,  720,    1,  134,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2309,    9, 1943,  317,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2828,    1, 3313,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  275,  681, 1012,  388, 2703, 1120,    1, 1176,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2183, 3370, 3350, 1061,   32, 2755, 3360,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   80, 1586,   28,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1158,  721, 1098,   32,  792,    1,    1,  792,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1173,   37, 1435,    1, 2565,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1, 1306,  546,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2580, 2851, 3049,    1,  331,  813,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    6, 1273, 2403,  102,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2557, 1648,   98, 1645, 3365,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,   12,    1,   37,  135,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2554, 3300,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3102,    1, 3041, 1259,   37, 1211,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2617, 1373,   37, 1584, 2214,    1, 2844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   83,   37,  930,  187,  654,   82,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  560,    1,   28,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  204,    1, 1846,    1,  600, 2977,  317,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1089,  396, 1665,   37, 1796, 3102,   12, 1204,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  761, 1086,  195,  931,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1774,   39, 1230, 2528,    1, 2668,  220,  163,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,  332,  756, 1228, 2690,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1,   91, 1980,   37,  498,   98, 3107, 3366,    1,    1,\n",
      "          716,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  657, 1774,   81,  157,    1,    1, 1999,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843, 2523,  140,  837,  593, 1787,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  991,    1, 1965,    1,    1,    1,  227,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,    1, 3260,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,    9,  342, 1994, 2143, 1377, 2322,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  951,  691,    1,  449, 1463,    1,   74,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,  361,    1,  507,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 1630, 1216,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  542,    1, 1183,  847,    1, 2620,    9, 2692,  714,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2278,  708,    1,  326, 2469,    1,    1,    9,    1, 2027,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2779,    1, 3169, 1758,  176,  455,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,  517,    1,    1,   92, 1766, 1767,  704,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   37, 1075, 2283,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1571,  154,  186,   32, 2184,  444, 1715, 1281, 1140,  460,\n",
      "         1514, 2389,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   81,   32, 1505,   37,  631,  978, 3138,   32, 1918,\n",
      "          297,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579, 1411,    9, 1029,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977,  582,    1,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  162,    6,  384,  474,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2, 702, 353, 197, 987,   1, 897,  88,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 353, 105, 720,  32, 197,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  819,  321, 1000, 1507,  229,   32,  163,    1,   12,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  744, 2306,    9, 1126,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   27,    9, 1527,  379, 2747, 3369,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652, 1236,  829,  297,    1, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  580,  312,    1,  149,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  105,    1,   45,    1,  361,    1,   45, 2218,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3215,    1,   37,    1, 3316,  808,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  437,   32,  531,  396, 1887,   45, 1485, 3102,  844,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3096,  166, 1147, 2494, 1086,  187,    1,  726, 3077,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,    1, 2006, 2347,   32, 3149,    1, 1260,   32,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   12, 3135,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2386,    1,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  667,  947,    1,  297, 2249,  487,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  195,  230,  756,   61, 1621,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3324,  490, 1048,   32,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  957,    1, 2764, 3356,  562, 2024,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  571,    9, 2920,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715, 1379, 1161,    1,   32, 1657,   98,   69,  636,  948,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  379,  837, 1876,    9, 1407,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1570, 2192,  357,  335,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2136, 2137,  365, 2138,  261,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,    1,  686,  242,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1064, 2156,   37,  194,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2765, 3060, 1333, 1530,   32, 2018,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2141, 3061,    1, 1209, 2630,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861, 2393,    1,  548,  103, 3354, 2764, 3394, 3060, 2572,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,    1, 2924,   98, 3114, 2735,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,    1,    1,   32, 3339, 1656, 2950,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3297, 2951,  511,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2992,  645,  468,    1,  357,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1110, 1832, 3260,    9, 1264,  841,  220,  726,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  411,    1, 1385,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  709,    1, 2681, 1654,  963,  147,  695,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1934,  267,  460,  190, 1211,  297,    1,  388, 3080,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   35,  261,   39,   22,  438,  662, 1377,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  439,  242,  277,  191,  503,    1,   60,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  681, 1120,  565, 1509,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61, 1013,  600,   37,   52,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  418,    9,  601,   74,  187,   49,   51,  194,  532,   37,\n",
      "          395,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1520,    1,  104, 2419,  218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,    1, 2638, 1529,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105,    1, 1893,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,  839, 1273,  259, 1140,  408,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1716, 2759,  218,  983,  897, 1087,   12,  332,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,   12,  650, 2478,   28, 2224,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2743, 1760, 1689, 1891, 2710,  299,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  677,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  952, 1250,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    9, 2925,    1,  105, 1133,  698,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,   32, 1533,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1317,  704,  104,  353, 1455,  354,    1,   15,  276,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  700,    1,  389,    9, 2693,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1876, 1294,  696,  166, 3232,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  208,  458, 2596, 2137, 2856,  786,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3349, 2785, 2162, 1950,  677,    1, 1060, 2249,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,    1, 2896,  837, 2992,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  903, 1447, 1271, 2673,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2278,  325,    1, 2657,    9, 2051,  763,  331,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  220,  365, 2367,    1,  829,  952,    1,    1,  566,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,  167,  664,    1,  671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1183, 2921,    1,  688, 2413, 2932, 1210,   37,    1,   39, 1433,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2597,    1, 2793,  220, 2909,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,   99,   12,    1,   37, 1198,  347, 2141,   60,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,  438,    1,   37, 1083,  529,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  531, 2924,  221,    1,   12, 3165,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  534,  162,    1,  187,  204,  765,   39,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  947, 1229,   37, 2446, 3373, 1927, 1656,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510, 2414,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1713, 2514,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,    1,  183,  889,   69,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1, 2104,   51,  501, 1125,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1583,    1, 2095,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1711,    1,  709, 2741, 3164,    1, 2912,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1762,    1,  606,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  224, 1475, 1126,  636, 2320,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,    1, 1589,   21,   37, 1427,   15,  191,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  996, 1470,    1,  140,    1,  388,  962,   51,   52,  166, 1851,\n",
      "          454,   39,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1929,  893,   81, 1147, 1896,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1122,   37, 1539,  111,  538, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1509,   32,  166,  112,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1625,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275, 2386,  451,  706,   45, 2189, 2471,   37,   10, 1708,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  458,   45, 2741,  894,  335,  105,    1,  176,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1920,  140, 3126,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  187, 3079,    1, 2087, 2614,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190,  460,   52, 3303,  357,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2097,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066,    1, 1406,    9, 3242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3344,    1, 2833,   36,   32,  121,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1126, 1518,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3254, 2094, 1104,   37, 1361,  787,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2162,   45,   27, 1306,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2596, 1976,   98, 2921, 2074,  548, 1861, 2237,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2137, 1296, 1619, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2314, 2843, 1056,   81,  176,  294, 1456,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181, 2914, 1199, 1102,  841,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1105,  787,    1,   32,  572,   15,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,  425,  426,  710,  513,  514,   37,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3253, 3329,    1,   32, 2936,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081, 1441,  107,  380,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1771, 1022,    1,    1,  548,    1,  354,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3354, 1497, 1260, 3384,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1405,    1,  845,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1086, 3339, 2831, 2625,  380, 2708, 1530,    1, 1884,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1932,  295,   72,  401,  197,  641,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2919,    1,   37,  606, 1846,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1477, 1990,    1,   98,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,  163,    1,   12,    1,    1,  864,   37,  943,  531,    1,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,   22,   82, 1550,    1,  943,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1242,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,  191,  105, 2847,   32,  463, 2170,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  493,    1,  636, 1637,  452,  465, 1014,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3256, 3280,   61,    1,  191,    1,   32,    1, 2139,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1, 1031,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  138, 2260,   37,  932,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 2384,  365, 1116, 2549,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  548,    1,   32, 2841,   12,    1,    1,    1,    1, 1542,   37,\n",
      "          877,  247,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 2920,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1539,  777,  279, 1659, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  951,    1,  365, 2741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,   12,    1,  458,  267,  156,  288,   37, 1124,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1748,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2820,    1, 2700,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994, 2095,  947, 2263, 3402,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1523,  921,    1,  841,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3221, 1554,   19,  841, 2151, 2689, 1717,    1,   32, 2513,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  148, 1564, 2069,  647,  693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1898, 1815,   37,    1,  854,    1, 1323,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1444, 1445,  176,  582,   45, 1515, 1280,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160, 1161, 1042,   32, 1169,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,   1,   1, 693,   1,  37,   1, 726,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 225,   1,  98,   1, 101,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  861,    1,   32, 2197,    9, 3358,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  863,    1,    9,   69,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2749,    1, 2382,    1,  522,    1,    1,    1,  590,  460,   12,\n",
      "          193,    1,   12,  457, 1204,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1, 2968, 2983,  680, 1165,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   56,  497, 1539, 1428, 1311,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314,  551, 1692,  267,  228, 1682, 1910,  721,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  163,    1,   12,    1,    1, 2541, 1360,  612, 1121, 2735,\n",
      "            1,    1,  293,  963, 2122,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1841,    1,  191, 1920, 3160,   12,  531, 2162,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2533,   37,    1,  627,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1811,  404,    1, 1550,  134,   45,    1,  220,  864,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 1615,  361,  388, 2030,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  747, 1586,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 2108,    1,    1, 2055, 2041,    1, 1316,  447,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,    6,    4,  187,  479,  315,  365,  250,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1891,    1,    1, 2834,    1,    1,  345,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181, 2471, 1545,   32, 2038,  922,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  105, 1787,   37, 1228, 2718,    1,  384,  786,   45, 1515,  248,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2238,   37,   52,  848, 1090,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1247, 1564,  914,  714,    9, 3206,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  304,  297,  116,   15,   45, 1792,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  866,    1,    1,    1,  530, 1547,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  528,  810,  166,    1,    1,  275,    1,    1,  612,  921,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  179,    1,  180, 1025,   37, 2123,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302,    1,   32,  104,  233,    1, 1670, 1428,  522,   98, 2862,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,  267,  163,    1,   12,    1,    1,  809,   98,  453, 3032,\n",
      "          210,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  563,  564, 1812,    9,  815,   98,  793,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1002, 3358,  901,  311, 1021,  537, 1490,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  552,  551,  405,   37,    1,   28,   37,    1,    4,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1273,  987, 1394, 2175, 1371,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885,  311, 1628, 1998,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  378,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  345,   37,    1, 1993,    1, 1415,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2828, 2250,  220,    1, 2337,    1, 2857,  298, 1834,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1, 2596,  531,   12, 3391, 1114,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035, 1036,    9, 1065,  199,  844,   16,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1, 3343, 1414, 2625, 1219,   32, 3376,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,   70,  245,  105, 1913,   74,  187,  531,  641, 1828,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    1,    1,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  857,    1,    1,  477, 1550,  386,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,    1, 1817,    1, 1117, 2208, 1603, 2290,  149,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  137,  341,   64,   25, 1473,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  365, 1273,  259, 1013, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1009,    1,  220,  147,  695,   98,  863, 2431,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190, 1334,   98,  187, 1583,  475,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  840,  227,  258,    1, 2806, 1011,    9, 2112,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  950, 1745, 2192,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3089, 3297, 1246,  167,  619,  365, 2240,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   22,   95,  473, 1542,    9,  477,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094,  908,  388,  539,  458,  399, 1219,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2991, 1059, 2017,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  213,  220, 1712,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2280,   12, 2288,  626, 1671,  140,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1641,  105,    1,    1, 1465, 1151,    1,  361,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  430,    1,   37,  907, 1009,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2065, 2064,   37, 1636,  191,    1,  118,  424,  356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    7, 1842,  844,  132,    9,  829,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  212,   72,  401,  197,   28,  419,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2728, 1464,   37, 1083, 2875,   37,    1, 2818,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  111, 1107,  778,   42, 2730,  149,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3345,   32,  531, 1211, 1312, 1538,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2425, 3002,    1,  176, 1778, 1192,   32, 2101,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1353,  395, 1116,  778,   32,  465,  218,  973,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  954, 1044,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1746, 1149, 1154,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  662,  624,    1, 1776,  365,    1,  250,   24,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1740,    1,  176, 3092,   12, 1140,   37, 1250,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  964, 1921,   32,  854,   37,   92,  112,    1,  626,    1,  622,\n",
      "         2471,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2995, 1681,  565,   81,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1187,  193, 1838,  247,  449, 3285,  698,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1,    1, 2415, 1855, 1647, 1750,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   98, 1485,    1,    1,    1,  736,    1,  289,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1050,  947,    1,    1, 1671,  548, 3387,  304,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2206,    1, 2040,  548, 1123,  765, 3251,   37, 2016,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  674,    1, 2320,  775,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  754,  757,  155, 1470,  187,  197,  921,  308,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1,  169,  132,   51,  973,   25,  242,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2412, 1421,    1,    9,  786, 2107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1413, 3129, 1049, 1411,  356,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1413, 1477, 1990,  872,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   12,    1, 2779, 2540,    1,  316,   32,  455,   26,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2620,  488, 1090,   45,  593, 2522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766,  952, 1080,  444,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,   12,    1, 2889,    9,  547, 1675,  191, 3092,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  372,    1, 1056, 2166,   37,  619,    1,   48,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1413, 3151,   12,    1,   37,   91,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  317, 1839,  651,   46,  439,   98,  105,  340,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  683,   37, 1510, 3333,    9,  593, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  260,   28,    9,  159,   32,  458,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,  167, 1719, 1533,  388,   37, 2235,  763,    1,  182,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  971, 2139,   37,  875, 1559,  297,    1,  382,  333,\n",
      "         1144,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   79,   37, 1319, 1953,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3160,    1, 1976,  514,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  755, 1241,   28,  365,  834, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  492,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  756,  757,   82,   39,    1,  709, 2925, 1009,   32,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,  778, 2073,  163,    1,   12,    1, 3102, 2572,   32,  531,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3225,  877,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 1542,   37, 1173, 1159,    1, 2362,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  251,    1,    1,  152,    9,    1,  225,  490,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2102,  920,    1, 1197, 1632, 2464,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  612,  302,  347,   71,   32, 1611,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3191,  884,  674,  220,  726,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1497, 2497, 3384,    1,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2931,   32,  395, 2162,  191,  270,  884,   98,  105,  365,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1038,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1107, 2165, 1079,    1, 1433,  151, 1232,  334,  321,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,   98, 2382,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3391, 2924,  680, 1884,  114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2,  25,  71, 187,  68, 338,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 179, 716,   1, 354,  32,  72, 401, 428,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,   12,    1,   32, 2646, 2572,   32, 1056, 2458,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3257, 1809,    1,   26, 1844,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2347, 2523, 1056, 1593,   81,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  500,  387,  271, 1452,   32,    1,  225,   85,  419,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1008,    1,   82,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2065,  166,  954,   32,  105,    1,  454,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1186,  580,  573,  745,  910,    1,  420,  108,    1,    1,  446,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428,  475,  267,  116,    1,  166,  627,   45,  550,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1100, 1627,  166,    1, 2060,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1547,  682,    1,  187,   69, 1458,   79, 1653,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1517,   12, 2925, 2246,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1628,  341,    1,  818, 1697,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  159,  697,   37,  698,  699,  143,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1, 1133,  460,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1013, 1522,    1,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  338, 1139,   98,  741,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2550,  674, 2344,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  837, 1532,    1, 2309,  600, 1925, 1583,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  321,   52, 1452, 1488,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596, 2232,  983,  407,   32,  581,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 2253,  471,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2442,    1,    9, 1338,   45,   94, 3283,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,   39,  854,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98, 2941,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,  920,    1,   28,   37, 1700,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1944,   45,    1,    1, 2124,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2628,    1,   37,   18, 2017,  220,  183, 2963,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 627, 996, 406,   1, 338,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 157,   9, 646,  85,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2826,  439,  220,    1,    1,  591,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2272,   85,   98, 2975, 1064,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  854, 2272,   85,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,   37,  125, 2978, 1491,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1592,  420, 3106,  570, 2666,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3328,    1, 1194,  913,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2161, 1268,   28,  631,   98,  121,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,    1, 2987,  460,   12,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,    9, 1107,    1,    1,  575,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   40, 1732,  162,    1,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147,    1,    1,  176,   10,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3256, 2333,    1, 1660,    9, 2379,    1,  361, 2939,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1936,   32,  176,  551,  612,    1,  196,   61,  553,  613,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,  924,  580, 2263,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1, 2179, 1898,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2849,   45,  531, 2619,  297, 1428,  907,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2551, 1844,  297, 1879,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708, 2153,  707,  115,  220, 3358, 2237,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  584,  744, 2589, 2186,    1,  804,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  231,    1,    1,  256,  365,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  915, 1140,    9,  615,   37,  142,   98,  224,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  331,  551,   12,  325, 1146,    1,    9,  215,  331,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2925, 1675,   98,  844,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035,   61, 1229,   37, 1642,  199,   32,  539, 1037,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 2254,  872,   28,   37,  877, 1521,    1,    9, 2530,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503, 1670,  365,   82,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1423, 1831, 2745,  220,    1, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425,   32,   54, 1883,  170,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  810, 2615,    1,  810,  730, 2614,  810,  166,  199,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1867,  111,  538, 2190,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  422,    1,    1,  927,    1,   37, 1682,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  161,    1,   12, 1333,   32,  166,  886,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2577,    1,   37,   52, 2827,   32, 2235, 2697,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3173, 2137,    1,  548,    1, 2712,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  876,  612, 1426,  630,   37,    1,   69,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800, 2671,    1,    1,   37, 2611,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  313,   37,   92,    1,   32,  531,   37,\n",
      "         2074,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151,  474,  681,   28,  453,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1029,   69,    1,  191, 1002,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,  726,    1, 1876,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977, 3015, 2324,    1,    1,  193,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1487,  794,  449,   45,  792, 1107, 2008,  792,    9,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  245,   37,    1,    1,    1,   32,  282, 3154, 1090,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,    1,  777,  259, 1108,  384,  171,  804,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,   90,  121,   37, 1636, 2673, 2471,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  396,  593,  119,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3069, 1666,   46,  220,    1, 1190,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,    1,    1,  759,  260, 2285, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   82, 1454,  503,   98,  749,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151, 2348,    1, 1873,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1668,    1,    1, 1247,    1,    1, 2922,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,  147,    1, 2180,    1,    1,  695,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  311,  190,    1,  384, 2091,  437,    1,  267, 2565,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  698,  166, 2789,    1,    1, 1921,   32,  166,  104,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056,  597, 2615,   37,  619,    1,    1,   32,    1, 2811,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  168,   37,  166,  806,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   72,  401,   61,  599,    1,  202,  579,  600,  601,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1810,  177,    1,   32,  596, 1279,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3345,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    6,   32,    1,    1, 1649, 1648,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  113,   98,   37,  477,  460,  252,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  258,    1,    1, 1818,  147,  736,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  470,  548, 1677,  191,  107,   78,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1711,  388, 2705,   76,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1729,  804,   32, 1412,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640,  105,  119,    1,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3181, 1387, 1881,   45, 1411, 1267,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,  623,  200, 1107, 1863,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1029,   12, 1459,  580, 2179,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  446,   37,    1,  985,  351,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2912, 1401, 3206,  297, 2475,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,   37,  619,    1,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  647,   37,  648,  334, 1445, 1558,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 2053,  293,  288,    9, 2205,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  612,    1,  885,    1, 1346,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3132,  168,   28, 3232,  726, 3201,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  306,  794,  105,  777, 1013, 1108,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 2023, 2104,   37,    1,    1, 1563,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  680,  114,    1,  136,  859,   37,  917,  453, 2728,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1628,   74,    9,  195,  441,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   20,    1,  331,  384,  104, 2485,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3361,    1, 1674, 1918,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,    1,   71,    1,  697,   37,  726,\n",
      "          449,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1648,   37,  764, 1121, 2822,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  141,   47,   79,  162,  680,  454,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1138,    1,    6,   81,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 166,   1, 821, 633,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  600,    1,  361, 1161,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2907, 1408,  730, 2614, 1625, 2793,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  315,  734,  333,   45,  131,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3262,  664,   39,   37, 3320,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2888,  640,  878, 1688, 1465,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1347,   16,  573,  910,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2708,  446, 1082,    1,    1,   32, 2299,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   28, 1488, 2171, 1463, 2753,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1247,    1,  156, 1253,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3356,  578,  204,  190,  690, 2024,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  571,    1, 3263,  664,  902,    1, 3263,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1786,   61, 1176, 1125,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  567,  799, 1414,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1326,  244, 1253,   32,  449,    1, 1023,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3215,    1,  191,  645, 1567,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596,   93,    7,   37,    1, 1681,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3276,  335,   98,    1,  519,   98, 1602,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  882,  733,  327,    1,  361,  526,  844,  883,   50,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  978,  769,  245,   98,    1,    1,   69,   25,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1,    1,  596, 1793,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,   98, 1139,  439, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1612, 1335,  514,   32,  286,  927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  599,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  288,   28, 1972,    1, 1651, 1597,   32,  395,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1667, 1765,  105, 3188,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  882,  623, 2361, 1299, 2261,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1, 1612,   37,  273,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,    1, 2724, 1521,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  318,   12, 2415,  166, 1787,    9,  166, 3375,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    9,  829,   12, 1778, 2232,    1,  365, 1626, 1323,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  493, 1738,  640,    1,    1,  361,  460,   12,  972,   37,\n",
      "           71,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2466,  682,   92, 2467,   45, 1238,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1583,    1,  513,  514,   32,  531, 1038,  966,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496,  560,  347, 1180,   28,    9, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1869, 1494,   37,    1,  220, 1904,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  220,  933,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  129,    1,  733,    1,   50,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810, 1167,    1, 2385,  612,  671,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1008,    1,   37,    1,  896,    1,  187,  475,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  590, 1400,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1858,  895, 1240, 1527,  393,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564, 3304,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2154, 2997, 2026, 2988, 2952,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230,    1,    1,    1,  163,    1,   12,    1,   26,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1713, 2321,  220,  661, 1750,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2590, 1427, 3078,  271,  972,   39,    9,  914,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   28,  528,    1,  646,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384,  116,  886,    1,   37,  166, 2463,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401, 2920,  608,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 2979,   37,  815,  617, 1151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1159,  915, 2144,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1140,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,    5,    1, 1097,    1,   32,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1282,  166, 1194,    1,    1,   32, 1019, 2218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  657, 1949,  103,  846,  660, 1151,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  491,   37,    1,  182,  104,   37, 1504, 1356, 2337,  840,    1,\n",
      "         1331,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  529,  636, 1480,   79,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3013, 3229, 2236,   37, 1594, 2193,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1484,    9,  326,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2789,    1,   32,  171,  806,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  936, 1350,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,   37,  125, 2128,    1,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3303,  580,    1, 1948,   32, 2741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1795, 2279,  197,  407,   32,  401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  160, 1161,  953,    9,  581,   73,  339,  389,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3152, 1421,  656,    1, 2523,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  196,  936,    1,  389,    6,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  460, 2055,  220, 2151,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3298, 1293,   98, 1434,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715, 2404,  738,  220, 2708, 1513,  115,   45,   46,   32, 1094,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12,    1, 1509,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106, 1713,  166, 2355, 1013,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   93,  338,   37,  339,  340,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  223, 2420,   86,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1948,    9,  166, 1990,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1042,    1, 1367, 1368,    1,  305,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  565,  334,    1,    1,    1, 1608, 1103, 1174,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  744,   39,    1,   98,   80,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1861, 1373,   10,  204, 1710,  193,    1,   32, 1876,    9,  443,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  755,   37,  125,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3108, 2615, 1090, 2052,  191, 2620,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359, 3090,  590, 1161, 2591,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  667,  446, 2331,   32, 2069,  863, 1034,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  228, 1013,    9,  671,   32,  104, 2161,   12, 3096,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2004,    1, 2226,  933,  777, 1085,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1002,    1,  275,  315,  565,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  443,    1, 2272, 1018,    1,   45, 2518,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  640,  166, 2798,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  860,    1, 1998,  658,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1031,   45,    1, 1240,   52,    7,   37,  195,   12,  270,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  183,    1,    1,  183,    1,    1,  183,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1435,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,   37, 1198,  909,   98,  104,    1,  202, 1574, 2449,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387,  572, 1103, 1315, 1944,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 2184,   61,  400,  942, 1654,    1,    1,   12,    1,\n",
      "          562,   37, 1343,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196, 2652,  176,  612,  613,  887,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  379, 2047,    1, 1687,  167, 1686,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885, 1607,  211,  176,  657,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  790, 1579,    1,  161,  769,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  211, 1718,    1,    1,    1, 1592,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  547,  163,    1,   12,    1, 2548, 2844,   32,  531,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,    1,  640, 2174,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1821, 2190, 2640, 2652,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1773,    6,  636,   98, 1090, 1667, 1758,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  967,    1,  227, 1561,    9,  247, 2293,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2693,    1,    1,  829,   12,    1, 2884,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  338,    1,    1,  297,  954,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1294, 2758,    9,  116,  259, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,   12,    1,  852,   81,   98,    1, 1747,  327,  593,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1068,  568,   93, 1270, 1271,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,   37, 2809,    1, 1159,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1185, 1645, 1920,    1,   32, 2235, 2578,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2332, 2192, 2829,  453, 1134,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3100,  921, 3100,  501,  827,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,  159, 2035, 2381,  356, 1653,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3079,  565, 1372,   37, 1031, 1515,    1,  550, 1028,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2094,   26, 1039,   37,    1,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2087, 2614,    1,  105,  910,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   42,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  766,    1,  331,    1, 1395, 1597,   37,  877,  183,  844,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  267, 2755,   69,  532,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2576,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  176,  166, 2661, 1510,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2254,    1,  157,   88,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  147,  520, 1393,  191, 1525,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   49, 1536,    9,  467,   32,  163,    1,   12,    1,  147,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,   37,   47,    1,  331,  159,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2257,   39,  187,    1, 2225,  512,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,  474, 1195,    1,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2887,  230, 2850, 2516,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3024,   37, 1937, 2300, 2923,   45,  166, 2918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2730, 2362,    1, 1406,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  197,    1,   98,  529,  102,    1, 2015,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  219, 1350,  927,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1512,  297,    1, 3360, 2405,    9,  741, 2116,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1013,    9,  365, 2792,  512,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,   12,    1,    1, 3053,   37,  930,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2391,    9, 3081,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  894, 1221,   52, 2281,  134,   32, 1283,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2083, 2791,    1,    1, 1204,  729,    1,    9, 3118, 3396,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  936,  365,    1, 2544,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3300,  183, 1940,  221,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  681,    1,    1,  783,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 3262,  512,  444, 3187, 1737,  332,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  580, 2062,   32, 3295,  424, 1981,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  547, 2265, 1612,   45, 1011,  669, 1333, 1530,   32,  105, 2597,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1728,    1,  191,    1,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,   98,  845,  439,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  200, 2528, 1616, 1230,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3038, 3343, 1585,    1, 3102,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 2472,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3115,    1,    1, 1323,  193,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  411,   37,   71,    1,  193,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  487, 2924,   37, 1876,  104,   32, 2597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1621,    1,    1, 2673,  529,  903,    1,  464, 3397,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2690, 1396,  829, 2987, 2762,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,   37,  480,    1,  481,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2347, 3131, 1414,    1,   37,   81,   39,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1938, 2607,  382, 2206, 2989,  951,    1, 2692,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  460,   12, 1176,  857,   37,    1,  829,   32,  342,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,  365, 2036,   44,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3132, 1575,  297,  405,   12,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12, 1733,    1,    1,   32, 2139,    9, 1021,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3169, 1249,    1,    1,   37,  726, 1684,   32,  316,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147, 1360,  612,    1,   32,    1,  856,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  140,    1,    1,  149,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,    1, 2580,  442,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  200, 1935,    1,    1,  566,  242,  332,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,   45,  414,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  305,    1,  242,    1,    1,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938,  796,  103,    4,  176,  941, 1201,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2880, 1527, 2210,  697,    9,  590,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1931,  297,    1, 1046,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1181, 1542,    9, 1675,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,   37,  151,  649, 1885,    1,    1,  150,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2123,   37, 1505,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,    1,  162,  885,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1363,   37,  345,  220,   20,   32,   95,  116,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  811,  812,    1, 1645, 1076,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,  829, 1467,    1,  232,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  744,  365, 1757,   98,  647,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,   47,    1, 2549,  112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1520, 1380,  453,  327,   32,  166, 2301, 2012,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,  790,    1,    9,    1,   32,    5,  302,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,  104, 2872,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1924,  356,   45,    1, 3005,    1,  777,  700,    1,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,  418,  187,    1,    1,   79,  425,  426,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 519,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 328, 596,   1,   1,  98,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2655,    1,    9,  449,    1,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   68,  744,  365,  119,    1,  106,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3218,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 1158,    1, 1128,  631,  327, 1889,    1, 1279,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,    6,  636, 2320,    1, 1086, 1611,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878,  744,    1,  529, 2461,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 1164,   45,    1,  781,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,   82,  387,  198, 1838,   37,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,  119, 1018, 1816,   32,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  803, 2242,  387,    1,  726,   32, 2138,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1861, 1454,  443,    1, 1082, 1016, 2789,   37,  123,    1,  361,\n",
      "          856,    9,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,  885, 1855, 2886, 3395,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1118, 1778, 2580, 2851,    9,  754, 2264,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  242,  548,  720,   32,   69,  102,    1,    1, 1886,   98,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  153,    1,  167, 1306, 2006, 2119,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   39,   45,    1,  628,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  220,    1,   32,    1,    1, 2615,    1, 2394,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1252,    1,  511,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1213,   12, 2162, 2503,  171,  237,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,  580,  104, 1756, 1232,  179,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  550, 1376,  919,  810,    1, 1279,  608,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  515,  787,    1, 2012,   37, 1192,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2995,  140,  297,  207,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1312, 1074,  159,  832,  187,  117,  983,   93,    1,  293,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  212, 1077,    1,  182,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  506,   30,    1, 1398,  612, 1198, 2398,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  764, 1658,  985,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  409,   25, 2035,  390,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3330,  176,    1,  193,   37,   52,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1994, 2834,    1, 2250,    1,    1, 1160,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2122,  387,  227, 1578,   32, 1645,    1,  741,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2663,    1, 1019, 1247, 2321,    1,  463,   63, 2378,  823,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  704,  361,    1,  579,  334, 1210,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2244,   32, 2103,  617,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1538,   45,  531,   12,    1, 1456,  565,    1,  460,  810,    9,\n",
      "          105,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  885,  198,  401,    9, 1095, 3000,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2713, 2488, 1634,   37,  195,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12,  810,    1,    1, 3289, 2437,  220,  105, 3077,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   49,    1, 1994, 1512,  469,  384, 2521,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1, 384, 510,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   4, 420,  34,  25,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  470,   45,  349, 1564, 2102, 2947,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  693,    1, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2844,   32,    1, 1686,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  222,  885,  301,  214,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,    1,    1,   32,  622,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105, 2693,   32,  166,  100,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  199,  421,   37,  138,   59,   37,  875,  755,  134,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739,    1,  159,   28,   98,  218,  714,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  540,   37,  540,    1, 2267, 1944,  384,  166,  103,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1396,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1390,    1, 2619,  297,    1, 1346,  187,  467, 1552,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437,   45, 1312,  476,  388,   69,  568,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 409,  25,  66, 816, 548, 682,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  37,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  780, 2781,  105, 1298,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  197,  418,    1,  225,   85,   98,    1,   29,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   21,  156,   93,   32,    1,    1,  195,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  225,  218,  578, 1894,   98,  348,  197,  420,    1,  389,  550,\n",
      "            1,   69,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,  333,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,    1, 1090,    9,    1,  966,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  488, 2673,  114,    9,  455,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3151, 2565,    1, 2424, 2017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  557,  540, 2386,  447,   45, 1939,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1, 2336,    1, 1643,    8,  361, 1628, 1693,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  281,  282,  283,  560,    1,  285,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2912, 1008,    1,  187,  929,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  487,  695,    1,   80,  293,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   28, 1765,    1,  176, 2882,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307,  897,  259,  218,  332,   32, 1488,  763,   76,  737,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   37,    1, 1772,  384,    1,    1,  440,  183, 1410,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1107,    1, 2405,   37,  691,    9, 2733,  776,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  105,  365,  454,   37,    1,   85, 1778, 2580,    1,\n",
      "            1, 2851,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3129, 2941,    1, 2398,   37, 1403, 3324,    1, 2545,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,  256, 1021, 1499,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1420,    1, 1401, 2235,   98,  807,  332,  752,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1005, 2942,  140,  581,  671, 3126,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3155, 1345,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3310,  398, 1574,    1,   12,  857, 1787,   37, 2971,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1861,  580, 1016,    1,  297,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2431,   37,    1,  166,    1, 2356,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2180,  210,   61,  105, 2566,   45,  453,  248,  270,    1,\n",
      "          420,  267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  612, 1273,  936, 1766, 1767,    1,  630,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  236,  237, 1086,  242,  528,   69,  636,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340,  361, 1110, 2624, 3209,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1259,   37,    1, 1149,    1,  176,  727,  613,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1938, 2607,  382, 1472,  507, 2440,  384, 2502,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1128, 1203,    1,    1, 1129,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777, 2165,  498,   37,   52,    1,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  342,  991,  215,   98, 1220, 1597,  191,  654,    1,  848,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,    1,  187,  247,  223,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2708,  890,    1, 2386, 1094,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3161,   12, 2087,  167,  726,  581, 3193,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  341,   29,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   34,  332,    1,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,   26,    1,    1,    1,    1, 3253, 1774,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2051, 2026,  126,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  700,  187, 1177, 2253,  109,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   26,  417,  657,    1,   69,   25,   85,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  179,    1,  180,    1,  170,  630,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  350,    1,  685, 2496,    1,  388,   76,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1809,  164, 1593,    1,    9,  166,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3113,  298, 2565, 2582, 1056,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1211,  111, 1084,  716, 1174,  906,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  166,   16,  220, 2494, 1567,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1432, 2279, 2040, 3151, 1756,  190,   52,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2153, 1248,  211,   32, 1147,  890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  199, 2175,    1,  202,    1,   12,   61, 1120,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,   98,  632,    1, 1358,   32,  493,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2909,    1,  104, 2262, 2856,   32, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363, 2040,    1,  191, 1585,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   91, 1484,   98, 1094,   37,    1, 2516,  674,    1, 2764,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  942,   32,    1,  182,    1, 1499,  170,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  482,  176, 1840,   37,  506,  142,  191,    1,   37,  335,\n",
      "           50,  457,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   28,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147, 3356, 3357,    1,  674,   45, 2646, 3346,    1, 2656,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  437, 1518,    1, 1007, 2542,  574,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  854, 2257,   39,  600,    1, 2924,  384, 1815,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175,    1,    1,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  245,   98,   69,    1, 1099, 1453,  927,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  756,  757, 2120,  929,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359,  140, 3339, 1463,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  433,  102, 1556,   32, 1352,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056,    1,  927,  503,   12,    1,   45,  453,  749,  195,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1158,  162,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  596, 2641,    1,  365,  414, 1015,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  225,  407, 1969,  586,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2056, 1011,    1, 1249,  837,  528,  677,  408,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,   20, 1413, 1414,   37,  588,  957,  460, 1495,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,  949,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1527, 2664,    1, 1658,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1147, 1190,  744,  365, 1757,    9, 2764, 3356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  794, 2355,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1082, 2707,   37,  168, 2025,    1,   98,  342,   46,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 2962, 3276, 2365,   37, 1194,   73,  726,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1568, 1220,    9, 1697,    1,   37, 1633,  786, 2771,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  229,  633,   37,  168, 1300,   98,  810,    1, 1916,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359, 1544,  700,   98,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3006, 1439,   98, 2095,  134,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1855,  446,  571,  754,   37, 2773,   12, 2714,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  166, 1397,    1, 1340,  140,  885,  331,    1, 1917,\n",
      "            1,  552,    1, 1624,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,  865,  187,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3051, 1557,    1,  957,  698, 2024,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1062,  458,    1,    1,   37,  138,  152,   37,  439,  927,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  947,   32, 2426,  220, 3344, 1178,  548,    1, 1333,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1842,    1, 3043,    9,    1,    1,  114,  420,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  215,  692,  734,  591,    9,  594,  497,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  107, 1542,  220,    1, 1208,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181,  325, 1159, 1412,    1,  769,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  150,  159,  720,  548,   72, 1843,   15, 1306,  570,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  460,   12,  920,  357, 1745,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  217, 1174,    1,   33,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3186, 1445, 1421,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2753, 1103,   32,  265,  496,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136, 2744,  293,   12,  449, 2693, 1942, 2389,    9,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1307,  459,  331,  132,  220,  976,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  732,    6,    1,  541,   37,  688, 1118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  447, 1268,    1,  290, 1159,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1663,  197,  418,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2221,  632,   69,  532,   51,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1452, 3322,  619, 1515,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1139, 1382,  176, 2826,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3122,    1,  150,   12,    1,    1, 1631,   85,  105,    7,    1,\n",
      "          539, 1798,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,  414,   45,  116,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213, 1566,    1, 1144,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1501,  498,   37,  138,   37,  875,    1,  767,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   32,  166,    1, 1010,  996,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  726,    1,    1,  267,    1,   12, 2565,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,  475, 1454, 2089,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1123,  892,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,  559,   79,  139,  471,   50,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2396,   98,  557,  540, 1512,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1583, 2577,    1,    1,   59,   24,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  169,    1,  702,   37, 2123,   32,  131,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,   51,  741,   98, 2650,  302, 1411, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  441,   37,  877, 2287,    9,    1,  297,  116,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548, 1167, 2784,    1,  590,  707,   81,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3052,  186,  444, 2095,    1,    1, 1530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1372,   37, 1083,  347,  187,    1,   15,  838,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2615,    1, 1293, 1762,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1533,  917,    1,    1,   37, 2564, 2179, 2457,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2646, 3006, 2562, 2074,   37,  946,  357, 1046,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  459,   45, 1204, 1315,    1,    1,  753,    9, 1965,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3181,  162, 1415,   37, 1545,    1,  166, 2601,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,   12, 2789, 2591,   37, 1154, 3339, 2271,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3035,  837, 1147,  861, 1414,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,   12, 2836,   45, 3107, 3366,  193, 1864,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614, 1758,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  938,    1,    1,   63, 1202,    1,   85,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  197,  167, 1306,  236, 1022,    1,  570,  191,  187,  445,  187,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  884,  105, 1150,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1,  361,  166,    1,    1, 1176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,  331,  354,   32,  572,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087, 1042, 2336,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773, 2510, 1090, 1863, 1564,  198,  455,  714,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2851,  754, 2581,   37,   52, 2812,   98,    1,  328, 1275,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,    1,  693,    1,  613,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,  531,    1,  176,  163,    1,  903,    1, 1564,  550,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273, 1182,  588,  242, 1620,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  708,  747,    9,  764,  840,  378,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2737,  966,  134,  729, 1734,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  273, 1609,  157,    1, 1944,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1822,  100,   37,    1, 2141,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1290,  396,   71, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 3212,    1,  928,   45,  985, 1260,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2018, 3109,    1, 1479, 2764, 3394,  722,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1467,    9,    1, 1804,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2523,   81,   32,  166, 2482,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,  971,  288,    9, 1798,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3375, 2844,   32, 3339, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296,   82,    1,   66,  123,   37,  119,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   12,  706, 1594,  114,   98,    1,  652,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,   12,  565, 2810,   37,   52, 2260,    1,    1,  191,  331,\n",
      "           12,    1, 3175,  489, 1452,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1447,  267, 3203,    1,  716,  105,  163,    1,   12,\n",
      "            1,  722,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  364, 1625,   37, 2250,  365,  542,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  294,  922, 2712,  191, 2838,   61, 2615, 2491, 2085,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310,   25,  582,  463,   98,  236,  237,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1931,    1,  600,  863,  932,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,    1,  891,  176,  754,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  342,    1,  213,   37, 1198, 3368,   98,  976,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  662,   37,  221,    4,   37,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2932, 1835,  705,  259, 1017,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,  958, 1233,  333,   37,  730, 1571,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2578, 2850,    9, 1056, 2847,  631,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  871,  642,  227,   57,   71,    1,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  162, 2623,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2747, 3363,   12, 1708,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3339,  469,   51, 1403, 2708,  171, 3359, 2431,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428,  864,  765, 1750, 2673, 1069,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2571, 2153,  907,   37, 2000,  557,  540, 1512,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1818,  147, 1293,    1,   12,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  147,  167,  771,   39,   45,  171, 1393,   37, 2014, 1159, 2388,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2948,    1, 1008, 1965,    1, 2666,   45,  166,  356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3113, 1877,   37,  856,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  631, 3116, 2579,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1333, 2471,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3186,    1,  730, 2614,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,  241,  698,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  709,    1, 2565,    1,  928,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  700, 1707,    1,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,   45, 1964,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1117,    1,    1,  749,  122,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  882, 2182,  798,   37, 2084,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3123, 2540,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2817, 2856,   32,  395,    1,  590, 1584,   28,   32, 1881,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2868, 1562,  284,  219, 2860,   98,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353, 1253,   32,  581,  401,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,  852, 1425,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1549,    1,  973, 2333, 2527, 1750,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1340,    1, 3330,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  868,   85,    1,   45,    1,  100,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   15,   45,    1, 1219,  720,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596, 1151,   15,   93,    1,   32,  871,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1459, 2237,   37, 2468, 2070, 2282, 2795,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  804,  681, 1822,    1,  809,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2800,    1, 1231,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2190, 2640,    6, 1011,    1,    1, 1489, 1104,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  558, 1518,   32,   98,  132,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1486,  140,    1,  131,    5,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3213, 1408,   28,  730,    1, 1450,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1701,   84,   28,  856,  444,  111, 2086, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1566,  149,  297, 1156,  494,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,  664,    1,    9,  914,  220, 1987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1965, 2948,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  430,  936,  529,  636,    6,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,  520,    1,  647,   43,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1033,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2049,    1,    6,  197,  157,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  934,   30,  112,  175,   45, 1222,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3358,   79,   37, 2197,    1, 1811,  404, 2000,  365,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,  942,  739,  572, 1455,  174,   45,  331,    1,   28,  384,\n",
      "          331,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2768,  917, 1265,  191, 1936, 2177,  260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3142,    1, 3331,    9,  726,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1388,   45,  166,  275, 2807,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3260,  276, 1144,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3016, 1935, 2294,  443, 1552,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  440, 2001,  994,    1,  150,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1454,  453,    1,  559,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  786, 1530,    1,  176,  177, 2347,   32, 2522,   45, 2137,   32,\n",
      "         2755, 2490,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   80,  162,  105,   92,  384,  166,   75,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018, 1585, 2162, 1950,  418,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178,  386,  214,   46,  271,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   16, 1698,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1,    1,  220,  657, 1151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  183,  156,   37,  184,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3238, 2175,   37,  727,  220, 1009,   10,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1043, 1276,  185,    1, 1448, 1091,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,    1,  166, 2527,  164, 2693,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 1298,  633,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  640,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2007,    9, 3343,   32, 1887,   45, 3073,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  410,    1,    9,    1,  314,  475,   12, 2022,    1,  220,  591,\n",
      "            1, 1057,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  227,    1,    1,  357,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  236, 1022,    1,   66,  410,  773,  343,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861,  439, 2264,  565, 1658,  449,  260,   45,  750,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  571,   37,  166, 1551,  220,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  837,  307,  837,   98, 1925, 1583,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2737,   12, 2742,  599,  548,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   51,    1,    1,  261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  386,    1,  104,  358, 1809, 1647,   98, 1384, 1251,    6,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  615, 2047,  590, 2324,    9,  500,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   12,    1,  808,   32, 1033,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1123,  542, 1075,    9, 3048, 2923,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  886,   37, 1289,    1,    1,   37, 1411,    1,  769,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1360,  612,  123,    1,    1,  250,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  870,  326,   37,  218, 3014, 1718, 2079,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777, 2165,    1,   10,    1, 2275,  220,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1156,    9,  851,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2388, 1993, 2307,   32, 2069,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2235,   19, 1158,  124,   37,  877,  219,  714,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 1492,    1, 3149,  590, 1400,  952,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  449,  197,  452,    9,  780, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1840, 1595,  600, 2174,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  224, 1137,    1,    1,    1,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1795,  361,  166,  627,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 2227, 3135,   32,  968,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 3235, 3212,    1,    1, 1530,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  801,   37,  163,    1,   12,    1,   26, 3295,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  359, 1003,   37, 2155, 1821, 3027,   32,   22,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1667,    1,    1,  967,    1,   37,    1,  176,  915,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,   51, 1719,   27, 2113,  504,    1, 2248,  888,    9, 1861,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1662,    1, 1003,    9, 1821,    1,  361, 2428,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1745, 2017,  384,  166,  756,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1017,  327, 1828,   71,  419,  481,   32, 1913,  401,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,  726,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1019,    1,    1, 1976,   32, 1739,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1, 1408,    1,    9,    1, 2793,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1485,  379, 1248,  949,   45, 3365,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  267, 2102, 1107,  525,  920, 2352, 2464,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  647, 2120,   82, 1010,  148, 1523,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968,  140, 1427,  442, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  615,   37,  817,   47,   79,    1,  156,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  491,    1, 1346,  384, 1622, 2299,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3303,  546,   37,  120, 1159,  631,  176,    1,  294, 1456,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826,    1, 1642,   28,    1, 2107,   98, 3024,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2115,  218,  580,   28,   37,  257,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3299,  361,    1, 3260,   37,  726,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2939,  967,    1, 3265, 1323, 2353,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  761,   37,  138,   59,   37,  875,    1,  396,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018,  872,   37, 2237,    1,   12,    1,    1, 1075,    1, 1117,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1588,  726,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2374, 1008, 2104,   37,  927,   10, 2681,  724,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,    1,    1,    9, 3112,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2135, 1663, 1554,  531,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2774,    1, 2414,   32, 1537, 1815,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  164,  165,    1, 2317,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  204,   12,  176,  754,  220, 2218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  367,   30,  105,    1,   32,  495,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1303,    1,    1, 1437,   24,  191,    1, 1273,  369,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  358, 1008,    1, 1009,   45,  283,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  854,    1, 2018,  565,   98,  114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3102,   53,   37, 2051,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1527,    1,    1, 1560,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,    1, 1691, 2298,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  865,   45,    1,   34,    1, 3130,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3399, 2237,  903,    1,  464, 1585,  778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   13,    1,    1,   98, 1675, 2842,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2591,   37,    1, 1351,   37,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,   98,    1,   45,  593, 2522, 1684,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   94,  176,  241,  845,  187,   89,    1, 1625,   45,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  716, 1523,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   22,  438,    1,   35,   77,  662, 2494, 2793,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1, 1412,  844, 1151,  934,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3348,    1,   79,   37, 2597,   32,  142,   37, 1211,  487, 3102,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2774, 2696, 1707, 3363,  693,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,  173,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3051, 1527, 1149,  820,  191, 2751,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  721, 1098,    1,  648,   12, 2667,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2591,    9,  365, 1009,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  951,    1,  105,  551,  331,  191,  166, 2033,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   37, 1816,    1,  932, 2675,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,    1, 1505,  955,  662,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3327, 1360,  612,  865,   37, 3239,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  119, 1844,  515,  294,    1,    1,    1,  671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1243,   98,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788,  361, 1130,    1, 1077,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  199,    1, 2094,  673,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  324,  958,   32,   46,  220, 1479,  460,  669,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,    1,    1,    1,  733,   98, 1095,    9,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3374, 3006, 2856, 3101, 3160,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3306, 1414, 3181,   98,   37,   81, 2380,  220, 1377,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 2161,   12, 3096,  680, 1249, 2468,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  397,    1,  909,  444,  104,    9, 1994,    1,  625,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   15,  686,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  241, 1157,    1, 2414,  176,  177,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 113, 147,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1, 220, 105, 688,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1194,    1, 2907, 2471, 2522,    9, 3209,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   37,  125,   28,   37,    1,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  978, 2820,  256,    1, 2665,   37,    1, 2549,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   61,    1, 1997,    1,  320, 2056,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1445, 1421,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2005, 1045,   37,   56,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1583,    1, 2414, 2729, 2548, 2100, 3339, 2835,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  991,  454,    9,  138,    6,  176,  104,  358,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  519,  664,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2037, 1443,  105,    1,  873,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2779,  921, 3064,   32,    1, 1787,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3239,    1,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1256,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  293, 1236, 2733,   32,  691,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1017, 1167,   51,    1, 1656, 2421,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,  582,   37, 2197,   37,  927, 3358,   12, 2162,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 2036, 2963,  691,   32,  449,  786,   74,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176, 1428,    1,   10,  729,  782,  247,  531,  469, 2177,   37,\n",
      "           47,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1009, 1564,  449, 2784,   37,  404,  108,  444,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,    1, 2962,   28, 1953,  220, 1877,   37,  846,  977,    9,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    9,    1,    1,    1, 1564,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1971, 1542,   37, 1376,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  726,  297, 2748, 1710,   52,  183,    9, 2486,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2222,    1,  105,  454,   37,  224, 1658, 2177, 1027,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2298,    1,  176, 2464,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2377,   45, 1530,  487, 2548,    1,   39,  176, 1861,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  547,  388, 2496, 1976,   32,  531,   12,    1, 3383,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  297,  949,   45, 1527, 1149,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  183, 2489, 2192, 3183, 1285,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1396,    1,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2838,    1, 2017,  726,  297, 3132,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2104,  313,   37,    1, 2017,    1,    1, 2298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2604, 2923,   61,  105,  311,  199,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,   91,   37,  125,    1,    4,  191,  166,  439,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2658,    1,    1, 2742,   45,  492, 2736,    1,  928,  176,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,    1,    1,   45, 1227,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,  315,  658,  336,    9,  660,    1, 2581,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,  267,  163,    1,   12,    1,  663,  625, 1564,\n",
      "           46,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 716, 119,  72, 401,  15,  88,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 303,   1,   9,  60, 190,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  709,  638,    1,  598,   37, 1348,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1358,   98,  993,  302,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2504,  446,    1,    1, 2705,   98,  844,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  213,   37,   52,   53,    9,  152,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2614, 1698,   45,  753,    1, 2522,  571,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1940,   45, 3386,  254,  415, 1969, 2921,    1,    1,  267,  667,\n",
      "            1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3128,  267,  163,    1,   12,    1,  580, 1463,   45,    1,   32,\n",
      "          531,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311, 2936,  688, 3312,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  136,  765,   37, 1664, 2650,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305, 1285,   28,   98, 2127,   31,   29,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,  224,  225,  109,   32,  488,  186,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,  184, 1107,  218,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 2509,    1, 2614,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1109,    1, 1579,  372,   94,    1, 2187,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  130,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835,  719,   37, 1706,  228,  131, 1714,  105,  356,  388,  446,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  359, 2905,  465,   22,    1,   45, 1821, 3027,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  166,  439,    1,    1,  750,   61,   28,   37,  166, 1463,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   68,  338,   98, 1625,    9,  679,   69,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 1428, 2108,    1, 2682,   10,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1943,  786,  936,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,   85,    1,  786,   37,  168,    9, 2614,   32,    1, 1312,\n",
      "         1844, 1194,  696,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  365, 1729,   51,    1, 2711,  566,  384,  166, 2041,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2498, 1567,  919, 3250,  297, 1497,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2816,  548,    1, 1665,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425,  566, 1273,  259,  218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  354,  195,    1,   32,  356,  506,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384,    1,   37,    1,    1, 2759, 2718, 1348, 1607, 1314,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  735,  681,  288,    9,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3113, 1564, 2509,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  810,  297,  166, 2655,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3333,    1,    1,    1, 2545,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  199,  472,   39,    9,  531, 3365,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  915,    1,    1, 1550, 3296,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  477,  515, 3262, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 3159,  730, 2614,    1,  786,  726,  384, 2872,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   76,  892,   37,  288,   28,  544,  193, 1140,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2197,    1,   37,  726, 2826,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2942, 2908,  548,    1, 2263,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  217,  808,  343,   32, 1047,  287,   87,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3051, 3118, 2751, 2684,    9, 2024,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  275, 1463, 2994, 2995,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3344,  437,    1,  632,   36,    1,   46,  698,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1787, 3192,  721,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  773,    1,  845,   98,  821, 1402,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 1411,  756,  949,    9,  357,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  696, 3244,    1, 3227,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  162,  105, 1694,   98,    1, 1406,    1, 2063,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1034,    1,   12, 2495,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096, 1292, 3066,  645, 2693,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2045, 3034, 2264, 1371,    1,   37,   33, 1117, 1525, 1704,  157,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1163,    1,  105, 2463, 2382,  361,    1,    1, 1593,  361,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1934, 1949,   46,  220, 2751,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1831, 1550,  439,   45,  971, 1832,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  605,  287,    1,    1,  156,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1444,  565,    1, 1492,  817,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2414, 1056,   32, 2597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 2153,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  751,    1, 3335,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1174, 2208,   32, 1422,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 2275,    1,   37,  726,  443,   98, 2095,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98, 2283,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3231,  608, 3232,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885,  496,  267, 2993,   28,    1, 2997,   85,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2999,   91, 1321,  453, 2819, 1345, 3050,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178,  514,   32, 2162,   45,    1,   12, 2068,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1073,    1,  250,    1,  221,  226,   37, 2839,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,    1,   45,  430,  477, 2007,   37,  439, 2283,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  256, 2516,    1,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3298, 1114,  782, 1918,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1479,    1,   61,  105,    1,   37,  166, 1331,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676,    1, 1231,  297,    1, 1463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  379,  774, 2288,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1531, 2127,    1, 2571, 1223,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  321,    1, 1154,  593,   12,  553,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3189,  967,  183, 1090,    1,  202,  750,    1,   32,   37,  688,\n",
      "         3247,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,   98,    1,   45,  996,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3227,    1,  730,    1,  928,  176,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  870,  148,  197,  418,   98, 1228, 1220,   32,  572,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  636,  423,  967, 2582,  792,  905,  792,  805,   98,  395,\n",
      "           12,  954,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,    1, 2638,    1, 2827,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2490, 1679, 3105,    1,   32, 1313,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2355, 1013, 2549, 1680,  166,    1,    1,  267,  829,  918,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1699,    9,    1,    1,    1,    1,   61,  105,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  733,  331,   48,   32, 1050,  535,  437,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2780, 1642,  187,    1, 1866,  384,    1, 1030,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  188,  187,  889,  529,   25,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1498,  804,   32,    1,   45, 1076,  671,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1693, 3192, 2308,    1,   95,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1704,  105,    1,  778,    1, 2468,    1,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,   32, 2107,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1,    1,  187, 2292,    1,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,    9, 1011,  166, 2804,   45,  810,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,  113, 2764, 2765, 2985,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361,  566,  754, 2264,  220, 1361, 2724,  328,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1471,   37,  125, 1429,    1,    1,  721,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3182,   37,  698, 1247,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  312,    1,    1,  357,    1,    1, 1366, 1445,  487,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2909,  686, 3111,    1,  531,  844,  756,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1754,  199,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2779,    1, 3169, 2139,  202,  726,  176,  455,   26,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2482,  361,  105,    1,    1,  744,  813,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3204, 1249, 3169,   37,  759,    1, 3329, 1990, 3295,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   99,  387,  346,   31,  383, 1315, 1056,  419,   32,  581,  401,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2022,  806,    1, 1530, 1245,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  522,  444, 3136, 1353,  285,   32, 2160,   45,    1,   32,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  104,  560, 1274,  245,  915, 1034,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  105,    1,  458,   12,  625,  149,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,   25,   28,  699,  548,  479,  570,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 2612,  442, 2471,  220,  463,  507,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3226,    1, 3240,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,   28,  301, 1013,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,  131,  486,  802,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1007,  945,  551,    1,    1,   37,   26,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  448,  703,   37,    1,  131,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2211,    1,  197,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  183, 1831,   61,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2057, 1670, 1300,  615,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1509,  151,  737,  197,  407,  419,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  251,  192, 1085,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  352,  267,  147, 1579,  286,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  242,   98,  996,   29,    1,  156,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 335, 105,  84,  81,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 758, 258, 162, 454,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  978,  769,  439,  417,  548,   69,  418,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186, 3067,    1,    1, 3302, 1484,    9,  927,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3115,    1, 2551,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 3220,    1, 1188,    1, 1140,   32, 3209,  951,    1, 3260,\n",
      "         2522,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  661,   98,   26, 1039, 3031,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   74,    9,  671, 1078,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2856,  547, 3343, 2548,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  376,  327,  102,   32,  395,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3324,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  662,  772,  307,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1957, 2856, 3101, 1763,    1, 3375, 2844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1142,  275,  321,  674, 2189,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  422,  852, 1159,  896,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1883,   37,  151, 1117, 1525,  669,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   60,  338,  548,   65,   67,  423,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,  286, 2054,  242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,  593,   61,  388, 2342,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2954,  498,  132,   37, 1154, 1938, 3197,    9, 3243,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2523,    1, 2876,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2388,   12, 3188, 1401,  191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  326, 1249,  308,    1,  105, 1894, 1421,    9,  293, 1160,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3178,  980, 1159,    1, 2033,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1721, 1937,  562,    1,    9,   81,   37,   36,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12,  629,   45, 2177, 2585,    9,  954, 2126,    1,  104,\n",
      "          267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1123,  730, 2614, 1334, 2793,  220,    1, 1194,    1,  726,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  262,  263,  353,  354,    1,  225,   79,  419,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3172, 1090, 1829, 3089,  176,  584,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,   37, 1046,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1492,  108,   45, 2252,    1,  297, 2527,  164, 2693,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  352,   51, 2346,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  848,   37,  138,    1,    9,  849, 1662, 2641,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1521,  267, 1708,  583,  572,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  474,  738,  220, 2878,  590, 1647,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2871,    1,  267, 2289,    1,    1, 3310,  792,  590,  792,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  315,  248,    1,   45,  691, 2522,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3236,  442,  683,   37, 3319,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  150, 1353, 1140,  656, 1876, 3004,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1458,  171,  539, 1033, 2389,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1258,   37, 1330,   55,  166, 2561,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1408,    1,   98,  166, 1844,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  903,    1, 1417,    1,  171,    1,  365, 1546,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422, 1566,  134,  444,    1,   50,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  744,    1, 1224,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2246, 3244,    1,    1, 1240, 1188, 1857,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  225,    1,  193,    1,  105,  227, 1421,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3084,   37,   81,  342,    1,  315,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,  660,  102,    1,  191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2591,   37,    1, 1351,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  938, 2032, 2225, 1463,  175,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1285, 3110,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,  952,   37, 2935,  647,  220, 2025,   54,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192, 2018, 1285,   39,  854,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  215,   12,  935,   37, 1539, 1821, 2057,   32,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537,    1,   32,    1, 3128,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,  200,    1, 2969, 1766, 1767, 1151,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2794,    9, 1488,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  386, 1831, 1301, 3177,  714,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,    9, 2473,    1,    1, 1128,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  140,  119, 1194,    1, 1090,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,   44,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  494,  469,  388,  495,  496,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1185,  649,    1,    1, 1215,  187,  445,  187, 1515, 2698,   98,\n",
      "            1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   26, 3204,  640, 1505,    1,    1,    9, 2779,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  102,   98,  166,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   37,   47, 1772,  111,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,    1,  623,   37,  439, 1651, 1597,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1364, 1365, 1285,  115,  444, 2018,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  496,  166, 2970,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1417,    1,  890,  721,  908, 1354,  932,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  447, 1625,  531, 3365,  190,   52, 1683, 1371,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2159,    1,  231,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,    1, 1273, 1151,  102,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159,   28,  548,    1,  296,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  698,    9, 3142,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  927,  321,  612,  804,   39,  864, 3032, 2596,  469,    1, 1428,\n",
      "         1063,  267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  190, 1463, 1973,   12,  750,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092,  476,    1, 1530,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,  936,  737, 2786, 2976,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1, 1262,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,  705, 1458, 1421,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3001,    1,   32,    1, 2388,  105, 1057,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  702,   37,  151,  169,   32,  182,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  526,    1,  642, 1278, 1308,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2841, 2677,    1,    1,    1,  951,    1,    1,    1,    1,    9,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  166,  116,  719, 1018, 1901,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  254,  723,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 1228, 1213, 1231,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  982,   37,  130,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,  927, 2211,    9, 1530, 2060,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  636,   45,  679,   69,   32,  171,  490,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 2095,  190, 2253, 2846,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,  330,   37,  151, 1183, 2320,    1, 3055, 3162,  420,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1,    1,    9,  923,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1100,  891, 1828,   45,    1, 1273,  769,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1,    1,  331,   12,  498,   98,   56,  356,  132,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2518,  361, 1001,    1, 1841,   32,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1009,    1,  267,  903,    1, 1447, 1360,  612,  168,\n",
      "           37,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2246,    9, 1602,    1, 1332,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1287,  951,   94,  548,   29,  682,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1090,    1,    1,    1, 1031,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2217, 1579,    1,    1,  776,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  420, 3101,    1, 1268,  114,   98, 2729, 2924,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2068,    1,    1,  548,  245,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,   74,    9,    1,  176,    1,    1, 1503,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885,   96, 1548,   32,  247,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3141, 1974,    1,    9,  786, 1090, 1969,  514, 1727,   98, 2887,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3349, 2162, 1950,   32, 2817,  431,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3172, 1090, 1829, 3166,  176,  539, 1037,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  662,  220,  842,   61, 2534,   12,    1,    9, 2244,  700,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  238,  361,    1,   98, 1965,    1,  187,  921,   32,  191, 2948,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   82, 2742,    1,    1,   81,  176,  166,    1, 3000,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 709,   1, 513, 193, 514,  37, 365, 134,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1352, 1290,   67,  113,  816,  176,    1, 1146, 1703,    1,  267,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  458,    1,  170,   98, 1171,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1807, 2240,    1,  359, 1373,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  261, 1056, 1228,  681,  193,    1,    9,  912,  332,  396,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   69, 1086,  530,   98,  430,  997,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,  600,    1,   45,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2752,    1,    9, 2774, 2782,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  912,    1, 1994, 2086,  700, 1353,   32,   91,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  803, 3228,    1,    1,  220, 2777,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2883,    1,    1, 1054,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  107,    1,   37,    1,  218,  187,   69,  102,    1,  365,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343,  741, 2116, 2222, 1086,  220, 3363,  105,    1,  855,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2867,   98, 2439,    1,  202,  864,   37,  774,    1,  460,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  511,  275,    1, 2388,    1,    1,    1,   79,    1,   32,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2433,  455,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3300,    1,    1,  384, 2347, 1638,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2950, 2414,    1,    1,  155,  997,   45,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2599,  565,    1,  763,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 990, 476,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 942,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2059,   12,  589,   98,  132,    1, 2266,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203, 2725,   97,    1,    1,  985, 1450,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  691,   12, 1384, 2789,  580,    1, 1523,   32,  863, 1708,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1966,    8,  420,   98, 1899,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   85,  593,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2682, 2617,    1,    1, 1492, 2192,    1,   37,    1, 2476,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1614,  453,  777,  279, 1117, 1525,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1405, 1916,   37,  665, 2500,  580,   98,  287,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2597,  686,  191, 2006, 2596, 2137,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  191,    1, 1652,   12,   17,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3062,  671,   32,  166,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3112,    1, 1973, 1665,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1962,  108,   45,    1, 1080,  384, 1273,  259,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1369,    1,   85,  265,   45,    1, 1074,  191,    1,  131,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2425,   37,  151, 1883, 1228,   32,  132, 1960,    1,  131,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171,  488,   37,  489,  112,  384,  458,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  506, 2780,    1,   39,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 2132, 3190,    1,  316,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1228,  624,    1,  647, 2369,  326, 2471,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564,  424,  105,  388,    1, 2107,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  174,  526,    1, 1315,  570,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  880,   95,   37,  451, 1564, 2218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3168,  719,   37,  688, 3173,    1,    1,  632,   37, 1838,  590,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,  744,    1,    1,    1,  104, 2422,   45, 2523,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 2826,  565, 2093,  920, 2890,  986,    9,  105,    1, 2789,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1257, 1862,   98,    1, 1904,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1464,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3395, 2496, 1976,   27, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  395, 2000, 1789,  176, 1319, 2396,  395,    1,  220,\n",
      "         1578,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,    1,   32, 3343,  890,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   26,    1,    1, 1568,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321,  166, 1973,  489,  166,    1, 2963,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  700,  267,  453, 1538, 2827,   32,  531, 1683,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181, 1908,  176,  754,  220,  902, 3187,    1, 3328,  726,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1046,  134,   32,  854,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111, 1697, 2165,  317,  244,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,   22,  868,  837, 3356,  787,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384,    1, 1495,   37,    1, 1343,    1,    1,   12, 3322,  565,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  593,  458, 1301,    1, 1511,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  214,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2514,  785,  786,   32,    1,  187,  479, 2257,   39,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321,    1,    1,   37,   77, 1658,  725,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2862,    1, 2587,    1,  187, 1018,    1,   45,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  267,    1,    1,    1,  384, 2978,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1790,  353, 1520,   71,   32,  197,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  215,  947, 1768, 1294,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   49, 2726,   69,    1,  480,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203,    1,    1,  166,  985,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2068,   45,    1, 3102,  146,    9,  247,  949,  446,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510,    1,    1,   45,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  420, 2977,  894,  576, 2978,   37, 2324, 3015,    1,  193, 2873,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  137, 1046,  365, 1017, 2276,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  190,  193, 1636,   32,    1,    1, 1744,    4,  901,  191,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2104,  267, 2150,    1,  638,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  843,  973,    9, 2748,   32, 2712,   45, 1037,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1010, 2357,    1, 2114,  292,    1, 1212,  650, 1310,   37,    1,\n",
      "         1833,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2623,    1,   37,    1,    1,    1,    1,    1,    1, 1090,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358, 1921,   32,  447,    9, 2611,  351,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  511,  275,    1,    1, 1022,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  588,    1,   32,    1,    1,  336,  298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  348,  908,  372,    1,    1, 1500,  158,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,    1, 1141,  680,    1, 1260, 1114,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  503,  197,  338,    1,  583,  191,  749,  480,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  751,   37, 2822,  651,  420,  105, 1595, 1918,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,  247,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 2167,   98, 1472,  284,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2848, 1513,  680,   97,   32, 2315, 1027,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,   12,  129,  223, 1108,  162, 1001,    1,  132,  384,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  978,    1, 1766, 1767,    1,  259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  866,   32, 3201,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  614,   37,  776,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  833,  612, 1210,   37,  335,  460,  242,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  449, 2214, 1696,  548,    1,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,  715, 3329,  547, 1477, 1990, 2308, 1306,  125,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 314, 898,  27, 399,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 422, 980, 261,  98,   1, 721, 482,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1363,    1,  103,    1,  187,  460, 1830,    9, 2051,    1, 1015,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,    1, 3169, 2872, 1159,   26, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3194, 3195,    1,  316,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  331,   12, 2055,  332,  752,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  316,  400, 2740,  190, 3172,  100,   98,    1, 1411,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,  837, 2592,  671,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  353,  417,  197,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708,  947, 1013,    9, 1072, 1235,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307,  256,    1, 2215,  361, 1112,  176,  388,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1634, 2673,  218, 3385,  952,    1,  764,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1,  361,  166,    1,    1, 1176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1353, 3019,  260,  220,  365,  660,  331, 1151,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2873,  627,    1,   98, 1228,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,  251,  365, 1294,  861, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1861,  859,    1, 1511,   32,   72, 2113,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   28,  388,  763,  249,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2150,  338,   32,  537,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,  453, 2168,   81,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2637,   12, 1005,    1,    1, 3304,   32,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1,    1,  921,    1,  275,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2238,  190,  109,    1, 1151,    9,  365, 2979,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3237,    1,  273, 3055,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   60, 1044, 1045, 1258,  187,   94,  640,  365, 1653,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1369,  716,    1,  131,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  331,  197,  307,  236,  237,  308,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2673, 2375,  321, 1444,   52,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  447,   12, 2512,   37, 1706,   59, 1714,   32,  463, 1447,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  793,    1,   33,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1236,  829,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2165,  786, 2446,  834,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977, 3054,  313,    9,  846,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1183,    1,    1, 3361,  877, 1354,   45,  916,   37,    1,   98,\n",
      "          943,  538,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2944,  140,  671,   32, 1674,  238,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1235,  102,  720,    1,  442,  910, 1052,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3206,  688,  114,   32,   26, 2069,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993, 1566, 2355, 1013, 1416,    9, 2994,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  455, 1794,    1,  548, 2919,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,    1,  384,  166,    1,    1,  224,  952,   37,   26,  166,\n",
      "         2641,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1580, 1148,  388,    1,  619,  111,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,    1,    1,  210,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  232,    1,  350,    1,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,  952,  865,   45,    1,   32,  531, 1010,    1, 1665,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  978,  769, 1826,  187,   69, 1408,  677,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    8, 2432,    9, 2786, 2987,    1, 2762,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147, 2700,   37,    1,  443,   98, 2150,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  182,  704,   12, 2410, 2082,   61,  193, 1018, 2613,  786,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  389, 1013, 1522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  491,   37,   92, 1429,   37, 1504, 2249,   69, 1356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3161,  850,   39,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2948, 2223, 2864, 3001,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158,   12,  365, 2452, 1465,   61,  810, 1616,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1802,  535, 2386,  395,   45,    1,   32,  890,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1971,    1, 3285, 2434,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  410,  187,   69, 1276,  384,  119,  845,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2376,    1,   37,   52, 2758,   32, 1352,    1, 1861,  361,   10,\n",
      "           32,  166,  472,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   28,  187,  510,  488,   69, 2432,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2708, 2572,  187, 3101, 1583,    1,   32, 1850, 3339,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1005, 3215, 2810,    9, 2741, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,   45, 2646,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  846,    1, 3119,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1585,   32,    1,  218, 2414,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1204,  357, 2162,    1,    8,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,  765,   37,  737, 2432,  949, 2462,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973,  446,  267,  916,    9, 1850, 1423, 2024, 1176,  227,   37,\n",
      "         1306,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  100,   46,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1802, 2193, 2746,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  853,  538,   98, 1273,  618,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112, 1228,  681, 2346,  388,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 1874,  439,   45, 2646, 2426,    1, 1562, 3140,   12,  808,\n",
      "           32,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1548,   37,  480,    1,    1,    1,  712, 1680,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  617,  618, 1427,  187, 1084,  931,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1270,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  743,   12,   82,    1,  548,  365, 1857,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2142,  300,  105, 1263,   45,  753,  220,    1, 2825,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  453,    1,   48,  444,    1,  160,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 2635, 3257,  338,   37,    1,   32, 2936,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3124, 1518,   32,   98,  590,    1,    1,   32, 2788,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035,  476,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1, 3077,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  147,   37,  817,  912, 2285,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3176,  686,  191,    1,   32, 1698,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2474,    1,   37,  764,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  615,    1,  575,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,   12,    1, 2331,   32,  647,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  658,  763,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  386,   95,  473, 2253,  477,  297,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1986,  384, 3025,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1604, 1600,   98,  302,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,    9, 1460,    1,  890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,  437,  213,   32,    1,   37,  151,  849,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  902, 2365,  608,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,    1, 2619,   98,   37,  688,  105,    1, 2056, 2498,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746,   37,  125, 1711,   45,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  247, 1557,   37,    1,  484,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 2306,  220,  440, 3169,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2590,  187,    1, 2909,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  197,    1,  387, 2298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,  240,    1, 2427,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  459,   45,    1,    1,  187,    1, 2531, 1726,  907,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1808,   37,  693, 1821,  541, 1452,    1,    1,   45,    1,  176,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  617,  618, 1427,  187, 1084,  931,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  475,    1,  796,  590,    1, 2562,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2047, 2580, 3049,  190, 1389,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  729,  387, 1837,    1,   15,   28,  419,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,    1,  453, 1099, 1453,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  775, 1191,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  519,    1, 2672,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614, 2784, 3079,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   94, 2060,   93, 1258,   37,    1,   32,  572,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1258, 1607, 2731,  220,  365,  465, 2293, 1656,  653,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3198,  361,    1, 1647,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   91,   12, 1637,  826, 1898, 2821,  361,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808, 1273,  256,  388,   17,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3380, 2126, 1009,    1, 1583,  475,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458, 1713,  872, 1345, 1178, 1179,  214,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1663,  531, 1929,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3378,  776, 2361,  548,  339, 1183,  271,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  691,  108,   45, 1610, 1081, 1606, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,    1, 1421,   28,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  391, 1329,   37,    1,  105,  974,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2572,   32,    1, 1260,   32, 2597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1046,   79,   32,    1, 1090,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1477, 1990,    1,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1937,  590,    1,   45,   12,   69,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  459,  104,    1,  182, 1960,   45, 1495,    9,  296, 1497,\n",
      "            1,  715,  643,  963, 2122,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  957,  782, 1142,   32,    1,  636, 1336,  927,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,  197,  452,  170,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  886,  159, 1150,   98,  132,    9, 1151,  700,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2960, 2668, 1619, 2597,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387,  197,    1,   98,  800,  117,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3344,    1,    1, 2827,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1668,  105, 1292,  418,    1,    1,   32,  942,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3250,    1,  191,    1,   12,  824,  686,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  766,    1,    1, 1183,  472,  468,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   61, 1018,  116,  259,  917,    9,  334,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  617,  618,  167,   77, 3032,  199,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3260,  186,  608,  166, 1110,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2783, 1133,  395,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3101,    1,  446,   32,  463, 2170,    9, 1689, 2237,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1147,  232,   12,   32,  625, 3047,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1408,  340, 2395,  187,  702,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  346,  954, 1408, 1239,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2507,   95,  190,  335,   79,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  705,    1, 2317,    9,  786,  339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,  636,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2405,  754,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  297,  647,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1468,    1,  267,  204, 1360,  612,  865,   37,  210,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1875, 1243,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  220, 2685,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  590, 1377,  444,    1,  228,  427, 1281,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   72,  401,  354, 1470,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2528,  191,    1,    1,    1,    1,  961, 1215,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2394,   26, 1039,    1,    1,  949, 2255,    1,  730, 1777,   90,\n",
      "         1361,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2722, 3074,   37,  142,    9,  478, 2826,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2472,  650,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  220,    1,   81,    1, 2563, 1083,  689,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  354,  703,   59,   17,   66,  191,  356,   12,  439,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1019,    1,  167,   52, 2500,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  971,   91,    1,    1,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1412,  538,   15,  331,  191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  397,  884,   28,    1,    1, 1816,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2803, 3288,    9, 3182,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  503,   12,  721, 1342, 2104,   37,    1,    1,   45,  749,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2474,  259,  218, 1239,  388,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   69,    4,  380, 2184,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  684,  734,  102,  670,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,    1, 2789, 1822,    1,   37, 2319, 1215,  535,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1450,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  273,  463, 3210,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  818,  570,  111,   15,   37, 1192,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1870,  392,  354,   32,   72,  401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,  403,  464, 2960,    1,  193, 2673,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98, 1009,   12,  595,   37, 2192,   28,  622,  317,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100, 2373,  365, 1273,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147,  358, 2598, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3167, 1214,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1155, 1522, 1097,    1, 1656,  250,   32,  854,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,  877,  449, 2193,  698,    9, 3248,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  147, 1523,  297,  891,  297,  311, 1914,   45, 1340, 1194,  754,\n",
      "         1844,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826, 3204,   12, 1675, 2494,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1018,    1,  818,  712,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  879, 1965, 2550, 2699,    9,  885, 1700,  257,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  872,  187, 1366, 1847,  460,   61, 2218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  321,    1,    1, 1340,   37,  316,    1,  963, 2122,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  242,   32,  310,  605,   98,  477, 1665,   32,  430,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783,  884,  572,  354,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  457,  573,  681, 1000, 1033,  105, 2250,    1,  220,  762,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   12, 1043, 1738, 1993,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1627, 2355, 1013,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,   42,    1,   43,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  215, 1533,  917, 2789,  650, 1061,   98,   44,   45,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56,  441,  469, 1437,   32, 1037,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,  908,    1,   37,   92,  111, 1943,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296,   37, 1539,  105,   37,  413,   20, 1117,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2453,    1,  872,   37,  221,   37,    1,    9,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2547,    1, 2171, 1046,   79,  297, 1766, 1767,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   39,   98, 2498,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2889,    1, 2789, 1484,    9, 2024,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3342,  213,   37,  138, 1368,    9, 2059,   32,   12,    1, 2170,\n",
      "          420,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3387,  571,  220,  228, 2909,   32, 2936,    1,  590, 3307,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2700,    1, 2378,    1, 2325,   32,  166, 2822,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2811,   39,  443,    1,    1,    1,  166, 1388,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  224, 2567,   37,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3345, 2833,    1,    1, 3361,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  137,  672,  197,  308,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545,  929, 1458, 3213,  297,    1, 1559,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  314,  391,    1,   37, 1540, 1010,  927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1264, 2539,    9,  931,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  315, 1389,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2804,   45,  810,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  787,    1, 2572, 3102, 3025,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  104,   60,    1,   85,  191,    1,    1,  347,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  815,    1,  326, 2473, 2261, 2013,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  104,  137,    1,    9, 1913,  567,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  437, 2424,   98,    1,  596, 1793,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1378,  863,    1, 1687,   32,  584,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  681,   37,  588,  388,  861,  764,  384,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1202,  686, 1645, 2572, 1428, 1039,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  231,  471, 1699, 1746,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  375,  665,   28,  183, 1397,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  191,    1,    1,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  794,    1,    1, 1108,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3175, 2286,   37,   77, 1224,  220,  105,   12,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2640, 2137,   79,    9, 1821, 2190,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2759, 2718,  973,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  398,   37,  804,   98, 1204, 1876,    9,    1,  337, 2214,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   25,   71,   69,    1,  671,  245,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2617, 2286,   37,  764,  770, 1192,  453,  248,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   75,  692,  599,  444, 2114,  844,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2080, 3024, 2952,  176,    1, 1292, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2238,  361,  848, 2904,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  441,  498,   98, 2461,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1,  207, 3109,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2652,    1,  427, 1343, 2498,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1306, 2025, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2173,  720, 3311, 3310, 2930,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087,    1,    9,  105,  581, 3193, 3217,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1502,  267, 1503,  142,  927,    1,  612,    1,  693,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051, 2575,  837,  803,  681,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3170,  288,   37, 1343,   72, 1463,  951,    1, 2427,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405, 2520,  517, 2155,   28, 1560,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2045,  903,    1, 1447, 1585, 1389,    1,  202, 1744,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,   39,   45,    1, 3023,  220,    1, 1987,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  228,  365,    1,    9, 3022,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1290,  396,  720,  388,  763,   76,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,   98, 1018, 1758,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  561,  562,    1,  563,  564,    9,  295,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  267,    1,    1,  770,    1,  606,  277, 1154, 2853,\n",
      "           32,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  105, 3312,    1,    1, 2422,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   11,    1,  223,  315,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  561,    1,   32,  116, 2502,  856,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2523,    1,  191,    1,  361,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  275,    1,    1,    1,  552,    1,  693,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2868,  380,    1, 3388, 2139,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3140,    1, 1428,  297, 1430, 3146,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  581,  100,    9, 1577,  675,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,   37, 1388,  220, 3169,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  649,  631,    1,    1,  631, 2378,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3214,  614,    9,   32, 3236, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   21,   74,  786,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,   32, 1512,  187, 3361, 2253,   37, 2856, 3365,  297,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2048,   32,    1, 1229,   37, 1188, 1011, 1527,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,  102, 1473,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1285, 3244,   98,  166, 2041,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1456,  190, 2111, 1328, 1021,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  242,    1,  102,   92,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303, 1082,  673,  910,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  551, 1185,  580,  290,   32, 1186,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  106,   45,   69,  640,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056, 2137,    1, 1632, 2597,    1, 1887,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  916,   45, 2620,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  539,  967, 2961,   38,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213, 2331, 1167, 1545,  321,    1,  384, 1512,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  557,  540,    1, 2000,    7, 1506,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  313,  176,    1,  166, 1228, 2657,  226,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  476,   37,  865,   37, 2018,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1685,    1,  166, 1763, 1632, 2171,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  206,   12,  570,    1,  225,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3352, 2856,    1,   32, 1212,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 1972,    1,  531,   12, 3096,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654, 1458,  848,   32, 1935, 2294, 1523,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  204,    1, 1991, 2901,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,  446,  936, 1893,    1,  863,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,   71,  187,  109,  122,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548, 3071,    1, 3052,    1,   96,   37, 1755,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2614, 3055,  608, 2295,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1430,  697,   37,    1,  365,  446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 642, 643,  57,  28,   1, 118,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 104,  25, 439, 242,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2879,    1, 2321,   98, 2088, 2378,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 2835,    1, 3101, 2708,    1,  114,    1, 2024,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2140,    8,  365,  304,  444,  389,    1, 2861,    9,  531,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  297,  645,    1,   37,    1, 2024,   46,   32, 1364, 1365,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  590,   16,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3372, 1812,    1, 2156,  191,  166,  342,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158,  861, 2454, 2996,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  644, 1859,    1,    1, 1895,  442,  856,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  622,   12,  221,   37, 1211, 3080,    1,  187,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2641,  934, 1564, 1772, 2812,  111,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  615, 1399,   45, 1288,    1, 1242,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  138,  331,   37,  875,  422,  134,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3167, 2206, 2207,    1, 2722, 3074,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,   37,  123,  111, 1197, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3261, 1713,    1,  290,    1,    1,  375,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,    1,  829, 1994, 2819, 1017,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1307,  459,   28,    9,    1, 1102,  841,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  443, 2938, 3060,    1,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  329,   85,    1,  374,  526,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  600, 1046,    1,    1,  614,  236,  237,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,  831,  202,    1,   61, 1587,   98,    4,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  460,   12,  193,  166,  439,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1094,   46, 1133,   37, 3358,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1564,    1,    1,   37,  860,  112,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3160,  513,  514,   32,  531, 1038,  966,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2213,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2620,   85,  187, 2024,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3175,  872,  420,  385,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  387,    1, 1169,   15,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1201,    1,  435, 1173,   37,   47,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  567, 1582, 1554, 2028,  131,  302,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,   37, 2122,   98,  651, 1031,    1, 1787,   10,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  153, 1188, 2138,   37,   77,  902,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  361,    1,    1, 1532,    1, 1035,   77,    1,    1,\n",
      "            1,  147, 1392,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  147,  261,  444,  171,  777,    1,  625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  267, 2673, 1903,  792,    1,  202,    1,  792,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32, 2142,  187,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203,   37,   77,   69,    1,    1, 1706,    1, 1706,    1, 1706,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  494,  176,    1,  361,    1, 1173,  176,  183,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1237, 1658, 1117, 1525,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,    1,   81,  463, 2170,  528,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,    1, 1300,  225, 1996,  261,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  550,    1,   32,  870,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1256,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2197,    1, 2745,   37,   52,  105,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1707,    1,   54, 1062,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  361,    1,  912,    9, 1211,  639,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2368, 1245,   12, 1090,  726, 1045,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3079,    1, 1306,    1, 1022,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384, 2072,  166,    1,    1, 2922,   98, 1267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2328,  851,   37, 2564, 1821,   95,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1309, 1831, 2562,    1,   57,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  617,  259, 2264,  565, 2669,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 2709,    1,    1, 1908,  114,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158,  256, 1254,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,  100,  444,    1,   50,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  306,  872,  444,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2471,   37,  104,  361, 1033,  176,   48,   32, 2882,  806,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  344, 3035,  477,    1,   32, 2597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  515, 3081,   37, 3108,  420,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,  857,    1,  220, 2347,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  181,    1, 1107,   37,  247,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  815,    1,    9,    1,  151, 2552,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  220, 1791,    1,   37,   52,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1773, 2510,   37,    1,  187,  105, 1090, 2232,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   25, 1473,  187,   69,  102,  720,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  219,   25,  245, 1010,  365,  119,  636,    1,    9,   69,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187,  183,  404, 3278,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1572, 1414,    1,   32,   98, 2162,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1001,  977,  720,   37,    1,  131,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1060, 1061,   32,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1521,   45, 2820,   12, 2481,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1974, 2152, 2007,   37, 1448,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1250,   37, 2446, 2673,    1,    1,  864,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2527,  267,  872,  190, 2286,   37,  764, 3240,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  609,  162,  257,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1235,  102, 1253,   98,  626,  408,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  359,  690,  118,  125,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2565,    1, 1247, 1360,  612,  877, 1064,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1, 2957, 1463, 2348,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  419,   71,   32,  449, 1023,  197,    1,  113,\n",
      "         1396,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2108,    1, 1976,   32, 1700,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  176,  177, 2572,   32, 2597, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  942,    1,  415,  321,  612,    1,   98,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,    1, 2972,  475,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  200, 1211, 2366,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,  891,    1, 1334,  176, 1739,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  997,   37,  817,   98,   25, 1128,  343,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  683, 1070,    9, 2322,   37, 1048, 1323,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,  266, 1009,    1,  571,   37,  538,    1,  220,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3245,    1, 1414,  885,  411, 2022,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,    1, 1974,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260, 1625, 1747,   98,    1, 3330,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  550,   34,   88,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2377, 2286,   37,  161,  208,  114, 2372,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  443, 1202,    1, 1147,    1, 1010,  997,   45, 1698,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647, 1270, 1894, 2029,  148,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  992,   28,   97,  297, 3118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,    1,  384,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3166, 1774,   32, 3023,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2094,    1, 1263,   37, 1053,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1166,   32,  166,  593,   61, 1167,  389,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  261,   39, 2623, 2624, 2130,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1076,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1355, 1158,   12, 1230,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  756,  757,  108,   98,  197,  585,  583,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1698,  356,  197,  418,   98,   15,   93,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   65,   28,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1996,  167, 1403,   32,   59,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  251, 1211,   80,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1215,  115,   32,  166,  539,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,    1,   98, 1567,   37,    1,    1, 1649,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361, 2685,  759,    1,  630,   98,    1,   59,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963, 1340,   71,    1,   60, 1042,  548, 1331,   31,  948,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   37,   26,  417,   63,    4,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1369, 1009,   45, 2798,   15,  939,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3068, 1564,  617, 1484, 1211,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962,    1,   98,  114,  187, 3260,    1,    1, 2633,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3256,  429,   79,  978, 3138,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  200,  673,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2994, 2995,  884,   98,  829,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187, 3378,   96,    1, 1428, 1930,  588,   37,  619,  776,   81,\n",
      "           98, 1171,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   46,   98, 2299,   32, 3369,   12, 3118,   37,    1,   32,  430,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018, 1705,  176,  105,  474, 1494,   28,  105,    1,  176,  166,\n",
      "         1171,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  986,    1, 1445,   37,  335,  297,  112,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  557,  540, 2909, 2774, 2060, 1114,    1,  443,  997,   71,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2942,    1,    1, 1758,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1245, 2151,  984, 1939, 2584,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   37, 2677,  365, 1013, 1522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2948,    1, 3024,   12,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  914,  105,    1,   45, 3270,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 1527, 2664, 1999, 1530,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  484,   37,  913, 1899,  680,  433, 2263, 2317,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649,  947, 1385,   28,    1,  187, 2789, 1953, 1627,   72,   74,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  193,    1,   79,  191, 1515,  260,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,    1,  197,  418,  187,  568,  641,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1537,  954,   37, 1192,    1,  118,    1,  267,  446,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3400, 1554, 1583, 1967,    9,  365, 1204,   32,  455,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  321, 1910,  611,  220, 2196, 1197,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,  387, 1230,  844, 1669,  187,    1,    1,  193,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  492, 1448,  700,   11, 1663, 1448,  437,    9,    1,  131,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   37,  518,  297, 1023,   45, 2571, 2699,   32, 3118,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,  590, 1534,   32,    1,    1,  287,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3216,   92,   32, 2522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  744,  234, 3041,  235,    1,  234, 3041,  235,\n",
      "           73,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715,  232, 1562,  163,    1,   12,    1,  448,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  571,  565,   32,    1,  361,    1,  852,   55,  105,  855,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885, 1631,   59,  813,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3188,  729,  719, 1551,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3079,    1,    1, 1685, 2607,   44,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2206, 2207,    1,   12, 2214,    1, 2864,  449,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2610,  105, 2441,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  499,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1728,  105, 2876,    1,  105,  223,  469,   61, 2879,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,    1, 1193, 2585, 1737,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3234,  872,  420,  385,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  183, 1272, 1976,    1,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2045, 1680,  325,    1,   12,    1,  481,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  422,  929,  640,   39,  176,  652,  706,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117, 1525, 2208, 2134,  861,  122,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  370,  716,  449, 1023,  156,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  191,  245,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3105, 2411,   37,    1,   98,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777,  183,    1, 1450, 1361,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  683,   37, 1463,    1,    1,    1,    1,    1,    1,  361,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1061,    1,  475,   61,  820,   98, 1368,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1527, 1149, 1910,    1, 3114, 1223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1362,  313,   37,    1, 1446,   17,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1965,  167,    1,    1, 1204,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 1447,   37, 1598,    1, 1407,  214, 1077,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  519,    1, 1894,   63,  754, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1475, 3044,  102,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  191, 1428,    1,    1,    1,   45, 3086,    1,   32, 3114,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1668,  877,    1,    1,  967,  105, 2745, 2093,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  325,    1,   12, 1541,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284,  111, 2165,    1, 1897,  166,  818, 1882,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  138,  302,   98,  826,  827,  274,  828,  360,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3289, 1542,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2942, 1396, 1700,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,  515, 1368,   37,    1,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  388, 2558, 1976,   32,  829, 1778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  132,  162, 1805,  302,   45,  223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  539, 1037,   12, 2082, 1473,  297, 2998,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1444, 1445,    1, 1515,    1,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3153,    1,    1, 1458, 2571,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2708,    1, 1195, 3136,  477,  548, 1056,   74,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,  456,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2183,    1,  232, 1333, 1530,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3363,  972,   37, 2237, 2018, 1411, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2699,   37,    1, 1361,   12, 2796,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  928,  176,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   14,   12, 1298,    1,   18,   81,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    6,  581,  401,  646,    1,   37,    1, 1224,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  382,   25,  120,  548,  800,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3209,  186,   37, 1452, 2522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2899,  614, 1300,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1399, 1583,   37,    1, 3359,   12,   57,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2543, 1675,  726, 2223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2069,    1, 2328,  794,   98, 1524, 2286,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  593, 3009,  664,   37,    1,    1,  922, 1218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622, 1016,  437,    1,   28, 1876,    9,  529,  477,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1537,  460, 1479,    1,  207,  197,  407,  118,  187,  486,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1110, 1865,  365,  111, 1107, 1108,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  459,  878, 1994, 2650,  302,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2183,  649,  650,   37, 2237,  903,    1, 1447, 1411, 1034,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1386,  991,    1,  187,    1,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810,  166, 2615,  565,    1,  600,    1,   12,  581,  100,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2631,  321,  612,  664,  872,    1,  202,  744, 2925,  726,\n",
      "          813,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2258,   76,  187,  730, 2614,  907,  931,   32, 1090,  547,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1993, 1159,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  476, 2236,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2897,   98,    1, 2597,  237,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  217, 1210,  105,    1,   45, 1739,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   16,    1,  187, 1178,   45,    1, 2295, 2302,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  635,   12,    1,    1,    4,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3132,  332, 2376,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3327,    1, 3239,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,    1,    9, 2846,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,   81,   17,   32,    1, 1655,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1497,    1,  153,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 1061,   32, 2162,   45,    1, 1863,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  365,   82, 1625,   37, 1594,  460, 1425,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3342, 1231,  297, 2282,  722,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  424,    1,   61, 1658,    1,    1,  424,    1,   61, 2310,    1,\n",
      "            1,  361,  166,    1,   61,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1209,    1,    1,   45, 1017,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  295,  365,    6,  837, 1682,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  872,  140,   72,  671, 3126,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2882,  863,  167,  805,  104, 3057,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  613,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1584,   12,  439,   98,  105,  845,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144, 1009,    1,   37,   97,    1, 1458,  365,  741,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  818,    1,  167,    1, 1658, 1465,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388, 2292,   32, 2752,   98, 1194,   74,   45, 2774, 2782,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2221,    1,    1,    1, 2268,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3142,    1, 1957,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2471,    1,    9, 1548,  631,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  446,  292,  395,  942,  442,  187,  649,  700,  958, 1184,   32,\n",
      "            1,   69,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,   67,   71,  193, 2398, 2221,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1173, 1425,  166,  183, 1985,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1900,    1,    1,   45,    1,   32, 3349,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  441, 2145,   37,    1,  809,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3215,  476,  388,  522,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,  412,   98, 1497,   51, 1192,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2751, 2856,  547, 2548,   32, 1815,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226,  901, 2310,    1,    1, 2226,    1, 2602,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  364,    1,   37, 1030,   32, 3275,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  221,    1,    1,    1,  928,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2956, 1627, 1903,   98,    1,    1,    1,    1,    4,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1343,  198, 2125, 1090,   32, 1918,  297,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2279,    1, 2312,    1,  220,  104,  437,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  614,  232,  220, 1718,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  914, 2094, 2095,  304,    1, 1081,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649, 2684,   32, 3349,   37,  764,    1, 1250,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1509,  151,   12,  572,  156, 1473,  118,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2751,   32, 3369, 2517,  774,  590,    1,   32, 1450,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3006, 2596, 1056,    1,   32, 3383,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,    1,    1,    1, 2863,  973,    1, 1085,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2899,    1,  200,  822,  912, 2285, 1017,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  146,  147, 2682,    1, 2009,    1,  798,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3240,   12, 2099,    9,  199,   79,  105,    1, 1421, 3331,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,   12, 2510, 1249,   15,  837,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  770,   45, 1919,  649, 3102,    1,  754,  384, 2018,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2736,    1,    1, 1268,  651, 1320,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2164,    1,  686,  403,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3254, 1698,   45, 1161,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1625,   37, 1865,  105, 2438,  220,    1, 2161,   12,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 3006, 1220, 3382,   12,  949,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1128, 1042, 2627, 1128,    1,   37,  104,    1, 2627,    9,  104,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1665,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1463,  205,   98,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1577,  200,    1,  168,   37,  218, 1560,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  315,   32,  913,   37,  123,   28,    1,   32,    1,    1,   26,\n",
      "           28,   32,  316,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,  418,   37, 1056, 1034,  845,   98,  679,   69,  109,\n",
      "         1057,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3167, 2459,    1,  365, 1788, 2685,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  141, 1505,  662,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  103, 2132,  691, 1287,   37, 1911,  104, 3255,  922, 2963,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   45,  270,   61,    1,    9,  139,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   51,    1, 1962,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835,    1, 1094, 1508,  442,  132,  220,  104,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2308,    1,  154, 1195,   46,   98, 2901,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 3089,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2369,  261,    9,   95, 2172,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  348,  733,  854,  486,   50,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  531,  443,    1,    9, 2018,  191,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545, 1046,    7,    1, 1463,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1955,    1, 1819,    1, 1294,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144, 2591,    9,  365,  650,  187,  121,  361,  166,  539, 1075,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  619,  561,    1, 1323,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  872, 1380,  691,   32,  453,  913,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  786,   45,   91,   12, 1509,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  134,  297,    1, 1887,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2494,  872, 2257, 2017,   37,  688, 2468,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  996, 2005, 1207, 1527,    9,  594,  497,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  559,   79,   29,  471,   50,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  727,  190,   47,  453,    1,   48,   32,  942,   12,    1,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835,   12,    1, 1579,    1, 1140,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 1042, 2154, 2596,   98, 3383,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  231,  365,    1, 1090, 1354,    1, 2085,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  348, 1913,  401,  207,  418,  187,    1,  902,   15,   93,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  829, 1936,  822, 1003,  176, 1718,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,  197,  716,   37,  817,   98,   25,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  123, 1387, 1675,   45, 2615,  220, 1194,   73,  726,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2802,  919, 3142,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492, 3105,    1,  191, 1994, 2710,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  531,    1,    1,    9,  449,  199,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 2404,  859, 1876,    9, 2708,  741,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2506,   79, 3144, 1002,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 3345,  211, 3026,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  159, 1374,   98,  572,  304,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2128, 2129,   32, 1815,   51, 1174, 1387,  105, 1034,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,    1,  548,  104,    1,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,   12,    1, 1033, 1765, 1194,  673,  793,   37,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,  267, 2087,  433,    1,   97,  297,  825,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1484,   98,  864,   37, 1806, 2390, 3366,  315,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  864, 2673,   46,  420, 1647,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  295, 1243,  365,   24,    1, 1167,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  108,   45, 2786, 2987, 2762,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  832,   98,   69,  102,    1,  156,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,  708,    1,    1,   37, 1504,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2221, 1082,  615,   37, 1154,    1, 1807,  417,  571,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,   12,    1,   37,   16,  573,  977,  383,    1,    1,    1,\n",
      "          267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  242, 2247,  102,    1,    1,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2999, 3132, 1994,    1, 2186,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  150,  794,   98, 1220, 1876,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  311, 1261,  270,   45, 2441,  333,  459, 1688,  802, 3011,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226,  872,    1, 1751,    1, 2173, 2567,   98, 1727,  132,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   38, 3142, 1515, 1194,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3288,    1, 2622, 1836,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1,    1, 2255,    1, 2085,  820,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2295, 2321, 2315,  220,  750,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1024,    1, 1357,   98, 1610,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 1633,  686,  191, 3038,    1, 1450,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3282,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  361, 1100, 1523,    9, 2071, 1331,  769,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3124,  140,    1, 3329,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,  288,   37, 2354,  220, 1731, 2639, 1499,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  623,   72,  401,  244,   28,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   51,   47,    1,  118,   45,   49, 1331, 1069,   50,  420,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1385,   28,  386, 1632,  665, 3262,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  749,   12,    1,   51,  193,    1, 2135,  445,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1273,  259,   15,  120,  176,  119, 1224,   32,  581,  401, 2076,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,  361,  971,  125, 1069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1625,    1,    9,  395, 2003, 2372,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  251,  365, 2842,   45,    1, 2530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  631, 3276,   37, 1194,  726,   32, 1675,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640,    9,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  947,  271,   28,  186,    1, 2062, 1743,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1427, 1086,  547,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3401, 2770,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12, 1440,  387,    1,  207,   28,   32,    1,   45,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  963, 2949,  680,    1,    1,    1,    9, 2792,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  915,  872,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  234, 3041,  235,    1,  234, 3041,  235,   32, 1211,    1,\n",
      "         1393,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796, 2368,   28,    1, 2371, 1089, 1090,    1,   32, 1056, 1890,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1357, 2762,  167,  631,   37,    1,   45, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,   85,  548,  577,   65,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3221, 1554,    1,   32,  166, 2213, 1667,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,    1,   37, 1911,  467,    1, 1564,  284, 1647,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  702,   11,  169,   32, 2050,  131,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1423,  556, 1484,   37, 2064,   37,    1,  207,  126,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  393,  359,  930,  411,   63,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1,    1,   32,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,  613,  614,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   20, 1982,    1,   98,    1, 1821,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  165,    6,    1,  493, 1649,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  109,  488, 1821, 2640,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  941, 1201,    1,  475, 1213,    1,  938,  939,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  603,    9,    1,    1,    5,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1185,  614,   37,  147,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3108,    1, 2333, 1918,  297, 2615,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  331,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  686,  191, 1330,   98, 1827,   38,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3157,  774, 2205,    1,  202, 1360,  612, 2446,  741,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  344, 3403, 2414, 1056,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  109,  509, 1198,   69,  102,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  440,    1, 1501,  875,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1629,  134,    1, 1204,  220,  133,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1986,  919,   25,    1,  202,   69,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1, 1515,  454,   81,  548,    1, 1686,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  507,  111,  325, 1159,  413,   45, 1697,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  401,   45, 2377, 2139,   37,  138, 1515, 1879,    1,  506,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  485,    1,    1,   32,   46,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2997,   12,    1,    1, 1348,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  384, 2819,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  775,  453,  248, 1230,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2081,  297,  365, 2362,   98, 2567, 2074,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3075,  571, 2333,    1,   37,  121,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056,  556, 1176, 1533,   37, 1575,    9,    1,    1, 1487,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424,  914,    1, 1444,    1, 1846, 3001,   39,   45,  238,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3192, 1364, 1365,    1,  796,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  245,   98,  459,   45,  677,  109,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  941, 1663,   37,    1,    1,  400,  444,  597,   82,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358, 1625,    9,  104, 1563,   45, 2024,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,  729,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3178,    1,    1,   32,  602,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3113,   12, 1277,  509,  600,  531,  890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2875, 2640,    1,    1,  187, 1011,  109, 2202,  340,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  550,    1,  387, 2620,  384,  585,  245, 1425,  166,  593,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  216, 2856,  176,  177,   32, 3339,  787,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1128, 2369, 1718, 2471,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447, 1924, 1542,   37,  576, 2924,   37,  531,    1,  825,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 2018, 1003,   37, 2050,  691,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1013, 1522,  420, 2101,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2257,   39,   45, 1503, 2107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537,  171, 1386,  680, 1324,  187, 3038,    1,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3237,   61,    1,   37,    1,  166, 2685,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971, 1401, 1032,  163,    1,   12,    1,    1,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   69,  102,  105, 1665,   37,  342,  471,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    1,   14,   51,   52,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  455, 2924,   51, 2449,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2652,  245,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2672,  442, 2922,   37, 1214,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169, 1077,   37,    1, 3204, 1456,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788,  162, 3269,    1, 3171,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,  661,   98,   29,    1,  303,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  103, 2710, 3382,    1,   37,    1,   45,    1, 3358,   32, 1645,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1290,  396, 1374,  191,    1,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2896,   37,    1,    1,  259,    1, 1411,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  558,  431, 2282,    9,  104,  111, 1697,  437,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  620,    1,  580, 1600,   43,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1,    1,  952,  439,   45, 2771, 2522,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 2580, 2851,  267, 2076,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  325,    1,  700,   12,  934, 1499,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3188, 1518,   32,   98,    1, 1880,  813,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,  267, 1801,   37, 1096,    9,  845,   69,  102,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  275,   25,   26,  417,   98, 1051,  374,  526,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  361,    1, 1758,   37,    1,    1, 2069,   98,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  782,  453,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  528,  224,   12,    1,    1,  440,    1,    1, 1046,  762,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3191,    1,  631, 3312,    1, 2828, 2250,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1050,  650,  580,    1,   98, 2702, 3389,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1809, 1658,    1,  138,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,  215,  147, 1707, 1994, 2095,    1, 1563,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1558,  548,    1,   10,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1326,    1, 1955,    1,    1,  631,    1,   37, 2284,  104,  332,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  142,   37, 1195,  557,  442,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3382,    1, 1368,  191, 2235,  147,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  982,  737,  156,   71,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  707,  457,  166, 1677,  361, 2124,   45, 1821, 1697, 1821,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  314, 1692,   37,  125,    1,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2328, 2414, 3095,    1,    1, 1388,   32, 3339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  535, 1587,    1, 3052,    1,   45, 3070,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1848,   37,  138,   59,  599,    9,    1,  636, 1336,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,  884,  885,  832,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230,   37,  631,  104,  444, 2468,   32, 1764, 1990, 2069,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  552,  551,  405,    6,    1,    1,    1,    1,    1,    4,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  241, 2875, 2640,  387,    1, 2784,  528, 2323,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1557, 2892, 1910,    1, 2791,   32,    1,    1,  202, 1744,  469,\n",
      "           37, 1334,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  204, 1924,    1,   98,  166,    1,   32,  273,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1854,  571,    1,    1, 2917,    9,  854, 2579,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  446,   12,    1, 3340,    1,    1, 2253,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  389,   93,   61, 1103, 1315,  236,  237,  739,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2962, 3108, 2341,   72,   73, 2764, 1619, 1684,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  632, 1140,    9, 1965,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2614,  726, 2674,   73,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  720,   39,   45, 2708, 2107,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1326, 1761,    1,  132,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2292,    1,  176,  111,  772,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,   37,  764, 1664,  531, 2150,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   32, 1256,  551, 2196,    1,    1,    1,  220,    1,    1, 2292,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1419,  340, 1251, 1778, 2580,    9,  854,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593, 1990,    1, 2802,   12, 2318, 1036,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  299, 1648,   37, 2324, 2095,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,  455,   46,  877,  590, 1647,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2153,   45,  342, 2064, 1421,  365, 3341,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1809,  988, 1825,  166, 1292,   45,  166,   16,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   13,    1,  387, 2034,   28,  118,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3039,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2887, 1254,   32, 2507, 3246,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2929,  707,   37, 2171,    9,  453,  365, 1049,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  403,    1,  162, 1509,   45, 1022,    1,    1,   12,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2815, 2208,  167,   52,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1079, 3063,    1, 2355, 1013, 2549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1,  996,    1,    9,  449,  199,  452, 1014,  915,  356,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2226,    1,  612, 1584,  872,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947, 2886, 2399,   37, 1844,  297,  584,    1,    1,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1013,    9,    1,   32,    1, 1223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  449,    1, 1684,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  552,  552,  669,  162,  432,  384,  119,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  879, 1281,   98,  310,    1, 1196,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3226,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  943,   45,    1,  443,  361, 1302,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1990, 2250,    1,   28, 3180, 1388,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2057,   12,  365,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  106,   42,    1,    1, 2039,  328,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  113,  114,  115,   45,   65,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3200,  972,  664,    1,    9,  356,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   60,   37,  184,  517, 1953,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  730,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773, 2510,  951,    1,  848, 2371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  608,  569,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1848,  513,  514,   45,    1,  636, 1336,   37,  138,    1,  599,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1089, 1936,  460,  220,  334, 2973, 1764,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  624,    1,  197,  338,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  342,    1,  297,  296,    1,   20,\n",
      "         1527,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3266,  480,    1,    1,  913,    1,   98,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   14,   15, 1253,  202,   69,  640, 1161,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 1268,   98,    1,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  848,  872,   28,   98, 2723, 2724, 2657,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2285,    1, 1924, 2213,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1021, 2489,  187,  531, 1708,  914, 2055,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2409,   61,  388,  275, 1912,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1853,   12,    1,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  148, 1564, 2069,  647,  693,    1,  155,  142,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  143, 3374,    1, 1876,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1214,  852,   37, 2460,   28,  105,   64,  176,  754,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  449,    1,  730, 1571, 2514,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1252,    1,    1,  220,  470,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1848,   37, 1155,  105,    1,   32, 2573,   37, 1155,  769,    9,\n",
      "         1975,  361,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  255, 2332,  190,   18,   98,  105,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614, 1585,   79,  444,  166, 3175,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1151, 1091,  288, 2364,   98, 1412, 1089,    1,  327,  593,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  403, 3165,  335, 2649,  176, 1796, 2147,   32,  403, 1447,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3128,  108,  444, 1336,  993,   32, 2210, 2847,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2734,    1, 1364, 1365,    1,   36,    1, 1763,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  849,    1,   12, 1411,  183, 1265,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,    1,  342,    1,   45, 2707,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   98, 2887, 1281,    1,    1,  852, 1750,  890,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1019,    1,   12,    1,    1,   32, 2468,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1009,    1,  992,   85,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,    1, 1594,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  581,   32, 2792,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  938, 1970, 1554, 1778,    1,  978,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2163,    1,    1, 1236, 1785, 2044,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708,  993,  475, 1333,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3236, 1012, 2805,    1,  187,  512,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3336,    1,  297, 3071,  176,  632,   36,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307,   37, 1403, 1412,  844,   37, 1273,  618,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843, 1702,    1, 1159,   72,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1811,  404, 3358,  167,  606,    1,   45,    1,    1,    1,  232,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  213,   37,  365, 1056,  356,  132,  220, 3209,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  171, 2358,    1, 1111,   45, 2646,  716,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 1447,   12,  947, 1385,   28,    1,  521,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  762, 1188,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1,  488,   94,  142,   37,  439, 2673, 1559,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  861,    1,    1,  187,    1,   16, 1268,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 1656, 3403,  640, 2597,    1, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  942,    1, 2100,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1, 1361,  631,   32,  481, 2759,  675,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1228, 1901, 2865,   39,  215,  957, 1074,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  200, 2871,  220, 1768,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   33,   98,  142,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1342, 1902,    1, 1009,  361,  475, 1213,  655,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,   37,  538,    1,  195,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1668,  726,   32,    1,   12,  865,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3110,   12,  726, 2385,  612,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  475, 1707, 1484,    9, 1596,  297, 1791,  926,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2206, 2989,   55,    1,    1,   98, 1658, 1030, 2009,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,  978,    1,   28,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  506,  460,  389,  218, 1258,   37,   52,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764,    1,  267,  460,  967, 1089,   45, 1920,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   31,    1,    1,  465, 1895,    1,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,    1,  548,   65,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 1450,   51,    1,    1,   74,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  528,    1,    1,    1,  894,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  647, 1917,    1,  148, 1090,  297,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1017,    9, 1018, 1019, 1020,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1808,    1,   98,    1,    1,    1,  733,   98, 1095,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398, 1542,   37,  698, 1047,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1, 2649, 1219,    1, 2414,  786,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,  138,   59,   37, 1652,   32, 1350,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094,   12,    1, 2789,   37,  741,  444, 3339, 2271,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390,   46,    1,  608, 1757,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1283, 3059, 3183,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   28,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  596, 1395,    1,   37, 2284,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2648, 2801,  361,  982,  477,  259,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1,    1, 1294,  861,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1364, 1365, 3055,   37,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2693,    1, 1289, 1074,    1,   37, 3005,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,    1,  351,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  758,   37,  130,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3161,    1, 2570,  171,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  321,    1, 3076,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1,  197,   28,   98,   15, 1124,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  397,    1,  294,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3200, 3245, 2055,    1,    1,  411,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1468, 3092, 1990, 1286, 3179,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 2767,  404,    1, 1412,  754,  327, 2639,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2809,    1,  858,  695,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1778, 2580, 2851,  764,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  803, 2718, 1816,  861, 1787,   37, 2738,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2883,  852,   37, 1155,  195, 2502,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 1773,    1, 1721, 2309,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1477, 1990, 2420, 3258,   12,    1,  361,   36,    1,  210,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3069,  952,   37,   92, 1521,    1,    1,   32, 1811,  404,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129, 1286, 1287,   98,  932,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 2553,   98, 2772,  776, 1723,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 3255, 2583, 1777, 2739,    1, 2741, 2651,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2672, 1285, 3318,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3092, 1360,  612,    1, 3066,  297,    1,  841,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  867,   37, 1753,  207, 2633,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 2615,    1,  411,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3104,  271,   28,  469, 1908, 2081,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,    1,  326, 2035, 1151, 2657,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2941, 3210,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1957,    1,    1,   81, 1857,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    9, 3251,  221,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  256,    1,   37, 1013, 1017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,   37,  288,   28,  425,  426,  474,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1957,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1087,  200,    1,   45,  160,  280,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2546,    1, 1158,    1,  918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3076,  402,    1,    9,    1, 1042, 1298, 1117, 1159, 2073,   32,\n",
      "          180, 1990,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,   25,  242,   98,   69,  636,  591,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3107,  132, 1665,  187,  864, 1702,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   43,   51,   52,   32,  272,  548, 2408,   12,    1, 2961,   32,\n",
      "         2916,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  964, 1458,    1,  650,    1,    1, 1140,    9,  365,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  278,    6,  810,  600, 1560,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  151,  920,    1,  151,    1,    1,  202,  877,  105,  227,  132,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593, 1990, 2126,    1, 1292,    1,    1,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3102, 3025,  898, 2572,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  917,    1,    1,   61,  365, 1327,  232,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2871, 3175,    1,    1,  759, 3146,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800,    1,  884,    1,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3142,    1,    1, 2457,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  213,   37,  875, 1370,   45, 2628,  573,   43,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1181, 2914,  449,    1, 1102, 1151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3079,    1, 2720, 2796,   32, 1090,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1002,   92,    9,  667,  446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2104,  839, 3343, 1002,  133,    1,    1, 1961,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  196,   37,   47,   48,   32,    1,   37, 1022,    1,  361,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1065,  199,    1,    1,  199,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1938, 2607,    1, 2115,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1800,  716,   45,  105,    1,  220, 1645, 2565,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1191, 2073, 1843,  354,  703,    1,    1,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1934,    1, 1679,  103,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2620,   61,  105,  504,    9,  273,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,  613, 1353,  845,  846,   29, 1074,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  584,  135,   61,  816,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  903,    1,  464,    1,    1, 1237,  963, 2147,   32,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3204,    1,  608, 3169,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  361,    1,    1,  191,  166,  617,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,  453, 3044,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3354, 1178, 1061,    9,    1, 1260,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2487, 2153, 1936,  183,  762,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  924,   32,  925,  926,  927,  928,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1187,  166, 1427,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,    1,  907,  548, 3038, 3279,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,  412,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3221,  884,    1,   39,   45, 2689, 1717,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  220,    1,  361, 1021,    1, 3232, 2446,  166, 3231,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2137,  686,  795, 2468,  548, 3387,  937,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  294,  853,  112,  328,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2217,  288,   37, 2545,  365, 1277,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1,  657,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2741, 3144,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  845,  147,  190,  804,   98, 1842, 1074,  412,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1500,  197,    1,   15,  157,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3167, 2871, 1024,  442,  729,   32,  166,  272,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147, 2411,   37,  875,  912, 2285, 2096,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3173,   39,   37,    1,  284,  901,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 2926,  233, 2107,    1,  123,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  443,  193, 1018, 1144,  444,  864,  602,   12, 3139,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,  818,   15,   79,   37,  198,  698,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,   24,    9,  164, 1333,  165,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,  166,  625,    1,    1,  190,   52,    1, 1183,  361,\n",
      "         2177,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  591,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1326,   12, 2073, 1843,  197,    1,   98,    1,   50,   12,  701,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  233, 1392,   45,  286,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,  672,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1189, 2673,  210,   51,   18,   63, 1428,  861, 1906,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102, 2253,  241,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,  311, 1204,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1423,    1,    1,   32, 1912,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  783,  198,   32, 1657,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,  903,    1, 1447,    1, 1399,   45,    1,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  864, 3067, 2596, 1260,   32, 1081,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1550,  808,   32, 1695,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 1412,  754,    1,    1,  267,  657,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,   12, 1107,  525,  920, 2352, 2464,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1531,    1,  277,    1, 1477,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    9,   56,  569,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2646, 1523,  105, 1460, 1463,    9, 2877,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,    9,  453, 1594,   37, 1468,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428,    1, 3146,   37,    1,  596, 1994, 2095, 1708,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49, 1536,    9,  467, 1942,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1791,  650,   45, 3387,   61,    1,   32,  447,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2232,  723, 2373, 3011,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  683,    1,  376,  570,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,   37, 1876, 2071, 1331,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1398,  612,    1,   81, 2390,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2084,  282,   61,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3340, 1428, 3365, 1140,  754,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  759,   45, 3162,  920,    1,    1,  864,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  321, 2254,    1,  220,  326,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2366,  820,    1,    1,  551, 1211,   55, 1819,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,   37, 2192, 2017,  365, 1455, 1294,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1120,   12, 2934,    9,    1,  388,   45,  460,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2359,  794,    1,   32,  105, 1510, 3004,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,    1,  746, 1776, 1766, 1767,    1, 1259,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,  681,   37, 1124, 1278,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  884,  633,   84,  444, 2650,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  375, 1086,   28, 1139,   32, 3163,    1, 1183, 1253,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,    1,  156,  720,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1716,  387,    1,  276,   32, 2419,  218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2613,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   33,  190,  866,  166,    1,   98,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183, 3001,    1, 1298, 3001, 1523,  297,  166,  306,   12,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3083, 2681, 3254,   39,    9,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 2171, 2153,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,    1,  469,    9,    1, 2918, 2699,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,  733, 1023,  105,   59, 2510,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  259,   15,   16,  590, 1421,   45, 1115,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1913,  715, 1061,   32,  927, 1159, 2108,  442,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  140, 2474,    1,  400,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1258,  116, 2678,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2789,    1, 2241,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,    1, 1867,    9,    1,  548,   95,   37,  622,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  224, 1830,   37, 2962,   28,  332, 1611,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,  884,   80,    1,   39,   45,  171,   12,  637,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  854, 1917,  463, 2170,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111,  605, 1804,  166, 1868, 1172,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,   25,  123,  242,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190, 2992, 1504,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,   12,    1, 2065, 1102,  931,  220, 2474, 1151,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1940,    1,    1,  920,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2336,    1,  220,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3322, 2967, 1380,   98,  105,   16,    9, 3152,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  193, 2398,  187, 2982, 1334,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  666,  868,    1, 2865,   39, 1021,   37,  331,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1082,    1,   37,   92,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  499, 1173,  176,  163,    1,   12,    1,  531,  622, 2705,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3392,   32, 2499,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162, 1950,   32, 1932,  395,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  999,   61, 1488,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1417,  551,  717,  733, 1796,  886,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1,  365,    1,  361, 1577, 2518,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  688, 2615,   32, 2799,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3264,  627,  187,  512,   45,    1, 3096,  175,  729,   32,  166,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1, 1503,    1,  515, 1502,   59,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  844,    1, 2518, 1515, 1412, 1089,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   12,  647,  142, 1757,  431,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  230, 1900, 2192,  304,  600,    1, 1317,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 1147,    1,    1, 3382, 1921,   32, 2764, 2646,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1024,  551, 1024,   32,   46,   37,  151, 1026,    1, 2163, 1215,\n",
      "          716,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  523,   12,    1,    1, 1411,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3101, 2548, 2856, 2708, 3065,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   49,    6,  568,  570,    1,  159,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  388, 1867,    9,    1, 3280,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,   12, 2084,    1,  669,   32,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    1,  628,   32, 2941,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325, 1474,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1554, 2249,   32,  463,  395,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1050,  633,  967,  132,   37,  151,    1,  129,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,    1,    1,    1,  176,  442,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1717,    1,    1,  476,    1,   79, 2661,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2742,   45, 2018, 2764, 2765, 3060, 1536,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  958,  649,    1,  396,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  912,    1, 1228, 2175,   45,  823,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1405,    1, 1070,   59,  270,  278,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  848,  744,  636,    1, 2306,    9, 2979, 2869,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,   98,  542,  565, 1558,   28,    9,  949,   45, 2692,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1883, 1228,  325, 2215, 2815,  700,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  716,   45,  365,  116, 2542, 2454,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035, 1070,  398,  611, 2349,  920,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   45, 1212, 2369,    1, 1563,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  957,  719,   37,   84,   28, 2972,  293,  437,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2365,  166,    1,  444,  166,  590,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,    6,    7, 3018, 2560,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  365,    1,   37,    1,  669,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  140,  142, 1523,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  334,  254, 1120,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  223,  159,  245,  548,  672,  156,  570,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,  105, 2177,  199,    1,  220, 1100,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  155, 1184,  347,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,   51,   52,    1, 1461, 1539,  178,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307,  259,  256, 2693, 1942,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 2164, 2986, 1046, 2620,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  865, 1178,   81,    9,  388,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1372, 3193, 3217,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  695, 2789,  140,  863,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  681,  187,  289,   96,   37,  104,   29,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2700,  123,   32,   98, 1039,   45,    1, 2796,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  168,  166, 3115,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1861,  997,  651, 1031,  139,    1, 1355,  163,    1,   12,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1948, 1949,  131,  486,  132,  220,  326,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  244,  384,    1,  533,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2755, 3010,    1, 1667,    1,  505,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1127, 2726,    1,   32,  231,   45,  293,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1009,  972,   37,  726, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2275, 1484,  730, 2614,  507,   12,  872,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2699,  598,    9, 2820, 1374,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  420,  782, 2508,  315,  729,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  633,  354,    9,   65,    1,  183,  105,  551,  331,  504,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  180,   12,    1,    1,  897,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2136,    1,   10,   37, 1405,   12,  508,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2984,  782, 1056, 1298, 2662,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273, 1609,   37,    1,  909,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  453, 2734, 1530,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  193,    1,    1,    9, 3208,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2193, 2884,    1, 1086,  176,    1,   12,  754,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  611, 2156,    9,    1, 2596,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  361,    1,   28,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   45, 1997,  457,  994,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1645, 3073, 3340,   32,  531,  297,    1, 1281,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  221,    1, 3276, 1492, 1924, 1831,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  952,    1,  384,  395,   98,  863,    1, 2081,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193,    1,  384,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  206,    1,    1, 1810,  730, 2614, 2092,    9, 1211,  639,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1024, 2582, 1056, 1586,  951,    1,    1, 1306,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1181,  580,  122,  297,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962, 1340,    1,   32, 2578,  202, 1110,  186,    9,  183,\n",
      "          726,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  139,  729,    1, 2977,  379,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  560,  347, 1269,  424, 1034,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3021, 1360,  612,  664,  671,   32, 3185,  400,    1, 3261,  267,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1797, 2960, 2668, 3339,  787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1527,  376,  172,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1883,   37,  130, 1117, 1525,    1,  650,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  500,    1,  306, 1935,    1, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  686,  191,  954, 2063,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2676,    1, 2275,  297,  443,   98, 2095,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3339,    1,  508, 3071,  187,    1,  741,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  886,  159,  245,  327,  548,  104,  887,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1413,  166,    1, 1218,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  597,    1,  387, 2333, 1516,   98, 3388, 1030,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 1674, 2472,  187,    1, 3280, 2421,   39,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977,   12,    1, 2494,   37,  606,  915,   95,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,   60,  640,  105, 1034,  845,  951,    1,  166, 1547,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,    1,  204,   12,  729, 1286, 1133,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,   37,  125,  118,   45, 1604,   23,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  936,  723, 2876,   45,  166,  593,   12,    1, 1362, 1480,\n",
      "         2873,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1423, 2272,   85,   98,  116,  133,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1307, 1564,  227,   98,  112,  618,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1013, 1681,  224,    1, 2368,    1,  306,  886,    9, 1523,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2158, 1454,  331, 2545,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  256,   91,   37, 2610, 1107, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1313,    1,  695,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   45,    1,  124,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  761,   37,  335,    1, 1491,   44,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 1524, 1267,    1,    1,  884,  631,  176,  166, 1050,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 539,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 140,   1,   1,  72,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2774,  650,  776,    1, 1159, 1803, 1114,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3140, 1707,  104,    1,   45,    1,   32, 1147,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2893,  162,   98,  411,  863,    1,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947,    1,  439, 1824,  161,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1307,  200,   27, 2498,    1, 1607,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1084,    1,  449,  273,   98, 1047,   12,   43, 1638,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  496,  493,  102,  720,  187,    1,  614,   85,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  147, 2450, 2086, 1377,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 2479,  631,   32, 2480,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,   37, 2653,    1, 2153,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1333,    1,    1,   37,   52,    1,   45,  671, 3052,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  517,    1,  405,    1,  552,    1,    1,  692,  105,  469,\n",
      "           37, 1066,   28, 1417,    1, 2226,    1,  105,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977, 2270,   37,  211, 2978, 1539,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1429,  986,   79,  187,    1,  744,  119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  619,   32,  166,  454,   45,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,  193,    1,    1,  202,  460,   12,    1, 1433,    1,\n",
      "            1,  111,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 453,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  93,  67,  45, 954,   1, 242, 297, 478,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  617,  259, 2382, 2945,  877, 2263,  105, 2368,    9,  947,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,    1,    1, 3280,  321,  612, 1838,    1,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1829,  393,   12,  172,  533,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1, 3006, 1523,   32, 1619, 2597,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  584,  171, 3284, 2803, 3288,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  851,    1,  548,  861, 2393,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  510,  891,    1, 2732,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2459,    1, 2163, 1110,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2587, 2069,  125, 2193, 3016,    9,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3406,   32,   12,    1,    1,  190,    1, 3357,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299,  839,  286,  293,  287,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,    6,  197, 1470,    1,  159,  832,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1976,   32, 1212,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1228,  210,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    5,  125,    1, 1465, 1466,  354,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   60, 1042,   98,  448,  122,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2507, 3190,    1, 1710,   52,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1601,   45,    7,  695,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1369,  884,  172,   44,    9,  572,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1822, 2370,    1,  191, 3027,   12,    1, 2585,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1687, 1022,    1, 3008,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3018, 2232,   37,  606,  786,  659,    9, 1744,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    6,  570,   88,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  853,  538,  852,   37, 1344,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3209, 1245,    1,  884, 1463,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,    1,   39,    9,  547,  257,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  921,  104,  160,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2602,    1,    1,   32,  915,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,    1,    1,    1,   37,  872,   28,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1661,    1, 1178, 1550,  990, 2650,  134,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,  830,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   69, 1276, 1315,  187,  531, 2014,  418,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649,    1,  685,    1,   45,    1,  823, 2745,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2745,    1,  224,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3161, 2776, 1739, 1090,   37,   16,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  647,   82, 1366,  190,  193,    1,   32,  856,  444,  148,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,  810,  105, 1090,    9,   10,  951,    1, 2275,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1380,    1,  680,  903, 2036,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789, 2313,    1,    9,  472,  312, 1108, 2606,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2339, 1108,    1,  111,  161,  133, 1551,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  104,  673,  910, 1052,   32,  367,  684, 2358,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  105, 1090, 1667,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1718, 1586,   28,  128,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  398, 2450,   37,    1,  400,   32,    1,  636, 1939,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2737, 2226, 2556, 3311,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,  446,    1,  740,    1,  863,  190,   52, 2827,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1853, 1557,    1,  601,  477,   32,  105, 1034,    1,  101,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2467,  860,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2597,    1, 2696, 2572,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1178, 1475, 2332,  176,  395,   36,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  939,  187,  582,   45,  166,  395,   12,  622, 1984,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 1877,   37,  221, 1750,    1,  269,   67,  115,   45,  517,\n",
      "         1953,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  985,    1,  297,    1,  215,   12, 1861,  920,  762,    1,  443,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1808,   37,  693, 1972, 1821,  541, 1353, 1159,  111,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314, 1692,   82,    1,  939,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  632,    1,    1,    1,    1, 2137,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   37,    1, 2336, 1643,   17,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  328, 1528,   32,   46,   37,  151,  215, 1093,  574, 1039,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403, 1447, 1800, 2868, 2784,   37, 1033,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1292,    1, 1564,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,  197,  418,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2802, 1631, 1632,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118, 1512,  920,    1, 1056,   59,    1, 1428,  716,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  877,  400,    9, 2275,   32,  451,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  519,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  750, 1560,    1,  293,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2090,    1,  716,  417,  572,  156,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   61, 1231,   28,  202,  321,  612,    1, 1771, 1022,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1633,  325,  212,   50, 2552,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,  851,    1,   55,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1059,   28, 1924, 1745,   32,  424,  437,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,  849, 1992,  138, 2349,  449,    1, 1421,  166,  132, 2248,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1317,  704,  104,  353,  581,  401,  197,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2217,  446, 1082, 3072,    1, 1232, 1277, 2437,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2830,    1,  536,  105, 1264,  889,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1783,  884,  686,   98,  104,  358,  467,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193,    1, 1542,    9, 2218, 1772,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1994,  104, 2001,  193, 1167, 2474,    1,  267,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1587,  661,   98,  567,  666,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  502,  492, 1418,  384,  934,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3406,   77, 1075,  548, 3349, 2625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2114, 1713,  437,    1,  365, 2723, 2724, 1935, 2294,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2533,  484, 1961, 2191, 1411,  339,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  511,  640, 2041,  548,  422,  754, 1090,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1990,   37, 2460,   79,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1034,  590,    1, 1090,   15,  103,    1,   59,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  515, 3304,  105,   92,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1497, 1417,    1, 1631,  917,   38,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755, 1867, 2355, 1013,  327,  593,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1181,  572,    1, 2869, 2871,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  460,   32,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  244,  565,   28,  176,  654,  361,  320,    1,  460,  267,    1,\n",
      "           61,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 2414,    1, 2766,   32, 2597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1889, 1108,  166, 2884,    9,  105, 2500,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545, 1831, 1216,    1,    9, 1178,  787,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  228,    1,    1, 1380,  691,   32,  674,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968,  550,  649, 1009, 2770,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094, 2061,   98,  220, 3339, 2731,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   63,  166,  862,    1,  159,  242,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1677,  361,    1,   45,  749,    1,    1, 1125,   98,  365,  229,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12,    1, 2492, 2232,  614,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  648, 2554,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,   37,    1, 2419,   55,  259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  388,  984,  987,    9,  493,  679,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,   37,  429,   46,  220,    1,    1,    1, 3144,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  938,  551,  730,  361,    1,  191,  163,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  635,  244,   37,  720,  191, 1056,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  326,  956,    9,    1, 1108,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   73,    1,   98,  505,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1773, 1830, 1981, 1539,   45,  365, 2480,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3070,    1,    9, 2966,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,   37, 2225, 3327,  365,  582, 2565, 1970,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,   79,    1,   54,   32,  531,  734,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1542,   37, 2274,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  133,  134,  135,  136,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2291,  176,  434,  778,  176,    1, 1325, 2414,  176,  177, 2144,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1, 1661,  207,  418,   37,    1,    1,  131,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  244, 1150,  548,  287,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  700,  475,   32, 1053, 1211,   98, 1368,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  259,  754,  361, 1000,  166,  454,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1183, 2113,  560,  347, 1124,  995,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  623,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3160,    1,   85,    1,    1,  191, 2518,    1, 2948,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,  197,  716,   37,  817,   98,   25,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  691,   12, 2802,  928,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,  794,    1,   32,  166,  215,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,  785,  786, 2886,    1,   37,  930,  384, 1938, 3197,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2891, 2372,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,  671,   32, 2890,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3110, 1918,  297, 2628,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296,  162,   57,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,   98,    1, 1097,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1024,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  612,  508,    1,  506,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497, 2075,   81,  384,  354,   37, 3250,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 305, 243, 682, 548, 646,  29,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 739, 242, 197,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3051, 3396,    1, 2083, 1428, 1953,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1310,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1628,    1,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3146,   45, 1256,  551, 2196, 1816,  190,   52, 2084,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  163,    1,   12,    1, 2548, 2572,  191, 2596,   32,  531,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   28,  191, 3117,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   51,  125,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  251, 2176,  105,  454,   37, 1334,   98, 1171,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1211, 3025, 1484,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1166,   12,    1,    1,  104, 3164,  267,  484,   37, 2553,   39,\n",
      "          193,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2925,    1, 1436,    1, 1515,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,    1, 2812,  892,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   93, 1071,  525,   15, 1269,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1,  449, 1663,    1,   32, 1876,   45,  104,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1963,   90, 2746,   37, 1604,   98, 1521,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3262, 1831,  958,    1, 1013,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  446,  590,    1,   32,    1, 2322,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,    1,    9, 2527,  164,    1,  384, 1088, 2611,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  326, 2806,  911,  220, 1211,    1,    1, 2973, 1764,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  884,  296, 2096,   37,  397,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  273,  730, 2614,  872,  420,  385,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1504, 2477,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2321,    1, 3220,  548, 2148,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1407,  129, 1333, 1530,   32, 1785, 1633,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  704,    1, 3330,    1,  552,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  696, 3316,   37, 1918,  444, 3176,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  866, 1283,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   18,   28, 1139,   98,  286,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1643, 1644, 1380,   79,    1,  837,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   32,   46,   37,   47,  280,  176,  425,  426,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,  344, 2950, 2414,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    9,    1,  864,   12,  396,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2459,  153, 2363,    1,    1,   45,    1, 2437,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1084,    1, 2094,  458,   81, 1159,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2742, 2764,    9, 3258, 2579,  449,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226,    1,  166, 1973,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  705, 1458,  606, 1752,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  548,    1, 1844,  631,  444,  854,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3021,    1,  140, 2977,   24,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 1288,   37,  949, 1920, 3082,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  810,    1,   37, 2752,   12, 1633,  439, 1120,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  202,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1012,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1047,   12,    1, 1236,  458,   45,  507,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3153,    1,    1,  808,   32,  863,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,  884, 1003,  176, 2608,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2472,    1,    1, 1988,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3076,   37, 2192, 2177,    1,  378,  501,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1564,  268, 2366, 1211,   45,   44,    9, 1972,  815,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   89,  267,  104,    5, 1511,  972,   37,  289,   98, 1633,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,    1,   39, 2546,  220, 1230,  328,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,    1,   79,   98,  683,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1229,   37,    1,  647,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  768,  756, 1707,  829,    1,  768,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1363,  891,  517, 1273, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  802, 1641,   37, 1994, 2086, 1896,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   12,  507,  794,  605,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,    1,  812,    1,  187, 3176, 1493,    1,  402,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2994, 1249,   59, 2610, 1757,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1555, 1090,  959,  297,  176, 2916,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2692,  697,    9,  119,   15,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2605,   32,    1,   45,  294, 2717,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 1086, 2237,   37,  717,    1,  458,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  515,  543,   98, 3107,    1,  202, 2605,  565, 1111,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307,  794,  365, 2382,  259,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  275,    1, 1310,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1497, 2497, 3384,    1,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,    1,  161,    1, 1108,    9,  333,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  446, 1070,    1,   37, 3159, 1730, 2109,   98,  463,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868, 1484,    9, 2708,    1,   37,  439,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   39,   37,    1,   28,  166, 1394,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3140,    1,  284,  861, 1414,   32, 1430,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  561,  574, 2341,  161,  934,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  227,  550,  590,  550,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,  284, 1737,  901,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343,  162, 2162,    9, 3091,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2031,   12,    1,  108,   45,   26, 1039, 1264,  539,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193, 2398,    9, 3297,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,  220,    1,    1,  275,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2137, 2856, 1312,   32, 2597,   12,  501, 2060,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  749, 2129,   37,  194,  503,  156,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2388, 1572,  191,    1, 1056,    1,  361,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2924,  489,   39,  384, 2299, 2060,  548,    1, 1345,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 3369,    1,  187, 3148,    1,  952, 1632, 1428,  927,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2919,  297,    1,   12, 1656,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3215, 2934,    9,    1, 1198,   37,    1, 2741,  913,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2250,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  705, 2796, 1289, 1021,  886,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1216, 1953,  220, 3103,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  105,   85,   60,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1492,  544,  334, 2518,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3332,  361, 3113, 1710,   52,    1, 1232,  460,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1181, 2914,  845,    1, 1521,    1,    9, 2382,  618,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537,  947, 1385,   28, 2774, 2892,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  891,  220, 1450,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3248,  914, 1258,  453,    1,   32,  938, 2454,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2335,  487,    1, 2844,   32, 3113,  336,  298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  971,    1, 1976,  176, 2335, 2504,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  680, 2523,    1,    1, 1809,  284,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,  421,    1, 1200, 1237, 1842, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  350,    1, 1564, 1022, 1017,  574,  209,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1379,    1,   33, 1658,  178,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  786, 1034, 1159, 1756,  590,   46,    1,  590, 1647,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2833, 2890,  336,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  180,    1,    1,    1,   59,  180, 1749,  159,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,  854, 2018, 1651, 1662,    1, 2024,  226,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,  884,  105,  633,   84,    1,  140,  327,   45,  647,  159,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162, 1950,   32,  463, 1033, 2817,  640,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1817,    1, 2746,  753,    9,  388, 1695,  294, 2591,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325, 1204,    1,    1,  440, 1341,    1, 2166,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  386,   37, 1140,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  917,    1,  865,   37,  511,  540,  411,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  215,  398,  868,   39,  119, 1080,  798,  444, 2013,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978,  769,   79,    1,    1, 1198,  185,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   49, 2145,   37,  138,    1,  131,   32,    5,  734,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 2414, 3375,   32,  183, 3339,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  117,    1, 1231,    1, 1469,    9,  590, 1604,    1,    1,  290,\n",
      "         1373,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3233,    1,   61, 1866,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1243,   45,  299,  182,  302,   37,   10,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  684,  765,   37, 1911,    1,  734, 2010,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1613,  200,    1, 1101, 1027,  612, 2419,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1689,  829,  861,  469, 2405,    9, 3018,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  321, 2379,    1, 2446,  166,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2529, 3087,  640, 1850,  455,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,  859, 1896,   32,  856,  444, 2834,    1,  926,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  384,  166,  984,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3140,   98, 2731,  187, 1094,  488,   37,    1, 3389,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  861,    1, 1608,  361,  920,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1122,  538,  614,  111,  918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  754,   61, 1166,  166,  764,    1,   61,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2452,  517,  885,  552,  384,  166, 1230,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  638,    1, 2952,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1584,  166,    1, 1174,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1419,  365,  825,    1,  792,    1, 1230, 2102,  792,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2347,    1,    1,   39,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2494,  872, 1354,    1,    1,   32, 2826,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   21, 2707,   37,    1,  132,   98,    1, 1282,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  449,   95, 1463,   45,  365, 1461,  750,    1, 1464,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 3400, 1554, 1583, 1967,    9,  365, 1204,\n",
      "           32,  455,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  187,  978,    1, 2567,    1, 1160,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1053,  159,  439,  242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  191,    1,    1,    1,  446,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2883, 1360,  612,    1,  103,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1492,    1,    1, 1919,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    9, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1009,    1,   32, 1619,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485,  140,    1, 1940,   12, 2472,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  121,  315,   37,    1,  220,   49,   69, 1611,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  744,  365, 1653,   98,  889,  529,  509,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3340,    1,  820,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111,    1,  489,  590,    1,   98,  163,    1,   12,    1,  863,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  671, 1078,  253, 1822,  360,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  977,  565,  604,  977,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1739,   37, 1046, 2388,   32, 1022, 1672, 2771,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,  719, 1851, 1394,    9, 1477,  726,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1279,  977,    1, 1728,    1,    1,    1,   18,   45,  823,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  872,    1,    1,   45, 1756,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1107,  293,   37, 1753, 1479,  912,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  556,  142,  191,  104,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  921,    1,    1, 1022,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1, 1536,    9, 2240,    1,  607,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3281,   12, 3181,   79,   37,  105,    1,  187, 3116, 3314, 2250,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  780,    6,    1,  223, 1639,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1479, 1064,  288,    9,    1,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,   27,  119,  845,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1861,   37,  429,   46,  220,   10,   32,  316,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  256, 1663,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2843,  267, 1763,   32,  166,   27,  627,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  504,   66,   32,    4,    1,  202,  193,  223, 2135,  408,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 1140,   61,  824,    1,  166,    1,   61, 2025,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  666, 1491, 2291,  396,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2182,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3245,  967,    1,    1,   32,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3209,  688, 3260,   37,   23, 1524, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700, 3375, 2572,   32, 3339,   22,  868,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2068,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  942,  300, 1132,  384,    1,   37,    1,   37,  764, 1897,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  594,    1,  361,    4,    9,  207,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116,    1,  693, 1211,  777, 1821,   37, 1468, 1658,  778,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2307,   12,    1, 1292,   61,  105, 3252,  220, 1090,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91, 1489,  104, 1002,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2962,  978, 3138,    1,  191, 1700, 3299,  384, 2615,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  376,  163,    1,   12,    1,   15,  570,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1645, 3365, 1623,    1,   98, 2968,  290,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 1234, 2308, 2222,  714,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  307,  916,   37,    1,  375,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2960,    1, 3376,  115,   45,  890,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3068,  220, 2733,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  680,    1,  548, 2970, 2357,  444, 1887,   45,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  590,    1,  548,  538,  170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2267, 1944,   98,    1,    1,   45, 2107,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   45,    1,    1,    1,   45,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3087,  176, 1687, 1022,    1, 3008,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,  700,  951, 1547,   98,    4,  550,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  123,  242,  115,   45,  224, 1126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1028, 2707,    1,    1,    1,  361,  166,  342,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3205,    1, 2771,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  581,   98, 3172, 2709, 1638,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327, 2767,    9, 2893,  776,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3160,  162,  537,    9, 3402, 3408,  966,    1,  104,  622,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  756,  757,  929,    1,   82,    1,  939,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018,  321,  168,  810,  166,  454, 1632,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,  582, 2498,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1796,  619,    1,    1,  220,    1,    1, 2873,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  138,    1,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 2743,  236,  537,   98,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1581, 3358,   12, 1983,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2202,    1,   32,  288,  354,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181,  361, 1545, 2827,   37,  754, 1908,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  837,    9, 1412,  844, 1605,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   59, 1350,  599,    9, 1102, 1151,   13,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 2188,  973,    9, 2301, 2012,  327,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2576,  361,    1, 1654, 2545,  187, 1186,   12,  103,    1, 1885,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  236,  237,  162, 1198,  384,  479,  157,    1,    1,   79,   69,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  160, 1161,  188,   32,  367,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  429,  430,   69, 2152,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2605, 2286,   37,    1,   85, 1477, 1990,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2522, 2871, 1022,    1, 2296, 1625,  364,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  321,  612,  713,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1095,   37,  151,    1,    1,  150,    9,  152,   32,  987,  361,\n",
      "          225,  328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 2132,    1,    1, 1440,  171,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  579,   12,  166, 2084, 1787,    1,    1, 1710, 1046,  187,  104,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3322,  877,  105,  320,  320, 1473, 1159,  449,  913,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1106, 1107, 1781,   32, 2144,  219, 2064,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  206,   12,  207,    1, 1944,    1,  202,  159,   71,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2353,    1,   32,  525,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978,  769,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2668,  202,  395,    1,  384,  593, 1990,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463,  507,  952,   37,    1,  166,  593,   12, 2601,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2006,  350,    1,    1,  661,    1, 1021,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1475, 1469,   98, 1279,  977,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,  766,    1,    1, 1183,  472,  468,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,   37,  981, 1636,    1,    1, 1074,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2982, 2139,  220,    1,    1,    1, 2604,  889,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  395,  945,  494,  946,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1924,  105,    1,   23,   32, 1645,  195,  170,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3244, 1403,   32,    1,  187,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3141,   37,  288,  365,    1,  861,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  159, 1174,  605,   98,  329,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  612,    1, 2902,  125,  102,   98,  116,   19,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043, 1086,   85,    9, 2073,   74,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1085,  159,  245,   98,  572,  932,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3253,    1, 3173,    1,   98, 2410, 2539,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1091,  458,   98,  845,  275,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2347, 3204, 2257,   39,   45, 2442, 2630,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  104, 2673,    1, 1921,   32,  447,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  612, 1273, 2090,  387,  845,  846, 1074,  537,   79,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1178,  513,  514,   32,    1,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   37,  138,  331,   37,    1,  875,  573,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  792, 2603,  792,  166, 1357,   45,  166,  356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1,   32,  220,  365,  844,  275,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1022,  197,  570,    9,    1,  294,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  921,  166, 2819,  922,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 3397, 1894,  600,  861, 1906,   46,   98, 3369,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3266, 3079, 1090, 2052,  191, 2620,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  103, 2597,  232, 1333, 1530,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 2924, 2856, 2708, 3006,  178,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  810,  809,   26,    9,  107, 1953,  864,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1305,  225,   85,  548,  156, 1306,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2,  81,  37,  36, 994,   1, 150,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 515,   1, 542, 105,   1, 943,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,    9,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  197,   98, 1017, 1278,    1,    1,    6,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  219,  159,   28,   98,   65,  591,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,  140,  768,   43,  444, 1361,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1245, 1654,   37, 1957,  202, 3332, 2951,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779,    1, 3064, 2139,   37,  726,  176,   26,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   79,   37,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3318, 2555,  885,    1, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035,    1,  220,    1,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  635,   12,  244,   37, 1673,  331,  686,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  551,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  396,  311,  199, 1876,    9, 1718, 1273,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1896,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2477,   12, 1567,  619,  631,    1, 1911,  183,  786,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,  622, 1017,   32,  531,  443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144,    1,    9, 2823,  741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2741, 1912,  686,  191, 1674, 1559,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 2472,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,  313,  340,  220,  365,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2698, 1188,   37,    1, 1089, 1675, 2221,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3151,  542,  619,  105, 2724,   45,  753,   32,    1, 1756,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,  356,  452,   49,  582, 2263,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  186,    9, 2596, 1786,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  504,  185,  115,  202,    1, 2088,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2962,    1, 1585, 1086, 1449, 1844,   32, 2916,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3093,  361, 2516,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3077,   61, 2213,   37,    1,   12, 3269,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327, 3191,  726,    1,    1, 2857, 2827,  191,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1617,   32,  105,    1,  297,    1, 2225,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746,    1, 2903,  199,  191,    1,  199,    1, 1729,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3088, 1731,  176,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1363,   37,  332,  613, 1074,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  664,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1815, 2537, 1360,  612,  168, 2017,  220,  284, 2924,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 326,   1, 365, 192,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 709, 758, 103, 710,  37, 582, 698,  28,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  449, 1675,  951,    1, 3251,  190,   52,  176,  104,    1, 2498,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,   45,  523,  961,  290,    1,  978,  769, 1159,  166,  730,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3192,    1,  884, 2318, 1509,  187, 1364, 1365,    1, 2018,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437, 1484,   98,  561,   37,    1, 2501,  861,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  176,  915,    1,  829, 2055,  166, 1107,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 3111, 2572,   32, 3155,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2464, 1108,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2616,  546,  586,  297,    1, 1867,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2339,  715,    1,   32, 1966, 1631,  356,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503,   37, 1418,  749,    1,   45,  985,  762,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  996, 2521,   91,  176,    1,   45,  105,  458,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  613, 1017,   37,  413, 1842,    1,    1,  657,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1651, 2122, 1929,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,  417,   32,   29,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   10, 1008,  365, 1943, 2541,    1,   21,   37, 1031,  996,  872,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  829,  398, 1484, 2050, 1953,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1286,    1,  453,  207,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433, 2466,  952,   37,    1, 2824,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  848, 2371,  614,   98,  333,   32,  455,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2909, 2856,   32, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  742,   12,  386,  142,   32, 1820,  548,  332,  701,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  619, 3358,   12, 1983, 2078,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  596, 1151, 2287,   15,   66,   85,    1,  419,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2157,  529,    1, 2684,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 971,  37, 125, 487,   4,   1, 474, 267,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  25,  66, 242, 187,  69, 102, 470,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  225, 1476,  977,    1, 1103,   32,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  116, 3005,    1,    1, 1592,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2292,  571,   37, 3360,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3365,  820,  191, 1147, 3125,  202, 2292, 1258,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428,  741, 2007,   98, 3140, 3146,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   69,  532,  125,   32, 1023,  548, 1260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1963,   37, 2746, 2000,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1448,    1,  640,    1, 2152,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  224, 1201,    1,  267,  453,    1, 1300,  159,  565,    1,  176,\n",
      "         2021,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,    1,    1,   37,  976,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056,  275,  681, 1192,  191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2263,    1, 3209,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  387,  932, 1139,   45,  837,  187,   72,  401,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2948, 2223, 2864, 3001,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1529,  967,  611, 2113, 2536,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1164,    1,  864, 1980,   37,  759, 2390,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,   71,  118,    1,  185,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  104,  851,  856,   51, 1594,   37, 2024,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   67, 1374,   51,    1,   65,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1360,  612, 1413,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  167,   52,    1,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1227,    1, 1377,  891,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3323,  335,  449,  401,  631,  297, 3285,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 1818,  147, 1579,    1,  370,  409,  170,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1720,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  369,   50,   37, 1706,  331, 2097,   32,    1, 2152,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  200,  365, 2800, 1131, 1008,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1221, 1924,  590,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1110,  912, 2730,  149,  444,  787, 1107,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1874,  854, 2018,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1866,   79,  411,  187, 3143,  798,  449,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,  166,  207, 2325,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962,    1,    9, 3330,  187, 3260, 2712, 3233,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  794, 1021, 1718, 2232,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  297, 2572,   32, 1656, 2950,  176, 2597,  947, 2190,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  305,  832,   98,  303,   69, 1470,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  572,  197,  307,  689,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3330, 2803, 3078, 1897, 3260,  726,  297, 3233,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2751,  477,   63,  104, 1260,   98, 3391,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  792,    1,    1,  792,    1, 2500, 3020,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2391,  845,   69,  636,   85,    9,  105,  581,   74,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1617,  738,  539,  176, 2643,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   64, 1554, 1700, 1530,   32,  447,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  531, 3373, 1752, 1816,   32, 1708,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1564,    1,  714,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1861,  515,    1,  531,  516,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  648,   12,  582, 1924,   98,  647,  222,    9, 2119,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3388, 1489, 2868, 2237,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2310, 1567,    1,  396,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2925, 1090, 1829, 2163, 1497,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 2896, 1409,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3300,  619,  110, 1694,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1,  163,    1,   12,    1,  442,  850,  297,  851,  630,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2087,  433, 2710,  639, 2141, 2095,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  996,   93,    1,   98,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  833,  612, 1807,  105,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1824, 1364, 1365, 1917, 3184,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1820,   98, 2467,   45,  903,    1, 1973,  132,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537,  446,  251, 1815,  228,  131,   60, 2024,   92,  187, 2924,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,  176,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  350,    1,  921, 1204, 2948, 2788,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3016, 1935,  682,  547,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3099,   12, 1994,    1, 1027,    1,  496,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1252, 2807,  872,  420,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  182,    1, 1417,    1,    1, 1685,  134,  548, 1571,    1, 2572,\n",
      "           32,    1,  129, 2578,  963, 2122,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,  967,    1,    9, 2390,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1379, 1310,   37,  222, 1503,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   39,   45,    1,  298,    1,   12, 2789,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  865,   37,  147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,   95,  473, 2287,   28,    9,  477,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  762,    1,  395,    1,  220, 1854, 2180,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2425,  546,   28,    1,    1,    9,  999,  681,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,   37, 1706,  152,   32, 2662,  250,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3065, 1411, 2009,    1,   61,  810,  166,    1,   32,  507,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   16, 2349,  171,    9, 3237,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   61,  311,  105,  311,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1477, 1990,    1,    1,   37, 1918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  121,  190, 1348,  453, 2673,  626, 2532,  220,  864,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   22,   23,    1,  829,  361, 1128,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  733,   28,  649, 2456,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  933,  934,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1, 2842,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1464,   98, 1821, 2190,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2203, 2475,  688,  166,    1,    1, 1224,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   74,  786,  614,   37, 2620,    1,  691,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2, 104, 580, 119,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1,   1, 753,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  311, 2936, 1293,   32, 2589,   45,  650, 3123,   32,  166, 1050,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2284, 3049,    9, 2994, 1071, 2993,  778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1931,  460,  190, 1734,    1,  267,  171,  729,  719,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584,  460, 1132,    1,  275,  719,    1,    1,    8,   32, 1177,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  295, 2192, 1804,    9, 1697,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2652,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2877,   12,    1,    1,  820,  191, 3125,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1304, 1229,   37,  875,  422,  549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3297,   12,    1, 2422,  332, 1381,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2343,   12,  103, 3404,  439, 1011, 1313,  104, 1583,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 3134, 3009, 2651,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3010,   12,    1, 2424,  166,    1,   37,    1,    1,  361,  627,\n",
      "          852,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1122, 1564,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2304,    1,    1,  967, 2487,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3117, 2712, 3260,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  606, 1176, 1744, 2375,    9, 1305,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 3022,    1, 1965,    1,    1, 1821,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1877,   37,  686,  166, 1567, 2290,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1458,   39,   45, 1126, 2973, 1764,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2835,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2835,  700,   37, 1706,  152,    1,   32, 1853, 1273,  259,  218,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,   12, 3359,  847,   28, 1876,    9,    1,  741,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  393,   21,  207,  354,   28,   37,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  753, 3237,  921,  247,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1530, 2496, 1976,   32, 2646,  147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  460,  190,  138,    1,  131,    9,    1,  596,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962,    1,    1,    1,  631, 3117,   37, 1918,  297, 3251,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,    1, 1567,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 2257,    1, 2924,  384, 1815,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2998,  584,  171,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   40,    1,  695,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  650, 2609, 2909,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   27,  119,  687,    1,  590,  517, 1876,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 2480,    1,  856,  460,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  565,  166, 1509, 1056, 2954,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1133,    1, 1134,  479,   12,  501, 1135,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  103, 2334, 2545,    9,  163,    1,   12,    1, 3004,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1924,  105, 1479,    1,  176,  183,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3238, 1114,    1,    1,  361, 1625,  204,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1433,  334,  894,  193,    1, 1658,  778,   98, 1013,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  438,  269, 1974,    1,    1,  133,  756,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 1674,    1,    1,    1,   72,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1191,    1, 1842,  357,  853,    1, 1543, 1167, 2474,  844,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 1230,   12,  183, 2068,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1256, 1256,  213,    1,   54, 1026,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  741,    9, 1009,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  244,   37,   52,    1, 1159,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    9,  503,    1,  105,    1, 2129,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  882,  159,  245,   98,  550,   45,   82,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861, 1164, 2123,   37, 1865,  786, 2446,  633,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    1,   26,  798, 1477, 1669,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  561, 2460,   79,    1,  160, 1708,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158,  315,  219, 1437,   45, 2102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  190, 1174,  117,    1,   32, 1312,   78,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2448,  386,  958, 3177,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,   26,  852,   37,  166, 2539,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1013,  951,    1,  861,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433, 1579,  302,    1, 2650,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1821, 2190,  719, 1588,  191, 1104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,    1,   37,  927,    1,   45, 2918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  865,    9, 2658,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1707,    1,  219, 1004,  297, 2673, 2426,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2104, 1082,  198,  304,   98,    1,    9, 1763,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1304,  353,  737,  354,  548,  422,  399,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  158,    1,    1,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3261,    1,    1, 2458,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  700,  884,  105, 1150,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1899, 1654,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 1546, 3284,    1,    1,    1,    1,  917,    1,   32, 1090,\n",
      "          444,  501,  827,  428,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,  879, 1318,  269,  693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  792,    1,  792,  776, 2055, 2198,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  707,  166,    1,    1,    1,   12, 2472, 3077, 1924, 2848,  872,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,  147,    1,    1,  612,    1,    1,  275,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1744,  920, 1406, 2141,  195,  190,   52,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  952, 2162, 1780,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 2924,  114,   37,    1,  557,  540, 2832,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,  444,   94,    1, 1547,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26, 1039,  357,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2754, 3102, 1683,   32,  531, 1621,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1635,  924,    1, 1268,  395,  756,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3335, 1544,  191,    1, 1563,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1412,  844,  302,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1057,  297,    1,    1, 1010, 2292,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  898,   37,  665,  453,  327,  112,   28,    9,  333,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1482,  217, 1084, 1563,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393, 2177, 2309,    1, 1496,  384,  467,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056,    9,  786,  333,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  606, 2015,   32, 2565, 1013,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3183,  103, 2672,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  826, 2845, 2741,  916,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  741,   10,    1, 1481,    1,   37,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 1861,  753,   37,    1,    1,  226,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 2612,   98, 2471,  220,  968,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3308,   44,    1,  548,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3355,  580,   97,  297, 2571, 2282,  722,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,  259,    1,  167,    1, 2322,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2379,    1, 2753,  166,  855,    1, 1748,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  162, 1133,   98,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  746,   37,  243,  453, 1604,   23,  118,  191,  166,  439,   45,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  346,   93,  570,   28,   32,    1,   85,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  709, 2774, 2137,    1,    1,  476,  854,   32, 2024,  226,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2597, 1656, 2596, 2414, 1312,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1994, 3036, 3037,    1,  163,    1,  903,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   37,  912,  400,  297,  296, 1859,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1425,  166,    1, 3271,  562,    1,   12,  132, 1632,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2190, 2640,  315,  365,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  200, 1718, 1021, 2168,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  744,  119,  202, 1710,    1,  606, 2941, 1569,    1,   12,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  111,  700,    1,  680, 1260,    1, 1261,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  135, 1081,    1, 1530,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 267,   1, 190, 726, 628,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 777, 818, 834,  28,  32,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  744, 1610,    1,    9,  627,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2496,   45, 1147, 2548, 1976, 1333, 1530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2629,    1,   37,  865,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  777,  550,  778,    1,   61,   28,    9,  333,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 2708,  954,    1,    1,  419,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  716,   77,  615,   98, 1285,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 1090, 1354,    1, 2085,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1895,  585,  894, 1121,   32, 1893,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  872, 2090,    1,  857,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3251,  542,  774,    1,  176,    1, 3283,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1789,    1,   12, 2193,    1, 2789, 1654, 1002,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2197,    1,   37,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  600, 3101,  650,    1, 3359,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1242,    1,    1,    1,  220,  221,   37,  853,  538,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1430,  765,   37,   77, 1009,   32,  756,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,  123,   28,    9,   72,   74,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  160, 1278,   28,    1,  118,   32,  871,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,  636,  720,    1,  783,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1139, 2113,  612,  302,  347,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,   12,    1,  140,    1,    1,   26,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,  837,  187,    1,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  295, 2145,   37, 1594,  297, 1168,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  923,  619,    1,   45, 1515,  248,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  361, 2018,   37,  907,  176, 1428,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2300, 3048, 2923,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  561, 1982,    1,  105,    1,   98,  923, 2405,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3315,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  844, 2495,    1,  572,  172, 2601,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  584, 3239,    1,   37,  183, 1343, 1262,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1742, 1408,    1,   45, 2433,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  296,  640,   81,  548,  104, 1536, 2118,  297,  219, 1859,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   84,   85,  548,  166,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1266,  159,    1,  187,   82,  796,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 1009, 1484,    9, 3406,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  455, 1259,   98,  844,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196,  155,  197,  157,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  716,    1,    1,    9, 1338,   45, 1647,   98,  460,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 1774,   39,    1,  340,    1,  327,   32,  395,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  754, 2567,  776, 2493, 2947,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  219,  379,  240,  484,   98, 1189, 2673,  210,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 3369,  193,    1,    1,   32, 3118,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1258, 1850, 3339, 2731, 1700, 2572,   32,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  758,    1, 1790, 1173,   37,    1,  777, 2943,   37,    1, 2417,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   83,    1,  654,   37, 1370, 1262,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2748,    1,  584, 1022,    1,    1,  548,   64,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  880,  546,  176,  433, 1166, 3045,    1,   37,   52, 1953,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1388,   45,  166,  275, 2807, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1994, 2095,  315,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   69,    1,  493,    1,   32,  531,   12,  463,    1, 2498,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  219,    1,   45,  166,  356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3359,    1, 3358,    1, 1004,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2677,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  183, 2326,   32,  818, 1090,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,   66,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1273,    1, 1173,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 1682,  176,  314,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1319, 1726, 1248,  365, 1705,   98,  442,   46,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3009,   18,   39,   37,    1,  176,    1,    1,  176,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 572, 197,  28, 191,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  68,  69, 123,  37, 119,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3252,  509, 2563,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,  117, 1708,  292,    1,  931,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  119,    1, 1980,   37,  907,  689,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1,    1,    1,  361,    1,    1, 2336, 2168,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  412,   37,    1,    1,  357,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2970, 1090,   12,    1,  338,   37,    1, 2099,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32,  298,   45,  487, 2702,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  874,  200,  365,  642, 2480, 1671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2261, 2819,    1,    1,    1,    1,   98,  166,    1, 1160,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649, 1821, 3027,  640,  433,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  506, 1243, 1273,  259,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,    1,    1,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3352, 2833,  104,  361, 1891, 3365,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,  686,  220,  241,   43,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 2764, 3394, 1928,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 1739,  113,   79,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612, 2116, 3226,   39,  415, 1724,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2828, 3159,    1,   37,  631,  437,  191,  547, 1394,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1,  187, 3181,  114,  411,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1625,   37,    1,    1,   12,    1, 3318, 1282,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2615,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,  664,  890,   32,   56,  715,   78,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  777,    1,    1, 2780, 1013,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  225,   98,    1,    1, 1721, 1894,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3052,    1, 1184,   32, 3187,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  758, 2035,   24,    9,  777,  378,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3106, 1086,  220,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835, 2137,    1,  191, 2267, 1900,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1663,  572,  197, 1137,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  786, 2847,  631,  176,  814,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1950,   45, 1530,  361, 2249,  384, 1157, 1177,  921,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2235,   66,  242,  202,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  379, 1152,   45, 3118,    1,  199, 2596,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777,    1,  649, 2456,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,    1, 2685,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1405, 1634,  215,    1,   32,  147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1963,    1,   98,  248,  548, 1857,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  244,   28,  225,  338,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3317, 1082,  542,   37,  619, 2072,  872,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1492,  794,    1,    1,   32, 2571, 2064,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  386,  952, 1018,    1,  131,   32, 1251,    6,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    8,    1,   45, 2996,   98,    1, 2432,   74,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3121,    1,  431,  455,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,   37,  865,   37, 1604,  548, 2133, 1857,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1211,  758, 2695, 2355, 1013,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  890,    1,  891,  892,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,   12, 1106,    1, 1108,   85, 2004,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   45,  507,   37,  125,    1,  388,    4,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   96,   85,    1,  214,  142,    1,   88, 1893,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160, 1278,  831,   32,  871,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2528,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144, 1557,  650,    1,  548,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  286,  293,  927,  614,  540,   37,  540,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 2122,    1,    1,    1,  421,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2988, 2690, 1564, 2997, 2762,  388, 2342,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2329,    9,  674,   45, 3088,  787,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  669, 1205,  191,  829,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1518,    1,  116,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   70,  402,   37,  888,    9,   25,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  188,   81, 1315,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1, 2264,  384, 1211,  970, 2549,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  581,  938, 2454, 1976,   32,    1,  454,   12,  656, 1821,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  818, 1697,   51, 1403, 1298,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2154,  591, 2456,    1,   32, 2785,  686,    1,  395,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1529,   51,   52,  258,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  191,  957, 1563,    1,    1,    1, 2255,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   30,  459,   45, 1376,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 2688,   32,  531, 1366, 1558,   98,    1,    1,    1, 1941,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1147,  863,  288,    9,  740,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  560,    1,   93, 1071,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  129,  975, 2073, 1023,  197,  418,   98,    1, 1011,   15,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   25,   28,  548,  198,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1211,    1,    1,   32,  968,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  936,  704,  705,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   60, 1993,   28,  548,   94,    1,   85,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,  565,  729, 1573,  548,  810,    1,  537,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2246, 3226, 1231,    9, 1345,  542,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1,    1,    9,  829,  185,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  657, 2540, 1100,   32,  147,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359, 2446, 2095,  361,  943,    1, 1886,   63,  522,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  479, 1205,   32,    1, 2009,    1,  798,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3061,    1,    1,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056,    1,   32, 2573, 1010, 2527,  164,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3252,  850,  608,  593,   12,  103, 1863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  947,  588,    1,    1,   32, 3141, 2811,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3236,    1, 2257, 1387, 1312,  640,   45, 1479,  922,  119,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   49,  333,  121,    1,  104,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3176,   32, 1909,    1,  187,    1,  477, 2783,  726,  444,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  284,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  844, 1468,  405,    1, 1988,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2962,    1,    1, 2615,  191,    1,  597,  872,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,  556,  147,   98,  543,  400,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1718,    1,  565, 1735,  386,   12,   38,   39, 1114, 3000,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3052,  804, 1114,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1342,  365, 1300, 2054,  582,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  813,  754,  757,  280,  220, 2392,   45,  432,    9,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  894, 1292,    1, 2844,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,    1,  716,   45, 3086,    1,   32, 3114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 294, 155, 157,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 105, 469,   9, 104, 626, 861,   1,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1140,   98, 2349,  640, 2101,  786, 1569,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   66,  526,  646,    1,   69,   29,   32,  289,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  541,   37,    1,  877,    1,   45,  166, 2391,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   37, 1075,  906,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  315,  166, 1411,  183,  789,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1256, 1256, 2660,    1,  372, 1259,   37,  151, 1026,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  877,    1, 2709,   32,  537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,   28,   37, 2308,    1,    1, 1247,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  335,  297,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  401,   45,  539, 2170,    1, 1592,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1138,   37,    1,  327,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1380, 2698,   98,    1,  600,  365, 1089, 1090,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2967, 2347,   32, 3152, 2138,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  398, 1707, 1708,  518,  261,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2536,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3362, 2892,    1,   32, 3349,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  852,  176,    1,   32,  365,  280,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,   91, 2390, 2362,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,    1,   20,  498,   37,  211,  851,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  102,  245, 1010, 1057,   45, 1115,    1,   32,  395,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843,    1,   79,    1, 1505,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,  435,  282, 2367, 2695,    1, 1718,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2137,    1, 1056,   32, 2490,   12,  463,  105,   74,  548,\n",
      "         1603,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1472,    1,   85,    1,   32,  913,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2073, 1479, 2164, 1414,    1,   32, 2433,  455,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1465, 1466,   42,  134,    1,    1, 2430,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741, 2579,   37,    1,  548, 3184, 1086,  535, 1281,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2733,   12, 3068,  251, 1211, 1484,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   37,  949, 2693,    1,    9, 1778,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2569,  195,    1,    1,   37,  163,    1,   12,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1963,  902, 1940,   37,  619,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  548,    1,  333,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,   74,    1, 1517,    1, 1352,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   37, 2677, 1013, 1522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504,  446,   37, 2653, 1833,   98, 2832, 2705,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3066,  162, 1322,   45, 3242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 2711,    1,    1,    1,  565,   32,  105,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  104,  358,   46,  220,  359, 1686,  474,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   34,    1,  236,  237,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3256,  331,  855, 1082,    1,    1, 3280,   37, 2286, 1114,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  655, 1713,  654,  721,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,    1,  837,  489, 2054, 1159,  730,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1766, 1767,    1,    1, 1119,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3278, 1564, 1064,   37, 2788, 1294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2499, 2094, 2349,    1, 2406, 2885,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  597,   20, 1644,  513,  514,   32,   24,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3263,  297, 1957,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3343, 3345, 2035, 1757,   37, 2675, 2539,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2037,   98,    1,    1, 2236,  162, 1354,   45,  522,  176,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,    1,    1,   12,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1762, 3316,    1,   37,   77,    1,   98,  166, 1737,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  116,  844, 1310,   37,  168,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  214,  142,    9,  634,  635,   12,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 1417,    1, 2855,  543,   37,    1,  886,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178,    1, 2736,   12,    1,    1,    1,  187, 3091,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1824, 1412,  844, 1921,   98, 1273,  618,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  384, 2347, 1638,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1486,    1,  387, 1488, 1890,  115,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2713,  176, 2197,   16,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151,  782,  753,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  199,    9, 2565,   37, 2760,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614, 2192,    1,  885,  356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2218,    1,  187,  395, 1830, 1938, 1674, 2175,   39, 2789,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283, 1385,   28,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1968, 1654,  768,  400,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3128, 2128,    1,  193,  972, 2191, 3361, 1032,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  580,  537,  611,  297, 2282, 2564, 1634,   37,  813, 3342,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708, 3006,    1, 3339, 2831,    1,    1, 2856,  547,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1774,  254, 1977,   37,    1,  297,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  617,  259,   15,   77,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  581,  916,   98,    1, 1292,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3286, 3009,  187, 3211,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1345, 1258,   32, 2646, 1010, 3346, 2426,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  794, 2154, 2731,   98, 2597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1905,   37,   52,  650,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1234, 2308,  288,    9, 1479,   93,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2862,   12,  446,  792, 1724,   37, 1761,  792, 3351,    1,   12,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  132,    1,   20,    1,  420,  267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  310,   25,  470,  548,  395,   67,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  256, 2603, 1013,   37,  365, 2524,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 2036,  517, 1074, 1781,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102, 1826,  995,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  393,    1,  359,  759, 1845,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,   92,  148,   32, 2670,    1, 1523,    9,  647,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  191, 2613, 3334,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 3249, 2317,    9,    1,  478, 1343,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  132,   37,    1, 2245, 1390,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1, 2873,    1,    9,    1,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  242,    1,  102,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  700,   98, 2924,  548,  531, 3102,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  443,  361,  105, 2919,    1,    1,  164,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,    1,  220,  105,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  113,  530,  109,  509,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  497,    1,   37, 1636,  861, 1906,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  171, 1976,   37,  138, 2025,    9,   36,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  891, 1183,    1,  176, 1477, 1990,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2055,  187, 3181,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  811, 1862,  528,    1,  996,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2376, 2024,    1, 1484,    9,  105,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,    6,   69, 1069,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  760,    1,    1, 2306,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1226, 1159,    1, 2759,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3155,    1, 2450,   37, 1195,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  613,  469,    1, 1109, 1110,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3398, 1564,    1,  471,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  446,    1,  650,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  705,    1,    1,  387,    1,    1,  104, 1239,  242,   32,  572,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   37, 1075,   98, 1282,    1, 1657,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1100, 1419,  365, 1273,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1716, 1320,   61,  460,    1, 1530,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2658,   45,    1,    1,  614,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3087,    1,    1,    1, 1114,  590, 3307,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2412,  665,   28,    9,  333,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1236,  749,    9,   13,    9,    1,   12, 2162,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  267, 1360,  612,    1,   37, 1220,   45,\n",
      "         3345,   32,  531,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  259,  669,   37,  125,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 2693,    1,  187, 3050,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018,    1,    1,  140,    1,    1,  384,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1794,    1, 2949,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1,  746, 2035,  956,    1,  469,  365, 1085,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  566,   98,  347,  220,  863,  297,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   64, 2414,  297,   32, 3349,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2114, 2884, 1313,   96, 2970,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  773,  317,    1,  818,   15,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094,   12,    1, 1980,   37,    1, 3374,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  561,  543,   37, 2460,   32,  331, 2021,    9,  479,\n",
      "          182,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2415,    1,   39,   45, 2340, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  241,    1,    1,   12, 1628,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1986,   98, 1815,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1574,    1,  297,  121,   36, 3071,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1413,   32,   98, 2081,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584, 1070, 1433,  320, 1744,  585,  424,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 3373, 1976,   32,    1,   45,  632,  880,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  104, 1141,  665,    1,   98,    1, 2476, 1188,    1,   45,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  942,  446,  267, 3349,  863, 1822,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,    1,   49,  159,   32,    1,   69,  669,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  200, 1499, 1228,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  861,   12, 2798,    1,    1,    7,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2871,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2161,  193,  187,    1,  187,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  852,    9,    1, 2007,  127,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  319,  163,    1,  903,    1,  317,   37,  865,   37,    1,\n",
      "            1,  428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  242,    1,  243,    1,    1,  244,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  493,  633,  462,   37,    1,   32,  632, 1611,   45,    7,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163, 1741,    1, 3272, 2142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810, 3065,    1,  872,  933, 1089,  772,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2743,    1, 2748, 1817,    1,  608,  511,  275,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1625,    9,  198, 1838,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,    1,   37,  907, 1220,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,   32, 2637,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2415,  105,  365,    1,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1325,    1,    1,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275,   12, 1513,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,  267,    1,   61,  227,   32,    1,   28, 2510,  378,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,  116,    1,   98,  166, 2009,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3271,  688, 3234,   32, 2799,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158,    8,    1,  861,  328,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3238,    1,    1,  631,  730, 2614,   37, 2613, 2410,  726,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 2880, 1527, 2210,  614,   98,  333,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2153,  774,  104, 2095, 2393, 1328,  202,  861, 1621,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  926,  167,    1,    1,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  475, 1082,  432,   45,  405,    1, 1437,  469,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2837,   51, 1188,   37, 1604, 1400,    9, 1888,    1, 1190,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2840,   37,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2376, 2223, 2525,  288,   37,   52, 2758,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  267,  903,    1, 1447,   12,    1,    1,  444, 2673, 2375,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1086,   74, 2456,   32, 3339,   12,    1, 2649, 2791,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  735,  669,  476,  957,   37,    1,   39,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3328,  810,  288,   37, 1421,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2152,    1,    1, 2253,  354,   45, 1711,  388,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2217,  446, 1082, 2056, 1013,    9,  365, 1277,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 3105,  973,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  297,  296,    1,   20,    1,   37,  397,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1380,    1,    1,   98,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  952,    6,   32, 2053, 1527,   37,    1,\n",
      "          594,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  235,  661,   98,   25,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1050,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,    1,    1,    1, 1942,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2707, 1648,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,    1,  855,   45, 3343,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101, 2924, 2856, 3375,   32,  463, 3339,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232,   77,   98,    1,  528, 1738,  979,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  582, 1739,  105,  551,  331, 1294,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  259, 2463,    1,  111,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3303, 3090, 2620,  187, 2523, 3209,  888,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  146, 2234,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1407,  450, 1429,  157,  227,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359, 1707,   46,  220, 3140,    9,  920,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1181,  200,  365, 1616,  781,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,  878,  921,  316,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  931,  103, 3260,   37,  335,    1,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  315,    1, 1904,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1771,  171, 2865,    1,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,  551,  552,   51,  125,    1,  437,   45,    1,  369, 1084,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 2580,  973,    1,  520, 3018,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087,  433,  692,    6,   32,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  715, 2313, 1492, 1532,    1, 3005,    1,  191, 1465,  861,  700,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   37, 1816,  159,    1,  125,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2820,  105,  227, 2919, 1821,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1366, 1188,   37, 2447,   55,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1228,    1,    1,  829,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790,  794,    1,    1,  815,   45,  192,    1,   37,  194,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2816,  365, 3121,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053, 3358,   12, 2162,  916,    9, 2024,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2449,    9,  163,    1,   12,    1, 2911, 2301, 2311,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  198, 3024,    1,  321,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  614, 1159,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 1852, 1484,  491,    1,    1,  328,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2547,  335,    1,    1,    1,   98,    1, 2041, 2784,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  437,  155,    1,  693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,   45,  166, 2014,   45, 1147,   69,   37,  294,  575,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 1867, 1461,   63,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1176,  445,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 1282, 1034,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1920, 3403,  868,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  993,  652,  302,   51,    1,  104,  299,  444, 2087,  433,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1705,   61,    1,    1,  105,  506,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2414, 1364,    1,  398,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1354, 1891,    1,  565,    1, 1515,  225,   32, 2719,   10,    9,\n",
      "          105,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2563,    1,  598,   32,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3356,   90, 3357,   37, 1594,  297, 3346,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  542,   18,   85, 2177,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  199,   37, 1594,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550, 2101,    1,    1,    1,    1, 2558,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3237,  891, 1204,  187,  105, 1211, 1178,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,    9,  104,   37,    1, 1099,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   91, 1670,  365,  808,   32,  593,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3093,    1, 1627, 2107,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  294,  754,    1,  149,  219, 1477,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  754,   15,  120,   32,  385,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2919,    1,    1,  116, 2351,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,   12,  650, 1082,  395,   37, 1174,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1364, 1365, 3184,    1, 2522,  427,  653,   79, 2007,   37, 2620,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2470,  387, 1896,    1, 1224,    9,  903,    1, 1447,   46,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428, 2576,  356,  452, 3038, 2950,   45,  531,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  474, 1707,   24,  693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1804, 3270,    9,  183, 2107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  530,  361,  760,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  138,    1,    1,    1,   37,  875,  961,  927,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  100, 2126,    1,   28,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 447, 692, 597, 342, 442, 475,   1,  37, 582, 397,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 656,   1, 612,   1, 452,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  224, 1991,   37,    1, 2566,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178, 2430,   32, 1095,  133,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1687, 1022,    1, 3008,    1,    1, 1545,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2533,    1,  665,  548, 2104,  556,  221,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3017, 2225,  261,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1235,  102, 2084,  504,  452,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1009,   45,  393,   12, 2441, 2437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3380, 1924,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1172,   12, 1173,  115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  810,  459,    1,   37, 3305,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1, 1508, 1013, 2131,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  346, 1726,    1,  104,  187,   60, 1308,   37,  365,  687,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  331,    1, 2226,    1,  612,    1, 1017,  231,    1,  388, 1328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,  476, 2266,   37, 1334,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1, 1820,   98,    1,    1,    1, 1294,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1968,  387,  198,  219,    1,  310,   40,   93,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  582,    1,  230,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1364, 1365, 1310,   37,  764, 2734,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  393, 1475,    4,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  102,  120,  608,  105,  106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3296,    1,  425, 1765, 1211, 2256,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  957,    1, 1672,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2466,  476,   10,   37, 2250,    1,   79,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  775,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1848,  494, 1156,    9,  636, 1336,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 1380,  854,   32, 1881,   45, 1918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   22,   37,  125, 1213,    1,  419,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1003,  498,   37,  152,  399,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,   28,  187, 1448,  681,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  803, 2032,  729,    1, 2738, 2032,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,   45,    1,   37, 1539, 1169, 1913,   32,  403,  507,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  547, 1479, 1107,    1, 1832,   28,  220,  552,  552, 1108,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3173, 1494,   81,  384,    1,   37,  726,  395,   26,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2016, 1906,  908, 2578,    9,    1, 3251,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1029, 1874,  163,    1,   12,    1,    1,   37,  860, 2471,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  190, 2199, 1450, 1897,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  176,  192, 1929,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  777,    1,    1,  168,  613,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1, 2041,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  492,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2059,   32, 2811,  220, 1645,  947,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  947, 2856,    1,   32, 2887, 1523,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  155,  157,    1,  159,   28,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2004,    1, 1276, 1159, 2325,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1121,   98, 3024,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3343, 3006, 2035, 3102, 1757,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,  313,   37,  619,   10,   37,  289,   98, 2024,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3405, 1542,   37,    1,  557,  540, 2024,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  244,   71,   98,   14,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3175,    1, 3236,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    8, 2432,    9, 2786, 2987,    1, 2762,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1304,  256,   37,   80, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2492,    1,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3190,    1,  590,    1, 2142, 1022,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  829,    1,   37, 2518, 1718,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3357,  650,   57, 2756,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   57,    9,  642,  643,    1,   32,  871,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3253, 1310,   37, 1604, 1479, 2463,  176,  823,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  409,   25,  417,  176,  857, 2305,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2226,  331,  118,    1,    1,  267, 3021,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,   72, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  727,  378, 1003,  176,  365,  170,  415,    1,  196,  176,  551,\n",
      "          612,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1108, 1297,  104, 1173,  176,  334,  603,  176,  104, 1160,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1537,    1,    1,    1,    1,  928,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1852,  267, 1099,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  491, 1605,   32, 1560, 1464,   37,  726, 1876,   45,  615,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2280,  140,  129, 2948, 2223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3062,  455,   12, 1194,    1,  671,    1, 1464,   37,  726,\n",
      "         3126,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3348, 3382,    1, 2689, 1061,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  715,  112,  783,  418,   32, 1837,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  586,  267,  365,   22,  942,  105,  227, 1139, 2113,  151,    1,\n",
      "          202,   52,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2590,    1,  361,    1, 2276,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1173, 1425, 1929, 2090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1978,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,    1, 1938, 3197, 3298,  581,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  395, 2479, 1228, 1116,  802,  528,  762,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3309, 1542,   37, 1463,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1, 1167, 1360,  612, 1910,  334,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   37, 1925, 1583,    1,  837,   61,  166,    1, 1492,    1, 1104,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  597,  381, 1682,   51, 1046,   12,    1, 1117,    1, 1417,    1,\n",
      "          134,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2238, 1774,  613,  535, 2403,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 220, 926,  32,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  75,   1,   1, 116, 412,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3405,  894, 1048, 2225,  297, 3349,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159, 1758,  548,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3213,    1,  220, 1545,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 2619,  547,  195,    1,   32, 1300, 1603,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1661,  551,  331,    1, 1784,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3117, 1445, 1421, 2469, 3224,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1211, 1994, 2693,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1901, 2865,   39,    1,  957, 2261,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1019, 2214, 2527, 2663, 1976,   32,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1272,   28,  350,    1, 1670, 1534,   37,    1, 2343,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  167,  764,  455, 1814,    1,  856,  220,  121,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 3186,  606, 2613,  140,    1,    1, 2963,\n",
      "            1,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3188,   32,    1,  421,   39,    9, 1110,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2640,   12,    1, 1554, 1821, 2190,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  252,    1,   39,  176,  177, 1700, 2119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 2615,   37, 1421, 1024,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  121,   36, 2426, 1086,  220, 1530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  578,  105, 1021, 1119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    9,  153,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2693,    1,  193,  105, 1195,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  715,  147,    1,   43,  444,  224,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  259,  669,    1,   37, 1178,  537, 2248,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  485,    1,   61, 1041,    1,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  572,  156,   37,  427,  357,    1,  572,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  773,   66,    1, 1595, 1332,    1,   15,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965, 2982,    1,  238, 2218,  176, 1056, 2165,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  183,    1, 2389,  852,  227,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  213,   37, 1198,    1,   98,  104,  643,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  790, 1579,  195, 1167, 2659, 1227,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3259,  599,    1,    9, 2249,  872,   95,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  506,  155, 1057,  297,  230,   45,  761,    1, 1646,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   28,  166, 3012,  298,  778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328, 1880,  458,    1,    1,    9,  104, 1437,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1004,  927,   45, 1791,    1,  191,  104, 1583,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  364, 1293,   32, 1030,  191,    1,    1,   32,   81,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   28,   98,    1,   12,  225,  636,  837,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428,  391,    1, 1874, 2266,   12, 1140,    9,  652,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   94, 2060, 2061,  163,    1,   12,    1,   98,  800,   60,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3286,    1,  365, 2036,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,    1, 2067,  594,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  848,  361, 1234,    1, 2444,  176,  915,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708, 1656, 2870,   32, 3339,    1,    1,  547, 3006,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  510, 2414,   32,    1,    1,  488, 2028,    1,  104,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  123,  403,  404,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  885,    1,    1,   32, 2811,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1139, 1662,   30, 2693,  707,   32,    9,  166, 2856,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  102,   71,   98, 1057,  600, 2051,  107,  568,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,   12,    1, 1178,  928,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  919,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61, 2764, 3212,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  233,    1,   98,    1,  317,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,  590, 2808, 2274,   32,  424,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,  459,    1,  132,  220, 1725,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2804,  361, 2214,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1821,   95,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   26, 3173,    1,   37,   52, 2242,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  458,   98, 1434,   37, 1806,  347,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,   12,    1,  786, 1090,  631,  297, 3175,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2774,    1, 1492,    1, 1260,   51,  920,   52,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  439, 2060, 3248, 2420,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  663, 3061,    1,  964,   12, 1511,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1029, 2911, 1594,   39,   32, 1797, 1397,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 2864,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 2896,    1,  928,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,  417,  737,  197,    1,  119,    1,  174,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1497, 1260, 3043, 3384,  778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2254,    1,  156,  157,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1625,   37,  222, 2819,  220,  365,  278,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  458,   45,  507,    1,   50,   32, 1153,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800, 3306, 1512,   46,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1737,   92,    9, 3262,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2699,   37, 1965,    1,  112,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2195,   32, 1789,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,   37,    1, 3118, 3148,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  217,  720, 1876,   45,  142,    9,  632,   69,  633,   12,   50,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,  256,  172, 1470,   37, 1499,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32, 2597, 3389,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,  360, 3359,   12, 2024, 1463,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  142, 1532,   37, 1865,  593,   12,  553,  671,  669,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2017,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  614,   37, 2447,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   82, 2296,    1,  267,    1,    1,   37,  271,   28,  669,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2789,    1,   32,  715,  741,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2206,    1,  171,  580,    1, 2082,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1009, 2270, 1159,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1473,   98,  720,   32,  160,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  864, 1550,  898,    1,   45, 2556,    1,   37, 2835,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1008,  365,   82,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1701,    1,  949,    1,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  297, 2472,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2700,   37,  506,    1,    9,  434, 1804,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  221,  297,    1,    1,    1, 1120,   18, 2170,   12,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  803, 2983,   66,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3339,    1,  928,   45, 3307,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1100, 2373,    1,  769,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545, 1631,  384,  166, 2242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  386, 1070,  147,   37,  562, 1028,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  183,    1, 1293,  176,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3281,  637, 3181,   12,    1,  105,   74,   79,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  967, 1857,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2741,  477,  411,   32,  449, 1463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1459, 1082, 1557,   37,    1,  932,   45, 1743,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2445,  947,  429,    1,    9,  163,    1,   12,    1,    1, 2772,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1648,   37, 2199, 2673, 2657,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2680, 1419,    1,  220,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,   69,    9, 1011,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  777,   12,  627,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  325, 1159,    1, 1085,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  957,  919,    1,   98, 2752, 1633,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282, 1863,    1,   37, 1413,  667, 3129, 2579,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2687,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  279,    1,    1,    1,  202,  590, 1487,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  741,    9, 1009, 1010,  997,   45,    1,  361,  555,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1009,  908,  388, 2883,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  939,  187,    1,  940,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1867,  365,    1, 1461, 1010, 1789,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  305,  670,   98,    1,   29,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12, 1619,  458,   90,  104,  193,   37, 1096, 1130,    9,\n",
      "          996,  533,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3375, 1594, 1750,  627,  187, 1444, 1348,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  398,  908,   43,  191,  844, 1468, 1492,  267,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  111,  133, 1366,  416,  625,    1,  202,  590,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2806,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2508, 1564,  912, 2285, 2246,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2602,    1,   51,  729,   52,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  510,    1,    1,  764,   61,   98,  166,  454,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2070, 3161,  171,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  306, 1205,  297,  777,  778, 2560,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,    1, 1232,  864, 2390,  315,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1,   37,    1, 3339, 2271,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437, 1355,    1, 1880,  458,  170,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2176,  361, 1958,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3314,  140,  219,  463,  294, 1990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2136,    1, 2676,  288,   37,  907,   32, 1851,  736,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1360,  612,  865,   37, 2570,  171,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3096, 1218,   37,   52, 1231,  220, 2772,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2086,  804,   61,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  989, 2001,   98,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  460,   12,    1,    1,  202,    1,    1,  166,    1,\n",
      "           61, 1284,  105,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1415,    1,    1, 2744,    9, 3260,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437,   37,  693, 2362,   37,  335,  297,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98,  166,  754, 1030,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  793, 2055,  451,  541,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2961,    1,    1, 3250, 2724, 1751,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2229,    1,  565,    1, 1211,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3123, 2565, 1082, 2557,  528, 1918,  297, 2936,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3155,  289,    9,  104, 1414,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32, 1658,  582,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  684,   12,   89,  267,  223,  408,    1,   93,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  107,   34, 1069,  837,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3272,    1,  176,  455,   26,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3337, 2660, 1990,    1,    9,   91,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1190,    1, 1665,   37,  319,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  136,    1,   28,    1,  280,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1414,    1,  384, 2800,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2800, 3316, 2582,    1,    1,  267,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 2227,    1,   12,    1,  835,    1, 2759, 1108, 3000,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2527,  164,   51,  606, 2572, 2504, 3079, 1190,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  422,  692,    1, 1126,  261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2734,  437,  190, 1636,  453, 1074,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  302, 1458, 1027,    9, 2673,  626,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1178, 2827,  297,  531,  493, 2705,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2226,  606,   37,  469, 1018,  460,  934,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1994, 2673,    1, 2572,   32,  447,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1900,  907,   37, 2000,  651, 1031,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1417,    1,    1,  466,  275,  829, 1564,    1,    1, 1160,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1524, 2132, 3100, 1249, 2307,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  200,  365, 2603, 2043,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105, 1298,  417,   32, 2235, 2843, 1654, 2589,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   45, 2974,   12, 2507,  541,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  792,    1,  792,    1, 1683,   98, 1368,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  565, 3115,  810, 1167, 1444, 1445,    1,   28,   37,   52,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1689,  829,  469, 2405,    9, 3018,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3364,  952, 1663, 1876,    9, 2708,  890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  967, 1229,  460,  967,    1, 3107, 3366, 1699,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  901,    1,   45, 1298,  249,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2471, 2732,   32, 1990,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  539, 1037,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  180, 1229,   37,   52,   32,   46,  220,  179,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 288,  37, 168,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  68,  69,   1, 641,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  286,   21,  331, 1582,  390,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,  190,  698, 2379,    1,   32, 1090,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  198, 2164, 2803, 1700,   32, 2883,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2676,  416,  164, 1333,    1, 3404,  774,    1,    1,  985, 1816,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  132,  640, 1486,   12,  932,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12, 1176, 1371,    9, 2254,   37,    1,  361,  774,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1199, 2981,    1, 1797,    1, 1821,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  365, 2925,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 1545,    1,  166,    1, 1305,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2057,  729,  580,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1280,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 2199,  568,  176, 2152,    9, 1338,   45, 1448,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  166, 1509,  202, 3303,   61,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,  957,  366,   32,  806,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,  42, 422, 133, 134,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 686, 846,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3194, 3195,   12,    1,    1,   37,  865,  548, 2249,  914,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503,  894,  606,    1,  749,   32,  506,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2275, 1450,   10,   12,    5,    6,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  323,   37,  798, 1918,   32, 2846,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2754, 2548, 2572,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275,   26, 2069,  736,   32, 2142,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1486,  155,  570,  187,  197, 1137,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  884, 1383,  176,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    4, 1754,   32,  104,   32,  385,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1326,    1,    1, 1413,   37,    1, 1656,  623,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2615,    1,  166,   74,  548,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   69,   28,  530,    1,    1,  510,    1,  107,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  942,  520,  442,  909,  444,  104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1459, 1484,    9, 1994, 2095,  469,  548, 1887,   45,  171,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  148, 1564, 1509,  361, 2069,  647,  693,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   22,    1,  359,   37,    1,    1,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  388, 3109,   32, 2638, 2931, 2678,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2313, 2598,   32,  851,   12, 2585, 2287,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3142,  872,   28,   98, 1245,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1367,  166, 2259,   37, 3331, 1141,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2680,    1, 2650, 1942,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  354,  195,    1,   32,  356,  506,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094,  765,   37,    1, 1428,  591,   37, 3375,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,  166, 2041, 2655,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  867,    1, 1994, 2086, 1896,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2661, 2790, 2659,    9,  389,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2226,    1,    1, 1662, 1380, 2500, 1046,   98, 2649, 1512,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1230,    1, 1935, 2308,  631, 1275,    1,  623,  102,  417,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 2918,    1,  166, 1870,   37, 1965, 1821,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  978,  769,  245,   98,  503,  480,    1,   68,   28,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2308,    1,   37, 2362,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3167, 1834,    1, 2295, 3117,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1320,  162,    1,  493,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1122,  853,   28,    1, 1170,   85,   63,  862,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1354,    1,   37,  865,  754,  548,  493,  114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  195, 1958,  833,  612,    1, 1399,  166,  974,  724,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3290, 1508, 2469,  230,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1564, 1273,  535,  973,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  293,    1,   98,  340,    1,    1,  468,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  190,   52, 2632,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504,    1, 2596, 2414,    1, 2766,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2729, 2548, 2572,   32, 3101, 2485,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994, 2995,   98, 1018,    1,  468,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  449,  517,    1, 1362,  529,  617, 2030,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2893,  267,  190,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,  361, 2275,   84,   28,    1, 1523,   63,  915,  736,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2028,  221,    1,  443,   45, 1886,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1584,  166,    1, 1174,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1972, 1220,  361, 2605, 1027,  327,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1740, 1399,   45,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 3102, 1757,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3184,   12, 3372,    1, 2087, 1098,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,   37,   52, 1066, 1159,   56, 1501, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1031,  166,  625,    1, 2370,  166, 2075,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596,  616,  509,    1,  615,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  872,  353,    1,  590,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  743,   12,   82,  992,   85, 2007,   37,  505,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1089, 1090, 2292,  614,   37, 1411, 1722,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1433, 2768,    1,    1,  166,    1,  220, 1227,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  506,  782, 1017,  167, 1876,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3249,  619, 1973,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   61, 1221,  105,    1,   32,  166,  433,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  634,  635,  315,  636,    6,   37,    1,   17,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,    1,  114,   32, 2433, 3360,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    1,  131,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2567,    9,    1,   61, 1333, 1530,   32, 1785,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1989, 1990,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2103,  617, 1116,  220,  878, 1714,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,    1,  166, 1516,   37, 1330,  247,  872, 1159,  166,  593,\n",
      "         2522,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  971,    1,  219,  285,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2170, 1877,   37, 2446, 3118,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   32, 2936, 3329, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  833,  612, 2898,  445,   45, 3211,  357, 2315,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   59, 1368,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 2420,   98,  424, 2784,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1174,    1,  195,  776,  932,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1955,  798,   48,   32, 2412, 2227,  872,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  572,  197,   85,   98,  567,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187,    1,  884, 3194, 3195,  389,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,   94,   12, 2923,   45,   60,   61,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1178,  220,  166, 2213,  886,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 498,  37, 713,   9, 493,   5, 983,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 829, 162, 105,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1206,    1,  828,  741,   37, 1605,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1444,  321,  612,  619,  105,  271,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328, 3255,  691,  712,    1,   37, 1468,  601, 2080,  872,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2633,  498,   37, 1145,  220,    1,  361,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3021, 1558,  191,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,   12, 1718,  279, 1465,  193,  320,  638,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,    1,    1,    1,   98, 1802,    1,  721,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  811, 1310,   37,  470,    1,  487,    1,  297,  531,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  636, 2405, 2029,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,    1,   80, 1292,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2583, 1862,  115,   45, 1700,  497,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1992,    1, 1333,    1, 1054,    1, 1311,   98,  872, 2090,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2835,    1, 1094, 1604,   37, 1814, 2096,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 3279,    1,   32,  539, 2752,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1230,    1, 1230,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 1959,    1, 1214,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  726,  682, 1024, 1298,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777,  951, 1361, 1523,   45, 1886, 1618,   28,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1619, 1739,  162, 1173,  176, 3048, 2923,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3330, 1542,   37,   84,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   29,    1, 1240,   52,    1,   32, 2468,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 2645, 3380,    9, 1994,    1, 2731,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  187,    1,  187, 3032, 2596,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707,    1, 1585,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1613,    1, 1615, 2474,  259,  220,  365, 1151,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1462, 1190,  796,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  384, 1199,    1,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3255,  691,  726,    1,  497,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2363,  917,  335, 1021,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2817, 2856,   32, 1932,  395, 1013,    9,  166, 2249,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   12, 1994, 2819, 2362, 2443,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1855,  669,  936,  460,   61,    1,  384,  531,   37, 1154,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  375,  801,   32, 1183, 1253,    1,  190, 1844, 3163,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  776,  193,  972,   37, 1174,  424,  356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1079, 3063, 1713, 1523,    9, 2355,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  402,   37, 2558,   32, 1778,  861,  328,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3380,   12,  786,  454,  132,   61,  415,  166, 2247,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1105,  787, 1749,  220,  727,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2031,   12,    1,    1,  187,  822, 1469, 1687,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,   61,    1,  388, 2510, 1090, 1501,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  548, 1118,    1,  657, 1394,   37, 1151, 1809, 1758,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  663, 1900, 1313, 2095,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1662,  293, 1536, 2842,   45, 1994, 2086, 2039,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1341,  975, 1083,  158,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  315,  365, 1108,    9, 2700,  361,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   98,  105,    1, 2290,   32,    1,   12,    1,    1,    1,   12,\n",
      "         2121, 2853,   98,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1539,   45,  365, 1821, 2190, 2640,  288,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2596, 2414,  786,  163,    1,   12,    1, 3160,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2870,   27, 2708,  861,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2305,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2899, 1359,  162,    1,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1451,    1,  197,   28,    1,  817,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,    1, 1251,   45,    1,  439,   37,   36, 3071,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2806, 3130,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1825,  125,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2416,  893, 1231,    9, 1157,    1, 2950,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  485,    1,  197,  338,  419,    1,  159,  720,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,  156,  688,  308,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  620,  661,    1,   37,  764,    1, 1731,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,   22,  477, 2414, 1056, 3006,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1758,   37, 3293,   45, 2936, 3329, 1660,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187,    1, 2489,   39,    1, 3358,   12,    1, 1456,    1,    1,\n",
      "         2047,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1092, 1236,  668, 2633, 2928,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2396,   34, 2288, 1204, 1942,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  267,  864,    1,   32, 2673, 2813,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1276,  202,  113,  530,   98,    1,  209,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  593, 1659, 1222,  952,   37,    1,    1, 2910,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   45, 1423,  197,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2831, 2421,  474,  650,  777,  778,  318,  361,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2899,   12, 1273,  218,  315,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1957, 1558,   98, 3339,  787, 2791,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,    1, 1058,   98,    1, 2924,   37,  531,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1568,  357,  984,    1,  391,  371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2266, 1187,  193,    1,    1,   32, 2160,   45,   69,    9, 1011,\n",
      "          287, 1435,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1086, 3347,   12,    1,    1, 2564,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,   12, 1021, 2428,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1449,    1,  387,  734,    1,  115,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1026,  267,  460,  140, 1377,   32,  768,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 2107,  420,    1,    1, 1998,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1591,    1, 1126,    1,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1228, 2086,    1,    1,  619,  807,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1,  163,    1,   12,    1,    1, 2860,  698,    1,  861,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    9, 2331,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2107,    9, 1021,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3335,  812,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2848,    1,   45,  270,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3231,  186,   32, 1194,   37, 2712, 3117,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1,  166, 2114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1570,  151,  685,  365, 2367,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1214, 1215,    1, 1216,    1,    1,  939,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  548, 1555,  105, 1183,  199,    1, 3178, 1408,  460, 1139,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   95,  473,  474,   37, 1174,  477,  741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1022,    1,    1,    1,  952,    1, 1323,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1667,   12, 1095,    1, 1668,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428,  861, 1906,   37, 1142, 3369, 2024,  543,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 3109,    1, 3043,   45, 2765, 2471,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  335, 1018,    1, 1594,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1290,  396,  245,  995,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962,  375, 3299,    1,  187, 3209,   85,  931,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  884,  166, 1524,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1481, 1688,    1, 1699,  619,  105,   92,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343,  650,  952,   37, 1504, 2529, 2696,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2868,  387,    1,   32,  903,    1,  464, 2673,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12, 1013,  338, 1533, 1139,   45,  224,   12,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   29, 1394,  486,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  526, 1913,  401,  932,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3115,    1,  167, 1306,  284,  199,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   74,    9,  104,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1408,  340, 2395,  220,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193,  514,    1,  267, 1922, 1890,   32,    1,  344,    1,\n",
      "          565,  297,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2175,   37,  166, 1746,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3020,    1,  187, 1373,  191,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  571, 2713, 1951,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340,  140,  119, 1194, 3212,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  395, 1070,  942,   37,   38,  297,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 2028,  442,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   28,    1,    1, 2973, 1764,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  331,  331,    1,  331,  331,    1,  167,   52, 1488,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  422,   66, 1809,  224, 1126,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1573, 1675,   32, 1658,   12,    1, 1773,   61,    1,  334,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  523,   12,  207,  174,   28,    1,   61,  837,   45,  927,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1245,  540,   37, 2613,  726,  297, 1668,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051,   37,  130, 1228, 2683,  552,    1,    9,  331,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,  256, 1273, 2403,   37,    1, 2340,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  519,    1, 3188,   12,  183,   74,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1731,    1,  191, 3151, 1756,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,  236,  237,  537,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  142,    9,  104, 1950,  826,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2525,  361,    1,    1, 1990,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006, 1207,   37,    1, 3358, 2162,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  826,   32,  593,    1, 2599, 1316, 2755,  447,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2573,   12,    1, 1542,   37,  168, 1300,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018,    1, 3080,   98, 1515,  865,  384, 3127,  827,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810,  424,    1,  361, 1444,  335, 2455,    1, 1176,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,   37,  125,    1,    1,  191,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   82,   61,    1,   45, 2281,  927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  951,  224,  378,  224,  140,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2632,   32,  166, 1811,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  880,    1, 1821,    9,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390,  159,  554,   98,  474,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   74,    9,  105,  613,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426, 1586,   28, 1437, 1224,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  941, 2386,  938,   45,    1,  926,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1475,  535,  408,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  848, 1572,  437,   37,  151,  849,   32,    1,  182,  132,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   37,  397,  163,    1,   12,    1,    1,  942,  909, 2189,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 3017, 1812,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2889,    9,    1, 1176,    1, 1232, 3175,  877,  460,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2926, 2125,  260,    1,  548,  354,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,  389,    1, 1672,  915,  339,  328,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2087,  433,  692,  993, 1064,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   32, 1067, 1085,  132,  220,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1212, 3073, 1210,  388,  861,  548,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1002, 2911, 1210, 1603, 2290,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1797,    1,   37, 2354,  608, 3024,  906, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1774,   39,  613,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1908, 1722,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  716, 1169,   14,   15,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1107,    1,  775,   98, 1102,  841,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1224,   45,  104, 1097,   93, 1071,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  281,  282,   37, 1195,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  882,  108,  387, 1424,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,  267,  199,  193,  917,   37, 1198,  395, 2108, 1281,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  475, 1702,  652, 1358,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  297, 2836,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  743,   12, 1913,  401,  156,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1654, 1737,  444,   94,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  384,   26,  985, 1857,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  294,  922, 1090, 1829,  718,  176, 1531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1691,    1,  288,   37,  877,  105, 1104, 2457,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2163,    1, 1261,  229,    1, 2130,   32,    1, 2162,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2551,    1, 1449,  562, 1700,  356,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1808,    1,  794, 1821, 2057,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3199, 1918,    6, 1159,  364,   12, 1990,  631,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  839,  971,    1, 2009, 3307,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147, 1707, 2638, 2931,  116,  625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  558,   37,  130,    1, 1697,    9,    1,  131,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613, 1614,  166, 1615, 2474,  259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3144,    1,   37, 2237, 1690,  787,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 2871, 3294,   51,  193,   52,  245,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  147,   45, 1377,   37,  877,    7,  695,   98, 2095, 2985,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,  391, 2540, 1081,   12,    1,    1, 1463,  240,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1477, 1990,  411,    1,    9,    1,   32,  163,    1,   12,    1,\n",
      "          872, 2012,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1917,    1, 1158, 1762, 1076,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  109,  507,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1173, 2920,   32,    1,  384,  166,  698,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1117, 1525,  384, 2890,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2777, 1564, 2321, 2553,   28,  361,  335,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2752, 2751,   64,    1, 1223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  224, 1867,  825, 1013,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1,  105,  106,  187,  585,  686,  568,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  592,  108,   98,  596,  433,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1139, 2113,  305,    1,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 620,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  81, 220, 242, 142,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 2861,    9, 1714,  105,  106,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  721, 1707,  148,   12, 1509,  361,  915,  693,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359,  267,  864, 1809,    1, 1705,   37,    1, 2673, 2108,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1667, 1564, 1089, 1090,  714,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3194, 3195,  546, 2800, 2565,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2076,  829, 1249, 1570,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  215,    1,  531, 2128, 1605,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2754,  741,   45, 1161, 1552,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2755,  878,  992,  460,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1, 2176, 2506,   45, 2608, 2607,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2578,    1,   37,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1900,  856,  104,  469,   37, 2856,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3326,  688,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1877,   37,    1, 2890,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,   12,  365,    1, 1441, 1100, 2071, 1331,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  593,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  531, 3373,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1760,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  397,  261,  444,  342,    1, 1859,    1,    1,   37, 1377,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,   23, 2577,    1,  331,   24,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1559,  297, 3043, 2282,  722,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2784,   28, 3079,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3014, 1749,  220,  326,   37,   47, 2079, 1228,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1597,  884,  297,    1,   32, 1270,  182,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  179,  180,  170,  703,  910,   37, 1273,   12,  606,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2916,    1,  920,   66,  187, 3129,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  547,  696,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 2691, 1882,   37, 2368,   28,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1938, 2607,  382, 2206, 2989,  786, 1264, 1747,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,  907, 1010,  716,   45, 3358,   12,    1,  223,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  398,  991,  224,   98, 1013,  378,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 2222,  967,  453, 2223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  800,   15,  583,  355,    1,  156,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  896,    1, 2383, 3277,  220,   56,  388,  569,   32,   91,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2507, 2954,  907,   32,  593, 2522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  681,   37,  317,  195,   29,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3124, 1518,   32,   98,    1, 3329, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  650, 1458, 2020, 1002,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  691,  551,  365, 2036,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  654, 2072, 2723, 2724,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2004,    1,  686,  284,    1,    1, 2165,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 2496, 1976,    1, 1976,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2275,  884,  631,  297,   10,   32,  428, 1002,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,    1,    9, 3006,  548,    1,  336, 3389,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  542,  729, 1587,   45,  742, 1665,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3130,   61,  105,  590,   16,  951,    1, 3010,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,  843,  411,  304,   45,  861, 2558,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510,    1, 1219,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,   79,    1,  202, 1784,  951,  963,   60,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984,    1,  387, 2820,   12, 2534,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3226,  712,   28, 1144,   98,    1,  375,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1157, 2785, 2372,  664,  753,  187,   64,  431,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1393,    1,  150,  155,  885,   59,   32, 1799,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1028, 3043,    1, 1887, 1867,  492,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   12, 2162,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   78, 1937,  961,    1,  187,  863,  431,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2045,  328,    1,  972,   37,  875,    1,  134,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  267,  395, 2908,  297, 2949,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 572, 156, 670, 669,   6,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 405,  12,   1,  98,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  938,    1,    1,    1,  253,    1,  422,  396,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  536,  395,   12,  954,   37,    1, 2127, 2585,   32,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1158,   61, 1526,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3286,    1,    1,    1,   37,  365, 1477, 1990,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962,    1,    1,    1,  631,    1,  297, 1957,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  726, 1334,   45, 3026,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 2286, 1114,   37,  665,  802,  111,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  238,   45, 1204,  361,  440, 1609, 2420,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,  69, 765, 215, 442, 448, 242,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 830,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3232,  335, 3260,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2922,    1,  590,    1, 1739,  190, 1844,  917,  176, 2021,  440,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2980,    1, 2894,  618,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885,    1,  631,  176,    1,  628,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2800, 2122, 1929,  288,    9, 2283, 2305,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  433, 1042,  315,   37,  221, 2972,  808,   37, 2087,  433,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,  166,    1,    9,  502,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965,    1,   37,    1, 1334,   32, 1821,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  193,    1,  227,  187,  671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1148,   37,  631, 3260,   44,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3094, 1530,    1, 1744, 2347,   32,    1,   45, 1450,   32,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,  417,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    5,  302,  431,  432,  191,  433,  233,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  703,  793, 1168, 2937,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  535,   25,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  197,  937,  335, 2230,   79,    1, 1633,  170,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1022,    1, 3008,   61, 2056, 1239,  453,  365,  103,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1013,  614,   98,  187,    1,    1,   37, 1334,  665,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2206, 2435,  469,  313,   37,    1,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  737,  197, 1784,    9, 1128,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1573, 1330,  361, 2155,   32,  166, 2925,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  612, 1273,    1, 1766, 1767,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  667,    1,  550,  369,    1,   37, 1119,   37,  236,  237,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  460,    1,   37, 1638, 1018,    1,    1,   98,  112,  931,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  951,    1,  166, 2378,    1,    1, 1970, 2539,   32,\n",
      "          718, 1160,    1,  150,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,    1,  617,  618,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  848, 1566, 1234, 1876,   37,    1, 1230,  542,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  487, 3160, 1554, 2789,   32,  344, 3403,    1, 2134, 2393,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1, 2371,  636,  680,  104,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2456,  777,    1, 1668, 2501,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,  136,   82, 1231,  220,  133,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  851,    1,   37, 1423,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,  649, 1190, 1450,   10,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,    1, 2707, 1421, 2417,   98, 2532, 2657,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  430,  852,    9,  477,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018, 1234, 3085,    1,   61,  288,   37, 1787, 1230,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1366, 2518,    1,    1,  361, 1851,    1,  190,  544,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219, 1244, 1313, 1610, 1281,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3208,  437, 1070, 3207,   37, 2192,   28,  671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3113,   12, 1277,  531,  890,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  709, 3141, 2193, 2285,  247,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,    1,    1,   67,    1, 2085,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   32,  870,    1,  140,  885, 1684,  176, 2213,    1, 2630,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   92,  164,  165,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1040,   37,  764, 2785, 2372,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1162,    1, 1597,    1,    1,    1,    1,   37,  168, 1300,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  216,  135,  730, 2288,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   45,    7, 1347,   32,  365, 1973, 2224,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  810,  166, 2524,   45,  224,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  608,    1, 2353,  627,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  395, 1273,  641,  156,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  626,  338,  548,  522,  444,  615,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2673, 2104, 1518,  111, 2641,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1570,   12,   40, 1705, 2321,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  854, 1401,  593,   32,    1, 1655,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2406,    1, 3380,   37, 2653, 1651, 2122, 1929,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1654,    1,    1,  400,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2063, 1167,  565,   39,   45,  424,  593,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  204,    1,  600, 1405,    1,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1183,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3343, 2161,    1,  105, 2290,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3285,  665,    1,    1,   98,    1, 1638,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  743,   12,   82,    1,  548,  365, 1857,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3100,  472,   81, 1764,  598,   37, 1343,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3358, 1216, 2958,    1, 1121,   98, 2708,  652,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1004,  297, 1273,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,  98,   1,   1,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 140, 365, 837, 656,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 1145, 2253,  282,   37,  327,  111,  772, 3011,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1542,   37,    1, 3243,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  964,   32,  973,   37, 2035,  247, 2113,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1803,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  487,    1, 1256,  635, 1241,   28,  449, 2085,  354,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2562,  916,   37,  877, 3296,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  173,   45,  627,    1,    1,  593,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1149,  741,    1,   32, 1440,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  104,  573,  639,  475,  108,   45,    1,  629,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192, 2741,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37, 1539,  845,  846,  116,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2137, 2856, 2144,   32, 2597,   12,  501, 2060,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  314,   12,  103,  494, 1910,  721,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2020,  776, 2306,  288,    9, 3151,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,  601, 1178, 1061,   32,  602,    9, 1791,  722,  444, 2877,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,   32,  591,  187, 3202, 2753,  845,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  857,  120,   37,  104, 1708, 2165,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  499, 1173,  176,  163,    1,   12,    1,  531,  622, 2705,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3188,  884, 1003,  176, 2925,    1,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  163,    1,   12,    1,  197,   93,   37,  838,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  671,  490,  187,   60,  338, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  140,  647,    1,  741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,   32,  395,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  437,  205, 3040,   98, 1009,   10,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   75, 2167,  858,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  295,  952, 1346,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777, 1064, 2089,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 3381, 2431, 2572,   32,    1,  104,  622,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   98,   37,  579, 2595,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,   12, 1532,   32,  395,    1,   32,  411,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  344, 3403,    1,   39, 3379, 1260,  947,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1638,   45, 2703, 2644, 3102,   32,  531,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,  288,    9, 1996,    1,    6,  332,  636,  191,  600,\n",
      "          105,  401,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1956,    9,  176,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3191,    1,  191, 2828,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  446,  267,  455,  622, 1822,    1,   37,  596,  230,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3102,   46, 2052,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  706,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   65,   67,  423,  300,   25,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 1981,   98,  844,    1,  538,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  211, 1527,   32, 3349,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  820,    1,    1,  682, 2529,  293,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1465, 1466,   37,  138,  297, 2089,  287,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,  251,  365,  861, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2201, 2003, 1585, 1554, 1530,    1, 1270, 2249,   32, 1619,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2384,  365, 2927, 1722, 1718, 2168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  328, 1100,   12,  572, 1572,  191,  198,    1,    1,    1,   15,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3012, 3027,  105,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   39, 2119,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,   12,    1, 1178,  928,  176,  823,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   32,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   30,   79,  105, 1529,  865,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1676,    1,   37,  346,  193,   32, 1820,  342,  379,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2785,    1,    1, 2424,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1161,   32,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2922, 1454,    1,   45, 2343,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1461,  750, 1463, 1086,   32,  595,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,   47,  453,  331,   48,   32, 1312, 1074,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  388,    1,   98,  829,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1985,  898, 1530,   32,  632, 2003, 1585,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,   91, 1398,  612,   52,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1122,  853,  200,  111, 1107, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1249,    1,   32, 1311,   26, 2033,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1674, 2962, 2213,    1,  335,  656, 1267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2685, 1523, 3117,   98, 2114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885,   98,  103,   45,  166,  593,    1,  361,  204,  416, 1221,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3275,  420, 3196,  614,  119, 2098,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3127, 2393,    9, 2095,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1258,   37, 2139,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 1009,    1, 2572,  191, 2003,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  814,   37,  138,    1,   82,   59,   32,  987,    1,  225,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1006, 2094, 2463,   81,   37, 3141,  166,    1,  550,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1289,   98,    1,    9,  157,    6,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1829, 2522,   45,    1,  686,  455,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1154, 2548,  191,    1,  674,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  220,  286,   25,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   51,   26,  417,   98,    4,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1560,    9,  491,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2193,    1,  474, 1877,   37, 1073,  441,   32, 2752,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  347,  410,   98,  612, 1879,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051,  200,  365,    1,    9,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,    1, 1841,    1,  460,    1,  372,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3204, 2865,   39, 3253,  176,  104,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   81,   37,   36,   15,    1, 2325,    1, 2819,   37,  365,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2656, 1296,   28,   37, 1719,  389,  390,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  827,    1,    1,    1,  187,  103, 3167,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2528, 1870,   12, 1234, 2528,    1, 1863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  702,    1,  365,   82,  384,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  463,    1,  614,   39,  105,  855,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2578,  884,    1,   37,  192, 1054,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,   37, 1865,  861, 2750,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283,    1, 1284,   32, 1134,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1097,   57,  720,  528,  689,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089,   30, 3025,   12,  915, 1377,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  796,  187, 1163,   82,    1, 1009, 2126,  929,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2424,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   94,   27,  365,  845,  310,   25,  504,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708, 2404,  104,  890,    1, 2024,  226,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2800, 2741,  698, 1708,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,    1,    1,  872,   28,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  398, 1800,  134,  951,    1,   10,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3258,    1, 1294,    9, 1477, 1990, 1394,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  650, 2418,   28, 2215,  700,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  192,  617,  618,  335, 1134,  176, 1307,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1034,    1, 1056,   85,    1,  361, 1120,   12,  579,   12,   28,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  967,  105, 1567,   32,  453, 2364,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2743,   37, 1468,  593, 3256,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2759,    1,  593,    1,  105,  112,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3232,    1, 3079,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   37, 1361,  619,  166,    1,   73,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1363,    1,  244, 1269,  101,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,  774,    1,    1,    1,   51, 1371,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428, 2673, 1063, 2329,  968,   98,  127,  176,    1,  250,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,  353,  572,  354,   98,    1,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  176,  166,    1,  236,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1173,  176,  163,    1,   12,    1,  622, 2705,   32,  531,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,  220,  365, 2355, 2549,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  578,  590, 1479, 1119,   32, 1407, 1563,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3006,   51, 1260,  531,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296,  387, 1273,  259,  815,   98, 1202,   32,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1433,  455,    1,  105, 1311,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,   51,  211, 2407,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3255,  463, 2170,    1,    9,    1,   12,    1, 1285,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2378,    1,  833,  612,    1,  579,    1,  245, 1167, 1827, 1922,\n",
      "          220,  105,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2,  25,   1, 242, 187, 615, 817,   1,  69, 444, 331, 551, 105, 234,\n",
      "         182, 235,   1,   1,   1, 234, 182, 235,   1,   3,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 189, 549,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    5,  943,  193,   98, 1247,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,  315,  389,    6,    1,  566,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  442,  770,    1,  220,    1, 1250,   98,  104,  963,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  640, 3374, 2172, 2791,   32, 3339,    1, 1887,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2962,  978, 3138,    1,  191, 3299,  384, 2615,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,  115,   45,   65,   67,  484,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3028, 2995,  328,  820,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1927,  851, 3338,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  613, 1017,   37,  413, 1842,    1,    1,  657,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403,    1, 1007,    1,  979,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  149,    1,  444,    1,  938,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1088, 1877,   37,  973, 1511,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  103, 2635, 3253,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1268,   28, 1056, 1333,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  129,   37,  130,    1,   32,    1,  131,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  361,  166,    1, 2826,  855,   61,    1,    1,    1, 2890,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   26,  242,   98, 2053,    1,    1,   29,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089,   12, 2229,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1682,   45,  104,  279,    1,    1,   37,   52, 1683,   32, 1081,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  282, 2334,  162, 1998,    1,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2206, 2435,  459,    1,   37,  547,  356,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1427,  492,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1211,  224, 1013,    9,  327,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  775,  331,    1,  166,    1, 3019, 1151,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   65,  716,    1,  996,   93,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,   37,    1,  365, 3144,  863,  602,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 1310,   37,  764,  163,    1,   12,    1,  681, 1706,   32,\n",
      "          976,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  809,    9,  458,  931,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2975, 1914, 1236,  829,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  493,    1, 2414, 1295,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1247,  571,   37, 2565, 3263,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1471,   37,   26,    1,  250,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,  794,  112,  993, 2043,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1, 2713,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  590,    1, 1771, 1022,    1,    1, 2138,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3068, 1484,   98, 1962,  618,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1149, 3060,   32, 2596, 2716,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  207,  338,    1,  583,  191,  584,  585,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 2442,   22,  847,  353, 1022,  737,  197,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,  551,  105, 1087,   12,    1,  387,  590, 1188,    9, 1087,\n",
      "            1,   98, 2695,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3125,   45,    1, 1210, 3382, 1683,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1651,  142,    9,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1342, 2846, 3096, 2565,  813, 2912,  187,  512,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  409,   25,   71,   60,   28,  951,    1, 1547,    1,   94,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2648,    1,   45, 1547,    9,  779,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,    1,   45, 1259,  220,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   12,  464,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187, 1122,  225,    1,    1, 1682,  138, 1595,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  744, 2019, 1563,    9,  365,  769,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1974,   56, 2308,  548, 2811,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1718, 2232,   15,  686,  105,  365,  845,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  356,  560,  347, 1180,   85,   32, 1034,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1384, 1535,  140,    1,   59,   32,   81,  138,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2293, 1778, 2580,  327,    1,  202,  167,   52, 1488,\n",
      "         1160,    1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2227, 2412,  744, 1224,   32,  395,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   12,  103, 3407, 3382, 1921,   32, 2646,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1070,  342,  147,   37,  899, 1350,  695,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  976,   90,  864,   52,   55,  104,  361,    1,  220, 3385,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3358, 2892,  429,    1,    1, 2083, 2611,   32, 2197,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  619,   98, 1477, 1990,  872,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,    1, 3269, 1103,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,  251, 1107, 3049,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  597,    1, 1190, 1061,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175,  726, 1022, 1131, 1684,   32,  537,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3299, 2192, 3296, 1285,  297, 3117,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226, 1924,    1,   98, 3386,    1, 1920,  396,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  590, 1400,    1,  220,  389,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  601,  671,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2077, 1342,  721, 1098,   37,  582,  395,  285,  963, 2122,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3153,  663, 3061,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  649, 3033,   37,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  169,  361,  702,   32,   54,  170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  627,  996,  406,    1,  338,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1619,  458,  300, 1251,   45,  734,  242,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1578,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,   26,  242,   60,  338,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  487, 1938, 3197,   79, 2227, 2462,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  756,  757,  315, 1140, 2363,    1,    1,  389,    6,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1572, 1414,  907,    1,   32, 3155,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,    1,   28, 1037,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1825, 2751,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2572,   32, 2018, 3392, 1585,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  582,    1,    1,    1,    1,    1, 1682,  774,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1214,   64,  140,    1, 1684,  297, 1361,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2962, 3236,    1, 3256,    1, 3175,  221, 1048,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  413,    1,   37, 1427, 1234, 1863,  847,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2754, 3102,    1, 1147,  947, 1940,    1,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37,   52,    1,  424, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1189,    1,    1,  220, 2673,  132,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   12,  365, 1230, 2420,  365, 1607, 2575,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,   23,    1, 2356,   45, 2901,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1414, 1953, 2051,    1,   32, 3155,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640, 1194,    1,  187, 3296,  688,  705, 1458,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  621, 1542,    9,  104,   22,   23,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  593,   12,  553,  161, 2607,    1,  580,  537,  611,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1426, 3293,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   61,   39,  176,  474, 2211,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428,  475, 3067, 2292,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2907, 1308, 2838,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2834,  100, 1937,  487,  947, 1013,    1,    9,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   90,  147,  148,   51,  417,  142,    9,  647,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  649, 1090,   13,   30, 2315, 2589, 1379,   12,  112,  499,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  355,  737,  197,   85,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1723,  848,   50,   37,  138,  331,   37, 2206,    1,  669,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3233, 1025,  288,   37,  114,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3184, 1190,   37, 1046, 2292,  134, 1603,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  113,  631,  176, 2957,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1403, 1167,    1,   81,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   12,  964,    1, 3144,  446,   32,  844,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1477, 1990,  415,  786,  388,    1,    9, 2523,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2238,    1,   28, 2657,  910,  220,  657, 1259,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  848, 2371, 1480,   79,    1,    1,  449,   74,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,  566, 1698, 1913, 2113,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1305,  572,  197,   79,  419,    1,   37,    1,  331,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  593,    1,    1, 2402,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 195, 681, 686, 191, 230,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 815,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3123, 2479, 1133, 2041,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1,   32,  378,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,  37,  52,   1, 452,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 300,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  156,  388,  763,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2963,  297,    1,   12, 2564,   37,   97, 3207,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1465,  326,   12,    1, 1510,    1, 1294,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885,  354,   37,  694, 3205, 3194, 3195,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2132, 3013, 2668, 3013, 1022,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  199,   55, 1065,  199,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1652,    1, 2355, 1718, 3004,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,    1, 1248,  822,  522,  297,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12,    1, 1924,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,   37,    1,   98,  166,  454,   37, 1965,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1423, 2024,  132,    1, 1533,   79,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  340,    1,    9,    1,   12,  890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  398,   37,    1,  527,  142,   37,    1, 1384,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785, 2161,  335,   37,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  393,   82,  387,    1,   37,    1,  389,    6,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102, 1315,  105,  106,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 674,  45,   7, 853,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 206,  12, 197,  28, 419,   1,   1, 921, 308,  88,   1,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  865,    9,  914,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  163,    1,   12,    1,  515,    1, 3207,  105, 2213,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2800, 2308, 1231,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  673,  793,  580,  467,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1,  460,   12,  920,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1975, 1188,  436,    1, 1176,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  105,  365, 2866,  220, 1778,  535, 1863, 2928,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3364, 1564,  863,  221,    1,    1,   37,  973,   81, 2042,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   61,   80,  415,    1, 1031,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2728,  377,  643,   32,  385,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  398,    1, 1035,   12, 2099,   37,  698,    1, 2113,    1, 1082,\n",
      "            1,    1,  357, 1817,    1, 2165,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2266,  267, 3369,    1,  612,    1, 1450,   98,    1,   32, 3118,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1773,  571,   37,  197,   32,  449, 1023,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  491,    1,    1,   32,  395,   14, 1597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1452,   27,  754,    1,  105,  365, 1030,   61, 2410,   32,  166,\n",
      "         2095, 1523,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129,    1, 1401, 2337,    1,    1,    1, 2017,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1205,  297,    1,    1, 2695,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  496,  387,    1, 1147, 2705,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  938, 1075, 2924,  221,  403,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  996,   93,    9,  395,   32,   76,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  448,  187, 1533,  187,  661,  321, 1937,   37,   52,  125,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1022,    1, 3008, 1585, 1229, 1610, 1387, 1890,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2241,   45,  777, 2264,    1,  220,  858,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1433,  166,   26, 1039, 2876,  321, 1604,   32,  854,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962,    1,  640,  726,  813,  187, 3117,  103, 3248,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2127, 1001, 1900, 1046,  365, 1737,  261,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  654,  721,    1, 1632, 2256,   12,  495,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  316,    1, 1214, 2211,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 2864, 1204,   45, 3053,  944,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  191,    1, 1987,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1,  908, 1994, 2650,    1,    1, 1506,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3096, 3116,  922,  282,    1,    1, 2331,  187, 1987,  361,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1, 3005,    1,  297,  116,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2415, 3172,   12, 1589,  476,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1390,  389,    6,  205,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2708, 3065, 1941,  191, 3101, 1461,  187, 2804,   45, 3082,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2384, 1230, 2528,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2994,    1,  777, 2995,  218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2571,    1, 1408,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  439, 1450,   98, 1094,    1,  267, 3364,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2855, 2287,   28,    9, 1460,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 148, 155, 693,   9, 647,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 160, 716, 256, 229,  37, 636,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,  168,   98,  495,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,  267, 1428,  909,    1,    1,   37,  861,   32, 3118,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3343, 3353,  437,   12,  396, 2848,    1,  774, 3399,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  594,  341,  640,    1,   15,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1472,   28,  220, 1230,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 2652,  955, 1461, 1463,    1,  171,  550,  639,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2004,    1,   37,  109, 1181,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3082, 2968, 2434, 2032,    1,  992, 1750,    1, 3101, 2729, 2471,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 224, 376, 689,   9, 453, 265, 428,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 531,  12,   1, 729, 176,  48,   1, 420, 108,  88,   1,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   80, 1876, 1754,   37,  613,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  592,  437, 1464,   37,  759,    1,   98,  734,  591,  210,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3117,  619,    1,  384, 3234,    1, 2815,    1,  384, 3079,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1827,   37,    1,  166,  354, 1010,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  381, 1831, 1554,   32, 2160,   45, 1446,  287,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092, 1070,  103,  147,   37,  817,  912,  605,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3075,   37,    1, 1689,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746,    1,  829,   32,    1, 2348,  279,  844,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  758,    1,   37, 1463, 2355, 1013, 1522,   32, 2020,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2355, 1013,  884, 1003,  176,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   75,  981,    1,  207, 1484,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,   81, 1159,    1,    1, 1749,  220,  829,    9, 1778,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2025,   61,  193,    1,    9,  166, 2943,   45,    1,  116,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2809,  730, 2614,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  744, 2364,   98, 2314,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  976, 2520,   69,   24,  315,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  342, 1707,  104, 1727,    9,  296, 1527, 1281,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3301,   61,   32,  547,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  724,  191,  318,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1384,  475, 2411, 1433,  565,    1,  729,   32,  531,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  647,  615, 1066, 2591,   98,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  317,  863,  186, 1774,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  885,   84, 2100,  166,  454,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  683,    1,  737,  197,   28,  225,  407,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1443,   20,    1,    1, 1000,    1, 1737,   32, 1821,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2939,    1,  786,  388, 1427,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3260,  335,  631,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,  876,  612,    1, 2751,   32, 3118,   37,  907,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  155,    1,   37,  197,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   51, 1527,  506,   45, 2130,  420,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2967,   39,    9,  914,    9,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1786,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,  765,  156, 1836,   37, 1837,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359, 1670,   37,    1, 1876,    9, 3339,  469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2,  60,   1,   1, 388,   1,  76,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 575, 529, 658, 996,  93,  88,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2154, 1090, 2131,    1,   37, 1527,    1, 2166,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,    1,    1,  249, 2298,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,   12,    1, 1211,  844, 1564,  258,   30, 2869,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144, 2409,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  105, 1941, 2843, 1293,   32,  166, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1249,    1, 3289, 2779,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1152,   98, 2063,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2482,  415, 2074,   63, 1477, 1990,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3213,  640,   81,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1090,    1, 1247,  321,  612,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2414, 1897, 1537,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978,  769,  670,  187,   69,   25,  817,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3322, 2740,   32,  191,  750,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 2962,    1, 1401, 3218,  186,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1730, 1484,    9, 3102,   12,  949,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2782,   45,    1, 1258,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  600, 2827, 3102,  176,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1695, 1696,   82,   37,  631, 1943,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  320,  445, 2181,    1,  460,   12, 2281,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1405,    1, 1723,  193,    1, 1724,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3214, 1564, 1844,  176, 2507,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  125,    1,  629,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1492,   12,    1,   45, 2869, 2759,  535,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790, 1353,  973,    9, 1089,    1, 2528,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3369,  459, 3118,  802,  220, 2751,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1521,   45,    1, 1292,    1,    1, 1497,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3116,  922,  437,  517,  231, 3313,  298,   39,  220, 2828,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878, 2458,    1,    1, 1753,  829,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  449, 2725,    1, 2443,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1720,  872,  640, 2041,    1,    1,  190,  335, 2498,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2297,  117,  176,  404, 2926,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1176,  411,    9,    1,   37,  271,   26,  453,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2942,  671, 1882,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1359,   37,  741,  444, 2187,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  136,  353,  572,  354,   98,    1,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783,    1,   79,  509,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  566,  791,  297, 1338,   45, 1876,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  947, 2263,  786, 1178,  680, 1994, 2095, 1506,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   56, 1848,  494, 2861,   37,  611,   98,  636, 1336,  134,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2862,    1, 1683,   32,  949,   45,    1, 3080,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2924,    1,  548, 3391,   22,  477,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766,    1, 1230,  220, 2627,  413,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2858, 2665,  614,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1107,  293,    1,    1, 2730,    9, 1211, 2518,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1035,   37,  946,    9, 1038,  191, 1893,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1008, 1633, 1499,  582,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,   79,  187,  311,   12,    1, 1258,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1627,    1,    9,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422, 1536,  521,  149,  444,  709,  941, 1682,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  856,  365, 1016,   12,  234,    1,  235, 1002,  234,    1,  235,\n",
      "         2608,    5,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1170,  390,    1,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   12, 1447,  387, 2205,  115,   98,  903,    1, 1447, 2673,   46,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2480, 1523,  891,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  561, 2884, 1039,   45, 2466,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  705,    1, 1417,    1,  123,  176,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  466, 1017, 2913,  614, 1412,  220,    1,  470,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1962, 2522,    1,  167,  631,   37, 2322, 1080,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1492,   12,    1,   45,  166, 3180,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  159,  120,  187,  170,   66,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,  719,   37, 1706,   54,   32, 1021, 2273,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  788, 1908,    1,  384, 2911,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1103,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783,  460, 1901,    1, 1228, 2323,  176,  163,    1, 2196,    1,\n",
      "          639,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,  365,  769,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  520,  365, 3118, 3146,    1, 3148, 2669,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  902,  429,   79, 2920,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  686,  266,    9,    1,    1,  654,    9, 2196,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  907, 1584,  166,    1, 1174,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374, 3352, 2856, 1791,    1,   32, 3339,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  281,  282,  936, 1064,   32, 1131,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,   81,  384,  340,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  167,    1,    1,  506,  782,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2256,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962,    1,   34,  931,    1, 1110,    1,    9, 1340,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  225,    1,   98,  985,  776,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1965, 2982,  716,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129,  975,    1,  105,    1,  105,    1,  332,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2090,  967,  166,    1, 1628, 2721,  565, 1532,   45,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3128, 1931, 2343, 1927,  345,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1227, 2659,    1,    1, 1654,    1,  361,  515, 1055,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1,   98, 1815, 2362,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,   37,   26,    1, 1636,  124, 1411,  356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  743,   12, 1564,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1956, 1178, 1231,    9, 2673, 2596,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1173,    1, 1191,  220, 1935,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  914,   45,  753,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845, 2395,    1,  650, 2317,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   49,  952,  163,    1,   12,    1,  467,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   37, 1876,    1,    1,  442,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1586,   28,    1,    1, 1728, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   12,  647,  142, 1757,  431,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  389, 1103, 2740,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  650,    1,    1,   81,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 2527,   55,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1260,  105, 3392,  361, 3105,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  648,    1, 3046,    1, 1924,  264,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2708, 2855,    1, 2661,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,  146,   37, 3358,   37,   84, 1483,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  215,  852,  176,    1,  161,  841,  220,  223, 2135,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,    9, 1792, 2580,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  547,  649, 1295, 1530,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2315,   61, 1676,   37,  104,    1, 1661,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1056,  583,   32,  344, 1260,   98,  938, 1075,   23,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1091,  590, 1400,    1,  680, 1656, 1311,  625,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  430,  529,  636,  477, 2055,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1319,    1,    1,  288,   37, 1174,   32, 1966,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 3108, 2072,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181,  794, 1199, 1102,  841,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2855,  544,  275,  441, 1876,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1404,    1,  105,    1,    1,  166,    1,  361,  105,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  852,    9,  118,  474,  138,  125,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  108,   45,    1, 2275,    5,  469,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3207,  580,    1,    9,  671,   32,  845,  147,   45, 1283,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2642,  135, 3225,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3169,   32, 1194, 2287,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2733,    1,  600, 2086,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2366, 1441,  845,    1,  784, 2359,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193, 1724,    1,  191,   69,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  341,    1,  845,  237,   15,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123, 2246, 3186,  489, 1387, 1056,   45,  166,  105,   12,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  245,   32,  913,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  515, 2751, 2074,   37, 2192,   28,    1, 1523,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3285,    1,  750,    1, 2484,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116,  741,  105,  270,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2050, 1676,  855,   32,    1, 1575,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  636, 1042,  202,  997, 2449,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2226, 2112, 2226,  705,    1, 2467, 2391,  845,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,   66,    1,  365, 1766, 1767,  769,  424, 1034,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,   28,  951, 1547,   98,  800,    1,   29,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 1090, 1091, 2116,   98, 1273, 2287,    9,   93,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,  484,   98, 3207,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497,  664,    1,    1,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  617,  259,  321,    1, 1658, 1411,  221,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503,  225,    1,   98,  195,  550,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2339,   45,  270,    9,  537,    1,    1,    1,    1,  105,    1,\n",
      "          157,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1366, 1445, 2602,    1,  381,   90, 1346,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1773,    1,  848, 2286,   37,    1, 1220,  115,   45, 2063,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  989,    1, 1707,    1,   12,    1,  131, 2187,  142,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  344, 3403, 2414,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  231, 1158,   12,  365, 2452,  517, 1139,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  715, 1656, 2054,  580,    1,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,   37, 1174, 1809,    1,   32,  395,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1539,   98, 1220, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2746,  837,  531,  861,  187,    1, 1124,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  395,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192, 2018, 1722, 2522,  444, 1364, 1365,  220,    1,  726,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  457, 1821, 2728, 1478,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  382,  293,  420,  479,   82,  967,  365, 1567,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  203,   37, 1662,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  459,   45, 1204, 1976,  176,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  105,    1, 2254,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  475, 1584,   12,  168, 1154,  166, 3015, 1821,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  539,    1,    1,   37,    1,  901,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280,    1,  220, 2472,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1128,  361,  755, 1636,  327,  210,    9,    1, 2547,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1383,  167,   92,    1,   12, 1948, 2467,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2991, 2384,    1, 2549,    9, 1095,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3314, 1293, 2793,    1, 1545,  361,    1, 1647,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1471, 1384,    1, 1533, 1979,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374,  650,  578,  460,  967,    1, 1450,   98, 3095,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  961, 1482, 1268, 1953,    1,    1,   37, 1083,  347,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2375,    1,  531, 2582,  590,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,    1,   37,  104,   48,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327, 1467,  331,   37, 1211, 3365,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2, 179,   1, 180,   1, 170,  59,   1,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 829,   1, 331, 116, 844, 132,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  593,   32,  870,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2323, 1167,    1,  818,  325, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1016,   74,    1,  628,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1962,  140,    1,  372,   94, 1085,   24,  384, 2656,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1715,    1, 1162,  250,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3340,    1, 2572,   32, 3360, 1142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  584,    1,    1,  600,  495,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2034, 2051,  763,  105,    1, 1146, 2102, 1171,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2376,  855, 1082, 2209,    1, 2024, 1559,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1855, 3365, 2572,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  393,  159, 1253,   98, 1858,    1,  943,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2945,    1,  540,   37,  540,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  654,   37, 1012, 1013,  700,   37, 1000,  365,  475,  191, 1014,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777, 1586,   28,    1,   45, 3028,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1100,    1,  449, 2071, 1331, 2403,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  850, 3103,  951,    1, 2807,   37, 2675,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1151, 1091,  243,    1,   11,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  317,  170,    1, 3031,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147,  232,    1,  163,    1,  903,    1,  863, 1527,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2142, 1022,    1, 1249,    1, 1022,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1020,   12,  627,   32,  593,   45, 2205,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  202, 2711, 2083,  166, 1948, 1360,  612,   52,\n",
      "         1059, 2330,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1173,   37,  166, 2391, 2697,    9, 2923,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938, 3194, 3195,    1, 2360, 2667,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  705,    1, 1417,    1,  921, 1833,   32, 2161,   12,  138,    1,\n",
      "            1,  220, 1940,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965, 2982,  619, 2919, 1021,   92,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3254,  361, 3046,  631,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1089,   30, 3340, 1428, 1149,   32, 3360,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1643,  388, 1912,   37,  148,  647,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  569,  764,    1,  688, 1178,    1,  787,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1396,    1,  191, 1987,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 2414,  163,    1,   12,    1, 3111,   27, 1147, 1223,\n",
      "           45, 3391,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3129,  873,    1,  453,  248,   95,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548, 1744,    1,    1, 1545,  566,    1,   32,   91,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  744,  119,  176,    1,  427, 1343,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 2962, 2920,  186,   37,  688, 1957,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2728, 1308,   79, 2707,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3238,  967, 1857,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386, 1426, 2069,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1447,   51,   52,  653,   63, 1428,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2861,  754,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2470, 1931,  403, 1447,  190,    1, 2191,  104,  741,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2527,  164,  407, 2083,    1, 2060,   32, 2573,    9, 1022,  199,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  597,  475,   45, 1465, 1466,    1,  513,  193,  514,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390,  225, 1137,  187, 1625,   71,   98,  132,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1046,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777,  835,  755,   12, 3028, 2232, 1228,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  879,   24,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296, 1550, 1322,  829,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1818,  147,  958,  484,   37, 2831, 1899,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,    1, 1120,   37, 1752,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1531, 3263,  872,  420, 1657,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 3311,   76,   37,    1, 2920,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  732, 1346,   37,  619,  125,  636,  541,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3400,  891,   74,  611, 1175,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  695, 2789,  958,    1,  469,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  958,  104, 2099,    9, 2924,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,    1,    1, 2549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  617,  618,  335, 1230, 1787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1702, 1159,   91,  220,  517,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  487,    1, 2430,   98,  163,    1,   12,    1, 2834,  134,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3140, 1648,   37,  489, 2924,  384, 1430,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  166, 1065,  289,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273,  259, 2264, 1427,  452,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2471,  184, 3116,  922, 2250,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311, 2936,    1,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3088, 1731,  321,  612, 2446,    1,    1, 1044, 1045,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2719, 1024,   98, 1283, 2925,    1, 1123,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3180,  470,  608,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1397, 1090,    9, 3298,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  538,  524,   37,  125, 2471,   37,    1, 1467,  191,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1018,  661, 3201,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3065,   61,  449,   37, 1878,    1, 2198,  105, 1333,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  770,   45,    1, 1213,   12, 2059,    1, 1976,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  256,    1,    4,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2918,  190,   52,  915, 2923,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   20,   12,  572,  197,   28,   98,  622,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3369,  267, 2751,    1, 1450,  528, 2024,   46, 3355,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   74,    1,  193, 1232,  334, 1445,  829,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3183,  664,    1,    9,  356,    1, 1289,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  884,   98, 1531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  810,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,   61,   28,  220,    1,  361,  758,    1, 1525,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3141, 1236,   37, 2446,  231,   45, 2811,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384,    1,   37,    1,  220,  829,   12,    1,  475,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3240, 2317,    9, 1694,   45,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,  421, 2749,    1, 2382,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1090,  384,    1,    1,    1,    1, 2297,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,  267,  460,   12,    1,   17,  452,  170,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,  176, 1487,    1,  105, 1107,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1983, 2218, 1151,  321,   52,    1,   32,  770,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2826,  519, 1210,   10, 1708,   37,   81,   79,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196,  155,  197,  157,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3053,   37,  907, 2214,    1,   98,  865,   37, 3024,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   52,    1,  220, 2742,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1290,  396,  245,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   77,    1,  929,    1,  361,   81, 1437,  315,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230,    1,    1,   37, 2062,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1056,  104, 3111, 2572,   32,  531,   12, 3155,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2687,    1, 1242,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  625,    1,    1,  103,  275,  681, 1413,   37, 2199,  111, 2026,\n",
      "         2574,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  316,  317,    1, 2275,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 3329,   45,  559,  726, 1114,  220,  402, 1294,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2086,  103,    1,   45,  365, 1092,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  775, 2355, 1013, 2549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3385,  738,   37, 2000,  864, 2390,  210,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  942,   12,  139,  751,  872, 1298, 1991,    1,    1,  187, 1603,\n",
      "         2843,    1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151, 1417,  551,  717, 1716,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1147, 1009, 2037, 1876, 2072,  740,    1,  863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2673,    1,  384,  531, 2249,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  509,  176, 1545,    1,  267, 3213,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1176,  411,   37, 1807,   12,    1, 1447,   12,    1,   37, 1428,\n",
      "          861, 1906,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,    1, 1811,  404,    1,    1, 1428, 1953,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  520, 3146,    1, 3369,   98, 3118,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1755, 1499,  994,    1,  150,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2144, 3111, 2844,    1, 2337, 1656, 2596,  868,  844, 2363,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  344, 3403, 1396, 2597,  947,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  656,   45,  661,   45,  666, 1564,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3172, 1090, 1829, 3194, 3195,  176, 2388,  171,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 2077,    1,  479,   37, 1706,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   61, 2584, 2565,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,   51, 1306,  837,    1,    1,  267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  453,    1,  195,    1, 1249,  195, 1532,  191,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,   32,    1,  297, 1623,   45, 1527, 1149,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  496,    1,  495,  411, 1411,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425,   37,  151, 1883,    9,    1,  131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  105, 2994,   32, 2997,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  560,  347, 1124,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,  361, 2466, 2165, 1673,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296, 1042,  829,  695,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141, 1090, 1829, 1717, 3219,  176,  365, 1546,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  854, 2018, 2471,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2321,    1, 2270,   37, 1343,  583,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1543,  365, 1009,   32, 1422, 1002,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  475,   37,  907,  810, 2708, 1900,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 2161,  103, 2132, 1252, 3090,    1, 2716,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  727,  794,  365,    1, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1903, 1610,  220, 2531, 2885,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  453,    1,  528,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3170,    1,    1,   12,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  374,    1,  329,    1,   12,  551,  552, 2338,   98, 2022, 1002,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1527, 1121,   37,  759,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  885,  471,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425,   37,  151, 1883,    9,    1,  131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  135, 1850,  455,    1,   74,  548,    1, 2572,  176,  177,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  218,  332, 1784,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  375, 2070, 3285, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   47,  960,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  931, 2236,    1,    1,   37,  698,  176, 3229,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12, 1100, 2747,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  845,  626, 2919,    1,  176,  166,    1,  656,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  710, 2520,  647,  132, 2973, 1764,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  374,  375,   37,  349,    1,    9,   59,   32,  987,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  398,   37, 2360, 1899,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  171,   12,    1,  947, 2655,    1,   37,    1,   22,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  102,  453,  141,   48,    1,   61,   76,  103,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,    1,    1,  229, 1787,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878,   12,  365, 2103,  617,    1,   61, 1621,    1,  122,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  375, 1187,    1,    1,   98, 2318,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 1938, 3197, 2440,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1184,  347,  698,   37, 1526,  187,  433,  636,   93, 1071,   37,\n",
      "          547,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  297, 2547,    1,    1, 3047,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3083,    1,    1, 2434,    1,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,  267,  460,  190,    1, 1428, 3146,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1070,  146,  147,   32,   91,   37,  211,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,   33,  625, 1308,  166,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  625,  261,  548,  147,    1,  715,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3263,  103, 3287,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  531, 3006, 2856,    1, 3365,  777,  778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,    1,    1,   98, 1021,  548, 1450,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  302, 1712,    1,  334, 1445,  590,  224,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3152,   85, 3259,    1,  860,   37,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3303,  140,  593,  427, 1343, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  105,    1, 1837,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   25, 1473,   98,  677, 1097,   57,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2563,  499,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1100, 2384,  340, 1251,  207,  412, 1671,   32,  854,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 2870,   32,  531, 1633,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  503,    1,   37,  417,  763,   76,  156,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1420,    1, 1579,  104,  331, 2003,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2178,  597,  391, 3390,   32,  187, 1009,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777, 1008,  365, 1644,  187, 1280,  522,  767,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,    1, 1108,   37,   52, 2812,   32,  388,  763,\n",
      "         1509,  151,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,   10,  729, 1862,  600,  531,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1245, 1380, 1090, 1045,   37, 1463,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1159,  845, 2287,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  790, 1380,    1,    1,   98, 2056, 1171,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  361,  657,  168, 1300,  220, 2436,    1,   45,  166,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  438, 1678,   37,  973,    9, 1211,  442,  220,  104,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  137, 1582,  396,  176,  600,  372,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3203,   81,   98,  730, 2614,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938, 1075, 3160,   12, 2162,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1123,  593, 1990,   46, 1647,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  485,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,   81,    1,  105,   74,  548,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,    1,  475,  680,  433, 2263,   32,    1,  927,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3164,   12,    1,    1,   16,    1,  951,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2136,    1, 2676,   37,  907,   32, 1851,    1,  736,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   75,  692,  119,  599,  444, 2114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280,  140,  365, 1788, 2472, 1564,   28,    9, 1674,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  709, 2379,    1,  239, 1335,  514,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1005, 2942, 2590,   81,  888,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3312,    1,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2104,    1,   61,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  503,  749,  480,  586,    1, 1379,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,   28,    1,  218,  566,   65,    1,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,   25,   26,   85,  548,  682,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1022, 2589, 2186,    1, 1603, 2290, 2911,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2885,  879,  631,  297, 2523,    1,  431,  103, 2788,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1017,   37, 1155,  649, 1097,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1952,  506,  782,   71,   32,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  748,   79,   37,  105,  227,  698,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  273,   12,    1, 1343,  967, 2769,   98, 1204, 1876,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1955,    1, 2412,  420,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  176,  915,    9,    1, 1492,    1, 3370,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1342,    1,    1,   37,  582,  283,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1645,    1, 2816, 1803,   32,  557,  540,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971, 1149,   32,  602, 1313,  389,    6,  105, 1913,   74,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3214,  431,  686,  119,   32, 3236,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  650,  108,   98, 2141,    1,  357, 2844,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,   32, 3343,    1,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1746,  162,  680,  454,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  705, 1458,   37, 1348, 1024,  442, 1896,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647, 2352,  645,  148,  693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  947,    1, 1223,  548,    1, 2844,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  295,  459,    1,  132,  220, 1545,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2388, 1022,    1, 1249, 1619,    1,    1, 1022,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2819,  680,  674,   32, 1056,  537, 1712,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,    1,    1,    1,    1,   32,  455,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,    1,   37,    1, 3118, 1512,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3349,    1,    9,  388, 2292,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1592, 1937, 1220,    9,  777,  286, 1077,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  275,  533,    1,   69,  817,   98,  310,  159,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  304, 2264,  357,    1,   28,  112,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1037, 1268,    1,  951,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   52, 2297,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2881, 1718,  321,  612,    1,   37, 1778,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  119,    1, 1236, 1158, 1465, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1542,    9,    1, 1787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  375, 1654,  915,  916,    9, 3126,  176, 2890,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  845,  147, 1360,  612,  665,    1,   98,    1,    1, 2661,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2918,  884,    1,    1, 2697,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1700,   73,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283,    1, 3272,  103, 2635,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  384,    1,  963,    1,  865,  754,   37,    1,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390,    1,  587,  759,  630,   37,    1,    9,  209,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  741,   76,  424, 1034,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3155, 2024,    1,  820,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   98,  199, 1998, 1137,  176,  405,    1,   32,  385,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,   37,   26,  704,  551,  705,  656,   32,  455,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  121,   12,    1,    1,  964,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 2246,    1, 2354,  845, 1114,   32,  925,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1492,  140, 1232, 2292, 2151,  531,  741,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2753,  182,   32,    1, 1495,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  815,   45, 1568,    1,  565,  786,   84, 1415,   37,    1, 2276,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503,  992,   28,    1,    1,  548,  480,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1536,    9,  105,   59, 1126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1708,  777,  778,  556, 2311, 2770,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1040,  814,    6,  111,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,    1,  508,    1,   37,    1,    1, 1492,    1,  537, 1490,\n",
      "           32, 1327,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1408, 2500,    1,  736, 2793,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1829, 1510, 1029,   12, 1009, 1877,   37, 1171,   85,    1,   45,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2484, 2681,    1,  571,   37, 2760,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,    1,  676,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1853,   32, 1242,  187, 1585, 1950,  640,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2760, 1564, 1084,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2004, 1900,  973,   98,    9,  844,   98,  617,  618,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1795,   82,  387,  593,   45, 2252,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  299, 1229,  288,   37,   81, 3388,  442,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   69,    1,   98,  954,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   85, 2979, 1781,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1443, 1413,   37, 1835, 1736, 1656, 1017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428,   37,    1, 1711,   45, 2924,   32,  463, 3369,  548, 2024,\n",
      "          132,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700,  388, 2496, 1976,   32, 3383,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  786,   45,    1,   12,  638,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  120,   37, 1389,    1,    1,  267,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  167, 2303, 2258,    9, 3079,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  936,  365,    1, 2474, 1075,  220, 1106,  450, 1108,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1298,   37,  151,    1,  639,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1591,    1, 1126,  155,  152,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1024,   37, 2615,  967,  105, 1204,   45,  453,  248,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1249,    1,   37,  759,  671, 3126,  427,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1971,  504,    1,  220,    1, 1031,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   67,  418,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1524,   67,  423,   76,  384,  104,   65,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,    1,  140, 2505,  176, 3292,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,  933,    1,   29,  220,  365, 2943, 1499,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425,  200,  861, 1560,  918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1300, 2988,    9, 1778, 2987,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1808, 1412, 1107, 1218,  251,    1, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2373,   37,   14,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497, 2347, 3131,    1,   12, 2787, 2119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1181,   30,    1, 2382,  259,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  561,    1,    1,  190,   52, 1754,    1,   37,  365,  312,    1,\n",
      "            1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1105,  787,   15, 1124,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384, 2780,   37,    1,   12, 1354,    1,   28, 1886,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  386,  781,   37,  151,  215,   12,    1,    9,    1,  372,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2884,    9, 2986,   45, 2835, 2950,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,    1,    1,  176, 1953,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1721,  324, 1018,    1,    1,    9,  326,   12,  327,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3346,   32,  104,    1,   98, 2751,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307, 1355,    1,    1,    1,   98, 2351,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  457,    1,  140,  331, 2223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  861,  260,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 353, 105, 720,  32, 197,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 458, 994,   1, 150,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  726,    1, 2777, 2577,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116,   25,    1,  185,  242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1089, 1090, 2633, 2177,  176, 1604,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  261,   39, 1864, 2673,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  103,    1,  675,   77,    1, 1998, 1650,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1492,  606,  565, 1278,  460,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  176, 3112,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2922, 1360,  612,   52,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  310,   25, 2582, 2084,    1,  504,   32,  257,  848,  418,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3013,  171, 3134, 2308, 2317,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  885, 2059,   45,    1,  796,  176,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2685,   37,  114,    1,  176,  166,  439,   45,  166,  914,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1178, 1231,  220, 1887,  597,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1699, 2327,    1,    1,  571,   37, 1922,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  968, 1458,  395,   98,  442,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2565, 1301,    1,    9,    1,   55,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3265, 1987, 1414,    1, 2800, 3164,   37,  930,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  837,    1,    1,    9,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  409,   25, 1473,   37, 1034,  181,  845,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043,  418,    9, 1022,  199,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   93,   32,  572,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425,  190,  151, 1883,    9,    1,  131,   32,  225,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  794, 2333,  676, 2131,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1528, 2471,    1,    9,    1,  628,  631,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 373,   6, 381, 731,   1, 225,  85,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 829, 951,   1,   1, 460,  12, 297,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1079, 3063,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   83,   37,   84,   85,  187,   82,   32,   87,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  113,  721, 1953,   37, 2000,  214,   45, 2245, 3096,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3188,    1, 1103,   32,    1,   28,  808,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2206, 2435,  313,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  640, 1777, 2739,   32, 3181,   12,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2835,  692,    1, 1140,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1940,   12, 3134,  550,  328,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1327, 2489,  808,   45,   91,   12,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1632,  105,    1, 2408,   12,    1,  566,    1,  166,  593,   96,\n",
      "            1,   85,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 789, 986,  79,   9,   1, 361,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  63, 166, 862,   1,   1, 148,  71,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3227, 1285, 2551,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  439,   28,  187,   69,  102,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3192,    7,    1,    1,    1, 1260,   32, 2741,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178, 2827,   32, 1051,  400,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2045, 1577,  387,   15,    1,  237,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 3162, 2856, 3006,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  792,    1,  443,  792,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  636,  125,  187, 1808,  200,  104, 1107, 2610, 1108,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1186, 1544,  700,  187, 3102,  513,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  176, 1604,   98, 2355, 1013,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  458,   45, 2741,  113, 1184,  347,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3206,   71,  297, 1668,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  587, 1377, 1390,  389,    6,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1230, 2264,  168, 1159,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1918,  193, 2398,  187, 3182,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3054,    1, 1270, 1215,  846,   45, 1620,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  384,  166,    1,   45, 2162,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1107,  293, 1070, 2899, 1359,    1,  709,    1,    1,    1,    9,\n",
      "          764,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3101,    1,  294,    1,  726, 2376,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  590,    1,    1, 1000,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  104, 1290,  396,   71,   98,   81,   45,  567,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 1194, 1267,   45, 1050,    1,    1,  729,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1246,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  193,  810,  363,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,  469,   37, 1594, 2355, 1159, 1766, 1767, 1153,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1169,  389,   93,    1,  800,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  975,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  753, 3118,    1,  190, 2199, 2292,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1870,   12,  865,   37,  455,   51,   52,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2373, 2627, 2177, 1027,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  631,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  879, 2851,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1293, 1913,   32, 1327, 3123, 1401,   32, 2468,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,  159,  439,  526,    1,  202,  649,   25,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   69, 1276,  202,   27,   98,  889,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2095, 2985,    1,    1, 1791, 2764, 3394,    1,    1, 1231,\n",
      "           32, 1186,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  616,   77,  661,   98,  156,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,    1,   10,  269,  850,  297,  531,  187, 1009,    1, 1428,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  715,  112,  157, 1042,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3198, 1249,    1,    9,   72, 2197, 3329, 2545,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2868, 1949, 2890, 2784,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810,  809,   26,    1,  202,  439, 2095,  449,  446,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  624,    1,  154,  726,  695,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 2187,  162,  410, 2407,  384,  647,   17,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  182,    1,  831,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2859,    1,   92,  743,   12,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1564, 2218,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2190, 2640,  884,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  614,  548,  845,  439, 2232,  218,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,  660,  331,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1652, 2061,    1,   37, 1174,    1,   37, 1718,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2676,   32,  599, 1505,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1, 1103,   32,  445,   45, 1033,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   34,    1,  861,  673,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3015,   12,    1, 1333,   61,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,   85,    1,  786,   37,  168,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2221,    1,   32,    1, 1863, 2162,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171,   45,  166,  593,   12,    1,    1,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1758,   37,  862, 1787, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  365, 1920,   32,    1,   12, 1204,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3204, 1542,   37,  665,    1,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  952, 3154,  631,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  548,  105,    1,    1,    1,  224,  159, 1473,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    8,  228,    1,   98, 1778, 2558,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1106, 2270,   37,  693, 1013, 1228,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  902,  821,  525,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3286,   12, 2378,    1,    1,   12,  114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147, 1579, 1022,    1, 1432,    1,  152,    1,  895,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2924, 1388,  220,    1,    1, 3357,   32,\n",
      "         2646,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1,  108, 3140,  444,    1,   32, 1430,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1220,  531, 2129,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3303,    1,  191,  786, 2847,  176,  464,   26,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2993,   12, 1117, 1525,    1, 3056,    1, 1781,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,    1, 2003,    1,   32,  584,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  658,  763,   76,    1,  267,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203, 1710, 1444,  439,  166,  443,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3245,  967,    1,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,  715,   26,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  666,    6, 1021,   37,  331,   32, 1817,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1212, 2696, 1458,    1,  187, 2722,    1, 2616,  512,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  766,    1,    1,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1256,    1, 1417,    1,    1,  708,  709,    1,   12,    1,    1,\n",
      "          582,  428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  511,  275,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  638,    1, 2571,  474,   51,  764,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1520,  256, 2177,  988,   37,  453, 1718, 2419,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878,   37, 1753, 1117, 2208,  700,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3151,  891, 1756, 1167,  167,   52,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1082,  104,  193,   37,  588,  105, 2010,   37,  453,    1,\n",
      "          532,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  617,  259, 1281,   55,   37, 2449,   32, 1601,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3248,  442,    1,    1,   37, 3183,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2441, 2434, 1108,  640,   81,   32, 2086,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974,  105,  633,    1,    9,  845,  275,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  479,    1,   37, 1334,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845, 1480,  602, 1173,  115,   37,  463, 1447, 1463,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 2067,   61,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  414,    1, 2111, 1393,  614, 1412,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  567,    1,    1,    1,  202,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299, 2591,   37, 1281,   78,  384,    1,  116, 1108,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2, 112,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 503, 155, 749,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1584, 2218, 2495,  255,  627,    1, 2736,   90,  602,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2967,   39,  176,  177, 1056, 1675,  220,    1, 1987,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3294,  361, 1247,  167,   92,  166,    1,   32, 1352,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3170,  338,    1,  187, 2427,  477,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2843, 2523,    1,    1,  597,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  696,   32,    1,    1,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  381,   37,  138, 2196,  599,   98,  574,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1353,  395, 1116,  778,   32,    1,  973,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3134,    1,    1,  967, 1031,   45,  985,  361,    1,   37, 1343,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081, 2591,    9, 1031,  187,  597,  391,   98, 1171,    9,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1117, 1943,   15,   71,   32,  581,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  361,    1,    1,    1,    1,  537,   32,  756,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,  879,  214,  693,    9,  647,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   12,   37, 1752,    1,   12,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2250, 2758,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  381,   12,    1,   37,  619,  590,    1,  317,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  386, 1654, 1164,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117, 1525,    1, 1251,    1, 2461, 2449, 2298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1654,  505,  856,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  686,  885,  845,   98, 1282,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  320,  193,    1,   37,   52,  474, 2228,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1054,    1,  394,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  273,    1,  934, 1229, 1698,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2265,  947,  949,    1,    1,   45, 1530, 2764, 3394,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,   24,   37,   92, 1718,  861,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1085, 2054,   28,  187, 1097,   57,  670,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  518, 1726, 1953,   32,  104,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,    1,  191,  784,  211,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 1307, 1775,  220, 1018, 1285,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,   12, 2084,    1, 1976,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1327,    1,   37,  489, 2924,   39,   45,  531, 1232, 2597,  957,\n",
      "         1070, 2404,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,   57, 1476,  977,   37,    1,    1,  138,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3113,   12, 1277, 2940,   39,   98,  531, 1929,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181,    1, 1836,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2405,   37, 1029,  548, 2804, 1025, 3340,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1277,    1,    1,   37,  865,   37,  163,    1,   12,    1,\n",
      "           32,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129,  119,  156,    9, 2885,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  848, 1303,  244,  384, 1273,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100, 1396, 2065,  593,  220,  340, 1251,  327,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  527,  369,    1,  952,  467, 2022,  394,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1445, 1421,    1,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  550,  632, 1041,    9, 2693,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,   34,   95, 2462,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3260, 1529,    1,  472,   39,   45, 2467,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  504,    1,   32,  863,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2631,   36, 3250,   32,    1,    1, 1334,   98, 2365,  187,  750,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 2371,    1,   81,   37, 1014,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1666, 1539,   45, 2080, 2056,  880,   37, 1970,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  391, 1329,   37,  877,  810,    1,  974,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3232,    1,    1,    1, 1041,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  581, 1385,   45, 2018,  854,   46,   32, 1332, 1837,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962, 1123,  228,  686,    1, 1401, 3231,   37,  726,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2764, 3356,  213,   37, 1418,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1925, 1583,    1,    1,    1,    1,  818,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3211,   32, 2205,  548,    1, 1427,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   32,  585,    1,    1,  224,   61,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  166, 1264,  175,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  384,    1,   37,  166,  957,    1, 1744, 1592, 1937,    1,   68,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2909,   32,  531, 2856,    1,    1,  388,  763,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,   37,    1, 1772,  384,  183, 1410,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1902,    1, 1851, 2592,  321,    1,    1,    9, 3280,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2018,   12, 3380,  267, 1926, 1927, 2793,    1,  202,    1,   39,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  176, 2862, 3082,  949,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2663, 1391,   37, 2449,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1218,  958,    1, 1992,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1095,  716,  995,  242,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,   95,   85,    1,  786,   37,  168,    9, 2974,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,  714,    1, 2544,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1792,    1, 1074,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2964, 2988,  829,   12, 2987, 2762,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3327, 1321, 2225,  384,  584,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  720,  361,    1, 1085,   47, 1095,    9,  334,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1774,   39, 1463,   45, 1139, 1263, 1108,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3358, 2598,   37,  447,    9,  351,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  352, 1583,   37, 2192,  669,  388,  199,   37, 1814,    1, 2096,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  176,    1,  996,  805,   66,  187,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2528,   45,  365, 2023,    9, 1230, 1443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   77,    1, 1684, 1625, 2793,  220,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  737,  197,  418,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,  407,  115,   45, 1087, 1230,    1, 2452, 1539,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98, 2730,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2227,    1,  705,    1,  105,    1, 1579,    1, 1151,    9,    1,\n",
      "           12,  223,   29,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1256,    1,  552,    1,  485,   12,  197, 1556,  118,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1183, 1139,  977,  606,    1,  119, 1379,   12,  112,  499,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1647, 1594,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   91,  296, 1625,    9,  880,   57,  191, 1014,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  564,    9,   29,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453,    1,   28,   37,  422,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2857, 1285, 3123,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 395,   1,   1,   1, 650,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 224, 809, 439, 449,  74, 220,   1,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,    9,  105,  339,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1708, 2058,   79, 2697,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  602,    1,   37, 3077,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387,  590,  626,  109, 2537,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3343, 2696,  852,   37,  627,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  348,  859,   37,  907,  261,   45,    1,   32,  422, 1259,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  398,   12,  695, 1176,  123,   37,  754,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2695, 2223,  855,  267, 2977,  719,  885,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1109,    1,  159, 2317,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1583, 2465, 1755, 2504, 3105,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   49,    1, 1974,   69,  532,   37,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 3028,    1, 2994,    1, 2997,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,  315,  768, 1942,    9,   26, 1039, 2366,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3296,  872,  420, 1352,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2372, 1399,   45,    1,    1, 1013,    9, 2476,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1364, 1365,    1,    1, 2162, 1780,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2994, 2995,  387,  120,   32,  815,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,    1,  288,    9, 2646, 2024,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3151,    1,  390,    1,  420,  267,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1450, 1056,    1,   32, 1850,  691,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  197,   28,    1,  159,   85,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1007, 1090,  275,  353,  417,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2826,    1,    1,   39,    1, 2161,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2814,   45,  484,    1,    9,  903,    1, 1423, 2024, 1861,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,  45, 166,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  60, 700, 548, 577, 163,   1,  12,   1,  29,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1100,    1,   61,    1,   28,  220,    1, 1017,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  293,   21,  590, 1031,    9, 1850,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2414,   32, 1619, 2597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1811,  404,    1, 1167, 1360,  612, 1604,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1240,  606,    1,    1,   98,  220,  413, 1292,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1899, 2810,   37, 1734,  776,    1,  398,  261,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  166, 1090,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  361,  849,    1,   79, 1114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1226,  384,  119, 1653,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   72,   45, 2476, 2898, 3002, 1360,  612,  477, 2588,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  823,   45,  501, 1975, 1921,  187,    1,  125, 1649,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1236,  297,  787,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363, 3390,   32,  187,  449,    1,    1, 3343, 1009,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   91, 1401,  104,   32,  581,   74,   45, 3129,   12, 1477, 1990,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2733,    1, 3068,    9, 1211,  207, 1484,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2254,  140, 2255,  768,  149,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1258, 2457, 1844,  176,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   32, 2107,    9,  103,    1,    1,  729, 1333,   37,  619,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  517,    1, 2226,    1,  610,    9, 2772,   45, 1147, 3160,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  196,   12, 2204,  214,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,    1,   39,   45, 1273,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  224, 1126, 1954,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1,  286,    1, 1236,    1,    1,    1,    1, 1130,  420,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  794,    1,    1, 2549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  212, 1564,    1,   54,    1,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,   12,  142,    9,  647,  682,   98,  342, 1350,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   15,    1,  197, 1427,   98,  117,  983,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1537,    1,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  132, 1380, 1087,   81, 1159,    1,  218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  844, 2190,  665,   98,  104, 2095, 1638,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1237, 1658, 1117, 1525,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3391,   22,  868, 2856, 2144,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 2640,  744,   79,    9, 1821, 2190,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1565,   45,  596,  471,   32, 2360, 2477, 1247,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3230,    1, 3173, 1642,    1,  176,  163,    1,   12,    1,   26,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  915,    1,    1,  408, 3262,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  848, 2384, 2193,  845,    1, 1089, 1294,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  590,  388,    1,  500,    1,    9, 1935,    1,  636,  443,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  313,    9,  103,  220,  365, 1050, 2334,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275,    1, 2778, 1278,  331,   98,  378,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2004,  148,  879, 1757,   98,  647,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  581,   73,  667,   26,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2314, 3358, 2405,   37, 2197,    9,  351,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  593,  190, 2370,  557,  540,   12,  888,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1084,    1,  159,    1,  191, 2275,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282, 3257,  726,   32,  104,   26,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1778, 2580, 2851,  861,   37, 1658,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  519,    1, 1444,    1,    1,   37, 1343,    9,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2183,    1, 3382,    1,   32, 2597,   12, 3356,  787,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1226, 1114,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1742,  288,    9,  785,  786, 2107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   36, 3009,   32,  449, 3101,    1, 1089,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1611, 2126,  492,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968, 1550, 1284, 2673, 1017,  384, 2018,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  108, 2650,  167,    1,   28, 1294,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2323,   32, 2981,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  162,  227,    1,   98, 2851,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447, 2565,  251,  753,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  225,  809,  583,  163,    1,   12,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1657,    1,  729, 1610,    1, 1744,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3232, 2236,    1,    1, 1401,    1,  202,    1,  686,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3402, 3408,  514, 1727,   76,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1168,  851,    1,   37,    1,  548, 2596, 1665,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3335,  729,    1,  297, 1545,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 1502, 1503,  142, 1710,   92,   37,  458, 1416,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  387,    1,  354,    1,   98,    1,  408,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  232,  488,    1,   98,  171,  977,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3250, 1751, 2317,    9, 1056, 1675,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3262,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   15,  276,    1,   98, 2015,  328,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2563,    1, 1061,   98,    1,   44,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1421,  505,  195,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  606,    1, 1283,    9,  105,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117, 2208,  542,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  203,  445,    1, 1187,  758, 1013, 1279,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2528,   45,  365,    1,    9, 1230,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2741,    7,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  852, 2083, 1033,    9,  331,  105,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   9, 657, 279,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  438,    1,   37,  151,    1,   48,    9,  438,  331,    1,\n",
      "          566, 1126,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  732,  851,   32, 1193,    1, 2585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2087,  884,    1,    1,    1,  405,    1, 2577,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3315,    1,    1, 1124,   97,  187,    1,  670,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   47,    1,  112,   37, 1680,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2415,  361,    1,  384, 2211, 1940,   12, 3134,  535,   74,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  147,   37, 1709, 3126, 1377,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1405, 1723,    1,  891,   32, 2110,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1547,  418,  384,  687,    1,   69,  729,  105, 1665,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12, 1739, 1594,    9,  105,  245,  628,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   71,   32,  215,    1,    1,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,    1, 1461, 1463,  798,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2846, 1584,  916,   32,  105,   59,  670,  187,    1,  810,    1,\n",
      "         1980,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3309, 1301,    1,   56,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3326,  664, 1764,   37, 3265, 1987,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2962, 2838,    1, 3108, 1066,    1,   37,  439,  914,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   98,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3059,    1, 3244,   37, 1343,   32,  409,   32,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   21,   37, 1343, 1517,    9,  153,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,  261,   39,  786,   98,  786,   46,  220,   12,\n",
      "            1, 1447,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  864, 2390,   46, 1781,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2236, 1360,  612,    1,    1,    1, 1810,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2876, 2702,   13,    1, 1536,    9,  467, 1942,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  972,   37, 1048,  148,  132, 1039,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2775,  191, 1018, 3343,    1,  868,  105,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   53,   37, 1095,  492,    1,  778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2668,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1473,  528,  677,   69,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  204,  190,    1, 2579,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3147,  488,   37, 1260, 2751,   32, 3114, 1428,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,    1,  187, 1138,  108,    1,   69,  407,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  803,    1,  441, 1406,  600,    1,  388,   37,  815,  746,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   65,  232,    1,  677,  102,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  366, 2764, 2765, 3060, 2572,   32, 2887, 1523,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  227,    1,  176,  854, 2018, 2396,    1,  202, 2041,   37, 2024,\n",
      "         1183,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  166, 1411, 1568, 1017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1236, 2280, 2441, 2852,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700,  565, 1231,   32,    1, 1109,  927,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3096, 1863,  928,   32, 2002,  922, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  501, 1586,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1362, 1353, 1033, 2211,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  105,  365,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1976,    1,   37,    1, 2047,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3142,    1, 3083,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3151,    1,  474,   12,  645,  693,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2208,  891,   32, 3360,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3394,  488, 1430,    1, 3140,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,  105,   26, 2679,   82,   98,    1,  220,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  338,    9,  854,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2462,    9,    1,  845,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   28,    1,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3105,  167, 2394, 1460,   32,  863,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2870,  176, 3101,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3253,  765, 1159, 3295,  176, 2936,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3276, 1421,  103,  712,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1417,    1, 1293,    1,  105,    1,  552,\n",
      "            1, 1002,    1,    1, 2034,  590,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1981,    9,  183,  403,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  510,  891,    1, 2732, 1950,  640,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,  611,    9,    1,  195, 1463,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1, 1573,  321,  334,  103,  424,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2468, 3109,    1, 2985,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3355, 1554,    9, 3118, 2237,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,  825,  176,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2341,  161,    1,   37,  856, 2964,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2897, 1897, 2868, 2237,   37, 3349,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  225,  338,  187,  332, 2300, 1660,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3192,    1, 2586,  297,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,  729,    1,  191,  915,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,   45,    1,  298,    1,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 2728,  657, 1718,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  900,    1,  698,   37, 1526,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3330,    1, 1750, 1888,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  102,  120,  608, 1146,  106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1427,  957, 1465,  595,   30,  315,   37,    1,  810,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  534,  140,  741,   37, 1119,  550,  369,   37,  104,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1151,   15,   32,  260,  220, 2507,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2580, 2851,  328,  361, 2650, 2299,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  424, 2306,   32, 1123,    9, 1893,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  476, 1064,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1017,  441, 1539, 1222,  934,   37,    1, 2264,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1,  342, 2390,   46,  729, 2198,  630,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3260,    1, 1257, 3209,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  167,  360, 1377,    1, 1250,  906, 1167,    1, 1531, 1975,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2048, 1827, 2198, 1021,  187,  567,  666,  868,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  886,  325,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3323, 2583,  686,  220,   56, 1090, 2836,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  191, 3361,    1,  163,    1,   12,    1,    1, 1370,   45,\n",
      "         2774, 1223,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2408, 1924,  792,  454,   39,   45,  674,  792,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3356, 2751,   92,  863, 1625,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  573,  639,   12,  448,  640,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  895,   51,  288,  166,    1,    9, 1130,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3285, 2728, 3310,   37, 1971,    9,  485,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1559,    1,   98,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  305, 1285,    1,  242,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,  232,  267,  531,  476,   16,  776,    9, 2343,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1502,  315,    1,  389,    6,  176, 1503,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  743,   12,   82,  992,   85, 2007,   37,  505,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  686, 1817,    1,  274,  162,    1,  384,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,  912,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  197, 1936,    1,   25,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  192,    1, 2175,   37,  105, 2641,   27,  334,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  864,  267,  453, 3162,  321,  920,  759,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103,   51,   52, 2198,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2872,    1,    1,  689,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1973,    1,    1,  543,   37,  439, 2292,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  622, 2731, 1954,   32, 3118, 2571,  474,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   71, 1577,   34,  275,  159,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3118,   46,    1,  297,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1633,  538,    1,    1,   51, 1865,  807,    1,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2508,  839, 1232,  232,    1,    9, 1094,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  858,  759,   37,  619,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1413,  311,  548,    1, 1983,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 2962, 1902,  744,  365, 2174,  187, 3287,   77, 2315,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  964,   12,  198,   38, 1464,  121,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  794, 2456,   37, 2555, 3149, 3006,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   34,   35,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,    1, 1352,    1,  361,  460,   12,  193,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  778, 2455, 2528, 1230,    9, 2063,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1242,  361,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1281,    9, 2333,  310,    1,  442,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2733,   12,    1,  884,  885,  822, 2148,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  200,  723, 2232, 2581,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1256,    1,  552,    1,  485, 1949,  326,  486,  132,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  566,   51, 1539,    9, 2978,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  123,  548,  537,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 2168,    1,   37,  535,  437,  191,  104,  561,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1971,  582, 2565,    1, 1764,  939,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  973,   37, 2446, 2638, 2548,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3385,  582,   32, 2470,   37, 2000, 2673,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652, 1614,    1, 1718, 2355,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   20,  361,    1,    1,    1, 1821,  662,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,  315,  365, 2294,    9, 1412, 2945,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2695, 2223, 1539,  288,    9,  906,  176,    1,    1,   98,  429,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1756,  408, 1834, 3151,  810, 1292, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3289, 2963,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  548,    1, 2137, 2856,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,   66,   28,   69,  113, 1315,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   51, 1154, 2853,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2463,  130,    1,    1,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999,   91,   12, 2194, 2549,  590, 1400, 2812,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,  359, 1947,  138,  125,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2862, 1679,    1, 2179, 3080,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   80,  218, 2153,    1,  105,  636,  443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   89, 1177,    1, 2755,  365, 2036,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2018,  716,  590, 1421,   45, 1926, 1927,    1, 1550, 3104,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,  102, 1731, 1146,  106,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,   37,  125, 1230,  631,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106, 2355, 1013, 1626,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  384, 2819,   37,    1,    1,  105,   74,    9,  166, 1772,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   69,  102,  866, 1315,  105,  106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2765,  650, 1025, 2572,   32, 2018,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  967, 1658,  327, 2626, 2026,    1,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  267,  460,   12,  288,   37,  439,  225, 1611,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  558,   37,  151,    1,    9,    1,  182,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,  353, 1637,  572,  983,   32,  959,  105,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,    1,    9,    1,  595,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101,    1, 2708, 2572,   32, 3339, 1388,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1486,    1,    1,  565, 1041,    1,   59,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2640,    1,  187,    1, 3220, 1174,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1, 1417,    1, 1007,    1,  163,    1,   12, 1013,    9,\n",
      "           29,   98,    1,    1, 2387,  997,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2307,    1,  365, 1546,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649,  232,    1,  187, 1733,    1, 1021,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,    1, 1492, 2270,  247, 1389,    1,  593, 1267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25, 1758,   32,  411,  605,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  198, 2164,  898,   32, 2140,  163,    1,   12,    1,  639,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403, 1447, 2673, 1816, 1822,   52,    1,    1,    1,  463,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2781,  187,  872,   12,  650,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  169,   15,   71,   98,    1, 1565,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  159, 1372,   37,    1,    1, 1224,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089, 1675,  619, 1328,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428,  193,   37, 2702, 1930, 2343,   12,  776,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1720,  334, 2556, 1658,  248, 1227,    1,    1, 1178,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 548,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 524, 213,  37, 138, 331,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1326,  315,   37,   26,  632,  250,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,  388,  734,    1,    9,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2615,    1,  284, 1250,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  780,  317, 1022,    1,  356,  452,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1178,  610,   37, 1204,    9,  903,    1, 1973,    1, 2772,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,  361,  180,   37, 2123,    1,    1, 1339,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2984,  927,    1, 1199,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  879,  531, 2128,    1,  786,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  365,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,  884,  365, 1992,   32, 1512,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1059, 1067,   37,  105,  131, 2258,  994,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1594,    1, 1159,  105,    1, 1804,   98,    1,  105,  227, 1204,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   75, 2241,  908,  196,  176,  612,  613,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181, 1917,    1, 3314, 1824,    1,    1,    1,  446,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  971,  972,   37,  125,    4,   32,   91,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2878, 2625,  228,    1,   32, 1412, 2086,  927,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1712,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  852,   37,    1,  219, 1749,   32,    1,  973,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  179,    1,    1, 1413,   32,  116,  259,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  989, 1877,   37,    1,    1,  195,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2406, 2885,    1,  763,    1,  176,    1,    1,   98, 1602,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1090,  190, 1641,  608,    1, 1092,  967,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   85,  202,  193,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1401, 3268,  297, 2959,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   12, 2432,   45, 1406,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973, 2422,   37,   47, 1178, 1179,   48,  176,  552,   37,  742,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   65,  155, 1184,   67,   37,    1,  118,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2846, 3097,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,   32, 2340,    1,  202,  321,  612,  764, 1531,  688,\n",
      "         2206,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3323,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101,    1,    1,    1,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 3028, 2995, 1441,  116, 2542,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2909,   32,    1,  854, 2856,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2924, 2681,  591,  285,   32, 2785,  686, 3349,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2415,    1,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835,   37,  865, 3030,   37, 1094,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1405, 1644,    1,  331,    1,    1,  939,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,   37,   77, 1480, 1354, 1202,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,  335,  424,    1, 1265,   37,  166,  458,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1452,   32,    1,    1,    1, 1833,  434, 1271,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2843, 2523,    1,  166,   97,  176, 2916,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3214,    1,    1,  920,    1,   45,  813,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2620,   96, 3282,  943,   37, 2858,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1284, 1159,  224,  825, 1013,  224,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  271,   32,    1,   32, 1674,    1,    1, 1463,  927,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994,  395,    1,  176,    1, 1277,   12, 2653,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1855,  446,  566, 1894,  342,  221,    1,  202,    1, 1394, 2449,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  920,    1, 2024,  765,   32,    1,  437,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3144,  446,   37,  907,    1,   32, 1002, 1844,   79,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 3149, 1009, 2536,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2378,  685, 1019,  250,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 1466,   37,  151,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  335, 1133,  260,   98, 2502,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2170,    1,    9,  388, 2141,    1,    1,    1,    1,  977,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  715,  112, 1161,    1, 2917,   37,   56,  339,  340,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1,  384,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1582,  105,    1,   45,    1,  567,  914,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,   37,  804,   98,  647,  887,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3311,  400, 1698,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2620, 1337, 3275,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2104, 1484,    9,    1,  163,    1,  903,    1,  652,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75, 1458,    1,   98,    1,  259,  260, 2285, 1650,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1085,   93,    1,   32,  367,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  157,    9,    1,    1,    1,  187,    1,  681,  221,   32,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977,  267, 1336, 1821, 2978,    1,  167,  103,  131,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1791, 1792,    1,  631,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12,  356, 1175,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1872, 1001,    1, 1370,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1084, 2277,   61, 2613,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,  190, 1289,    1, 1197,    1,   37,  617,  618,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  746,   37,  815,    1, 1074,   37, 2035,  196,  759,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1242,    1, 1349,  967,  331,   37, 1539,  247,    1, 1159, 2818,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,    1, 2226,    1,  193,  707,   37,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1933, 1359,  967,    1,    1,   32,  467, 2092,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  287,    1,  729,  619, 2213,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,    1,  443,    1,  384, 1147,    1, 3343,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3010,    1,  603,    9,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,   69,  102,  288,    9,    1,  245,  297, 1411, 1056,  537,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3096,    1,    1,  449,  754,  726,  444,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1203, 2871, 1871,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  929, 2437,   32, 1169,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  992,   28,    1, 2236,  744,  119,  187, 3318,  726,  183,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2178, 3087, 2414,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  323, 1821,    1,   51,  606,  105, 1568, 2339,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2573,  295,    1, 1361, 2579,   45,    1,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  361, 3361, 2625,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2062,  741,    1, 1139,   45,    1, 2461,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2335, 3111, 1530,    1, 3038, 2960,    1, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  447, 3067,    1,    1,  344, 2950,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  834, 2198,    1,  105, 2698, 2495,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2501,  861, 1553, 1648,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2924,    1,  548, 3391,   22,  477,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  953,  202,  113,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   63,  166,  862,    1, 1784,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,  267,  460,   51,  606,    1, 3086, 2924,\n",
      "           32, 3114,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 2748,  187,    1,  796,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1105,  787, 1052,  572,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925,    1, 1184,   32,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1170, 2812,   32,    1, 2522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2313,   12, 1095,    1, 2134,  304,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056, 2748,    1,  167,   52,   39,    9,  914,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2944, 1760,  333,   45,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2723, 2724, 1443,  288,   28,    1,  437,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  329,   98,  166,  832,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  680,    1,    1,    1,    1,  361,  410,  861, 2407,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2031,  967,  581,    1,  600,    1, 2157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2476,   84,   28, 1450,  444, 3155,  187, 1798,  220,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3296, 2277,  228, 2202,   79,  678,    1,   32, 2513,    1,   37,\n",
      "          688,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051,   37, 1706,  388,    1,   32, 1033,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  193,  445,  856,   32, 1973,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   91,    1,  104,  498,   98, 2824, 3146,   98,  864, 2673,  210,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  315,   37, 2324,  116,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1, 2835, 2434, 3080,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994, 2819,  469,    1, 2165,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  883, 2054,  897,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715, 2122,  231,    1,  602,   12, 1428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1227,  794, 2580,    1,    9, 1537,  218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3079,    1, 2087, 2614,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,   28,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3349, 2162, 1950,  384,  799,  418,   37,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  183,    1,    1,    1,    1,   51,  606, 2562,    1,    1,    1,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3211, 1176,  198,    9, 1853,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3250,    1,    1,    1, 1751,    1,  688, 3285,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3253,  140, 3204, 1411,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1406,  297,    1,    1, 3348,   93,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640,   39,  176, 1361,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2048, 1822, 1604, 1400,   37,  138,    9,  869,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  799,    1, 2977, 2978,  434,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1934, 2599, 1033,   91,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,   78,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1290,  396, 1376,   32,  645, 1034,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,  391, 1329,  219,    1,   48,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2144, 1095,    1,    1,    1, 1077,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327, 1283,  365, 1173, 3273,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  148, 1564,    1,  131,  335,  460,  357, 1910,  460,  647,  693,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1412, 2521,    1,  334,  894, 1847,  600,  858,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 971,  37, 508,  79, 176, 365,   1,   1, 250,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  37, 151,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  631,   61,  125,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162, 1056,    1,    1,  802,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2496, 1976,   32,  531,   12, 3383,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2634,   37,  949, 2627, 2177, 1825,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3194, 3195, 2540,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2391,  140,    1, 3192,   24,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,   12,    1,    1,  104,  615, 2311,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  954,    1,   32,   72,  401,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2638, 2931, 1560,    1,  777,  681,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98, 2114, 1140,    9,    1,   16,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  550, 1796,  217,    1,    1, 2473,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,  729, 2040,    1,   32,  531,  190,   52,  820,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977,    1,  938, 2538,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  590, 1512,  176,    1,    1, 1748,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1246,   61,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  159, 1253,   32,  329,  714,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  794,  453,  248,  777, 1013, 2549,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  162,    1,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1829,    1,    1, 1976,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  477, 1140, 1391, 3144,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2551,   77,    1,   98, 2041,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1082,  909, 1114,  864,    9, 2673,  210,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3349,   64, 2162, 1950,  167,  759,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2159,  794,    1,    9, 1100,  769,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   12, 2107,  167,  631,   37,  166, 2227,    1, 1417,\n",
      "            1, 1417,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3170,  598,    9, 1463,  865,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1304,  418,   98,  898,  399,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718, 2495,    1,    9, 2065,  497,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  675,  256,  365,    1,   37,  260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  585,  631,   37,    1,   32, 1290,  396,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2827,    9, 1994,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1256,    1,  552,    1,  485, 1949,  182,  326,  486,  132,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  267, 2414, 1407,    1,   32,  531,  477,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,    1, 1222, 2359,  934,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,  459,  170,  132,  220,  647,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187, 3108, 2446, 2615,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 1259,  220,    1,  485,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   12,  365, 2706, 2232, 1396,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,  288,   45, 1718,  861, 2558, 2030,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,    1,  220, 3265, 1987,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2922,   66,  998,  816,   98,  104, 3388, 1563,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61, 1117, 2208, 2341,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  176,  177, 2572,    1, 1941,   32, 2018, 3389,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,    1,    1, 2625,    1, 3011,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  354,   45,  674,  548,  593, 1990,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715, 1743,   98,  342, 3341, 1372,  202,  193,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3115, 1403,   81,    1,  913,    1,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2527,  164,  190,  335, 2006,  537,   37,    1,   32, 1033,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2784,    9, 1805,  238,    1, 2493,  105,    1,  786,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,    1, 1268,    9, 1988,   12, 1583, 3400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  361,    1, 1670,   37,   47,    1,   37, 1496,  170,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  108,   98,  983,   93,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2162, 1950,  418,   32,  649, 2201, 2003, 2960,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758, 1008,  475, 2101,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   32,  870,    1,  936,  365,    1,    1,    1, 3004,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1452,  220,  105,    1,    1,    1,  166, 3276,  415,   77,   98,\n",
      "         2315,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  597,    1,  475,  213,   37, 1780,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1450,   32,  121,    1,    1,  220,  539,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32,  531, 2292,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3274,  603, 1836,   37,  365, 1463,   32, 2033,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  375, 1536,    1,   43,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102, 1826,    1,  104,   25,   45,   68,   66, 1239,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  176,  365, 1653,   98,  889,  529,  997,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1747,    9,   35,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1713,    1,    1, 3336,   32, 2067,  845,  361,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  439,   37,  903,    1, 1447, 1512, 1372,  680, 3203,  391,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1310,   37,    1,  342,  132,   98, 2673,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3378, 1484,    9,  674,  297,  248,  776,  750,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  424, 3126,   61,    9,  334,    1,  363, 1753,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  636, 1042,  548, 1147, 1069, 2361,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1643,  315,   37,  221,    1,    4,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  369,    1, 2478,  331,  384,  848,   32,    1,    1, 1090,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  849, 1293,   32,  166,  173,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2002, 2561,  928,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  854, 1564,    1, 1377,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  884, 1349, 1263,   37, 3140,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1985, 3101,    1,   32, 3339,  622,  178,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2028, 1419,  228,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 3169,    1,    1,  582,    9, 1183, 2921, 1798,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537, 3365,  288,   37,  865,  754,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2077,  353,    1,  131,  104,  197,  548,  354,  915,  356,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1890,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1079, 3063,  330,   37,    1,  224,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,    1,  187,  455, 2141, 2164, 2372,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,  37, 123, 124,   1,   4, 125,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 262, 263, 197,   1,   1, 225,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3025,   12,    1, 2940,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1167,    1,    1,  688,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1166,  334,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 3365, 2827,    9, 2119,   32, 3360, 1683,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  219,   25,   85,    1,   60,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3267,   32, 3179,   45,  166, 1742,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 2441, 2126,  166, 1690,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  127,   37, 1048,  658,  763, 1444,  321,    1, 1371,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  294,  295,  376, 2748,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,    9,    1,   93,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37,  245, 1139,   45,   15,  837,   32,  395,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  161, 2607,  400,  685,  514, 1727,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2749,   98, 1923,  171,   12, 2789,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,    1,    1, 1624,   32, 1313,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2007,   37, 1174,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2571, 3372, 1268,   32,  463, 2170,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,  338,  187,  448,  509, 1687,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1140,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   82,  939,  548,  197,  304,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,  986, 3345,    1,  590, 1574, 2411,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  421,    1,  162,  142, 1992,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  300,   39, 1018,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  479, 1009,    1,   37,  930,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,  613,   37,  151,    1,  728,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2551, 2905,    9,    1,    1, 3059,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2268,   32,    1,  187,   56,    1, 2793,  384, 1157,  139,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3207,    1, 1922, 2840,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  382,    1, 1391,  777,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2466, 1209,  105, 1267,    9, 2719,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   12,    1, 2209,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  342,   93,  190,  712,   28, 1371,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  880,    1,  593,  846,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  107,   69,  102,   51,  417,  996,   93,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  612,  551,  612, 1898,   28,  220, 2226, 1842,   98,  207,\n",
      "          618,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  288,  365,    1,    9, 1273, 2234,  548,    1,  142,\n",
      "         2443,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,   69,  393,   46,   37, 1195, 1282,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1053, 2405,   36, 1463, 2601,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  382,  293,  420,    1,  927,  972,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1118,    1,    1,    1,   37,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1688, 2932, 1787,   10,  726,   32,  584,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   25, 1473,  242,  187,   69,  102,  670,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   12,    1,    1,  460, 1278,   61,  105, 1628, 1265,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  196,    1,  176,  612,  361,  176,  612,  613, 1814, 1589,    8,\n",
      "          918,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1380, 1526,   98, 1443,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1100,  846,  769,  191,    1, 2670,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796,   25,  504,    1, 1572,  191,    1,   98,   69,    1,  948,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2570, 1022,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,    6,  102,   98, 1744,  301,  280,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3172,    1,    1,   37, 3161,   12,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800, 3328,  335,    1,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 1019,    1,    1,    1, 1976,   32,  215,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  365,  776,   45, 1646,    1,  361, 1574,   98,  453,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  515, 1957,  105, 1198,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994, 2275,  378,  193,    1,    1,    1,   10,  267,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1173,    9,  824,  493,   98,  116,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  454,   45,  950,   12,  916,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  328, 1053, 2843,  358,   37,  698,  541,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1537, 2924,  489,   39,   45, 1815,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 1604,   23,    1,  176,  551,  612,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1949,  844, 1151,  934,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 2312, 1183, 1027,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   85,   98,  119,    1,    1,  910,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3318,  603,    9, 2383,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  606,  762,   98,  166,    1,  225,  269,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  476, 1064,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,  655, 2226, 1924,  917,   37,    1,  356, 1691, 2638,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 2948,    1,   32,    1,   28, 3012, 3027,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98, 3076,  166, 1948, 1494,   85,   37,  786, 2107,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2432,  861, 2538,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,    1,    1,  193,   32,    1,  267, 2708,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  387, 1269,   32,   72,  401,  244,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777, 1008,  365, 1085, 1213,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,   32,  593, 1990,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1072,    1,  172, 1049,    1,   37,    1,    1,  550,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  105, 2774,   12,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,  115,   45,   65,   67,  484,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2672,  442, 2922,   37, 3323,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193,    1,  191, 3167,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1072,    1,  597, 2374,  232,  187,  453,  104,  475,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963, 2328,  142,  665,   98,  429,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1092,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 1948,  220,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1081,  159,  670,  548, 1585,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,   98, 2667,  176, 3194, 3195,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1936,  105,    1,   37, 3200,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1065, 1190,  936,  365,    1,    1,  861, 2060,   79,  691,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  455, 1566,  909,  951,    1,  903,    1, 1447,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1902,    1,    1, 3221, 2689, 1717,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  947,    1,  361, 2856, 3102,    1,   32, 2184,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 2264, 1205,    9,    1, 1107,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  593,    1,   86,    1, 1450,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  391,    1,  353,  242,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   28,   32,  411,  442,    1,    1,    1,   37, 1962,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465,    1,  844,  170,  891,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2615,  686,  365,  340,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492,   44, 3348, 1940,   32, 1887,   45,  105,    1,   45,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1656, 2596, 3060, 2572,    1, 2375, 1976,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1465, 1466,   37,  130,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,   12, 1043,    1,    1,  288,    9, 2084, 1042,   32, 1700,\n",
      "          257,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1212,  992,   28, 1523,  444, 2189,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  717, 2275, 1018,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2395, 1081,   12,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  518,  765,  479, 1159,  166,  938,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2863,    1,  885,  822, 1641,   32, 2956,  149,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,    1,    9, 1104,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,  632,  232,  851, 2095,  972,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,  454,   37, 3293,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1586,    1,    9, 1378,    1, 1539,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1486,  155,  157,   98, 1107, 1998,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,  361,  105, 1264, 2539,   32,    1,   98, 1978,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2313,   37, 1343, 3258, 2579, 2630, 1411,  914,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 2561,    1,  523,  439,    1,  343,   32,  927,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1751, 1401,  202,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1423, 2272,   85,   98,  207, 2574,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  884, 2442,    1, 2545,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3389,  176,    1,    1,   32,  166, 3393,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  590, 1357,   98, 3156,  395, 1295,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006,    1, 2108,  384, 2646, 3346,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  854, 1707, 1407,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181,  572,   15,    1,  244,   16,  198,   93,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,  638, 2620,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2320,  384,  713,  361, 1937,    1,   37, 1075, 2588,  168,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1011,  102,   28,  187,  854,  477, 1258,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1, 2072,  388,  207, 1450,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3269, 3237,  459,  331,  132,  220, 2163, 2685,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1674,    1,   74, 1312,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2748,    1,  585,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273,  259,    1,    1,   12,    1,  464, 2171,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2925,    1,  827,    1,  365, 1546,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 1518,  453, 2147,   32,  316,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1773, 1831, 2682, 2371,  187, 2510,    1,  837,   61,  969,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428,    1,   37,  930,    1, 3327,   51,  619,  389,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1796,  147, 1800, 3139, 2099,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1658,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  861, 1906,  736, 3147, 3114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  515,    1, 2232,    1,  269, 2232,    1, 2264,  105,  803,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1547,  980,  444,   60,  187,   25,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,    1, 1928, 2759,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018, 1082,  395,  193,   37,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1883, 2483,    1,  779,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  867, 1070, 1818,  147,   37, 3159,  552,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,   76,   37,   77,   78,   79,   80,   12,   81,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  864, 2744,  955, 1461,   37, 3344, 1414,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 2844,   32,  344, 2950,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  190,   52,  380,    1,    9,    1,    1,  337,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1306,  593,    1, 1599,    1,   45,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  123,   37,    1,  214,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,   51, 1251, 1590,  166,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 782, 594, 861, 176,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  69, 102,  37, 838,  79, 342,  93,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  879,  832,    1, 1588,   66, 1239,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   42, 1370,   45,  633,  573,   43,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  206,   12, 2612,  845,  689,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766,   37,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  758,   37, 1463, 2355, 1013,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1971,    1, 1240, 2553,    1,  193, 1844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3138,    1,    1,  730, 2614,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878,  477,  640,    1,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1497, 2714,  166, 3103,   37,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  851,    1,    1, 1009,    1, 2421,   32, 1440,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  108,  903,    1, 1447,  444, 1461, 1867,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  329,  475,  387, 1064,  115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1115, 2053,  218,   51,    1,   31,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3075,    1,    1,    1,   12,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  561,   37,   47,   59,  159,   32,    1,  942,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  907,    1,  548, 1281,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  393,    1,  467,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2631,  729,    1,   28,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,  710,  577,  600,  395,   12,  192,  315,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1007, 1448,  437,   37,   52,    1,    9,    1,  182,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  996, 2005, 1980,   37,  498,   98,  734,  591,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1639, 1465,  595, 1803,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  903,    1,  331,    1,  729,    1,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  550, 1538,  477, 1627,  581,   74, 2539,  631,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2974, 3090,  105, 2716,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,  667,   26,  191,   56,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,  183,  855,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1950,    1,  572,  244,  688,  308,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  632,  957, 1579, 1839,    1,  300,   37, 3372,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  369,    1,   12,  572,  197,   28,  118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  954,  641,    1,  118,   32,  581,  401,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   37,    1,  395,  187,  593,   12, 1354,    1, 1255,   32,\n",
      "          506,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  811, 2770, 1861, 1010,    1,  297,  531,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640,    1,    9,  449,  199,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  600, 2315,    1,  193,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  772,  109,    1,  879,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  224, 1013,  210,  162, 1253,   98,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2918,    1, 1551, 1976, 1425, 2662,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1695,    1,   32,    1, 2596,  722,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  249,  583,   32, 2596, 1585,  176, 1855,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  103, 3374, 3384,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   15,    5,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1189,  622,  655,    1,  792,    1, 1563,  792,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 2924,  361,  947,   32, 3349, 2286,   37, 1598, 2193, 3362,\n",
      "         2292,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  663,  187, 1823,  167, 1083, 2208,   48,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800,    1, 2226, 2233,   81, 1575,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1071,  649, 2003, 1746,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2332,   79,  556,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2, 105, 385,  37,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 193,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1711, 2816,  365, 2292,   32, 3118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1966,  947, 1388,  220, 2396, 2832,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1123,  190, 1878,    1,  415,   55,  460,    1,  967,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  867, 1236,  912, 2852,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2087,   32, 3193, 1505,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1421,  384, 2592,    1, 1759,  309,  475,    1,  166,  861,\n",
      "          625,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1940,    1,  563,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  220, 3244,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  691, 1988,  297,  264,  776, 1140,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523,  634,   37,    1,  220,  770, 1064, 2885,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1287,   37,  688,  590,    1, 1739,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 3201,  590, 2589,  804, 1268, 2009,    9,  166, 1298,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  615,   51,   52,    1,   98,    1,  937,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1082, 1094,   37,    1,  454,    9, 2708,\n",
      "          741,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1458,    1, 2266,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  595,  300, 1440,   37, 1194,  354,  548, 1936,  166,\n",
      "          631,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1236,  777,    1,    1, 1130,  297, 2819,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2408,    1,  191,  730, 2614,   32,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3112, 2781,  917,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405, 3291,  571,   37, 2760,    9, 3226,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  487, 1462,    1,    1,  213,   37,  151,    1,    9,   59,  104,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1450,   98, 2275,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,    1,  455,   37,  619,  397,   12,  168,  115,   37,  686,\n",
      "           81,  176,  104,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  267, 2239,   51,  606,    1, 3012,  298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 2924, 1758,   98, 3155,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2113, 1204,  286,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1572, 1414,    1,  674,   32, 2774, 1147,  787,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  474,    1, 2016,  960,    1, 1903,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  920,   98,  721,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3325,    1, 1477, 1990,    1,  191, 1936,   74,   79,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  105, 2474,  361,    1,  225,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  387, 1107, 1516,   32,  617,  618,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  697,   37, 1348, 1131,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1910,  460,   37, 2685,   37,  483,    1,  166, 2855,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158, 2408, 2165, 2438,  220,  943,   45, 2528, 1542, 1230,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1268,   94, 2102,  124,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2871, 2163,    1,  191,    1, 1728, 1114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741, 1371,  664, 3201,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  792,    1,    1, 2844,    1,  320,    1,    1,  792,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2297,  365,    1, 1831,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2666,    9,  529, 2727,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1050,  446,  476,   37,    1,  176, 2702, 2909,  927,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  388,   29, 2156,   98,  195,    9,  312, 1027,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510,    1,   69,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453,  172,  716,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545,   12,    1,  307,    1, 1388,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  592,    1,   98,  596,  996,   93,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3283,  987,    9, 3180,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  225,  361,   69,  102,  417,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1249, 1254, 2085,  331, 2498,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   31,   67,  418,    9,  601,  339,   32,  105, 1559,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91, 2153,    1,  220,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2177, 2567,    1, 2582,   37,  168,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,   84,   28, 2851, 3049,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3128,  267,  104, 1414,  792, 1372,  792,   37,   64, 3088,    1,\n",
      "           32, 2646,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718, 2718,    1,   37,    1, 2762,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1821, 2190, 2640, 1187,  284,    1, 1604,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,    1, 3104,  420,   98,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2668, 1081,   12, 2197, 2147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3257,    1,   39,  361,    1,   98, 2725, 1463,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  276,    1,  420,  267,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128, 2384,  365,    1, 2355,  327,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  267, 3155, 1995, 2133,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1932,   37,  125,  541,   87,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,    1,    9,    1,  131,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  183, 2247,   57,   71,    1,  851,   57,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,  917,    1,   61,  384, 1965,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3168,   30, 1565,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1959, 3285,    1, 2295, 2321,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,   71,  187,   69,    1,   37,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  380,    1,   45, 2197,    1, 1056, 3348,    1, 1594,   37,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3209,    1, 3251,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1396,    1,  220,    1,  328,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,    1, 1306, 2565, 1973,   12, 2731,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  590,    1,    1,    1,  140,  590,    1,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1454,  484,   37,    1, 2343,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3003,    1,  867,   32,  856,  444,  912, 2852,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  119,   32,  691,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2885, 1082,  539,   37,    1,  556,   98,  903,  275,  791,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 2767, 3107,    9, 3366,    1, 1428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  442,   32,  557,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1840,    1,   37,  151, 1840, 1300,   48,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1212,    1,  163,    1,   12,    1, 2243, 2735, 1805,   28,  469,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   66, 1298, 1382,   69,  246,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 318,  37,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  25,  28,  98,  29,   1, 528,  69,  12,  71,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  303,   32,  289,  424, 1034,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98, 3177,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,  166, 1628,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 3165,  588,    1,   32, 2592,   36,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3118,   46,   37,  588, 2179,  132, 1010, 1345,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1089, 1090,    1, 3039, 3040,    1,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2626,  220,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1,  332,   45,  596, 1273, 1732,  218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1497,  361, 3247,  877, 3220,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564,  786, 2069,    1,  221,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  359, 2905,    9,  465,   22, 2155,   45, 3012, 3027,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1033,    1,   91,  588, 1415,  361,    1,  996,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1616,    1, 1912, 1975,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  102,   28,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1557,  650, 1082, 2517,   97,   98,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 2558, 1810,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2974,   95, 2479, 2695, 2223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1,    1,    1,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2466,    1, 1450,  187, 1209, 1268,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1228, 1669,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  365,  261, 2191,  548,  863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,   37,    1, 2673, 1806, 1220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  650, 1877,  443,   98, 1964,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  267,  864,    1,   32, 2673, 2596, 2813,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  186,   98,   69,    1,  996,  550,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  275,    1,  837, 1244,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1009,  577,  600, 2890,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2257,   39,   45, 2708,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  581, 2132, 3297, 2622,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1648,   37, 1463,  225,  809,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3268,    1, 2290, 3259,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2334,    1, 1245,   28,  220,  365, 2957, 2927,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  305,    1,   37,  197, 1936,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,   26,  242,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1670,  105, 1298, 1230,    1,  105, 1875, 1804,   98,  424, 1568,\n",
      "         1055,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2387,  122,  220,  224, 1013, 1228,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3343,  863, 2664,    1, 1130, 2572,  191, 2596,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1607,  231,  326,    1, 2695,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2620,    1,   98,    1,   12, 2405,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,  388,    1, 1160,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  597, 2774,  650,  288,   37, 1752,    1,  446,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   25, 1473,   98,  156,  716,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  602,   12, 1062,  317,  884, 1146, 1703,   48,   32,    1,   45,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  761,    1,    1,  117, 1708,    9, 1646,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  988,  682,  432,  384,  166,  790,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1842,    1,  105, 1717,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  405, 3291,    1, 1245,   77,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463,  464,  147,  261,  444, 1633,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1867,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3352, 2856, 2183, 1147,    1,  232,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1181, 2914,    1, 2056, 1101, 1102,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2841, 1918,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  352,  920,  267,  460,  190,  193,  619,  881,  384, 1583,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,   74, 2677, 1090,  199,  446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  433, 2424,  581, 1994, 2650,  302,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  656,  515, 1749,  105, 1718,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3253,    1,    1, 1021,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  810,    9,  949,   45, 3102, 1861,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1485,  957,  908,  174,    5,    6,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1380,    1,   98,  469,    9,  658, 1151,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   98, 1603,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1592, 1940,    1,    1,   37,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  958,   27, 2113,  157,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993, 3056, 1426,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2468,  361,  104,    1,    9, 1764, 1990, 1523,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  811, 2061,    9,  949,   45, 1056,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 1818,  147, 1949,    1, 2884,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 3365,   46,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2792, 1713, 1239, 1994,  735,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  503, 2399,   37,    1,  749,  122,    9,  537,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  136,  325,    1,    1, 2683,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861,  700, 1635,    1, 1988,   45,    1,    1, 2693,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  972,  449, 2528,   45, 3022,  760,  166, 2604, 1294, 1821,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3325,  267,    1, 1031, 1360,  612,  583, 1590,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  225,  574,   12,    1,  504,   32, 1332,    1, 2084,   32,  105,\n",
      "          356, 1379,   12,  112,  499,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,  947,    1,  344, 3403,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  550, 2688,    1,    1, 3155,    1,  161,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1923,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,    1, 1283, 3192,    1,    1, 1463,  427,   74,   56,  691,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3219,  856,   79, 3331,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  232,    1,   37, 1910, 1580,  317,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1617,    1, 2937,    1, 2942,  431,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,  829, 1228, 1396,  803,  441,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  582,   45, 1645,  538,    1,  939, 2007,   37, 1994, 3101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1022,    1, 2296,  176, 2110,    1,  446,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2604, 2923,   37,  698, 2283,    1,  439,  906,    1, 1821,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1366,  321,  612,    1,   37,    1,   28, 1114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 1210,   37,   77,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2868,    1, 3388, 2557,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3094,   45,  116, 2502, 2985,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  742,  155,   48,   32, 2448,  386,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  382, 1149,  477,   63,    1, 1953,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  782,  365,  754,  220, 3194, 3195,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3187,  967, 2443,  547, 1077, 1621,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2702, 2886, 2582,  415, 1056,    1,   37,    1,   63,    1, 1656,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  459,  625,    1, 2500,  663,    1,    1, 1527,   32,  403,\n",
      "         1447,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2278,    1, 1361,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2771,  297,    1, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2519, 1532, 1143,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,  384,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1123, 1292,   12, 2804, 3047,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1528, 1229,   37,   52, 1411,  104, 1477, 3164,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1875,    1, 2346,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  761,  190,  341,  166,   64,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3219,  245,   32, 1427, 1600,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   98, 1108,    1,  244,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1523,    1,   32, 2774,    1,    1,  187, 1527, 1149, 2816,  531,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2423,  664,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   49, 1536,    9,  163,    1,   12,    1,  467,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1539,  517,  776, 1085, 1371,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2899, 1867, 1107,   98,  166,  168,    1, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2931,    1,   16,   28,  111,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  547,    1, 2308, 2317,  548,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 2414,  463,   45, 2597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  167,  197,  220,  845,   69,   82,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  204,   12,   32, 2027,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,  443, 1662,    1, 1050,    1, 2223,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1386,  313,   37, 1083,    1,   37,  646,    1,   37,   32,  537,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1867, 2086,   33, 1017,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128, 1203, 1270,  105,   59,    1, 1129,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2775,    1,  668,    1,  220,    1,  331,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1486,  267,  460,  967,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3360, 2596, 1450, 2856,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   63,  166,  862,    1,  159,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  147, 2411,   37, 1198, 2412,   98,    1, 1393,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   51,  193,   52,  730, 2614, 2615,    1,  202, 1477, 1990,\n",
      "         1246,   61,  311,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  539,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  227, 1647,    9,    1,  361, 2512,  176, 3243,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,    1, 2250,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,    1,  176,  551,  612,   37,  138,    1,   59,   32, 1084,\n",
      "          400,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2925, 1974, 3323, 2583,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  546,    1,  176, 1652,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1449,    1,  187,  786,   45, 2925,   12, 1509,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  551,    1,  449, 1023,  207,  953,   98,  408,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2423,    1,   85,  191, 1247,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1352,    4, 2401,   51,   77,  104,  347,  677,   37,  166,  439,\n",
      "           45,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  302,   12, 3112,   37,    1,  979,  808, 1720, 2647,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481,    1,  297,   10,    1,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056, 2572,   32, 1378,  863,  555,   32, 3360,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,   23,  894, 1636,   32, 3349,  191, 1332,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2333, 2946, 1188,  442,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3065, 2691, 1664,    1, 2498,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3250,    1, 3290,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,    1,  199, 2337,  147,  933,  647,  214,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1163,  197,   28,   98,  198,  163,    1,   12,    1, 1220,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1118,  861,  328,    9, 1778, 2580,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3262,   12, 3283,  469, 1812,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  818,  275,   11, 2495,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1312, 1185, 1940,    1,   32,    1, 2162,   45,  356, 1691,    1,\n",
      "         2313,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2371,  778,  162,  501,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  297,    1,   37,  356,  845,   98,  104,    1,    1,\n",
      "          845,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  542, 2222, 1937,  872,  726, 1684,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1450,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  354,   45, 2954,    1,  202,  193, 1021,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2414, 1270,    1,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,    1, 1016,   37, 1413, 3057,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2254,  244,   98,    1,  285,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1408, 1477, 1990, 1443,  176,  827,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1913,  401,  197,  338,  176,  485,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1157,  947, 2884, 3035,  548,  218, 1585,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3252,    1,    1, 3269,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1, 1082,  163,    1,   12,    1,   37,  439,\n",
      "         3368,  951,    1, 2028,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  315,   26, 1039,    1, 2232,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  915,  973,    9, 2591,   32,  691,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2278,  792,  151,  792,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1,  326,    1, 1151,  315,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2770,    1, 1633,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2995, 2994,  193,  166, 1851, 2997, 2157,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  153,    1, 3142,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1542,   37, 1664,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1782,   28,   98, 3132,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  113,  413,    1,   37, 2250,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1905, 1542,   37, 1358,   37, 2341,  913,   32, 2218,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1, 1527, 2034,    1,  331,   32,  581,  401,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   75,  695, 2094,  858,   37,  166, 1021,  847,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1479,    1,    1, 2164, 2478,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,    1, 1159,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  870,    1,   37,    1,  932,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1674,  475,  288,   37,  319,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  953,  444, 1547,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1200,   28,    1,  268,   79,   63,  862,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1, 2196,    1,    1,    1,    5, 1631,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1592, 2237,  968, 2673,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2162, 1950,  418,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3306, 1924,  917, 2167, 3181, 1831, 3281,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,  782,  607,   45,   14,  524,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  560, 1274, 1473,  915, 1034,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2160, 2049,  833,  612, 1188, 1292,   37, 2230,   37, 2230,   98,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  391,  267,    1, 1571, 2537,  388,    1,  763,\n",
      "          449,    1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282, 3230, 1426,  581, 1385,   45, 2490,   26,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2940,    1, 2450,   37, 1413, 1816,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  147, 1458,  927, 1159, 1147,   12, 2162,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2571,  474, 1702,    9, 2108, 3368,  444,  557,  540,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2179, 2009,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3192,  691, 1838,   79,  438,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    6, 1913, 1843,  739,  187,   57,  720,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,    9,  914,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 2332, 1805,   28,    1, 2261,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1628,    1,   74,    9,    1,  813,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,    1,   37,  454, 2673,   46,  395,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1616,    1, 1173,   98,    1,  683,  782, 2505,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  166, 1510,  353,  198,  572,   98,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  395, 2185,  646,   93,   67,   37,    1,   32,  740, 1014,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1266,   82,  796,    1,  159,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3219, 2712, 3331,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387,    1,    1,    1,    1,   85,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2408,    1, 2196, 2934,    9, 1340,    1,  873,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  137,    1,  450,  686,  191,  510,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2960, 2668, 1094,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  557,  540,    1,  447,  442,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,   71,  682,    1,   98,   69, 1406,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  353,  242,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  884, 1742,   26,  631,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  150,  102, 1126,  786, 1034,  857,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 2615,    1, 1554, 2405,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  134,  938,  220,  133,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 575,   1,  37, 111,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  33, 402, 353,  71,  32, 572, 197, 428,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1762,    1,   28,    9, 1989, 1990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3076,  919, 1281,   98,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  828, 1862,   98, 2968,  639,  788,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,  884,  411,  631,   32, 3343, 2116,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1354,   81, 2918, 2784,    1,  202,  193, 1965,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,    1,   98,   37,  688, 3117,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2232,   15, 1348,   37,  554, 2973, 1764,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1471,    1,  474,  877,  590, 1647,   32,  449,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  421,  162,  166, 1217,  115,   45, 3188,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2250,  260,   32, 2128,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1089,    1,   45, 3039, 3040, 2576,  105,  365,  340,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2703,    1,  384,   10,  778,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977,    1, 2620, 1178,   12, 2895,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1435, 1953,  220, 1537,  446,   37, 1003,  176,    1,  434,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1412,    1,  765, 1415,   37,  258,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1702,    1,   45,  460,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1987, 1414, 3168,   37,    1, 2069,    1,    1,  726,   32,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2640, 1046,   72, 2539,   98,  114, 2949,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2748,    1,  585,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962,    1,    1,    1,  764, 3117,  688, 3234,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1721,  326,  840,  327,  112, 1564,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  220,    1, 1624,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,  476, 2571,    1,   32, 3118,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1454, 2108, 1907,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2373, 2658,   45,    1,    1, 1387,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 1414, 2155,    1,    1,   12,  861,  475,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2235,  142,    9,  792, 1509,  792, 2085, 2826,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  756, 2489,   85,  716,   45,    1,  890,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,  315,  885, 2457,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1949,  315,    9,  183, 2186,  844, 1151,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  220, 1582,   98, 1515,    1,    1,    1,    1,    9, 1385,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2498, 1567, 1380, 3290,  297, 2748,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   49, 2145,   37,  138,    1,   45,    5,  798,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2114, 1478, 2771, 3154, 2522,  132,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  645, 2630, 1533,   39,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2331,    1,    1,    1,  297,  487, 3222,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  709,    1,  475,  213,   37,    1, 1780,    1,  293, 1281,   37,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1042,  187,  557, 1512,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  411,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1564,  241,  120,    1,  889,   25,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  574, 1132,   37,  138,   59,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  105, 2408,   12,  566,    1,  166,  593,   96,    1,   85,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,    1,  616,   28,   98,   10,  726,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2484,  200,  517,  618,   32, 1183, 1961, 1539,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1360,  612, 1816, 2330,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 1447,   37,  912,    1,  220,    1,   98,    1,   12,  400,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   32, 2647, 1537,  389,  218,    1,  911, 1210,  460,  810,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   69, 2414,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1077,  104,  131,   37,  151,   39,  129,  975,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  619, 1658, 1090,   98,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1427,  629,   45, 2847,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  973,   60,  242,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  515,   28,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597, 2473,   82,    1,   37,  582,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1652, 2373, 2798, 2355, 1718,    1,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1184,  347,   98, 1139, 2113,  612, 1879,  410,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  422, 1268,  262,  263,  549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,   32, 2235,  147,    1,   98, 2834,  134,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1, 2662,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1036,    9,    1,   37, 1343, 3013,   32,    1, 2771,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3250, 1421,    1,    1, 1024,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  342,   98,  395, 2108, 1281,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1369,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2065,  497,    1, 2201, 2264,   37,    1,    9,   93,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  794,  215,  659,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2204,    1,  804,   98, 2601, 1093,  574,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,  604, 1560, 1728, 2112,    1,  920,  852, 2474,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1668, 1421,    1,    1,   37,  356,   24,  881,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1024,    1,   39,    9,  914,  220, 2961,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  235,  661,   98,   25,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  233, 1579,    1,  187,  582,   45, 3104,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  455,  475, 2908,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,   28,   98,   69,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1064,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  620, 2208,  155,  365,    8,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1130,   37, 1505,  553,    1, 1597, 1273,  700,   32,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  424, 1981,   12,    7,  365, 2741, 1675,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1126,    1, 1086,  892,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 572, 244, 554, 118,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 870,  58, 708,   1,  37,   1, 596,  29, 656, 285,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977,   37,    1,    1, 1056,  537,  548,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1086,  976,  909,  528,    1,  509,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  683,   32,  489,   39, 1665,  297,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  108,   45,  525, 1073,   79,    9,    1, 2102,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  449,  364, 1383,    9, 2570, 2107,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1329,  752,  469,  640, 2195,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1330,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  668, 1091,  837,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1531, 3079,  872,  420,  385,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1625,    9,  183,    1,  220, 2734,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,  365,    1, 2274,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9, 3240,    1,  892,   12,    1,    1,    1,  537, 1490,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,  506,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 2658,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2004,  326, 1419,  340, 1251,    1, 2168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117, 2208,  729,  105,  584,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,   51,   26,   14,  124,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  325,  647,    9,    1,  131, 1714,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  954,    1, 1552, 2738,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1443,  240,  479,   12,  315,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1622,   69,  393, 2774, 1489, 1194,    1,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1877,  581, 2113,  973,    9, 2708,  171,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  723,    1,  884,   48,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2217, 1277,   61,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1951,    1,  454,   37, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  627,   28,   32,  166,   22,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1081,   12, 3401,  884,  756,   51, 2225, 2224,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1912,  529, 2666,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,   37,   26,   28,   37,  124,   32,  395, 1411,  356,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,   45, 1149, 1313,  971,   12,  315,   37,  125,    1,    4,\n",
      "           32,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2633, 1838,    1,  442,  220, 3266,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 2851,    9, 2264,   45, 1691, 1778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  705,    1,  384, 1972,    1, 2495,  517,    1, 2226,    1,\n",
      "           12,   32,  531,   12,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3084,  315, 1133,  365, 2095, 1506,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  580, 3148,  134,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  361,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  167,  211,   95,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   90, 2792,  221,   98,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   91, 1477, 3273,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1856,    1,  220,  114,  361, 2725,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  449,    1, 1318,   45, 1428, 2218,   37, 2266,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1033,   25,  720,  289,   98,   69,    1,   93,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2028, 2055, 1797,  622,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3391, 2751, 2582, 2398, 2108,   37,  804,  531,  163,    1,   12,\n",
      "            1,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1033, 2178, 2164, 2414,  176,  177,    1, 1744, 2347,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61, 1178,   45,    1,  140,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3094, 1530,  361, 2249,   32, 1177,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1022,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3360,    1, 3363,    1,  220,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,  859,  297, 3025, 3125,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1636,  541,   37, 1327,  548,    1,  467,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3274, 1564, 2315,  865,   37, 2579,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  116,    1, 1073,   32,  451,    9, 2931,    1, 2325,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1369,  251,   37,  138, 1370,   45,   78,  396,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2226,    1,    1, 2226,  331,  105, 1228,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232,  698,  198,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1914,   45,  183,  620,  225,  605, 1294,   61, 1229,   37,   52,\n",
      "            9,  333,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1818,  147,   37, 2303, 1842,  116,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147, 3384,  437, 1679, 3047,    1, 2886, 1841,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2360,  361, 2259,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,   32, 2786,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  104,   32, 1951,  250,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1718,  321,  504,  384,  166, 2994,  117,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163, 1230,   98,  333,   32,   91, 2675,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12,  365,  593,   37,    1, 1658,  259,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  146,  147,  884,   28,  625, 1991,  444,  626,  239,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2596,    1,    1,    1, 1316,  447,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2297,   32,    1, 1117, 1525,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,    1,  104,    1, 1527,    1, 1618,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1855,    1,   32,  531,   90,   45,    1, 2139,   37,  429,   98,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3343, 2751,    1,   37, 2856, 1428, 3365,  774,   46, 2052,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 1428, 1822, 2035, 2108, 3368,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37,  138, 1417,   59,   37,    1,  170,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144, 1557,  650, 1082,  549,  548,    1,  420,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  754, 1465, 1054,  861,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1929,    1, 2780,  805,   98,  550,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  827,  171,  754,  102,   77,  677,  176,  198, 1224, 1452,  187,\n",
      "           15,  470,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102, 2328,   37,  365,  786,  339, 1653,  548,   25, 1374,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  548,  537,    1, 1215,   37, 2446,    1,  187,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  953,  951, 1547,  187,  163,    1,   12,    1,   29,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2, 305, 670, 187,   1,   1, 817,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 104, 954, 871, 365, 754,  15, 245,   1, 642, 643,  71,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  810,  365,  769,    1,    1,  267,  657,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006, 1260,    1, 2791,    1, 1056, 1530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2266,    1,  176, 2059,   12,  345,   37,   69,    9, 1011,  287,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1070, 2476,   37,    1,    1, 2192,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1652,  859,   37, 1496,   26, 1039,  444,  822,  396,  918,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2097,  389,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1683,  187, 2774, 3382,    1,  105,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 2664, 1231,  220, 1792,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3303,    1,   81,  191,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282, 3257,    1, 3198,  798,  140,  176,  166,    1,   45,    1,\n",
      "           32,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788, 3322,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178, 3382,   37,   52, 1231,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1364,    1, 2774,  650,  488,   37, 1539,    1, 2139,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613,   37,  877,  829,    1, 1615,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   22,  942,   37,  151,    1, 1497,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1034,   98,  166,  777,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  615,    1,    1,  424, 1034,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460, 1682, 1862,  600, 1262,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2073,   30,  460,  729,  967,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  315, 2678,   98, 2086,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  328, 2472,  159,  686,  119,  845,  548, 1901,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  132, 2576,  449,  395,  225,    1,   37, 1638, 1221,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   66, 1298, 1382,   69,  176,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1993,   39,    1,   37, 1758,   32,  395,   26,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 853, 538, 714,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 294,   1,   1,   1,   1, 471,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  615, 2155,  984,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 1069,   32, 1022, 2033,  417,  763,   76,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  148, 1917,    1,    1,  105, 2849,  297,  148,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1022,  197,  570,    9,    1,  294,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,   37, 1012, 1060,  388,   32,  854,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810,  566,  565,   98,  104,   65, 1953,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,   37,  907,  220, 3269,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  616,  120,   98,   10,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  475,  487, 1409,  267,  100,  920,   98,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,  98, 365,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 330, 361,   1, 986,  79,   9,  91,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2316, 2545,  225,  265,    1,   93,    1,  275,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,  693,  179, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  649,  954,  744,    9, 2127, 2585,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  646,   71, 1464,   37, 2199, 2557,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  443, 1229,   37, 2192,    1,   37, 1730,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  808,   32,    1, 2646, 1512,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1906, 1625,    1,   61,  227,  617,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  294,   22,   12,    1,  353,  354,    1,  315,  389,    6,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1537, 1583,   37,  125, 1815, 2128, 1397,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  398, 1707,  399,  148,  765,   37, 1504,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1763,    1,   32, 2170,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1023, 1204,   39,   32, 1169,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  696,  273,   37,  631,   32,  593, 2522,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314,  225,  407,   98,  943,   45,   82, 1031,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 420, 381,  37, 142,   9,   1,  88,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 104,  22, 359, 498,  37, 365,  46,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,  190,    1,   98,    1, 1510,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147, 1206,    1,   37,  365, 2322,   98,  626,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1305,  225,   85,  548,  156, 1306,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1236,   37, 2199, 2367, 2695,  949,   98,  207,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,    1,  104,    1,    1,  365,  813,   32,  310,  605,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200, 2627,    1, 1362,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1902,  900,   82,  361, 1644, 1734, 1483,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1033,  952,    1,   32,  854,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 2196,    1, 1167,    1,  590,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  493,  640,  339,  845,   45,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1600,  125,    1, 1149,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1290,  396,   71,   98,   81,   45,  567,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1934,  879, 3351,    1,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   12,  332,  636,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  699,  548,  626,  636,    1,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1687, 1022,    1, 3008,  105,    1, 1551,   45,  114,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   69, 1086,  417,  187,    1,  889,  529,   66,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1502,  313,   37, 1864, 1503,  349,  191, 1169,    1, 2013,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  667,  535,  633,  353,  156, 1253,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2172,   66,  187,  454,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 163,   1,  12,   1,  57, 295,  37, 949,   1,  29,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  60,   1,   1, 388,   1,  76,  88,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,  338,   98,  477,  408,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1414, 2596, 2597,   12, 3356,  787,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  166, 1076,  693,    9,  671, 1078,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,   37,   52,  330,  116, 2542,  413,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  132,   37,    1,    1,   12, 1218,  613,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147, 1554,  215, 2095, 1506,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1995, 1071,    1,  202,  517,    1, 2226,    1,   12,  335, 1023,\n",
      "           45, 3391,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275, 2005,  588,    1,  895,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  782,  388, 1534,   45,  238,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1976,  176,  163,    1,   12,    1, 2147,   32, 2573,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  242,  615,  240,   65,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  923, 2587,    1,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3358,   61,   32,    1, 1813, 1204,  361, 2162,    1,    1,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  190,    1,    1,  527,  474,  802,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1848,  494, 1335,  514,   32,    1,  636, 1336,    1, 1046,  611,\n",
      "          199,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98, 3358,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2868,  146,   37, 3358,   37,   84, 1483,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 2334,    1,    1,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 1046,  730, 2614, 1411,  187,   76,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2254,   12,  283, 2914,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3039, 3040, 1090,    1,   28, 2795,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1204,   32,  166, 2056,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1591, 1536,    9, 1126,  220,  422,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1156,    9,  537,   32, 2936, 2596,  776,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1529,  182,   12,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1821, 2896, 2477,  944,  928,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1604,   32,    1,   63, 2895, 1187,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  666,  105, 2056, 1239,  567,    1, 1533,   39,  176, 2288,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1046,  388, 1118,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  326, 1353,  192, 1085,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596, 1151,   15,   93,    1,   32,  871,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3118, 2024,   46,  588,   37,  271,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  361,    1,    1, 2700,  774,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2888, 1061,    9,  840,  829, 2690,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  439,   61, 1120,    9, 1728,  638,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  199,  421,   50,  200,  792,    1,  834,  792,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  433, 2682, 3140,   98,  663,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1652, 1494,   39,    1,  444,  829,  220, 1718,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  195, 2702,  884, 2476,   37,  942,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 1004,  864,  899,  810, 3366, 1491,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,  460,   37,    1,   32, 3152,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2016,  921, 1833,   32, 2161,   12,  138,    1,    1,  220, 1940,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1674,  315,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  420, 1407, 1696,    1,  921,  331,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1082,    1,   37, 1406,  600,    1,    1,  193, 2078,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  718,   65,  475,  242,  347,  110,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 2018,    1, 1530, 1940, 1399,  590,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3108, 2935, 2764, 1619, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,  669,  251, 1211, 2734, 2393, 1294,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1629,    1,  884,  297,  176,  314,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2869, 2071, 2186, 1294,  384, 1773,  967,    1,   45,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   98, 2800,  548,   56,  537,    1, 2136,  729,    1,  220,  105,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  913,   32, 2218,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2055,   79,   26,  220, 1918,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,   37,  151,  388,  728,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   92,  463, 2170,   32,    1,  786,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  952,   37, 1000,    1,  220,  104,  662,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  119,    1,    1, 2137, 3260, 1159, 2522, 1832,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 3160, 1333, 1530,   32, 3339, 1388, 1583,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  202, 1166,   61,  166,  567,  707,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1935, 3016, 1935,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2615,  875,    9, 2210,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  119,    1,  125,  802,  220,  912, 2285,  441,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2161,   51, 1844,  658,  763, 1940,   32, 1675,  506,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  227,  550,  361, 1628,  550,    9, 1972, 1821,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   89,  288,   37, 2370, 1245,   32,   91,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,   72,  401,  156,   71,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,    1, 2868,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3312, 1505,    1,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  744, 2019, 1563,    9, 2071, 1331,  769,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1,    1, 1022,    1,    1,    1,    1, 1022,    1,\n",
      "            1,  428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  146,    9,  949,   45,    1, 3377,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 2548, 2856, 2708,   32,  539,  458, 2625,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  566,    1,  187,    1,   12, 1625,  866,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  619,  331,   92,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  593, 1822,    1, 2051,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2960,   32, 1606,  176, 1094, 2835, 2735,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  193, 2613,   37,   84,   28,  548,    1,   32, 3141,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1140,    9,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 1671, 1976,   32, 1428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1518,    1,   32,  182,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1366,  565, 1542,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  397,   37,  342,    1,  455,    1,  163,    1,   12,    1,  442,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  281,  282,   51, 1046,  422,  522,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  952,   37,    1,  382,  436,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1674, 2965,    1, 2222,  140,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2161,  726, 3077, 3126,   32,  238,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1035,    1, 2963,  142,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  971,    1,    1,   32, 2883,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3096,  311, 2556, 2741, 1663,    1,  528, 1987,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3251,   37,    1,   37,  316,  716,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2741,  489, 3242,   39,   45,  166,  114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2909,  135,  166,  501, 2060,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   15,   23,    1,   81,   32,  166, 1381,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  460,   12, 1846, 1700,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 1365,  810, 2789, 2024, 1320, 1268,   37, 1860,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3369,    1, 1428, 1421,  132,   98, 3396,  865,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1118,  698,   45, 1343,   32,    1, 1463,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  457,    1,    1, 2562,  331,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374,  650, 2582,    1, 1094,    9,  537,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  168, 2391,  845,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,  967, 2562,  453,  706,    1,   45,    1,   37,    1,\n",
      "            9,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,   81,   28,   37,   98,  104,  889,   25,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2503,    1,   32,    1,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1985,  118, 2715,    1,  191,  506,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3045, 1641,   28, 1018, 1147,   69,  965,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  203, 2471,  190,   52, 2961,  176,  914,   12,  439,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  131,  301,    5,  302,  562,  705,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1414, 2497, 3391,   63, 2731,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1976,   32,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  472,    1,    9, 3161,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3347, 1411,   37,   52, 3395,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962, 3117, 1285, 3251,   37,    1, 1264,  841, 1224,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2765, 1089,   30, 3026,   45, 1147,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  650, 2216,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267, 3371,  190,  877, 2018, 1018,  996, 1021,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1043,  332, 1738,  338, 1270,  419,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3178,    1, 3064,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  282,    1, 1158,   12,    1,    1,  105,    1,  361,  388,  327,\n",
      "          593,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  572,  105,    1,  650,  852,    9,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  859,   37,  288, 1483,    1,  187, 1417,    1, 2226,    1,\n",
      "          105,    1,  475,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101,    1,  546, 1461,   32, 3339, 3133,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1404, 2399,   37,    1,  398,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  597,    1, 1831,    1, 2030,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1794, 2728,   37, 1752, 1609, 2542,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1971,    1, 2803, 3265,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  625,   98,  776,   45,    1,    1, 2153, 1812,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1189,    1, 1947, 3107,  302,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32,    1, 1450,   32, 1853,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  233, 2591,   37, 1083,  104,  734,    1,   37,    1,    1, 1714,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1629,  927,  167,  289,   98,  223,  286,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  327, 2264,    1,    1,  220, 1158,    1, 1128,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2013,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1971,   81,   28, 1515,  943,  220,  726,  297, 3250,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1484, 3369,    1, 3148,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428,  716,  410, 1647,   32,  856,    9,    1,  223,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1771,  171, 2889,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3282, 1764, 1990, 2493, 3169,   12,  754,  147,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111, 1624,   37, 1215,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  597, 1099, 1453,    1, 1216,  122,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   37,   52,   32,  105, 1111,    1,  176,   26,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,  288,   37,   26,   69, 1482,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1107,    1,   42, 2730,    1,  297,    1,  628,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428,  536, 2401,   32, 2873, 1384,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1412,    1,    1, 1753, 3003,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2254,    1, 1361,  875,  768,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1240,   52, 1542,   37,    1, 1167, 2925,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  571,   37,  501,  827,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169,    1,   73,   37,  915, 2144,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  350,    1,  532, 1124,   32,  356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  707,   37,  166, 2918,    1,    1,  191,  331,  331,   12,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3166, 1774,  548, 2056,  698,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  636,   12, 1295, 2341, 1372, 2771,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3387, 2985, 2827,   32,  447,    1, 2468,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708, 2405,   37, 2237, 3358,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 2161,  875,    9, 1832,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   12,    1,  580,  331,    5,  302, 2013,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  342,  193,    1,  203,   37,    1,   94,   32,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1419,  658,    1,    1,  660,  331,    1,  102, 2917,   98,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,  185, 2192, 1033,  105, 1198,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  418,   98,  107,  125,  943,    1, 1785, 1260,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,  848,    1, 1355, 1230, 2543,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2197,  246, 1119,   37, 1718,  384,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,  296, 1798,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437,  730, 2288, 2150,    1,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3053,   37,  930,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1733,    1,    1, 1081,   12,  365, 1009,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2725, 2918,   37,  877,  453,  813, 2697, 1897, 3048, 2923,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  334, 2233,   52,   81,    1,    1,   90,  455,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,    1,    1, 1822, 1719,  460,   12,\n",
      "         1989, 1990,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9, 1728,    1,  105,  163,    1, 1741,    1,    1, 2274, 1167,\n",
      "            1,   81,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  260, 2005,  942,   37, 1918,  951,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  458,   37,  151, 1973,  217,    9,   59, 2097,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  896,    1,  220,  777, 2681,   85,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1260, 2362,   37, 2653,  596, 1793,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,   12, 1861,    1,  818,  548,    1, 2909,    1,    1,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  169,  361,  702,   37, 2123,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3046,    1, 3126,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  715,    1,  420,  410,  156,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  113,  530,    1,    1,    9,  889,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  590,  531,  966, 2945, 1281,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1178, 1450,  404,  395,    1,    1, 2766,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3209,    1, 2100,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3261,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,  105, 1128,   12,    1,    1,   98, 2278, 2471,    1, 2759,\n",
      "         2461,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1051,   37,  130,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  558,   37, 1864,  349,   45,    1, 1589,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  218,  387,  885,   65,  423,  424, 1034,    1,  202,  627, 1434,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  365, 3118,    1,  898,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1101,    1, 1100,   12,  983,  157,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  267,  590,   37,   46, 1010,    1,  396,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  515, 1628, 2407,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   26,  242,   98,  996,  550,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  506,    1,  471,    9,  460,  389,  218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  251,    1,  176,  632, 2147,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  446, 1408, 1031,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2816,  187,  510,    1, 1530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  776,  190,    1, 3386,    1,  267,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  449, 1023,  207,  197,  407,  419,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  755,    1,   61,  861,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204, 1141, 1632,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   98, 1928,    1, 3047,    1,  267,  204,   12,  562,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  544,  334,    1,    1,    1,    1,    1,  612, 2898,  320,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3228,  588,    1,   45, 2218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3145,  115,   98, 2403,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1070, 2862,   37,    1, 1557, 2778,    1,  949, 3351,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  137, 1046, 2154,   64,  302,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  224, 1774,   39, 1013, 1607,    9,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,    1, 2410,    1,  384,  104,   32, 1764, 1990, 2069,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  531, 1386,  267,  967,  193,    1,  103, 2343, 2431,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1,  297, 2615,   32,    1, 1869,    1,  191,   70,\n",
      "          239,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   32, 2823,    1,    1,  105,    1,   45,    1,  361,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  566,  187,  567,  431, 1549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  224, 1660,  244,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,  366,   32, 3343,  806,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3038, 3121,  396, 2853,   32,  455,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1926, 1927,  104,  861,    1,   98, 1563,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  149,  444, 3310,  907,   32,  961,  147,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  746,  744,  844,  132,  220,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  794,  596, 2359, 1222,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  858, 2493, 2947,  327,  593,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2319,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 1917,  854,   72, 1463,    1,  123,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  864,   51,  588,   37,    1, 1461,    1, 2673,    1,  104,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465,   13, 1870,   37,    1,  225,  384,  507,  111,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  116, 2542, 1654,  218,  332,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340, 2405,  754,  729,  603,    9,  590,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  645, 2292,   32,  531, 1554, 2753, 1530,    1, 1744, 2198, 1021,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  216,   32, 2597,   12,  501, 2060, 2856,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1152,  444, 2587, 1227,  116, 2542, 2995,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  177, 1061,   32,  787,  187, 2832, 1388,  220,  947,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 3067,    1,    1, 1301,  455,    9,  193,    1,   37, 1730,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783, 1654,   59,   32,   72,  401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,    1,   12, 2009,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1689,  221,   37, 1584, 2476,  686, 2774,  353,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2909, 3338,    1,  121,  716,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 1414, 1758,   98, 2646, 3346,    1, 1523,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  441, 1753,    1, 2547,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2646, 3392, 1025,  686,  187, 2426,  614,   98,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,   37, 2303,   98, 2109,  548, 1275,   29,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947, 1152,    1,  115,   45, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   98,  166,  119,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  316, 2681,   37,  865,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328, 2077,  353,  572,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  454,    9,    1, 1151,    1, 2168,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1726,  260,   28,   37, 1260, 1040,  187,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  396, 2993, 2994,  193,  105, 1665,   37, 2997,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  579, 1444, 1445,    1,  600, 3214,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,    1, 1968, 2274,   37, 2654,   15, 2544,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1304,    1,    1, 1403,  853,  844,   37, 2433,   78,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1300,  600,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   26, 1039,  777, 2043,  669, 1668,    1, 1799,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,    1,   37,  771,   32,  388, 3118,    1,    1,  232,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2614, 2561, 2312,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1, 2684,  176, 1580,  656,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,   37,    1,    1,  552,  102,   37,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1051,  872,   28,   37,  843, 2348, 1074,  280,   32,\n",
      "          455,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   26, 1298, 1382,    1,  761,  338,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  936, 2071, 1331,    1, 2403,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  531, 3006, 1816, 3102, 2162, 1665,   37,  455,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12, 2339,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  602, 1489, 2468, 2251, 2099,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  999,    1, 1000,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    9, 1210,   45,  105, 2528,    1,  630,   61,  901,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   70,  720, 1315,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  590,   37,  889, 2826,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  779,    1,   12,  646,   93,  570,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  200, 1778, 2580,  535,  656, 2581,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 1376,  220,    1,   12, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3033,    1,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,  650,   45, 2214,    1, 1551,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  700,  794,  777, 1085,  279,    1, 2639,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  400,    9, 2275,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3101, 3350,    1,    1, 1159, 3065,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  325, 1223,    9, 2095,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3173, 2559, 2774, 1521,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 1070, 1053,   37,    1, 1204,   45,  195,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  247, 3329, 1067,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3244,    1,   32,    1,   56, 1090,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3114, 2257, 3399,   39,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092, 1070,  103,  163,    1,   12,    1,  147,   37,  817,  912,\n",
      "          605,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2925, 3244, 2286,   37,  221,   98,  384, 2175,   28,  415, 1139,\n",
      "           32,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1140,  297,    1, 2772,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    9, 2310, 2059,  176, 3275, 2630, 1924,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2976,    1, 2745, 2063,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,    1,   46,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   98, 1194,    1,    1,  105,   59,    1,  333,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1186,  108,    1,   45, 1081, 2834,  629,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 2069, 2227, 2107,   45,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2871,    1, 2034, 3212,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1021,  288,  166, 1267,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1699,  365, 2808, 1006,   61,    1,  361,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2705,   32,  531,  103,    1, 1485, 2161,\n",
      "         2827,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1109, 1126,   37, 1083,   28,   37,  104,    1,   54,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  716,  737,  156,   28,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503,  159,  832,   98,  521,    1, 2281,  839, 1159,  749,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,   52,    7,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,   98,  103,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3188,    1, 1902,    1, 3244,   37,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   22,  359,  498,   37,  365,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2523,  852,   55,  204, 2233, 1334,  590,    1,    9,  920,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,    1,  609,  162,  257, 1038,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2442,  905, 2103,  617,  432,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  446,  580, 1133,    1,   37,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2784,    1,    9,  721,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1924,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  342, 1484,    9,  241,  698,   32,    1,  442,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1851,  547,    1,  163,    1,   12,    1,    1,   32,  411, 1890,\n",
      "           32, 2890,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1472, 1018,  661,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   81,  863,  855,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1796,   25, 1285,  417,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  251,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2929, 1292,  488,  822,  522,  444,    1,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  749,  480,  155,    1, 1574,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  657, 1118,    1,  218,  714,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236, 1022,    1,   76,   37,   26,  699,  417,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1962,  396,    1,  613, 2666,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  259,  126,  927, 1668,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,   12,  535, 1539, 1360,  612, 1198,  156, 1724,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2899, 2094, 1412,    1, 1107, 2943,   37, 1778,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   53,   98, 1102,  841,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,  125,    1,    4,  481,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1951,  957,   37,    1,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1101, 2817,   32,    1,  854,  798,  388, 2853,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  469,   37, 1211, 1645, 3365,    1,  811,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2024,   46, 2434, 2375,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,   84,   28, 1107,   15, 1705,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1009,   10,    1,   98, 2433,   78,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1710,  334,  138,    9,  793, 1011,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087,  637,  297, 2336,   37,  657,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,  673,    1,  288,   37,  335,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  921, 1568,    1, 1638,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9, 2181,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,   32,  979,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303, 1446, 1294,   32,  227, 1134,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  678,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  991,  148,  647, 2552,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 357,   1, 276,   1,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 166,   1, 954, 424, 454,  37, 166, 627,   1, 111,   1,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  982,  313,   37,    1, 2436, 1285,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  254,    1,  411,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1652, 1536,    1,  149,  444,  829,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  231,  258,  327, 1013,  193, 1762,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1668,  271,  166, 2378,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75, 1679,   28,    1,    9,  517,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977,  794,  365,  853, 3072,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   51,   23, 1821, 2190,   37,   52,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  176,  166,  882, 3283,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  865,   37, 2295,  187,  204, 1710, 2330,  440, 1090,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  183,    1,    1,  183,  356,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311, 1734,  191,    1,    9,  920,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2802,  105,  865, 1178,  424, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,   37,    1,    1,    9, 1183, 2113,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2004,    1,    6,  636,   45, 1395, 2105,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  241,  142,   37, 1281,    1, 1662, 1464,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3157,  774,   37, 2856, 1428, 3102, 1232, 1004,  193,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,    1,  479, 1937,  800,   15,    1, 1069,    6,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2041,   37, 1717,    1,   98,  105,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2539,  166, 2749,    1,   39,   98,  511,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2528,    1,    1,    1, 2232,  260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2565,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  882, 2239, 1560, 2455, 1632,  526, 2186,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,  528, 2316,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 755,   1, 365, 834, 778,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 978,   1,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  522,  297,  596, 1793,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1152,   98, 2063,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   95,   45, 2695, 1961,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2339, 1108,    1,  116,    1, 2502, 1551,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   25, 1473,  242,  187,   69,  102,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2301,   32, 2056,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1859,   32, 1381,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311,   37, 1838, 2596, 2716,  427,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 2229, 2232,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,   33,   12,   32,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1997,    1,   45,   69,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968,   12, 2084, 2789, 2591,   37, 1910,  957,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1536, 1312,  365, 2819, 2039,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  443, 2994,  951,  116,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1755, 3101,  622, 2153,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  794, 1417,    1,  372,   32,    1, 1021,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98, 1918, 2290,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2414,    1, 2231,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  174,  910,   28,  297, 1056,    1,    1,   29,   16,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  472, 1090,  614,    1, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  857,  605,    9,  636,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2571,  474,   12, 1896,   37,  439, 3118, 1512,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3267,    1, 1159, 2069,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3177,   12, 1542,    9,   91, 3335,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  384,  455,  457, 1446, 2836,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  579, 1444, 1445,    1,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,   37, 2286,   37, 1598,   69,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  848,   12,  824, 2739,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2979, 1151,   37,  714,   32,  326, 2355,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2249, 3009,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2700,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1985, 3375,    1,  547, 3095, 2572,   32, 3339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  707,  636,    9, 1074,   45,    1, 2261,    1,    1, 1160,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  934,   37,  973,    1,  608,    1,   32,    1,  626,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  102, 1473,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,  680,  166,  826,  994,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2161,   12, 2677,  199,    9,  284,  365, 3009,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1235,  102, 2084,  504,  452,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1435,  187,    1, 2344,  289,    1,  103,  494,   37, 1066, 1604,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,   12,    1,  437,  835,    1, 1074,  176,    1,  636,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  105,  596,  116,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  534,  744,   28,    1,    1,  750,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2235,  332,  102,   28,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,  846,   45, 1254, 3019,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1174,   37,  619,  166, 1263,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   68,   69, 1298, 1382,  548,    1,   98,  679,   69, 1057,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  474, 2153,  817,  645,   24,  693,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  177, 1530,   32,  121,   36, 3071,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2387,  100,    1, 1250,    1,  163,    1,   12,    1, 1008,   98,\n",
      "         1638,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,   69,  102,  190,  805,   98,  104,  954,   65,  232,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  985, 2098,  354,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  537,   98,    1, 1851,    1,    1, 2449,   45,    1,   12,\n",
      "          715,  608,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1036,   37,  316,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1870,   30,  838,    1,  365,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,   37,  125,    4,   32,   91,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  647,  929,  267,  142,  110, 2267, 1145,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   22,   37,   77, 1480, 1354,   45,  453, 1202,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1477, 1990, 2294,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  295,  387,  388,  389,  390,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  356,  560,  347,  670,   32,  645, 1034,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006,   32, 1089, 2253,   37, 2856, 3091,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1070,  147,    9,  419,  474,  138,  125,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  353,  105,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2533,   24,    1, 1961,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3087,  640,   27,  854,  590, 1080,   66,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1727,    9,  764,   32, 2490,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,  475,   12,    1,   98,  166,  260,   32, 1523,  220,  253,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1656,  943,  114,    1,   98, 1955,    1, 1917,   61,  311,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 1034,   12, 1586,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   71,   98,  198,   14,   15,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3385,  475, 1921,   32,  463, 1447, 1010,  122,  297, 2673,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  567,  510,   12,    1, 2414, 2100,  166, 1549,  540,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  958,  221,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1953,   45,  166, 2822, 1906,   32,    1,   98,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200,  449, 2381,    1,  192,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   49,  580,    5, 1197, 1757,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375, 1260,  399,  548, 3358,  928,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  393, 1243,  389,    6,  469,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  915,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1414,    1,    1,    9, 2095, 1898,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  195,    1,    1, 1492,    1,    1,    1, 1156,    9,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1282,  550,  551, 2415,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  411, 2911, 1594,   39,   32,  584,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3232, 1046, 1133,  427,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  936, 2979, 2869,  636,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3172, 1090, 1829, 2755,  878,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32,    1, 1585,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  967,  166,    1,    1,   98, 1018,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  593,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 671,  37, 447,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 105,   1, 726,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12, 3131,    1, 1590,    9, 1354,   45,  166,  914,\n",
      "            1, 2764,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,    1,  112,  406,  897,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1773,  115,   45,  166, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2844,   32,  241, 2752, 3279,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,    1,  187,    1,    1,    9, 1292,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3116,  922, 3315, 1249,    1,    1,    1,   37, 1758,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,    1,  738, 1234,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,   26,  417,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,   98, 1139,  439, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1295, 2572,   32,  395, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  829,   37,  877, 2997,  388,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 3018,  315,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1640,    1,   28, 1156,    1, 1492, 1572,    1, 1438,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614, 2446,    1,   32, 2799,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2862, 1583,    1,   37,  907, 1537, 2038,   98, 2507, 2237,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  302, 1963,   37,  606,  985,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1211,  442,  469,    9, 1033, 2211,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2375,   15,   92,   20,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1976, 2793,   32,    1,  548,   64,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1247,  967,  590, 2012,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2137,  135,  730, 2288,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361, 2230, 1114,   98,  454,   37, 3179,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 2658,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3103,    1,   37, 3089,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,   12, 2431,    1, 1751,   37, 1335,  514,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3260,  688,  931,   37,  335,    1,  631,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  395, 2116,   85,   37, 1821, 2532,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  437,   45, 2458,    1,    1, 1236,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 1009, 1070,    9,    1, 2117, 3406,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3209, 1285, 3319,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  405,    1,  267,  204,   12, 1542,   37,  856,  134,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810,    1,    1,    9,   32,  531,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2,  97, 434,  98, 163,   1,  12,   1, 297,   1, 149, 428,   1,   3,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 458,  45, 507,  37, 125,   1,   4,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2843, 2489, 1632,    1,   45,   81, 1987,   37,   16,    1, 1027,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1149,  288,   37,  741,   98,  365,   24,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1380, 3381, 1074,   32,  531,   98,  453, 2095, 1638,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  596, 2034,  331,    9,  572,    1,    1,  220,  331,  354,\n",
      "          915,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1212,  787, 2757, 2744,  601, 2653,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  997, 1239,    9,  183, 1042,   32,  433,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  114,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051, 1039, 2690,    9,  333,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2176,    1, 2249,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,    1, 1031,    9, 3325,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2736, 2864,  220,  105,    1, 2789,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147, 2024, 2699,   32, 2646, 2597, 1585, 2414,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2715,  193, 1997, 2572,  191,    1,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  267,  453, 2334,   32,    1, 1631,  846,  119,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426, 2055, 2333,  676,  117,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3260,    1, 1625,   98,    1, 3224,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3244,  698,   37, 1000, 1515, 1076,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3326,  750,  884,  183,  686,   63, 1090,  220, 3115,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  678, 1484,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,  166, 3059,    1, 3188,   12,  714,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1663,  437, 2954,  444, 2819,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2080, 1178,   61, 1530, 1024,    1,  375,   32,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   51, 1876,    1,  671,    9, 1447,   32, 1674, 3208,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  727,  613,   34,    1,  669,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1,   98,  431,  455,    1,   51,  477,  409,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  501,  361,    1, 1041,    1,  191, 2925,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1354,  249, 1398,  612, 1847,  579,   37,  544,   37, 2192,\n",
      "           32,  357, 1910,  460,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  938,   74,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2511, 1581,  422,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  170,  406,  640,  119,  845,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  195,  753,   32,    1,  505, 2135,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3115,  606, 1198,   79,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  142,   37, 1154, 3243,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  150,  376,  983,  570,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294, 1456, 1236,    1,    1, 2180,    1,  217,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1481,  200,  863, 2639,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  485, 1948,  716, 1520,  720,   32,  156,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,   69,  909, 1665,  444, 3369,   32,\n",
      "            1, 1428, 3146,  963, 2122,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  217,  808,  343,   32, 1047,  287,   87,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  112,  830,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  284, 2438,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1002, 2823, 2107,    1,  905,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  479,  716,   15,  720,    1,    6, 1069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  424, 1981,   98,  844,    1,  538,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283, 2615, 3108,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1559, 3114, 1203, 3397,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1604,  388,    1, 1154,  388,  357, 2844,  594,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1, 619, 388, 674,  45, 166, 112,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  32, 214,  46,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  154,    1,    1, 2404,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1078,   45,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  702,   37,   47,  124,   37,  754,  757,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1082,    1,    1,  650,   37,  764,  221, 2024,  226,  115,\n",
      "           32,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  142,   37,  606,  147,    1,   43,   61, 2443,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1962,    1, 2656, 1776,    1,  131,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1108, 2054,    1,   71,   32,  572,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 2572, 1425, 2764, 2765, 3006,  452,  915,  356,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  621,  325,    1,    1,    9,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1157, 2785, 1950,  640,    1, 2986, 2884,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  176,  612,  613,  733,    1, 2665, 1671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942, 1249,  163,    1,   12,    1,   32, 1990, 2701,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2672, 3159,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3130,  838,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  726, 1524, 1090,   32,  105, 1559,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2802,   12, 2315, 1045, 1086,  176,  547,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   68,  744,  119,    1,  430,  122, 1687,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162, 1950,   45,  356, 2299,   32, 3114,  665,  176,    1,   59,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1366,    1,  445,   37,    1, 2973, 1764,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1292, 1293,  198,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  819, 1980,   37, 2192, 2645,   37,  425,  426,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1862,  297, 2673, 1903,  220,  342,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  375, 1236,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  565, 3262, 2249, 3215,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2206, 2207, 1696,    1,    1,    1,  967, 3108,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  476,  647,   37,    1, 1433,  460,    1,  148,   85,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2045,  592,  267,    1,   45,    1,   32,  395,   12, 1184,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089, 1090,  231,    1,  704,  722,   61,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  140, 1523,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   28,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  632,    1, 2783,  365,    1, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708, 1900, 2027, 2855,    9,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2397, 2095, 2263,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1716,  155,  327,   93, 1470,    1,  392,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  228, 1558,  176, 2722,    1, 2616,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   37,  764,    1, 2734,    1, 2853, 2868,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 749,   1, 384, 218,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 191,   1,   1,   1,   1,   1,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  683,    1, 2584,  608,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  146,  147, 1707,    1,    1,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1661,    1, 1007,    1, 1822,    1, 1232,  460,   61,\n",
      "            1,  600, 1251,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,    1, 1188,  388,  763,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  921,  539,    1,   32, 3201,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1282,  176,  166, 2890, 2826,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  942, 1249,  104,    9,  671,    1, 2618, 3062, 3077,   32,   56,\n",
      "          497,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  402,  302,    1,  951,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,    1,   39,   45,  166, 1510,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  733,    1,   13,  159,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3232,    1,  730, 2614,  815, 3299,   37,  726, 1123, 2941,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1774, 3274, 1542,   37,  865,   32,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  885, 1628,    1,    1,  163,    1,   12,    1, 3163,  872,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1708,  155,   59, 2300,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  294,  622,  591, 1705, 1586,   28,  128,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,  922,    1, 1690, 2326,    9,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,   52,    7,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,    1, 1801,    1,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485, 3365,  820,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3167, 2962,    1,   12, 1585,  696, 2087, 2614, 1285, 3233,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 1724,  885, 2762,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  547,    1,   98, 2095,  134,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3304,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 1056,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2267,    1,    1, 1690, 1578,  187, 2954,    1,    9, 1684, 1090,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  113,   98,   37,  726,  449, 1684,  176,    1, 1869,\n",
      "         3023,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868, 1949,  315,   37, 2237, 2890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3253, 1426, 3293,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1468,  163,    1,   12,    1, 2468, 1764, 1990, 2069,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  136,   37, 2225,   82,   32,   37, 1890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3232, 1445, 1421,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61, 1870,   37,  183,  199,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1156,    9,  976, 2471,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1411, 1821, 2190, 2640, 1542,    9,   95,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  503,  686,  191,   54,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1570, 1008, 1158,  597,  710,   37, 1504,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1232, 2599, 1370,    1, 2725,  730, 2918,  190,   52,   66, 1897,\n",
      "         2923, 2697,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   47,    1,   48,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3099,    1, 2774,  297, 3341,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3149, 2751,  693,   59,    1,    9,  964,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1256,  551, 1256,  132,  220, 1026,   32,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   31,    1,   28,   32,  367,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 1492,  967, 1005, 2868,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2736,  884,  166,    1,   39,   45,  593,  119,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  147,  908,   22,  942,  283,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   10, 1550,    1,    1,   98,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2846, 2632,  187,    1,    1,  115, 2029, 1838,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   22,   95,  473, 1542,    9,  477,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1723,  261,    1, 2124,  193,    1,  384,  669,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299, 1579, 2971, 1958,  302,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1274,   71,  699,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26, 1039, 3116,    1,   85,  829,    1,  768,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2862,   12, 1407, 1190,    1,    1, 1558,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2932, 1000,    1, 1211,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2107,    1, 1056,   32,  147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1212,   25,    1,  191,    1,  887,  550,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2680,  775, 2798, 1994, 2650, 2549,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1035, 3154,   44,    1,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  864,  267,  453, 3162,  321,  920,  759,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 1466, 1774,   39,   98, 1220, 1402,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  154, 2035,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826, 2871,    1,    1,    1, 1418,  548,    1,  195, 1867,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,  384,  786,   64,    1,  686, 2177,  191,  885,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,  420,  331,  354,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2308,  474,  952,  983,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,    1, 3174,  801,  176,    1, 2445,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  963,  898, 2572,  220, 2774,  437,   32, 3367,    1,  952, 1243,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1082,  264,    1, 1294,   32, 2490, 2013,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  412, 1704,  157,  590, 1400, 1211,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  676,  441,  197,   66,  677,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   76,   32, 2160,   45, 1531, 2451,  542,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1855, 2360,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 2422,   32,  449, 2819,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1122,  853,   32,   59,  132,  220, 2193, 1123,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2615, 1914,    1,  273,  730, 2614,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  297, 1061,   32, 2292,   98, 1899, 2282, 1856,   32,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  125,   85, 1778,  566,  388,  616,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1079, 3063, 2934,   37,    1,  224,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3257,  321,  612,  713,    9, 3198,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  736, 1759,  309, 1002,  932,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3282, 3253, 1774,   98,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1536, 1312,  365, 2819, 2039,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  615,   32,  305, 1192,  388,    1,   63,    4,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,    1,  455,  429,   46,   98,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  540, 2681, 1310,   37,    1,    1,   69,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1612,  610,  297,  493,    1,   32,  395,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2468,   12,    1,    1,    1, 2682,  315,    9, 3153, 2220,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  908,    1,  563,  564,    9,  284,  947,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3140,    1,  221, 2134, 2179,    1,   32, 1430,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 2789, 1953,   37,  289,   98,  531,  443,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  588,   37, 1814,    1, 1816,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,  863,   29,  384, 1771,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2693,  406,    1,  361,  388,    1,    1,  267,  861,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2160, 2049, 1993,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3405,  738, 2226,  540, 2153,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3400,  571,   37, 1046,  134,  548,  537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2875, 2640, 1373,   37,    1, 1011,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  898,   37,  665,  453,  327,  112,   28,    9,  333,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  459,   45, 1647, 1010,    1,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596,    1,  225,   85,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2934,    9,    1,  478,  187, 1130, 1183,    9, 1890,\n",
      "         2626,  191,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    1,   37,  877,  411,  631, 1734,   28,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  187, 1019,    1,    1,    1,    1, 1444,  483,    1,   39,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 2275,    1,  736,  442,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  506, 2506,   45,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2379,    1, 1038, 1523, 2414,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  597,    1,   82, 1713,  698,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1089, 1928,    1,   32,  104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3173,    1,   98,    1,    1,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,  444, 3342,   32, 2282,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  293, 1536,  388,  912, 2285, 2039,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,  565,    1,    1,  361, 3283, 1924,    1, 1176,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3211,    1,  176, 2882, 1378, 1463,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  307,  916,   37, 1473,   37,   72,  220,    1, 2250,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   37,    1,  361,  760,    9,  166, 2204, 1821, 2773,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151,    1, 2308,  474,  360,  365,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3375, 2884,    9, 3340, 1072, 1235,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2745,  361,   32,  845,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,    1, 1116, 1466,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,    1,   37, 1211, 3340, 3073,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3014, 1996,    1, 2079,    9, 1718,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   31,   32,   33,    1,  604,  102,   71,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3235, 3210,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,    1,   26, 1039, 1228,   74, 1316, 1033,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777,  325, 1017,  384, 3028,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  680, 1658,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1845,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1107,    1, 1421,  132,   98,  777,  538,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,    1, 1202,  477, 2597,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1366,    1,    1,  105,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  954,  897,  658,  763,   76,   32,  572,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,   81,   32,    1,  112,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3157,  813, 1856,  220,  410,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  335,    1, 1491,   37, 2245,  667,  671,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  861,  437,  744,    1, 2146,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1528,    1,   37, 1752,  104, 1477, 1990,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  245,   98,  355,    1,  275,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2705, 2797,   98,  567,  666,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056, 3035,  946,    1,  267, 1094,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2184,  708,    1,    1,   37, 1334,  838,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  300,   39,  885, 1525,    1,  920,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2677, 3255, 2966,   32,  166,   22,    9,    1,  176,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,  614,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 2871, 2327,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1,    1,   51, 1724,    1,  166, 1158,  724,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  395,    1,   32,   39,   45,  674,    1, 2620,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   78, 1046,    1,  195,  636,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,    1,  686,  411,  903,    1,  294, 1645,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1718,  437,  313,    9,  224,   55, 1013,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  218, 1192,  118,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2183, 2571,  474,  379,  429, 1193,    1,   98,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1076,    1,  600,  453,  443,    1,    9,  671, 1078,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3189, 3188,    1,    1,   28,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1993,   85,    1,  829,   34,  185,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  746, 2034,   28,   98, 1183,    1,    1,  858,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   59,  599,  444,  196,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  388,  531,    1, 2705,   66,   32,  506,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  782,    1,    1,   98, 2073,  851,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,  345, 1976,   37,    1, 2705,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1554, 2412,  187, 1955,  151,   48,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2468,   12,    1,  140,  487,  458,    9,  372,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  340,    1, 1308,    1, 1743,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  261,  187,    1, 1114, 1297,  104,   85,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537, 1228, 2401,   98, 1171,    1,  293,  582,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2998,   12, 1017,  627,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   37, 2446,  840, 2336,  279,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  130,    1, 2166,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186, 3039, 1090,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 2980, 2693,  300, 2819,   37,  632, 1273,  618,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178, 1631,    1,    1,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  729,    1,    9,  104,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2786, 2454, 1976,   32, 1778, 2580, 2851,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  103,    1, 2789, 1810,    1,   37,    1,  531, 1002,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1124, 2606, 1225,  191, 1059, 2017, 1975,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3175,  619,  810,  166, 1631,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,    1,    1,  979,  176,  166,    1,    9,  166,  872,  176,\n",
      "          166,  103,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2307,   61,   81,   32,  105,    1,  913,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  884,  885,    1,  176, 1228,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2525,   45, 2376, 2223,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2924, 1542,    9, 3383,  548, 3155,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  224, 1126,    1,  193,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  240, 2785,  591,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1051,    1, 1130, 1636,    1,    1, 2239,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  142,   37, 2155,  104,  954,  105,  183,  595,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2250,    1,    1,    1,  913,   32,    1, 2565,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    1,    1,   39,   45, 3289, 1656,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  233, 2855, 1388,  297, 2095,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  917,    1,  167,   52, 1809,  105, 2457,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 365, 625,  33,   1,  28,  33,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 136, 494, 321,  77,   1,   9, 920,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  176,   48,  424, 1981,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1760,  449,    1,   32,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  251, 1596,  716,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579, 3012, 2604,    1,  321, 1399,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1225, 1071,  176, 2056,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  469,    9,  596,    1, 1710, 1527,   32,    1,   45,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,  359,  693, 2069,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,  221,   98,  651,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2206,    1,  951,    1, 2570,  787,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1592, 1413, 1414,   37, 2446,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,  957,   45, 3369,  833,  612,    1,  453,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2977, 2334,   37, 1527,    1,  361, 2978,    1, 1821,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  276, 2007,   37,  596, 1793,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  815, 3153, 2220,   37,  588, 2911,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1006,  884,    1,   45,    1,  551,  903,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2376, 2024,    1, 2139,    9, 2024,    1,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  872, 2776, 2244,   37, 1155,  105, 1488, 2707,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136, 1614,    1, 1994, 2650, 1017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1283, 3186, 3256,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,  551,  105,  730, 1777,   12,   82,   98,  247,  669,   12,\n",
      "          645,  887,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1626,  820,    1,  933, 2255,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3079,    1, 2321,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 2486,  921, 1252, 1022,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947, 2704, 1065, 2985,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  636,  418,  686, 1108,  681,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1898, 1640,  793,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  806,   16,  667,  957,    1,  361,    1,  220, 1557,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1051,    1,    1, 1605, 2320,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1815,    1,   37, 2000, 2024,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1779, 1245,  444, 3100,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2990,    1, 1159, 3020,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2466, 2639,  858,  361,  704,  705,    5,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1573,    1,    1,    9, 1230,    1,   98,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1643, 1108, 1396,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  457, 1821, 2728,    1, 2695, 2223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2250, 1554, 3264,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3302,    1, 1327,    1, 2499,    1,  447,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051,   37,  288,   28,  704,  705, 2616,   32, 1742,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2485,   45,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2414, 3094,  176, 3354,  186,    9,    1,  650,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374, 1891,  171,   51,  606,  277,   32, 3140, 1887,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3075,    1, 3153, 2220,   32,  942,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   27,  119,  687,    1,  590,  517, 1876,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1542,    9, 1778, 1108, 1779,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1364, 1365,  952, 2024,  424,  199,  220,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    7,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283,  593,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  709,  326, 1213,  884, 2278, 2027,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437, 1236, 2189,  912, 2852,   32,   91,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  305,  526,   32, 1033,    1,  218,  566,   67,   71,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,  640, 1056, 1844, 2907,  187,  166, 2615,  688, 2307,   37,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  765, 1159,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  147,  726,  167,    1,  388,  802,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   59,    9,  171,  237, 1116,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  366,  649,  844,    1,  967, 1797,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2003, 1585,   32,  395, 1554,  297, 2249,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116, 2264,   66,    1, 1875,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1695,    1,  571,  754,  384,  208,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  840,  327,   50,   37,  395,   12,  324,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,  365, 2670,    1,  105, 2854,    1, 2854,  593,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  592,  395,    1,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  997,    1,   98,  104,  865,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 2520,  247, 1135,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3199, 1041,    9,    1, 2829,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2321,    1,    1,    9,  914,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 2769,   45,  166, 1246,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   37,    1,  453, 2494,   45, 1821, 2057,   32,    1,  232,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  786, 1833,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  596, 2807, 1437,   32,  395, 1494,  449,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   45, 1206,    1, 1426,  399,  220, 1528,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1013, 1522,    1, 1381,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  835,    1, 1873,  633,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  449,    1, 2382,  259,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3196,  546,   28,  166,  542,   32,  968,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1211, 1117, 1525,    1,  619,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  794,    1, 1013, 2549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3342,  205,   37,  319,   12, 2170,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3206,  619,  105,  271,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219, 1228, 2633, 2632,  918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  667,   50,  919,  197,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,    1, 1297,    1,   52, 1018,    1, 2968,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1930,  804,    9,    1,   32,  863,   92,    9,   10,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1366,    1,    1,  166,  932,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2519,    9,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   37,  619,  331, 1193,  209,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  323,  805, 1821,  927,  313,   37, 2809, 1159,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151,   12,  390,  193,  187, 1628,  187, 1444,  774,  994,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1450, 2743,    1,   45, 2821,    1,  220,    1, 2725,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1236,  297,  787,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1025,    1,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  615, 1399,  451,   37,  544,  388,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3169, 1159,  455,   26, 3295,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,   61,  424, 1178,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1147,  957, 1760, 2764,    1,  792,    1,  792,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1017, 2541,    9, 1037,  992,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1971, 1348,   37,    1, 3250,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1366,  416,   39,   45,  611,    1, 1216,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2708, 3065, 2572,   32, 3339, 2831,    1,    1,  774,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1897,  166, 2823,  736,  176,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  331,   32, 2685,  132,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189, 1564,  861,  973,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,    1, 1354, 2264,  384,  822, 2429,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1094, 1822, 2905,    9, 3358,   12, 2162,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3369, 2024,   46,    1,   98,    8,   45,  861,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,  700,  387,  572,    1,  260,  686,  384,  467, 2092,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2024,   46, 1046,    1,   32, 3356,   98, 2375,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  829,    1,    1,   12, 2997,  861, 2538,  892,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  818,  834,  162,   79,   37, 1121,  698,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2563, 3252,    1, 1061,   98,    1,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  105, 2876,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310,   25,   71,   98,  163,    1,   12,    1,  275,  801,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1492,   12,    1,   98, 1658,  617,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2590, 3265, 1987,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2851,    9, 1778,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103,   51, 1594,   37,   72,    1, 3229,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  726,  581,   73,    1,    1, 3246,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,    1,  854, 1822,   84,   81,   98, 1815, 3380,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  978,  769, 1285,   85,    1, 1158,  919,  275,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  260,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  755, 1830,  453,  248, 2995,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3226,    1,  612,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3360,  884,  449,    1,  992, 1750, 3093,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   39,   45, 2708,  890,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1203,    1, 1671,    1,  159, 1150,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3389, 2856,  176,  105,  186,  191, 1853, 1557,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1450, 2856, 1056,  104,    1,   32, 3360,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  364,    1,  157,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  446, 1465,    1,  513,  514,   37,    1,    9,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3274, 1707,  716, 2289,  190,  193,  877,  691,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3144,  863,   37,  168,   37,  581, 1385,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766,    1,  220, 1766, 1767,    9,  844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  630, 2011,   98,    1, 2836,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,  136,  256,    1,   55,    1, 1402,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  220, 2074,   37,  168,    1,    1, 2794,  132,  167,   52,   27,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3206,  245,   37, 1245,   32, 1385,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  547,    1,    1, 1976,  403,   45, 2597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,   43, 1355, 1994, 2086, 1017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147,  446,  267,    1,   37, 2020,  863,  469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  487, 2924, 2572,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  294, 1456, 1236, 2180,  361,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  556,  224,  550,  778,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  215, 3382,  580,  134,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1282,   12, 3235, 2246,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   57,    1,  433,   29,   30,  954,   98, 1171,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,    1,    1,  105,    1,   37,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,  121,    1,  114,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2527,    1,    1,  176,  119,  215,  340,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1483,    1, 2995,   61,  105,    1,   84,    9,  224,  918,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2911,  582,   37,  166,  806,   32,  691,  863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,  650, 1342,  365, 2789,  519,  115,   45, 2224,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1317,  704,  104,  967,    1, 1678,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2521,    1, 1247,   51, 1724,   18,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  597, 1009,    1, 1156,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  506, 2103, 2727,    1,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    7,    1,   32,  166,  608,  257,   32,  316, 3256,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  580,   45, 2170,    1,   98, 1515,  356,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1634,   37,    1, 1080,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,    1, 1380,    1,   32,  105, 1510,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  590,    1,  804,   32,  121,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2520,  467, 2928,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2045, 1072, 1235, 3338,   32, 3339,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1700, 1833,   46,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1718,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2832,  176,  754,   45, 3072,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1524,   72,  536,  417,  572,  157,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2779,  980, 1632,   37,  581,    1, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75, 1579,  449, 1228,    1,  538,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,  873,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,  565, 1587,   45,    1,    1,   98,  166, 1737,  357,   32,\n",
      "          166,   22,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   17,  838,   98,    1, 1228,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  148,   37,  151,  647,    9,    1,  182,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1790, 1419,    1,    1, 1907,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437,  396,  166, 2705,   45, 1485, 3365,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  617,  259, 1281,  972,   37, 2449,    9,  920,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777,    1, 1361,  710,    9, 2355, 1718,  973,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1527, 1001, 1822, 2014,    1,    1,  531,   37, 1399,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1061,    9,    1, 2638,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  459,  461,  785,  786,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1243,  315,   37, 1381, 2355, 1013,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,    1, 1000,  116,    1,    1,  202,    1,  912, 2285,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 1537, 2673, 1409, 2424, 2017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1973,  705, 2744,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  840,    1,  361, 2105,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  365, 1928, 1727,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  940,  796,  680,   97,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  694,    1, 2270,   37, 1734,   98,  248,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2057,  580,  230,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1008,  365,   82,    1,  929,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,  441,  973,  460, 1499, 1704,  777, 1085,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2071, 1331,  769,   51, 1083, 1228,  408,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3214, 1908,  535, 2242,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1497, 2136,    1,    1,  721,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1209,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1414,    1,    1, 2791,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  773, 2047,  388, 2127,   15,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2015,  167, 1403,  802,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2095,    1,    1, 2180,   37, 2237,  691,    1,  957, 1216,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3354,  361, 1537, 1065, 1726,  429, 2333,   46,   32,  365,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,  140, 1523,    9,  647,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1395,  636,    6,   98,  166,   71, 2007,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1, 1702, 2359,  187,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1191, 1380,  105,    1, 1046,   98,    1, 1397, 1160,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  265,  614,  760,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   96,    1,  187,    1,    1,  580, 3252,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  877,  357,  271,    9,   10,    1,    1, 1397, 1173,    1,    9,\n",
      "         1445,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1958,  365, 2544,  220,  284,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  160, 1942, 2819,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3315,    1,    1, 2072,    1, 1777, 2739,    1, 1249,    1,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  572,  197,   28,  995,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  985,    1,   61,    1,  384,    1, 2727,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1891, 1407, 1726,    1, 1430,   12,  917,   37,  105, 1211, 2179,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,   32,    1,   54,  132,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  335,   79,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1251,    1,  113,   28,    1, 1736, 1975,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2523,  140,    1, 3023,   37,  439,  701,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228, 2572,   32, 3343, 1002, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2485, 1380,    1,   98,  793,  590, 2354, 1638,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  365, 2759, 2287,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  886, 1426,   39,   37,  151,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2877,  936,    1, 2108,  752,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  187,    1,    1,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158, 2612,   98, 1230,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1211, 1084,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2646, 1345, 2361, 1010, 2024, 2699,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  995,  242,   98, 1269,   32,   69,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2388,    1,  590,    1, 3194, 3195,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885, 1798,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  167, 1371,  420,   37, 1604,  465,   95,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2743, 2094,   62,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 1158, 1230,  920,  384,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  750,   37,  619,  105,   92,  220,  865,   45,    1,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  487, 3160, 1941,   32,    1, 2596,   32,  531,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115,  335,   79,  176,  915,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2343, 3404,    1, 1011,    1,  163,    1,   12,    1,  622,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984,   12, 2820,   29,    1,  384, 2662,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1139, 1253,    1, 1628,    1,  439,  375, 1675,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1142,    1,   98, 1143,   12, 1144, 1145,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 3160, 2572,    1,  455,    1,   37, 1910,  531,    1,  487,\n",
      "         2924,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2493,  204,   12,   98,  166,  454,   81,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  233,  958,    1,    1,  187, 3104,  582,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   26,  417,    1, 1162,  246,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  425,  426, 2192,  773,  577,  698,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1226, 1114,    1, 1276, 1315,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3168, 1426,  590,    1,    1, 2198, 1938, 2809, 1684,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169, 1086, 3106,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  187, 2584, 2565,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,    1,    1, 2509,   98,    1, 2292,   32, 3118,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  506,   30,    1,   26, 1039,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  823,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2161, 2911,  948, 2206, 2207, 1377,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 1009,  108,  105,    1,  167,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1654,    1,  768,    1,  140, 2474,    1,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  852,   37,   77,   17,  548,  327, 1131,  333,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,    1, 2856,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  384, 2693,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  801,  176,    1, 2161,   12,  628,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178,  163,  542,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1829, 1510,    1,  369,    1, 1830,    9, 1133,  698,   37,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1446,  669,   42,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,  155, 1574,  600, 2374, 2417,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  238,    1, 1632,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  284,    1,  186,  444,  492,    1, 1553,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2640, 2137,   79,    9, 1821, 2190,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1011,  472,  340,    1, 2190, 2640, 2145,   37,  125,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  150,  387,  623,  366,  111,   15,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  582,    1, 1216,  808,  187,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3361, 1648,   37,  764, 1211, 3347,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094, 1112,  176,  622,  522,  951,    1, 3140,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447, 1670,   37,  665, 2271,   98, 2521,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  631,  176,  667,   26,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,    1,   37,  815,  769,    9,  613, 2287,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056, 1061,   32, 2162,   45,  104, 3091,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,    1,   28,   98,   67,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,  744, 3055,  674,   98,  660,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,  566,  116,    1,  195,  109,   37,  163,    1,   12,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  286, 1469,  680,  114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  176,  103, 1722,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1675, 2373, 1938, 2607,  382, 2206, 2989,    9,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,   60, 1654, 1737,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2308,  972,   37, 1377,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1539,  517,  618,  449,   32,    1, 1033,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  275,    1,    1, 1610,  220,    1, 2762,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081, 2061, 1934,   98,    1, 2206, 3351,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3352, 2833,    1,  361, 1056, 2476,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   14,   15,   16,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2868,    1,   98,  864, 1865,    1,   32,  316,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485, 3102,  820,   32, 2140,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  321,  612,  774, 2226,    1,  612, 1399,  334,  320,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141,    1, 1825, 2451,   37,  688, 2307,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1005, 2942,  140,  581,  671, 3126,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584, 2409, 1484,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  750,    1,    1,    7, 1534,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3194, 3195, 3272,  590,    1, 2388,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2962, 3188,   27,  119,  187, 3244,  688,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2282,  722,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   25,    1,   60,  361, 1340,  245,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2161,   12, 3141, 3009,  619,  166, 1263,  671,  357,  595,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   94, 1210,  864,   37,    1,  191, 1169,    1,  600,  453, 2673,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3190,   12,  449, 1674,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  565,   32,  105, 2213,  171,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 1830,    9,  627,  629,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  557,  540,    1,    1, 2751,    1,  447,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1941,    1,  619, 1030, 1559,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  632, 2328,  884,  365,  632,  104, 2640,   37, 2875,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  204,  315,   37,  865,    9, 1090,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,   37,  125, 1446, 1149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1433, 2161,    1, 1824, 1204,   98, 1285,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  896,    1,   12, 1957, 1173, 1176,  445,   55,  166, 3322,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3043,    1,   51,    1,    1,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  331,    1,    9, 3340, 3073,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2844,   32,  455,    1, 2260,   37,  777,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  422, 2386,  709,    1, 1682,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3178,  140,    1,  765, 1415,   37,  103, 1569,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3024,   37, 1937, 2300, 2923,   45,  166, 2918,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  321, 1937,  872,    1,  460, 2444,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2005,  163,    1,   12,    1,  297, 2468,    1,    1, 2228,\n",
      "           79,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2739, 1401,  104,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1660, 1208,   45, 1102,  931,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121, 2414,   32,  455,    1,    1,   32,  105,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  326, 2384,  365, 3044, 2168,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  113,  530,  109,  509,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   14,   15, 1376,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  273,  922, 3210,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,   37, 1174, 1958,    1, 1697, 1013,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  206,   61,    1,  361,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  215,  546,  521,    1,    9,    1, 2931,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   60,  338,  187,  239,  240,   65,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,    8, 1377,  187,  647, 1757,  431,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  729,  434,  176, 1790,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  920,  579,    1, 2383,   98, 1778, 2580,   12, 2851,  328,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2954,  661, 1211, 2878,  176,  889,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 2081,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  565, 2175,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  720,   98,  594,   14,   15,    1,   69,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1797,    1,    1,   98,  535,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  786, 1530,    1, 1700, 2249,  548,    1, 1260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1654,  453, 1644, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  446,   46,   28,    1,   37, 1081,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1640,  650,    1,  220,  844,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  845, 1625,   37,    1, 3012, 2948,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1958, 1355, 1983,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676,    1,  487,  947,  271, 2189, 1228, 1551,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1987,  420, 3009,   45,  166,   74,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1542,   37,    1,  220,  342,   57,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2909,  335,    1, 2162, 1950,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1392, 3226,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,  709, 2534,    1,  162,  851,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2822,  497,  498,   37, 1595,  751,   37,  651, 1031,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1721,  321,  612,    1,  224,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1353,  192, 1085,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1435,  848, 1303,  475,  387,    1,   93,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  920,    1,   16,   79, 1658, 2604,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1718,  361, 2608, 1085,    7,    9, 1652,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1139, 1747,   37,  139,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1537, 2702,  298, 2414,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,  225,  682,   98, 2001,  384,  964,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 2541,   45,  171,    1, 2027,   98, 1789,    1,  395,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  361, 1331,  347,   71,    1,  327,   32, 1332,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  657, 1825,  275,   47,   79,  187,   29, 1552,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  796, 1663,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3204,  967, 2069,    1, 3169,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  411,  347,   71,    1,    9,  691,  548,   27,  119, 1196,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,   45, 1853,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,   12,    1,  826,  190, 1584, 2711, 2354,   37,  166,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  548,  166,  245,    1,  765,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463,  464, 1149,  186,    1, 1207, 2154,  477,  297,  652,  302,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  203,   37, 1527, 3093,   32, 3144,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  610,   37, 2162,   32,    1, 1585,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1827,  548,  166,  245,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,   37, 2303,  215, 1233,  250,   12, 1623,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,  225,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  113,    1,  631,    1, 2523,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  496,  597,  391,  190,  726, 1081,  741,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1867,    1, 2320, 2673, 3085, 1461,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3343,  863, 2871,   39,    9,  166, 2116,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1479, 1778, 2851,    1, 2483, 2417,  481,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  245,  187,   69,    1,   60,  817,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018,    1,    1,  613,    1,  361, 2519,  288,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  183, 1272,    1, 1300,  272,  287,  357,  590,  183,  132,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233,   12,    1, 1734,  166, 1868, 1172,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596, 1793,   12,  183,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,  922,  775, 1232,  590, 3151,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2850,   56, 1530,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,  37,   1, 725, 726, 695,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 749,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  668,    1, 1077,    9, 1092, 1089,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1268,   32,    1,  549, 1159,  829,  199,  421,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  657, 1484,   79, 2657,   45,  844, 1151,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3014, 1898,   81,  756,   37, 1273,   41,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  156,  388,  763, 1427,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2972,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1110,    1,   37, 3260, 1844, 1194,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  636,  443,    1,    1,  700, 1369,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3118,   46,    1,  297,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  686,  220,  331,   81,    5,  798,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3167, 3220, 2615,  335,  631,   32, 2522,  297,  730, 2614,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1829,  829,   42,  220, 1652,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  746,   37,   47,  844,  116,  754, 2913, 1294,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3326,    1,    1, 1061,    9,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2098,  503,   12,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 2617,   33, 3358,    9, 2693,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158,    1,  848,   12,  533,  187,    1, 1230,  884,   79,   32,\n",
      "          455,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1486,    1,  716,  183,  354,   32,  581,  401,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  393,  162,    1,    9,   59,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  967,  769,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  247,  689,  565,  786,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  104,   26, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  949, 1056,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3148,    1,   98,  776,  176, 3147,  147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  375,   32, 1183, 1253, 2069, 1024,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2229, 2232, 1765, 2276,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   26,  242,   98,  801,   32,  104,  159,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3124,  140,    1, 3329,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1796,    1, 1631,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  837,    1,  818,  862,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1301,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2986,  813, 1194, 1856,   45,    1, 2909,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1349,   37, 1413, 1170,  853,  538,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2104, 1584, 1915,  861, 1017,  221, 1836,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  193,  472,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  490, 2144, 1394,  115,   45, 2275, 1002,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  901,    1, 1658,  259,    1,  105,  454,   39,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1046,  183,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  227,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  613,  116, 1962,  744,  613,   29,  846,  119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1245,  193, 2943,  220,  698,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1528,  361,    1,  332,  631,  176,    1,  628,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1676,    1,  590,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1718, 2146,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1674, 1123, 1564,  105,  686,   32, 1617,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12, 1893,    1,  863, 2472,  891,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1697, 1013, 2165, 1173,    9,    1,   98,  777,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1076, 1800,  671, 1078, 1462,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  420, 1369, 1635,    1,    9, 1610,  333,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3349,   64, 1950,  921,    1, 2249,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  766,   37, 2243, 3016, 1935,    1,   32, 1603,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   46,   18,  115,   45,  572,  420, 2007, 2283,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   10, 2224,    1, 1510,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1366, 1445,    1,  311,  501,  626,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  105,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1821,  639,  475,  939,  548,    1,  297, 1479, 1064,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1713,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  794, 3072,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   37, 3202,    1, 3332, 1552, 2738,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593, 1990,   45, 2701,  942,   34,  119,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3363,    1, 3343, 1009,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  295,    1,    1,    6,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3096, 3180, 2827,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  494, 1599,  210,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  726,  388,    1,    1,    9,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3401, 3390,   32,  187, 2178, 1009,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    7,  365, 2741, 1675,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1482,   61,  288, 1483,    9,  755,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  856,  276,    1, 1398,  612,    1,  460,    1, 1082,  405,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  919, 1665,   37, 1540,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1840,    1,    1,    1, 1132,   45,  356,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  616,  385,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3303, 1321,  384,  584, 2630,  220,    1, 1987,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  692,  116,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  449,  149,    1,  444,  116, 2650,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1317,  704,  104,  353, 1455,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401, 2615,  608, 3266,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2565, 1090,  105,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  186,    1,  439,  530,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,  713,  187, 3303,    1,   98,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2476,    1,    1, 1477, 1990,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61, 1211,    9,  334,  361, 2349,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  166, 1096,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,    1,    1,  759,  394,  895,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  183,  403,  729,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   36, 1950, 1784,   37, 1270,  187,  121,    1,  453, 1530,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  848,  361, 1181,   32,  768,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,  847,   28,    9,  844,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977, 2664,  513,    1,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3145,    9,  671,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  580, 1239,    1, 2534, 2537,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 2298,  220,  342, 2064,   32, 2673,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2871, 2079,    1, 1222,  674,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,    1,    1, 1994, 2650,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  978, 2820,  256,    1, 2665,   37,    1, 2549, 3004,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984, 2483,  365, 1551, 1425, 2662,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  864,  952,   37,    1,  284,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2720, 2796,  103,  140,  813,   32, 2148, 3079,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  994,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2995, 2454,  105, 1055,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  287,  190,   52, 2562,    1, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 1401,   32, 1764, 1990,    1, 1832,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  887,  696,    1,  716,  118,  156, 1124,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1487,   37,   92,    1,  102,   32,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2103, 2727,   71,   32, 1300,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1760,  105,  365, 1465, 1089, 1090,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,   37,   81, 1561, 2717,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302, 1712, 1117, 1525,  161,  469, 2443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018,    1, 1839,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   82,    1,  384,  669,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  187,  460,   96,   39,    1,  166, 1676,  454,    1,   37,   52,\n",
      "          166,  917,  454,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  117,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,    1,  746, 1636,  116,  132,   37, 1089,    1,  613,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2321, 1046,    1,  411, 1867,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3019,   37,    1,  220,  810, 1766, 1767, 2461,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  123,  124,    1,    1,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018,  267, 3006,   98,  166, 1844,    1,  528, 1585,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2899,  566, 1551,    1,  218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,  267,    1, 1167,    1, 1159,  453,    1, 1924,  649,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321,  166,    1, 1747, 1114,    1,  994,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  170,    1,  349,  406,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2095,  134,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3251,  221, 2562,    1,  432,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  991,    4,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2563,  631,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764,    1,  292, 1677,   45, 2103,  617, 1116,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  691,  730,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1104, 1494,  411,  220, 1615,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1273,  618,  598,    9,    1,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1839,  321,  612,  544,  166,  389,    1,  267, 2221,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1749, 1229,   37, 1876,    1, 1126,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 1186,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,   37, 1982,    1,    1, 1196,  384,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  865,   45,  166, 3032,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  496,    1,    1,  104, 1975, 1521,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  857,    1,    1,  477, 1550,  386,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   60, 1042, 1114, 2605, 1982,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1591, 2344,    1,   37,   51,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  729, 2587,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  957, 2094,    1,   32,  384,  166,  984,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3286,  113,   79, 2885,   37, 1758,   32,  593,  427, 1343, 3129,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  112,    1,  654,   12,  572,  156,  759,   59,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  997, 1189,    1,   32, 1147,  890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1528, 2297, 1477, 1990, 3164,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3151,  914,    1,   98,  365,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885,  967,  105, 1875,  388,  569,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2771,   37, 2545, 1131,    1, 2965,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1976,  176, 1428,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3358, 2450,   37, 1421, 1994,  926,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  698,   28,    1,    9,   26, 1039,    1, 3000,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2528, 2165,    1,  289,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3201, 2437,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  947, 2263,   32,  111,  161, 2607, 2574, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,   37,  877,  365, 2362,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3175,  298,   37, 3024,  187,  730, 2614, 1844,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  589,   66,    1,  531,   12, 3102, 1512,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158,  315, 1107, 2630,   61, 1018, 1230,    1,   98,  166, 2521,\n",
      "            1,  918,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,  494,    1, 1852, 2228,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1414,    1,   28,    9, 1798,  220,   28,   37,    1,    1,\n",
      "           32,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3020,  304,    1,   98, 1772,    1,   32,  147,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  957,    1,  315,    9,  493,    1,    1,  250,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  150,    1,    1, 1490,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,  551,  331,    1,    1, 1523,   32,  183, 1246,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2959,  872,  420, 1169,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  121, 1821, 2640, 1478,   98, 3024,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  859,   37,  860,   69,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2, 743,  12,  82, 162, 365,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 112,   1,   1, 582,   1, 300, 856,  37, 166, 234, 182, 235,\n",
      "           1,   1,   1, 234, 182, 235,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  501,   12, 2907,  919, 3231,  297, 1110,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1412,  161,  203,  565,  334,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3263,   26,  365, 3141,  914,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359, 1094,  190, 1636, 3339, 2731,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1976,   37, 1527, 2725, 2014,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 2192,  273,  388,   45,  166, 1690,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  171, 1535,    1,  475,  796,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  459,    1,  384,    1,    1,  593,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2708, 1920, 1333, 1530,   32,  539,  458,  787,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117,    1,  133, 2126,  105, 1665,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1497,    1, 3103, 1497,  565,  176,  103,   45, 1515, 1090,    1,\n",
      "          361,   81,  176,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0],\n",
      "        [   2,  104,    1, 1891, 2824,    1, 3101, 2129,  384, 3339,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,  693, 1507,    1,  905, 1778,   32,  121,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,  571,   37, 3042,  161, 1876,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  183,  404,  744, 2462,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  754,  756,  952,  559,    1,   37,   47,    1,  161,  841, 1589,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  335, 1370,   32,  166,  638,    1,    1,  736,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437, 1419,   26, 1039,  777, 1085, 2665, 2706,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1718,   61, 2015,    9,  104,    1, 1216,  829,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1935,  967, 2071,    1, 2481,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   61,  166,    1,   45,  166, 1234, 2175,   37,  105,  123,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,   98,    1,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  177,  228, 1530,   32,  885,  854, 2702, 2291,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1594,  242,  187,   69,  640,  119,  845,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  150,  200,  778,    1,  176,    1,   98, 1220, 1140,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2949,    1,   51,    1, 2279,   12,  449, 1479, 1407, 2579,  187,\n",
      "          446,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2046, 2937,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,   42,  187,  709,   82, 2430,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2964,  565,  548, 1658, 1001,    1,  108, 2425,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  199,  421,   37,  138,   59,   37,  875,  755,  134,  220,  104,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,   12,    1, 1707, 3057,  142,  449,  571,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3344,    1, 2833,   36,   32,  121,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1786, 2358,    1, 2272,   85,   98,  116, 2502,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2962,    1, 2951,  187, 2615,    1,  730, 2614,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 1804,  453,   38,   98,  365, 1230,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  160,  102, 1473, 1290,  396,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  384,  166, 1411, 2273,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2979, 2869, 1151, 1243,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2080,    1,    1,  497,   37,   52,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  294,    1,    1,    1,   32,   72,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  894,    1,    1,   98,  531,  492, 2404,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 1142,   83, 2582,    1,   37,  114, 1143,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,  267, 3375, 1532, 2958,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1988,   32, 1509,    1,  400,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2877, 1988,   45,    1, 1916,    9, 2343,   12, 3404,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 140,   1, 400,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 220,   1,   1, 105, 688,   1, 166, 104, 782, 453,   1,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   10, 1310,   37,  764,  271,  903,    1, 1973, 2024,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  605,   21, 1455,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2080, 2771,  378,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  551,  171,  112,  830,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2948,   32,  166,  550,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  361, 1054, 2550,    1,  723,    1, 2389,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2623, 2624, 1463, 1578,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1158,   12, 1230,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1188,  861,    1, 1176,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3160, 1156,    9,    1, 1147, 2313,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  854, 2018, 2024,   34,  442,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  182, 3005,    1,   98, 2522, 1704,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2177,  471,  384,  390,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  462,  162,  372,  209,    1,  315,  604,    1,    1,  774,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  665,   98,   16,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116,  279,  259, 1108, 2744,    1, 1484,    1,  340,  102,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2433,  613,  353,  331,   32,  572,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1625,   32, 1759,  309,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3190,   12,    1,  162, 1516,   37,    1, 3193, 2911,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,    1,  301,  739,   37,  288,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  327, 1091, 1174,  818, 2355,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  335,  183, 2155,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  382,  293,  919, 1645,  568,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   61,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  137,  815,  853,   29,   37,  506,  629,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  781,    1, 1201,    1,    1,    1,    1,  166, 2798,    1,  669,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1440,   61,  193,    1,  810, 1488,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  688,  166, 1721,   37,  780,   12,    5,  550,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1659,    1,   37,  423,  636,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 2505,   32, 2472,    9,  915,  104, 3126,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   10, 1562, 2275,   98,  223, 2135,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   45,    1,   12,    1,    9, 1970,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  534,   37,    1,  550,  132, 1232, 1654, 1002,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,   12, 1009, 2682, 2390,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3326, 2474, 2347,   98,    1,  865,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2231,  952,  356,  611, 2113,    9, 1327,   12,  446,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2431, 2356,   45,  447, 2262,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1421,    1,    1,    1,  187, 1987,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,  365,  260,   98, 1764,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1570, 1396,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3349, 1141,    9, 2785,  591,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1528,  244,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  253,  562,  372,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  630, 1297,  849, 1878,  170,  220,  848,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1421,   28,    9,    1, 1626, 2055,  892,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   83,   37,   84,   85,  187,  654,  475,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1,    1,    9,   26, 1039,  675,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2841,  683, 2167,  204,   61, 1488,  763,    1, 1616,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1941,    1,    1, 3155,  856,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,  104,   27,  439,   37, 2673, 1017, 2096,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  863,    1, 1604,   37, 1155,  497, 2143,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484, 2707,   37,  342,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1509,   45,  166, 1694,   32, 3076,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  251,    1, 2285, 2043,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,  849,    1,   79, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2689, 1717,    1, 2565,    1, 2308,    1,  335,    1, 1045,   32,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  193,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3076,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  273,  274,  275,    4,  276,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  708,  597,  355,  710,    9,    1,  764,  918,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2995,    1,  220, 2542,    1, 2994,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  716, 2977,  475,    1,  405,    1,   51, 1910,  639,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1796, 2176,    1, 2547,  191,  538,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2514,  804,   45,  625,    1,  166,    1, 2589,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2226,    1,  166,    1,    1, 3286,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  398,  868,   85, 1994, 2819,  625,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2627,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   37,  335, 2933, 2545,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 1861, 2000, 2024,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   64,    1,    1, 2816,  187, 2140, 2202,   39,   45, 1001,    9,\n",
      "          591,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2376, 2700,    1,    1,  884,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2748,  951,    1, 2163, 1497,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  938,  992, 1483,  187,  929,   82,   45,  941, 1201,    1,  115,\n",
      "           45,  147,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  155,  365, 1788,  171,  604,  731,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2206, 2435,  153,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  799, 1414, 1400,  713,    9,  449,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  683,  924,    1,  195, 1463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 1074,    1, 1756, 2304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2615, 2379,    1,  967,    1, 3131,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 2685,  759,    1,  132,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1003,  176, 1778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  176,  163,    1,   12,    1,   26,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2159,   12,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3239,  619,  579, 1444, 1210,   32, 3013, 2565,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  854, 2018, 1407, 1190,   46,  439, 1602,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1530,    1, 1941,   32,  649, 2003,  114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   61,    1,   37,  168,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1691, 1434,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,   12,  129,  975,    1, 1146, 1703,  197,   93,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3276,    1, 3250,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  874,  781,  794,  365, 1841,   45, 2798, 1280,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1203,    1,    1, 1871,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  160, 1161,  640,  339,  340,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  761,  716, 1894,  776,  932,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  108,   98,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  361,   77,   98,    1,  255,    1,    1,  460,  810,    1,    1,\n",
      "         2645,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1, 2835,    1, 2471,  220, 1038, 2434,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3306, 1216, 1958, 1894,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  375,    1,   37,  151,    1,   32,  152,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  705,  272,    1,    1, 1126,  469, 1167,  167, 2250,   28,   37,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  115,   32,  166, 2116,    1, 1444, 1847, 1977,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2963,  855,   32,  447,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  251,  116, 3049,   45,  302,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175,    1,    1,  191, 1841,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1074,   37,  123,  191,  465, 1657,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1561, 3009,    1,    9, 1445,    1,   45, 1104,  686,  537, 2248,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  539,  540, 1885,  640, 1228,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   12,    1, 2162, 1950,  407,   37,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2127,  657,  157,    1,    1,    9,  275, 2054,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  932, 2200, 2054,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  865,   45,  166,    1,  873, 2565,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  422,  992,   28,  927,   45,  262,  263,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3209, 2067,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2503,    1,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,    1,    1,    1,  460,   12, 1385,\n",
      "            1,  361,  845,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,    1,   81,  548, 3286,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3337,  167,  619, 1217,  528,  354,   45, 1505,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3251,  720, 3201,   37, 3209,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1340, 1194, 2907,  873, 1908,  142,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  556,  671, 1078,  214, 2564,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3369, 2299,  680, 1428, 1381,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2695, 2223,    9,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1317,  704,  104,  353,  207,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1008,  365, 1065, 1190,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,  317,  187,    1,    1,   94,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  167,  664, 3238,    9, 1090,  228,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1722, 1509,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  391,    1, 2775,   45,    1,    1,  963, 2122,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  535,    1,   51,  686,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3322,    1, 2584,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,   32, 1479,  192, 1437,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  384,  941,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2882, 1164,    1, 2018,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2084,    1,   61,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  531,  104,    1,  837, 2242, 1887, 3094,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  191,  166,    1,   32,  166, 2402,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2620,  637, 1065, 1669,   37,  103,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1570,  929,   37,   84,   85,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2615, 1445, 1421,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,    1,  297, 1018, 1996,    1, 1159, 1470,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  811, 1484,    9, 1415, 2471,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343,  890, 2934,    9,  166, 1509,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  153,    1, 1042,    1, 2401,  384, 1183, 2320,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  987,    1,    9,  923,  726,  905,  990, 1322,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2236, 1550,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2448,  386,    1,    1, 3143,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  117, 2061,  531, 1260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  884,   98,  224,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  492,  774, 2772, 3060, 1634,   37,    1, 3105,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  162,    1,  220,    1,  361,  950,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3024,   37, 1937, 2300, 2923,   45,  166, 2918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  275,    1,    1,  161,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,   76,   37, 1096,   32,  531,  966,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37,  856, 2189,  442,   32, 1264,    1,  361,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3403, 2411, 1404,   12,    1,   37, 2844,  105,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,  256, 1994, 2819, 2524,   37,  659,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1, 3375,  240, 2868, 2237,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1405, 1634,    1, 2070,   43,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1126,  157,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1530,    1,  297, 2347,  187, 2529,    1,  686,    1, 1081,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,    1,    9,  296,  644,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  288,   37, 1539,  645,  973, 1159,  160,  616,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  506,   98,    1,   37,  815, 1199,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  296,    1,  220,  104,  484,   37,  335,    1, 2096,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  548, 1815,    1,  446, 1077,   37,   62,    1,  546,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,  565,  227, 1678,    9,    1,    1,    9,    1, 1935,   12,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2352, 1780,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1028, 1232,  460,   12,    1,    1,  460, 1488,   52,  227,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3335,   12,    1,  166,  227,    1,  166, 1628,    1,  166,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  220,  730, 2614, 2626,    1,    1,   61,    1, 1176,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  923, 2518, 3042,  161,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,  921,  104, 1510,  756,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  330,   46,  220,  183, 1056,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2414, 1056,  176,    1,    1,  947,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  580,    1, 2020,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1200,   82,  251,    1,    1,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2816, 1159,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  252,  361, 2745,    1,  590,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343,  650,   12,  472,    1, 3090, 3370, 1260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1177,    1, 1183, 2113,  471,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1326,   61,    1,    9, 1054,  202,  171,  267, 2683, 1360,  612,\n",
      "            1,  619,  778,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  806,   26,   32,  667,  391,  863,  220,    1,   32, 1530, 1245,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 3373, 2249,    1,  163,    1,  903,    1,   61, 1373,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2494,    1,   12, 2491,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  585, 1641,  191,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  593, 1990,  455,    1,  220,  403, 1447,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,    1, 1167,  395, 3368,   51,  439,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3270, 1518,   32,   98,  593, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280,    1,    9,  166, 2586,   45,  472,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428,  861, 1906,  707,   37, 2170,    9, 3369,  907,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  943,   98,  474,  777,  778,    1,    1,  297, 1384,    1,\n",
      "         1064,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1390,  315,   37,  125,    1,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2956,  765, 1415,   37,    1,    1,  317,    1,    1, 1697,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  395, 1297,   32,  105, 1298,  388, 1125,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2047,    9,    1,  187,    1,  168,  403,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  515,    1, 2484,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375, 1079,    9,  863,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3204, 3145,   37,  104,   26,  915,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,  675,  156,   71,  118,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1446,  102, 1417,  331,   56,  356,  604,  176,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  650, 1562,    1,   12,    1, 2113,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3096, 3215,   98, 1171,    9,    1,  176,  706,  361, 2846,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1937, 2205,  115,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094, 2414, 3375,   32, 3339,    1,  717,    1,  458, 2262,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  393,  475,  467,  729, 1610,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  387,  198,  104,   15,   93,    1,  242,  158,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    6,  219, 3096,  837,    9,  914,  548,    1, 2712,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1430,   12,  901,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2640, 1830,    9, 1539,   37, 1821, 2190,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1072, 1235, 3338,  191, 3344, 1940,   32, 3339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,  778,   30, 1056,    1,   32,  531,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307, 1702, 2177, 1159, 1775, 2215,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2638,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   33,  424,   39,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,    1, 2463,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  606,    1, 2309,   32,  863,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3186,    1,    1,  191, 2825,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2551,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  671,    9,  511,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,  764, 2264, 2905,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2220,    1,    1,    9,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2615,  754, 2202,    1, 3138,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,    1,  315,  129,   74, 1819,   98,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2135,  940,    1, 1919,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  131,   60,  873,   32,  393,  359,  637,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2492,  105,  168,  168,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1550, 3104,  967,  288,   28,    1,   98,  453,    1,   32,\n",
      "         2884,    9,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  885, 1901,   34,  730, 1777,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  640,  365,  340,   32, 2759,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1876,    9, 1821, 2978,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2440,    1,  778,    1,  191, 2264,  499,    1,  689,  420,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  957,    1,   32, 2752,  686,  191, 2596, 2137,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   56,  163,    1,   12,    1, 2548, 2572,   32, 2596, 1260,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  542,    1,   37,  877,  544, 2198, 3151,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1517,   12, 3129, 3210,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885, 2529, 2164,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2615, 1509, 3237, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,  361,  326,    1,   98,    1, 2670,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1879, 2761,    1,  162,  449, 2318,  698,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  442,  448, 1137,    1, 1290,  396,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158,  879, 2102,   37,   91,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,    1,  670,   81,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2949,  680,    1,  548,  114,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2327,  331,  105,    1,  680,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  236, 1022,    1,   12,    1,    1,  166, 2053, 2054,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2863,   37,  856,   98,  548, 2956,  149,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  794,  105,    1, 1563, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  840,    1,    1,    1,  417,    1, 1021,  282,  918,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3051, 2024,   46,  686,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  651,   51,  606, 1846,    1,   12,    1, 1529,    1,  193, 1178,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 1992,  105,    1,    9,    1, 2404,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1548,    1,  608,  971,    1,  479,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2620,    1,    1,    1, 1033,   12, 2734,  591,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,  829,   37,  714, 1412, 2586, 1708,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1870,  327, 1408,  460,  838,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  660,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  245,   98,  197, 1936,  548,   70, 2709,  105,  106,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,   74,  334,  168, 3065,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1021, 1119,   32,  395,  155,  753,   45, 1488, 2301, 2461,    1,\n",
      "          202,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3240,   81,   32,  166, 2340,    9, 3226,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   98,  730, 3022,   45, 1204,    1,  978,    1,   45, 2162,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3274,    1,  600,  645, 1987,    1,  267, 3169,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  696, 1171,    1,  557,  506,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2576,  551,    1,  325, 1146,    1, 1589,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1258,   37, 2139,  444, 1022,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3321,    1, 2807,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  284,  253,  690,    1, 1130,  360,  148,  142,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12, 1385, 1056,    9, 1652, 1917,    1,  829,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   71,  179,    1,  180,  132,  696,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  879, 1253,  530,    1,  566,  741,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2389,   37,    1,  533,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  218, 3403, 2414,  228,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1880,  325,    1,    1, 1680,  197,    1,  158,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,  267,    1,  913,  176, 2673,   46,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  326, 2767,  365,  103,  439,    1, 2168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2026, 2574, 1124,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 1479, 1863,  176, 1405,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967, 1844,   39,   45, 2383,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2318,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 1090, 1829,    1,  176,  365, 2741,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,    1, 3293,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968,  515,  395,  411, 2695,    1,    1,    1,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051, 2659,    1,   32, 1109, 1821,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  308,  537,   45,  996,    1,   32, 1802,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   79,  166, 2904,    9,    1,  948,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3310,  398,    1, 2173,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3144,  952,   37,  674,    1,  927,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171, 1535,    1,   98,    1,   12,  223,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  327, 1151,   37,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 2781,   98, 2146, 2255,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   10, 1408,  289,   98,    1,    9, 2834, 2275, 2344,   37,  105,\n",
      "            1,   45,  753,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  256,    1,    1,   37,  454,    1,  454, 2168,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  572,  551,  105,    1,   82,    1,  365,  861,  669,   12,  315,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  848,    1, 2704,  315,    9,  617, 1151,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  220,    1,   39,    1,  289,   96,    1,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,   45, 1125,    1,  105, 2529,    1,    1, 1608,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,   86,  160,  783,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2663, 1000, 2493,    1,    1,  548, 1515,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  479,   37,  693, 1170,  538,  187, 1018, 1144,   32,  388, 1975,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087, 2614,  132, 1854,   37, 3234,    9,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3310,  162, 1022, 3258,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  954, 1353,  528,  677,   69,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    9,  853,  538,  542,    1, 1850,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  698,    9, 2563,   32,  925,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1090,  748,  163,   61,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,  943, 1230, 1560, 2880,   12,  956,  220, 1158,  967,  323,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  782,    1,    1,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2621,  220, 2723, 2724, 2636,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1796,  810, 3009,  186,    9, 1123,  726,  297, 1479,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1698,    1,   45, 1081,  139,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  111, 1675,  167,   52, 1411,  183, 1265,    1,  202,  193, 1724,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2563,  125, 2196,    1,  375,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1592,    1, 2879, 1323,    9,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2345,  105, 3022,  415,   55,  754,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  581,    1,  384,  166,  645,   32, 2171, 2800,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2206, 2435,   37, 1636, 1766, 1767,  210,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  754,  618, 1046, 2353,  627,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1570,   37, 1155, 2473, 2367,   98, 1718,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3086, 2924, 2684,   32, 3118,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2850, 1159,  581,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3345, 2856,  581,  294,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1203,    1, 2400,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977,   12,  566,   32,  166, 2391,   37,  764,  596,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,   12, 1230, 1822,    1,  533,   45, 3028,    1, 1307,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  393,   22,   12,    1,  469,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1877,  204,  321,    1,  176, 2412,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1412, 1262,   37,  606, 2181,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,    1,  247,  269,   67,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3118,   46,    1,  297, 1358,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2292,   32,    1,    1,  187, 2752,  213,   37,  907,    1,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,   37, 1075, 1970,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  391,   93,   37, 1752, 1032,  220,  887,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  755, 1241,   28,  365,  834, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597, 2977,    1, 1988,   45,    1,  600, 2978,  127,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  691,   12,    1,  325,  365,  636,  524,    9,  105,    1,  331,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1617,   12,    1,  267,  104,    1,  455,  110,   37,    1,   60,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  446,   76,   37, 1947,  981,  285,   32, 3339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1253, 2055, 1095, 1107, 1705,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 2299, 2198, 3358,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49, 1070,    1,  400,    9,  581,    1,  115,   45, 1611,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  367,  754,   15,   71,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968,   12,  954, 1353,    1,  118,   32,  572,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3066,  315,  247, 1462,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  258, 3105,    1,   98,    1,  361, 2024,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   66,   79,  316,  171,  540,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  366, 1675,   13,   28,    9,  333,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  548, 1118,    1,  657, 1394,   37, 1151, 1809, 1758,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1, 1100,    1,  365,  815,   45,    1, 2670,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1700,  388,  257,    9, 1965, 2982,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1285,    1,  794,  365,    1,   45, 2798, 2706,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3144, 1009,    1,    1,    1,  297, 1002,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,   37,  943, 1123,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3066, 2908,    9,    1,  841,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,  947,    1,  344, 3403,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  288,   37, 2230,  220,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1985, 1283,  361,  848,   37,    1,    1,   32, 1824,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  422,    1,    1,   37,  231,    1,   45,    1,  463, 2926,  856,\n",
      "           63,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2206, 2435, 1606, 1149,   37,  865,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  954,  816,  202,  389,   93,    1,    1, 1059,    1,   37, 2275,\n",
      "          361,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,  688, 3184,  191, 2144,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1018,  294,    1,   12, 3207, 2845,  221,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   37,  109,  626,    1,   37,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  171,   98, 1171,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,    1,    1, 2392, 1011, 1039,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2349,  105, 2447,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1923,  171,  307,  105,  916,   37, 1343,    9,  166,  183, 1684,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  415,  476,   37,    1, 2059,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 1260, 2414, 1700,  388,   32,  854,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,    1, 2047,    9, 3257,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  800,   60, 1554, 1619,  217,   32,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3111, 1237, 2784,    1, 3155,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  342, 2489,  105,  198,  808,   98, 3118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096, 3277,  603,    9,  787,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    9, 3289,    1,    1, 2107, 1533,  384,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3303,    1,   39,  294, 1456, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1094, 1619,   37,  657,   12,  627, 1116,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1842,    1,   37,  142,   32,    1, 1611,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2572,  187,    1,   64,    1, 2791,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  267, 1523,   32,  455,    1, 1521,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,   12, 1680,  361, 2622,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2179,    1,   45,  166, 1233,  484,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  388,  888, 2175,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1458,  142,    9, 1503,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1842,  361,  613,   37,   47, 1796,   50,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2386, 1428,   45,    1,    1,  297,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2978, 2382,   37, 1075,  529,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  322,   79, 1354,   45,  531,   12,  734,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  130, 1056,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2789, 1877,  193,   37,    1,   98, 1511,  548,  863,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,    1, 1499,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  167,  619,  669,  187, 1851, 3193,    1,  855,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2858, 1028, 2388,  176, 3194, 3195,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1357,   45,  166,  356, 2603,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1861, 1004, 1864,  439,   37,    1, 2292,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  251,   38,   37,   10,   32,  163,    1,   12,    1,  863,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2733,  794,  750,   32, 2730,  400,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1183,    1,    1,    1,   51,  606, 1846,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  288,   28, 1090,  786, 1918,    9, 2615,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   39,  810,  460, 1491,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  550,    1, 2501, 2429,    1, 1097,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2515,   37,    1, 1658, 1412, 2945,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  119,   44,    1,  125,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,    1, 2978,  210,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1, 1147, 2731,   32, 2970,  274,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  719,  388,   69, 1208, 1063,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 1360,  612, 2702, 1930,    9,  531,    1,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  593,   45, 2921, 2946,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,    1,  647,    7,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296, 1441,  829,   32,  342, 1350,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  676,  163,    1,   12,    1,    1,  600,    1, 2332,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2377, 1673,  384,  777, 1418,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,    6,   81,  517, 1278,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1720,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  373,   12,    1, 1034,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 2331,   45,  531, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  199,    1,    9, 1497,  415, 1360,  612,  168, 2017,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,  920,  837,   45,    1,  422,  290,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1022, 1023,  197,  338,   98,  377,  225,  682,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  612,    1,    1,  636,  967,    1,   32,  453,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1256,  551, 1256,   37,  151, 1026,    9,    1,   54,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311,    1,    1,    1,  331,   37, 2388,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1766, 1767, 1108,    1,  220,    1,  191,  746,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1291,    1, 2500, 2112,   37,  221,  327,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,  119, 1578,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1292,   30,   28,   32,    1,    1, 1935,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,  105, 2172, 1737,    9,  104,    1, 3331,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  186,  608, 2615,   32, 2513,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  994,    1,  117,    1, 1898,   98,  778,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2604, 2223,  298, 1478,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  105,    1, 1020,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2023,  365,  957,    1,  437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  572,  197,   85,   98,   44,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,    1,  794, 3029,  105, 2328,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,    1, 1322,    9, 2751,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  876,  612,  190,    1,   37, 3102,    1,    1,  202,  193,    1,\n",
      "         3355,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1181, 2373,    1,    1, 1102,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1963,    1,    1,  384,  863,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  758,    1, 1790,  477, 1013,    1,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2022, 1002,   30, 2911,    1, 1603,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3282,    1,    1,  176,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 2959,    1,  244,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2490,   26, 2807,   37, 1388,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614, 1173,   37,    1,  166, 2769,  220, 1090, 1312,  726,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2, 615,  47, 773,   1,  25, 245,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  37,   1, 437,  45,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2855,    1,    9,    1,    1,    1, 1923,    1, 2307,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1013, 1522,  794,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   32,  105, 1882,   37,  865,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2677,  902,  951,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 810, 166, 454,  37, 166, 458,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 529, 102,   1, 340,   1,   1, 295,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2104,  108,  104,   37,    1,   28, 2334, 1116,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  286,  293,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2872, 2721,  565, 1532,   45,  424,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2170, 1861, 1484,    9,  522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  885,    1,  134,   37, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622, 2751,  837,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  528,  247,    1,   32,  915, 1090,  444, 3276,    1, 2787,  267,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,  877,  449, 2193,  698,    9, 3248,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1785, 2044,   37,   26,   28,   69,  708,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  547,   37, 1285,  447,    9,   65, 1990, 1918,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  447,  476, 1743,   98, 2707,   12,  342, 2927,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1822,  562, 1963,   12,    1,  949,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3213,   94,  595,    1,  139,    9, 1545,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  103,   45,    1,   32, 1990, 1844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1203,    1, 1871,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37, 1776,  535,  656, 2367,  328,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3316, 2449, 2331,  528,  449,  922, 2712,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3321,  255,   45, 2611,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3189,  744,  119,   32, 3227, 2651,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 1586,    1, 1539,  778,    9,  633,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2779,  967,    1,    1,   37,    1,  542,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1, 2615,    1,  220, 1211, 2878, 1114,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1108,    1,    1,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,    1,    1,  249, 2298,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  854, 2018,   46,  504,    9, 2024, 3380,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2139,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  833,  612, 2192,   28,   98,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1824,  522,  384,  166, 1477, 1990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3221, 2554,    1,   12,    1, 1159, 1551,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1583, 2764, 3394, 2072, 2835, 2137,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1935, 1523,  105,  856,   37,  166, 2162,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  217,  420, 1124,   32,    1,    1,    1,  365,  496,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1084,    1,   37,    1, 1501,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3277, 3177,  190,  838,  460,   32,  547,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  581, 2504, 1920,  967, 2527,  164,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1, 3034,  861, 2454,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  741,  288,   98,  132, 1813,    1,    1, 1384,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2418, 1090, 1044, 1045,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3083,    1,    1,  220,    1, 1987,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885, 2946,    1,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2090,  326,  936, 1416,   45,  192,    1,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2768, 1158,  693,  848, 1018, 2102,  132,    1,  327,  593,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  864,    1,    1,   98, 2673,  630,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1680,    1,  102,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2137, 2856,   27, 2835, 3101, 2735,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  609, 1070,  146,  147,   37, 2392,  284, 1876,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,  227,  449,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 1212,    1,  845,  636,    9,  195,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  398,   32,  342,  829,  400, 1484, 1953,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 2702,  298,   27, 2235,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  565,  166,  730, 2614,    1,    1, 1411, 1034,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3285,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1056,  649,    1,    1,   85,   32, 2490,   12,    1,  463,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  390,    1,   32, 1018,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32, 2445, 1313, 2834,  548, 3038, 3071,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,    1,  163,    1,   12,    1,  297,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  105,  437,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1674, 1675,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  561,  167,   47,   79,  311,    1,    1,  860,   11,   37, 1154,\n",
      "            1,    1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    7, 2171, 1675,   98,  844,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,  288,   37, 2243,    1,  844,  259, 1039,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3055,    1,    1,  624, 1468, 2376,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1813,  135,  361,  105,  242,  913,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1523,   98, 2339, 1534,   32, 2737,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1554, 3339,    9,  447,   37,    1, 3358,   12, 2162,  420,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1126, 1603,  193,    1,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  535, 3016, 1089,    1, 1294,  820,    9,  282, 3011,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3244,  786,   45, 2041,    1,  424, 1034,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  267, 1930,    1, 2349,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2662, 2918, 2820,   12,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  947,   44, 1178,  220, 2522,   45,    1,    1,  384,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  422, 1536,  133,  134,  444,    1,    1,  938,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1313,    1,  104,    1,  395,    1,  671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1349,   12,  221,   61,  105,    1, 2630,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  664,  460,  857,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2990,  254, 1696,   37, 1844,    1, 2700,  774,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1,   37,   47,  327,  112,  548,  326,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422, 1118, 1952,  420, 2092, 1757,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  259,  847, 2654, 1411,    1,  844,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2696,  476, 1281,   98,  333,   45, 2970, 1089, 1675,   37,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1994,   10, 3061,   98,  166, 1314,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584,  628,  119,   74, 1464,   37,  877,    1, 2370, 2330, 1488,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1475,  215,   93,  739,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671, 1078, 1988,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  617,  618,    1,    1,   37, 2964, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  639,  952,  480,   45,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3168, 2055,  104,   26,  220,  105,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  531,   98, 2699,   37, 1154,  487, 3102,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  57,   1, 164, 165, 384,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,  361,   91, 1769,   37, 1154, 1189, 2673,  529, 2836,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1216,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1712,  361, 2881,  619,  138,  155,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1774,   39, 1463,   45, 1139, 1263, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3303,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  648,   12,    1, 1572,   37, 2667, 1160,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,   37,    1, 2108,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1000,    1,   45, 1728, 2249, 2688,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  790,  703,  985,  595,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2597,  216, 2856,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1654,    1,  768,    1,  140, 2474,    1,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  286,  927,  833,  612,    1, 2350,  159,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1013, 1522,    1, 1381,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1971, 2222, 1937,  166, 1125,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  776, 2306,  288,    9,    1,   32, 3402, 3408, 1038,  966,  400,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37, 1539,  365, 1013, 1522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  649,    1, 1866,   85,    9,  105,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  575,  335,    1,  187,   67,  418, 1526,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2886,   12, 1311,   61,  247, 3193,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447, 2767, 3146,   98,  557,  540, 2108, 1281,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  894,  334, 1210,  166,  365, 1230, 2528,    1,  460,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2474,    1,    1,  507,    1, 1862,  548,    1,  245,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 2143,  458,   45,  584,  967, 1698,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,    9, 2046, 2784,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   89,  267,  672,  442,  448,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310, 2830,    1,  166,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3370,  837, 2676, 2237,   37, 3363,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  293,  420,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  504,   98,   14,  170,    1, 1087,  156,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2576, 1194, 1856, 1010,  474, 1313,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 2592,    1, 2147,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,    1,  325,  215,    1,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  743,   12, 1690,  525,   15,   71,    1,  419,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105, 1385, 1509,    1,   45,  166, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  188,    1,  657,   28,   63,  862,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496, 1718,  967, 1183,  454,   37,  168,   32,   14, 2973, 1764,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1622,  233,   57,  491,   37,  138,    1,  131,   60,  797,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  321,  920,  335,  334, 2747, 1312,  638, 1410,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1426,  395, 2069,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  961,    1,   51,   47,  612,  551,  903, 1541,  548,  573,  693,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  112,    1,   79,    1,  646,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1233,  515,   28,   98,  785,  786,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777,  388, 2015,    9, 1361,  763,  829,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  113,   27,  845,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2136,    1, 1159,    1,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1809,  365, 3107, 1004,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  379,    1,    1,   98,    1,   33,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61, 1820,    9,    1, 1832,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  288,   37,    1,    1,   12,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 3378,  776,   61,    1,  453,  389,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   32,  163,    1,   12,    1,  863,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314,  551, 1692,  190,  138,   17,   81,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2523,    1,    1, 2876,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1736,  293,    1, 1737,   32,  166,  104, 1194, 1352,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3321,    1,    1, 2055,  444, 3244,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2153, 1542,   37, 1604,   98,   36,  518,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1, 1363,  691,  469,    1,  517, 1074,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  959, 2740, 1024,   37, 2615,    1,  501,   37, 2142,    1,    1,\n",
      "           37,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1989, 1990,   74,   32, 1739,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,  195, 1873,  140,  802,  220,   78,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  517,  413, 2226, 2969, 2222,  640,  166,  215,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 3358, 2000, 3101, 2271,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  477, 1740, 1937,    1, 1632,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1654,    1,  331,   98,  572,   15,  720,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051, 1022, 1843,  207,  418, 1010,  777,  259,   15,  504,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  542,  384,  810,  297,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1938, 2607,    1, 2115,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  147, 1250,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1, 3016, 1935, 2308,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2192,  854,    1,  444,  691,   32, 1463,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2279,  456,   85,    1, 2329,   37, 1911,    1,   45,    1,    1,\n",
      "         2659,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  361,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1768, 1294,   32,  815,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   28,   98, 1303,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1644, 1807,  104,   37,  877,  388,  183,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1178, 1156,  297,  395, 1935, 2931,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   27,  119,  340,  548,    1,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  602, 3315,  688,    1,   32,  103, 1388,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2186,    1,   37,  168,   98, 2731,  444, 2819,  777, 2165,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 1361,    1, 1647,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   37,  151, 1183, 2320, 3162,    9,   22,   23,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,  528, 1488,  763,   76,  104,   14, 1347,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,  361,  552,    1,  491,    9, 1610,  734,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  446,   12, 2237,   37,  289,   98,    1,   45, 1815,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3264,  680,   97,  548, 2792,  354,  176,  754,   37, 2046,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  420, 1340,    1,   37, 2587,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2953,  921,  449,   74,   45, 3123, 1463,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1417,  551,  717,   37,   47, 1796,  886,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1, 1396, 3006,   32, 3391,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2162, 1950,   32,  395, 2003, 1585, 1426, 1013,    9, 2986, 1258,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2247,    1,  193,    1,  227,  112,   32, 2890,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2999, 2257, 2194, 2186,    1,  384,  778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  458,  244,   51,   71,  528,    1,  401,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1412,  361,    1, 1753,  166, 3003,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004, 1361, 1564,  172, 1330,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2321,  168, 1185,   98,  705,  260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614, 1542,    9, 2615,  548, 3238,  140, 1194,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1730,  949,  365, 1089,   45, 3377,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,   98,  756, 1039, 2690,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,   98, 1085,    1,  486, 1501,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1460,   37, 2275,   12, 1625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938, 1282, 1702,  218, 1159,  501,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2672,    1,   39,  220,    1, 1987,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2479, 2943, 1499,  669,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  683, 1077,   37,  688, 3333,   32, 1869,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2838,    1,  917,    1,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3065, 3156, 1890,  548, 2164,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3276, 1174, 1684,  750,  220,    1,  726,  297, 3244,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1,    1,  361,  166,    1,  335,  225,   45, 1515,  627,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3315,   96,   28, 1245,  220,  726,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2070, 2838,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  293,  105,    1,   45,  709, 2516,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1465, 1466,   37,  125,    1,   87,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3277,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3038, 3279,  135, 1147, 2774,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  288,   37,   71,   14,  361, 1158,  343,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2484, 1564,  618,  943,   37,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,  361,   12,    1, 1447,   32,  442, 1259,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2708, 2153, 1697,   37,  447,   37, 2237, 3358,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089, 1675,  166, 2259,   37,    1,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  179,  132,  155,    1, 1574,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2331,   45,  342,    1,  131,    1, 1567,  548, 2468,  333,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   32,  166,    1,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  105,    1, 3000,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428, 3397, 2216, 3118, 2751,    9, 2705,   45, 1527,  379,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 2864, 1204,   45, 3053, 2477,  944,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1793,  488,  878, 1393,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,   52,    1,    9, 2073, 1509,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788, 1497, 1421,    1, 2967,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2776, 1117, 1525, 1028,   37,  856, 3002,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,  917,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1794,  967, 1176,  445,    1,    9, 1583,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  224, 1867, 1139, 1263, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  696,  104,  619,   32,  726, 2327,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1759,  309,  159,  123,    1,  417,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  891,  176,  754,    1,    1,  193,  176,  941,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  190,   52, 3251,  365,  971,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 1466,  190,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   85, 3018,  729,  251,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3254,    1,  967,  915,    1,   98,  825, 2633,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1110, 3188,  719,  199,   37,    1,    1,   55,  166, 1130,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3070, 1763,  865,   37,   36,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,  104,  498,   37,    1, 1196,   45,  284,  294,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302, 1712,  593,   12, 2101,  786,  837,   45, 2819,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2279,  543,   37,  860,  442,    1,  202,  590, 1288,\n",
      "           98,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3132,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,   12, 3356, 1830,   37,   38,  297, 2646, 3346,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  297, 1791, 2555,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1122,    1, 1170, 1054,  802,  220, 1326,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800,    1,   12, 1625,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  104,  103,  147, 1297, 1734, 2180,    1,    1,  695,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  617,  618,  335, 1230, 1787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1528, 2297, 1477, 3164,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  177,  786,    1, 1333,  176,  337,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1189,    1, 1492,    1,   37,  856, 3101, 2845,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3184,    1,    1,  764,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1633,  361,    1, 1832,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2397,    1,  994,    1,  150,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2396, 2694,    1,    1,    1, 2751, 1730,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,    1, 2396,  187,  460,  571,   37,  166,  985,   45,   91,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  224, 1205,  191,    1, 2528, 2606,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   66,  187,    1,  361,  105, 2769,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2614,  712,   28, 1166, 1444, 1827,   79,  951,    1,  105,   12,\n",
      "         2365,   28,  726,   32,  865,  234,  182,  235,    1,    1,    1,  234,\n",
      "          182,  235,    1,    3,    0],\n",
      "        [   2,    1,    1,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1322,    9,  333,   45,  176,  551,  612,  613,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2680,  197,   93,    1,  755, 1574,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,  794, 2679, 1851,  613,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,   69,  636, 2394,  105,    1,    1,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2004,  829, 1867, 1778,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,  919, 2375, 1281,  384,  976,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1236,  169,    1,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  487,  294,  735,  387,  197,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,  779,    1, 1017,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3124,    1,   79, 1031,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3218, 3159,  166, 3219,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  200, 1778, 2580,    9,  854,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1023,    1, 1568, 1569,  176,    1,    1,   98,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1256, 1256,  267,   37,  151, 1026,    9,    1,  131,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  720, 2696,   12, 2107,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2, 398,  57, 597, 171,   1,  81,  37, 611,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 244,  28,   1, 157, 969,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  644,  877,  365, 1260,   98, 2751,   32,\n",
      "         2646,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228,  709,    1,  493,  239, 1231,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2700,  774, 2663,  529, 1649, 1793, 2822,  658,  763,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2862,  859,   37, 1348,  792,    1,   37, 3093,  792,  420,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  458,   37, 2368,   28,  814, 1116,   50,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  410,  535,    1,    1,  176,  964,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  928,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3340, 2703,    1,    9, 2285,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  666,    1,   66, 1139,    1,   98, 1817,    1,  954,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1452,    1,   12,  865,    1, 1398,  612, 1289,   28,   37, 2398,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,    7,   37, 1764, 1990,  627,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485, 3365,  898, 2572,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1641,   28,  965,    1,   32, 1850,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2017,  671,    9,  395,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564, 1656, 1522, 1167, 2202,   79,   22,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3147,    1,  917,   37, 1260, 2751,   32, 3114,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1412, 2530,  810,  166,    1,  424, 1104,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1148, 1155, 2995,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  171,  890,    1,  129,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1440,  171,    1,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  365,  671, 2146,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,  736,   98, 2548,  361, 1515,  137,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2173,  720,  312,  400,  444, 3310,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1483,    1, 3276,  753,   37, 1376,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1128, 1078, 1180, 2871,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,  245,  187,   69,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1933,   12,  987,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,    1,  460,   51,    1,  869,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  894,    1, 1678,   45,    1,   12,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1993,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  306,   37,  349,  649,   98,  260, 1885,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1329,  325, 1159,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2957, 2914, 2056, 1465,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,  421,  986,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 2998,  850, 2017,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3292,    1, 2579,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2556,  191,  166,  947,  105,  227,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26,    1,    1,  444,  829, 2194,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1699,    9,    1,    1,    1,    1,   61,  105,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496, 2179, 2778,   66,  187,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  420, 1718,    1, 1224,    1, 1782,  792,  384,    1,   37,    1,\n",
      "          792,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1610,  220,    1, 2762,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2723, 2724, 2636,    1,  794,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  297,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  864,    1, 1147,  232,    1,  566, 1488,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1,   98,  550,   45,   12,    1,  464, 3107, 1463,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2594, 1257, 2595,  967, 1976,  166, 2339,   37,  270,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,   12,  566,   32, 2391,    1, 1159, 2288,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  854,   12,    1,  437,   11,    1, 1074,  176,    1,  636,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,   12,  442, 3224,    1,    1,   37, 3209,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  335,   98,  647,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2572,   32, 2596, 1585,  463,   45, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1405, 1723, 1070,    9, 1279,   37, 1534,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3053, 2855,    1,   45,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  182,  132,   37,  151,    1, 1541,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  356, 2836,   45,  294,    1,   61,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2779,  578,    1,    9,  104,   26,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,  353,  885,  401,   45,    1,  156,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2313,   32,  166,    1,    9,  449, 2936, 3389,  776,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1189,    1, 1683,   32,  531,    1, 1625,  969,    9,  440,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  393,  162,   28,   37,  331,   32,  365,  394,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1,  992,   85,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3276, 1174, 1684,  750,  220,    1,  726,  297, 3244,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   45,    1,    1,  140, 1940,   12,  331,    1,  671,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2941,    1,  640,  284,   98,  166,  389,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,    1, 3191,    1,    1,    1,  872,  929,   32, 3185,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,  417,  737,  197,    1,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053, 1874,    1,   12, 2653,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3144,  697,    9, 1460,  741,  680,    1,  661,   45,  539,    1,\n",
      "          121,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159,  245,   98,  304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  750, 1563,    1,   37,  907,  365,  596, 2429,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  297, 1449,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1037,    1,    1,    1,  977,   37,  764, 1344,  365,  326,    4,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  213,   37,  130,    1,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  234,    1,  235,  166,    1,  234,    1,  235,   61, 2880,\n",
      "         1698,   45,   12,  612,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  334, 1188,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2115,  159,   51,   71,   98,    1,  349,  630,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   28,    1,    1,   85,   63,  862,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1971,  664,    1,    1, 1764,    9,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,  967, 1857,   98, 1827, 3265,    1,   39,    9,  914,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  710,  267,  660,  331,   51, 1289,    1,  279, 1085,   32,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,  475,  108,   45,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  680,  104,   97,    1,    1, 1337, 3107,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  705,    1, 1417,    1,  960,  588,  365,   46,    1,  912, 2118,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  437, 1627,  963, 2147,   32, 2592,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  119,  449,    1,  726,   32, 2335, 1675,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  136, 1988, 1335,  193,  514,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1452,   32, 1018,  823,   45, 2834,    1,    1,  565,    1,   32,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1531,  787, 1906, 2424,    1,    1,   37, 1865,  938,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1834,   12,    1,  513,  514,   37,  581,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,  613, 2225,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1478,   98, 1778, 1273,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  766,   37,  877, 2627,    1, 1180, 1825,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1874,  144,  145,  469,   37, 1814, 1994, 2143, 1559,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2617,  361, 1404, 1882,   37,  175,   45,    1, 3358,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  410,  187,   69,  102, 1198,    1,    1, 1289,   37,  156,\n",
      "          937,  533,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  338,  384,    1,  531, 2292,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,   37,  764,   37, 3369, 2699,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  711,   51, 1066,  453, 1085,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967, 2626,  384,    1,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  420, 2977,  894,  815, 1821, 2978,   37, 1108, 3015, 1821,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2658, 1040, 1554, 2707,  548,    1, 2507, 2165,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1409,    1,    9, 2500, 3036, 2234,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187, 3334,  877, 2069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  936,  822,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1431,  967,  566,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,   51,  439, 1165,   45,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,  613, 2896,    1,  872,   28,   98, 2992,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1481,    1,   37,  726,  187,  806,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2246, 2885,  884,  631, 1159, 2069, 1385,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1861,  744,    1,    1,  837,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  327, 2264, 1046, 2353,  627,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1,   37,  130,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3194, 3195,  267,    1,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  356,  439,  837,    9, 3118, 2924,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  389,    6,  470,   32, 1352,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1539, 2995,    9, 1778, 1273,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,    1,   91,  167,   52,   98,    1, 1434,  420,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  603,   37,    1,    1, 1505,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1421,   28,  111,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1223,    1, 1130,  987,   32,   98,  535,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1039,    1,   37,  335,  316,  971,  389,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 1230,   12,  365, 2739, 2528,   16,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  147,  991,   22,  942,  283,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1017, 1355,  179,  180,  170,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  192, 1085,  279,   98,  326,   12,  248,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  990, 1458,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1454, 3304,  297, 3112,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1514,   98,    1,  179,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302, 1712,  515, 2819,  388,  537,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1773,  256,  535, 1573,   37, 2510,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1454,  531, 2874,  528,  420,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1421,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2167,  166, 1509,   61, 1724,   37,   18,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   32, 1739,    1,    1, 2547, 1463, 1018,  620,  661,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  123,   98, 1918,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  105, 1009,    1, 1119,   37,   10,   98,  676, 2165,    1,\n",
      "            1,  318,  361,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  844,    1,  220,  105, 1412, 1136,  260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1976,    1,   32, 1037,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  387, 1488, 2471,  220, 3371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1982,  810,  809,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2241,   45,   75,  908,  196,  176,  551,  612,  613, 1039,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    1,  451, 3329,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3359, 2361,  539,  458, 1165,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  396, 3096, 1863,   45,  356, 1114,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2006, 1530,  176,  557,  540,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260, 3330,    1,    1,    1, 1554, 1090,  444, 3233,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  169,  325, 1056,  258,  702,  124,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  112,    1,  276,  320, 1533,  424,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  294,  716,  449,  156,  452,  170,  220,  182,  551,  717,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  884,    1,   37,  660,    1, 2336,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3389,  176, 1056,    1,    1,  217, 2856,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1008,  365,  929,    1,   82,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  398, 2794,  148,   37,  142,    9,  647,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2137, 2856,  228,   32, 2597,   12,  501, 2060,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3319, 1285, 1110,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1,   37,  771,    1,  532,    1,  202,    1,\n",
      "           61,  125,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,  325, 1117, 1525, 1013,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,   12,  365, 2452,    1,  323,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2162,  361,  962,  565,    1,  202,  320,  565,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,  355,  710,   37, 1752,    1,   82,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1645,  861, 1563, 2909,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1818,  147,  190,  193, 1709, 1377,   45, 1439, 1529,    1,    1,\n",
      "            1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  649, 1190,  387, 2056,  996,   93,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,   12,    1,  218,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  326, 1070,    9, 1718, 1281,   98, 2031,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   37,   47, 1234, 1107, 2308,   32,  455,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  812,    1, 3112,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233,  958,  684,   12,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453,    1,    1, 1360,  612,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,    1,  218,  566,    1, 2509,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1813, 1803,  361, 1647,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  125,  191,  107,  833,  612, 1121,  166,  720,   32,   68,   12,\n",
      "          636,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  199,    9, 1465, 1466,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3157, 1046, 2970, 1139,  125,   37, 3093,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2883,   12,  594,    1,  195,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2877,  738,  220,  342, 2153,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2871, 3249,  774,    1, 1090,   61, 1822,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885,   56,    1,  537,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1117, 1943, 1215,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  811,    1,    1, 2000,    1,    1, 1623,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  221,  547, 1394, 1048,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1, 1953,  220, 3089,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1270,  583,   32, 1853,  477, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  193,  166,  449,   37,  168,  492,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1622, 2751, 1421, 2756,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  355,   37, 1306, 2073, 1023,  156,  308,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1492,   12,  590,    1,    1, 3297,  357, 3161,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2418,   28,    1,  613,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  902,  821,  525,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2313, 1988,   45, 1809, 2429,  600,   36,    1,    1, 2375,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  961,  398, 2037,   39,    1,    1, 2638, 2931,    1,  625,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2453,    1,    1, 1204,    1,    1,  361,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  527,  353,  152,  207,  354,   32, 1352,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537,  927,   45, 2623, 2624, 2725,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2255,    1, 1969, 2843,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3317, 1987, 2716,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2142, 1311,    1,  815,  176,    1,  921,   32, 1833,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12,    1,   28,   37,  104, 1094,  446,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,    1,  841, 1559, 1554, 3066, 1685,  730,  841,  384,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1213,   37,  930,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1541,  245,  331,   32,  367,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1043,  176, 1034,  181,  340,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1675,  135, 2890,    1, 1711, 2789,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  794,   15,  656,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302, 1712,  162,   59, 1117,    1,  105,   74,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2178,    1,  318,  610,   37,  356,   32, 1038,   32,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1335,    9, 2476,    1, 3347,   37,   52,  820,    1, 1919,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,    1,   28,  647,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1633,  538,  361,    1,   37, 2123,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  840, 1658,  803,  112,    1, 1630,  321,    1,  166,  454,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,  251,    1,   37,  105, 1013, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  683,   37, 1787, 3333,    9,  593, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1962,  794,  365,  142,    9, 1741,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  503,  744,   28,  749,  231,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3198, 1544,   32, 1438,   45, 3257,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  547, 1407, 1428, 3365,  820,   32, 3360,  947,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3306, 2908,    1,   96,   85,  693,   37, 1752,    1,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  870,  136,   21,  354,   98,  283,    1,  399,  134,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2278,  835,    1,   13,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018,  622, 2489,   85, 2095, 2396,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    1,    1,    1,    1,  361, 1608,\n",
      "         1221,   12,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,    1,    1, 1865,  593,   12,  553,    1,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171,   45,  166, 1013, 1299,  293,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  930,  384, 3141,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398, 1550,    1,  142,   37,  221,  776,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,  60, 953, 548, 303,   1,  88,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 169,   1, 220, 702,  32, 104,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  326, 2479, 2943, 1499,  669,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,  952,    1,   45, 3101,  379,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2388, 1771,  171,   61,  105, 1972,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 2471,  447,   32,   65, 1990, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,   37,    1, 1243,   98, 1465, 1151,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1,   37,  222, 2673,  909,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2822,    1, 1924,    1,  152,  537, 1490,  506,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219, 2122,  231,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  902, 1634,  220, 2526, 3181,    1, 3306,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  276,   98,  165,    1,  550,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1883, 1380,    1,    1,   98, 2226,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1, 2000, 2041,    1,    1, 1898, 1316, 2735,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1940,   12, 1183, 1253,    1, 2090,    1,    1, 2090,  361, 3237,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018,    1, 2534,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  176, 1325,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3298,  744,  813,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  381,  325,  449,  294,  458,    1, 1353,    1, 1159, 1739,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,   45, 1737,   37,   52,    1,   63, 1821, 2057,  321,\n",
      "         2354,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977,  475,  405,    1,   37, 1540,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1100,    1,    1, 1456,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  176,  985,   45,    1,   12, 1896, 1750, 2024,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1147,  446,  267,    1,   37, 2020,  863,  469,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 2781, 1125,   98, 1107, 2218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2826, 1617,  162, 2858,  365,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  242,  449,  401,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181,   42,    9, 2250, 2337, 3187, 1258,   37,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  187, 3378,   96,    1, 1428, 1930,  588,   37,  619,  776,   81,\n",
      "           98, 1171,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1528,   32,   46,   37,  151,  215, 1093,  574,   87,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1500,    1,  102,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115, 1348,   37,  184,    1,  404,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   32, 2169,    1,    1, 2047,   45, 2966,    9,   36,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1484,    9,  388, 2117,    1,   32, 3118,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  766,   37, 1539, 3016, 1935, 2871, 2261,   32,  572,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,  104, 2501,  861,  232,  939,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 3397,   90, 3144, 2153,   37,  429,  264,  741,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12,    1, 2051, 2331,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  872, 1910,    9, 1022, 1902, 2578,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2767,  885,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2673,  861,   61,  105, 2107,  444,  199,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,   37,  211, 1607,    9,  845,    1, 2105,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2899,  936, 1775, 1107, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   71,  699,  523,    1,  425,  426,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1537, 2548, 2572,   32, 1815,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 2663, 1391,    1,  193,    1, 1724,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   26,  242,    1, 1946,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,   71,   45,  166,    1, 1568,  238,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  627,  275,  166,  116,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1441,  961, 1994, 2086,  210,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3095, 2856, 2710,    1,  650,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3198, 2622, 3169,  176, 2197, 3329,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  947, 2263,    1,  548,    1,  298,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1419,  105, 2355, 1013, 2549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3108,    9,    1,    1,  312,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492,  828,  774, 2095, 1665,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32, 3155, 1260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2634, 2767, 2627, 2871, 1825,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  400, 1554, 2454,   32, 2563,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,    1, 2751,   37, 1421,    1, 2024, 1259,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  766, 2767, 3016, 1935, 2400,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 1711,   45,    1,    1,    1,  339, 1492,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2206, 2435,  176, 2206, 2207,    1,  446,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1408,  631,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1287,   37, 2963,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425,    8, 2996,    9, 2786, 2558,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 2652,  581, 1463, 1427, 2350,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 2144,    9, 2942,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  811,    1, 1861,    1,    9, 1945,  548,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  681,   15,    1,    4, 1473,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1212,  171,  546, 2565,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  910,    1,    1, 1396, 2161,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  493,    1,  384,   69, 2639,   79,    1,    1,    1,   45, 2640,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2227, 2954,  907,   98, 1251,    6,    1,  461,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  954, 1353,    1,  118,   32,   72,  401,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 2384, 1768,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1949,  923,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1838,  176,    1,  593, 1990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3178,   39,   45,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1810,  125,  191, 3318,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1841,    1,    1, 1140,    9, 1860,   45,  552,  551,  517,  280,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1512,   32, 2570,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2172, 1090,    9,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1257, 1187,  132,   98,    1,   54,  734,  176,  247, 1904,  112,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  317,  756,    1,   28,    9,  818, 1882,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  739,    1,  187,   69,  102,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  244,  120,   98, 1230,    1, 2400,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  262,  263,   12, 1628,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2563,  631,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 2035,  682,  530,  106,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3167,    1,    1,  606, 1724,   37,  759,  105,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  705, 2796,    1,  273,   12,  142,    9, 2764,  404, 1684,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  627,    1,  168,  445,  658,  810,   74,    1,  267,  657,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  597,   22,   23,  232,  610,   32,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  476, 2264,   37,  619,  466,  220, 1013,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 2759, 2232, 1396,    1,  441,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,  183,    1,   32, 1913,  401,    1,   15, 1716,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  121, 1542,   37,   47, 1479,   49, 2498,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424,  433,  967,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2925, 3115, 2551,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713, 1700,    1,   32, 1033, 2211,  662,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1991,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193, 2310, 1981,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  743,   12,  155,  156,  157,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  475,    1,   10,   98, 1445,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1037, 2202,   37, 1918,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   32, 1663, 1958,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  645,    1, 2455,  384, 2984, 1173,   55,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  316, 3118, 2024,   61, 1634,   37, 2024,   32,  166,  463,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1117,    1,  163,    1, 1498, 1048,  148,   12,  214,  142,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1542,   37,  319,  187,  311, 2565,  716,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   65,   67, 1500,   76,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  600, 1691,    1, 1388,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3250, 1879, 1090, 2415,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585, 2766,  547,  163,    1,   12,    1, 2548,    1, 3343,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  691,   12,    1,  200,  105,  331,  142,    9,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  593, 2078,    1, 2977, 2695,  105,  846,  119,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1603,    1,   10,    1,    1, 1638,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  167,   52,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  755,  852,   37,    1,  224,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868, 1949, 1617, 2237, 1010, 2357,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  179,   37,  151,  180,   32,  182,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1202,  477,   32, 2597,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1100,   30,   79, 1273,  260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  236, 1022,  852,   37, 1155,   98,  241, 1653,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  256,    1,    1,    1, 2876,   37,  784, 1021,  282,  517,\n",
      "          260,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  654, 1458, 2723, 2724,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3274, 1494,   81,  384, 1183,    1,   37,  877, 2315,  865,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  216,  135, 1619, 2597,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,   45,    1,  977,  875,  218,    1,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  112,  550,    9, 1017, 2153,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3336,  190, 2286,   37, 1343,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 2199,  382,  568,  176, 2152,   32,  455,    9, 1890,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1648,   37,  815, 1193,   69, 1356,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2427,    1,   98,  166, 2202,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1625,   37,    1,  105, 2050,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  511,  267, 2548, 2572,   32,  645, 3279,   32,  463,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3214, 1631,    1,   12,  914,  640,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  360, 3101,  516,    9, 1887, 2735,  947,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3254,    1,    1,    1,  176,  754,    9, 1990,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,   69,  744,  365,  845,   98,  889,  509,    1,  430,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  989,  267,    1,  833,  612,    1,  265,   45, 1277,  132,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3252,    1,  810,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3276,  726,   32,  810, 2915,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1100,  361,    1,   37,   47,  207,    1, 1671,   32,  854,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 1384, 1903,  288,   37, 1195,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,  314,    1, 1629,  132,   32,   87,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425,    1,  297,    1, 2980,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1869,    9,  683, 3333,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267, 1031,   32, 3130,  967, 1846,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 2323, 1167,    1,  818,  325,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  103,    1,    1,    1,    1,  953,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1173,   37,  804,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,   12,  553,    1,  669,   37,  130,    1,  669,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3334,  726,    1,  361, 2498,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1, 1149, 3395,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  403,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  409,   25,  417,   98,  197, 1936,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  643,  532,   28,   32, 1332,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3290, 1838,  198,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1149,  168,   98,  477,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2551, 2687,    1,  361,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2469, 2681,  938,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2181,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  755,  614,  834,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 1373,   37, 1427, 2311, 1527,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  853,  595,  640,  163,    1,   12,    1,  858, 1085,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1127, 1586,   40,    9,   91,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  121, 2369,    1,  861,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2902,    1,    1,  872,    9,  613,   80,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2767,    1, 1428, 3146,   98, 3369,   12,\n",
      "         3118,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2406, 1921,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2162, 1950,   45,  403,  395,  851,  298,    1,   28,   37,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  288,   37,   26,  417,  355,    1,   69,  817,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1604,   98, 3042,  161,  614,   98,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  256, 2355,   37, 1106,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1652, 1380, 2355, 1718,   37, 1604,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1766, 1767,  218,    1, 1479, 1119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3134,    1, 2850,   85,  386,   78,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1909, 2250,  548,  787,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  215, 1542,   37,  576, 2924,   37,    1,   45, 2162,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49, 1974, 1828,   37,  395,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,   82,  387, 2717, 1031,  187, 2039, 1687,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2388, 1022,    1, 2503,  590,    1, 3194, 3195,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  516,    9, 3313,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 2185, 3341,   37,  771,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1117,    1,   91,   12,  340,  408,    1,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2427, 2968,    9, 3379,  597, 2256,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  433, 2424,    1, 1442, 1580,  302,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1564, 2056,  698,    1,  865,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,    1, 2177,   37,    1,  302,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  778,  315,   37,  764,  542, 1000,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 1604,   79, 2498,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1173,  105,   40,    9,  259,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  746,   32,  132,  220,  829,   37,  843,  844,   98,  845,  846,\n",
      "          847,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1177,  565, 2312, 2333,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  990,  884, 1003,  176, 1791, 2650,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1972, 1168,  541, 1159, 1821,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  813, 1695, 2134,    1,  150,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  352, 1216,    1,   51,  606, 1846, 1467,   32,  430,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2633,   45,  166,  116,   61,  365, 1280,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2268, 2214, 1924,  415,  105,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   22,   23, 2577,    1,  327,  934,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  197,   98, 1032, 1220,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    9, 2643,    1,    1,  166,  999,  166, 1488,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  750, 1190,   32,  395, 2532,   46,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  393,  614,  810,   39,    9,  395,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  169,  353,  105,  354,    1,    6, 1698,  356, 1470,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2275,    1,    1,    1,    1, 1505,  310, 1904, 1597,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1417,    1,  171,  566,  584,  171,  140,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3374, 3384, 2572,  191, 3101, 2548,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  444,    1,    1, 1739, 1625,   37, 2222,  429,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  441, 1421,  132,   37,   47,    1,  297,  365,  912, 2285,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2584,  720, 3263,  119,   37,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3095, 2856, 3375, 3359,  680,   97,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035,  707,   37,  717,    1, 1741,    1, 1038,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,   12,   98,  166,  236,    9, 1759,  309,   12,  915,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1343, 2349,  357,  442, 2349,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2942,  671,    1, 2494,  193,  320, 1628,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    7,  342, 2005,  817,    1,  864, 2673, 1816,   37, 1428, 2104,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 2640,   37, 1910,    9, 1821, 2190,   98, 1893,    1,    1,\n",
      "         2977,  267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118, 2751,  429,   39,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1433,    1,    1,  319,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  913,   45, 1714,    1,  105,  838, 1031,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359,  267, 2443,  163,    1,   12,    1,  142,    9,   46,  220,\n",
      "         3140,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111, 2655,   45, 2895,    1,   37,   52,  820,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 1027,   37, 1403,  388, 2913,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,   25,  470,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  389,   93,  143,  763,   76,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2630,    1,    9, 1332,    1,   32, 1789,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1, 2759,  920,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2479, 1383,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1648,   37,  619,   81,   37, 1604,  548,  547, 1034,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1090,    1,  921,    1,   59,  449, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3227,    1,    1,   37, 3182,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1574,  600,  166, 3115, 3285, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  931, 2277,   32, 2513,   37,  103, 3296,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  300,  388,   29,   37,  790,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   12, 1228,    1,  967,  807,  293,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,   45,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2479,    1,  364,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2689, 1717,    1, 3221,   61,  600,  388,  763,  166, 3154,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   10,  292,  389,    1,   32,  844,  117,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   39,  247, 2290,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232,  759,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   20,  197,   28,  118,   32,  401,    1,  577,   98,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584,  171, 1360,  612,  489,    1,   98,    1,  548, 2748,  354,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3155,    1,    1,    1,    1,  267,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700, 1979, 1419,    1,    1,    1, 3031,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1051,    1,  829,  872,   28,   98, 1074,  412,  861,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2206,    1,  171, 2800, 2565,  939,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1716, 2480,   15, 1348,   37,  832,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758, 1008,  535, 1213,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3277,    1, 1167,    1,  190,   18,  227,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1354,  730,    1,    1,   37,  619, 1766, 1767,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 1671, 1905,   37,  222,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1124,  792,    1,  792,    1,  232,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1524, 1033,   91, 1953, 1268,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275, 1539,    1, 1450,  297,  531,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2883,    1, 2192,   28, 2375,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   37,   52,    1,  176,  247,  539,  458,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1114, 2645,   37, 3214,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596,   27, 3155, 2900,  163,    1,   12,    1, 2705,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2317,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  229,  437,  958,  142, 1992,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  167,    1,   55,    1,  729, 1824,   98, 3024,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1821,   95,  590, 2783,  331, 2223,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,    1, 1053,  774,  593, 1822,  764,   62, 1789, 1559,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,   60,  509,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,  593, 1874,  166, 1254, 1465, 2085,   37,   52, 1532,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2596, 2414,  176,  177,   32, 2018,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2108,    1,   37, 3339,   98, 2521,   45,   46,  220, 2729, 1407,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,    1,  829,   12, 2819,    1, 2146,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 1419, 2355, 1013, 1626,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  572,  343,  187,  460, 1278,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  251,  988, 2759, 2168,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193,  810,    1,  176, 2957,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2328, 1585,   32, 1619, 2597, 2414,  786,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3347,   51,  606, 1467,  105,    1,  636,    9,  247,    1,    9,\n",
      "          166, 1811,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3115,  949,    1,    1, 1130,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  882, 1111,  528,  244,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018, 2540,  929,   12,    1,  176,    1, 1006,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   69,  102,   71,   98,   49,  122,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  219, 3372, 1579,  365,    1,    1, 1213,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1, 2750,   45,  192, 1085,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  642,  643,    1,  417,   69, 1198,   25,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  235, 2069,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1105,  787,   93,  307,  308,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   51,    1,   28,   37,  372,   32, 1407,  734,   32,  518,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1530,   32,  455, 3121,  187, 1625,    1,    9, 2249,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128, 1129,  105,    1,  686,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2708, 2823, 2409,  267, 3101, 2548,  688, 1590,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294, 2297, 1009,   45,    1, 1589,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2110, 1328,  600, 1472,  453,    1,  656,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  573,  977,    1,    9,    1,  412,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  614,    9,  388,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  614, 1300,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 3207, 2411,   37, 2192,   28,  671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3253, 1268,  220,  105,  726,   32,  316,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,  476,  388,    1,   98,    1,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  619,  166, 2500, 2589,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  515,    1,  105, 1135,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1497,    1, 1879,   98,  857, 2460,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1712, 1713,  316,  317,  624,    1,  187,  940,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  686,  191,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  952,  562,   37,   92,  225,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 2284, 1998,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1539,    1,   95,  384, 2570,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878,   12, 1904, 2401,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2932,  949, 2209, 2955, 2079,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3076, 1659,    1,  548,  851,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1902,  900, 1903,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,   37,  138,   59,    9,  552,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  282, 2367, 2695, 2843, 2524,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1833,  593,  830,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1971,  688, 3250, 2072, 3254, 2925, 1034,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   78,  567,  390,    1,    1,  901,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  198,   93,    9, 1718, 2168,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2192, 1117,    1, 1256,    1,    1,  166,  741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1375,   37,  588,    1,    1, 1639,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  148, 2767, 1479, 2706, 2232, 1901,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 1612, 2289,    1, 3000,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2140,  952,   32,    1, 2950,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151,  951,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3119, 1445,  459,    1,   37, 2381,  356,  132,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2658, 1550,    1, 1318,   12,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   45, 2974,   12, 2507,  541,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1726,    1, 1665,    1,  774, 1592,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1492,   12,   37, 1096,    9, 1533,  917,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2144,  104, 3111, 1530,  187, 2597, 1656, 1585, 2414,  176,  177,\n",
      "         1312,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  460,   12, 1018,  411, 2022,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1074,   37,  123,  191,  465, 1657,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1334,   32, 1327,    1,    1,    1, 2487,   45,  334,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  282, 2367, 2695,    1,   45,  166, 1034, 1805,   28, 1167,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2115,  102, 1348,   37,  720,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   61,    1,   37, 2111,  361,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  691,  872,   28,   37, 1496,    1,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,   37,  125,    1,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 1585,   27, 2877,    1,   32, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1432, 3207,  140,  810, 1425, 2630,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1168, 1108,   37, 1821,   32, 1056,  537,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  503, 1475,  453,  308,   98,  749,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  765,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1,   45,  132,   98, 1323,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1716, 1320, 1433,  460,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   12, 2531,  396,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1486,  207,  354,   28,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  365, 2400,  220,  183,  535, 1021,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  593,   69,  102, 1992,  105,  106,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  486,    1,  664,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1281,  640, 1023, 1204, 2633, 2177,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2431,   32,  400,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  224, 1564, 3034, 2869,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  115,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,   72,   73, 2630,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1685,    1,   44,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1199, 1825,  220,  183,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1822,    1,   37, 2756,  859,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2376, 2024,  855,   37,   52, 2297,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   66,  242,   69,  816,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  433, 1680, 1038,  199,    9, 3017,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1273,  861, 1665,   66,  340, 2680,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  193, 2310,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  696, 1198, 3231,  608, 2642,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  903, 3165,   64, 2592, 2699,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  163,    1,  903,    1,  108,   45, 2673, 2501, 2095,  762,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,  879,  647,  693,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,    1,    1, 1056,    1,    1, 1638,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   45,    1,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3123, 2565,    1, 1394, 1048,    1,  612, 1360,  104,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1758,   32, 1447,   26,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  236, 1022,    1,  157, 1571,  218,  220,    1,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,  176, 2531,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  215,   37,    1,   98,  531,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  954,   61,  176,  453, 1509,    9,  228,  537,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  111,  640, 1473,  166,    1,  187,  538,    1,  166,  116,  823,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  623,  315,   37, 1539, 1234, 2382,  259,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  418,  530,   37,  119,   98,  104,  109, 1057,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1149,  741,   37,  439,    1,  868,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  455, 2164, 2414,    1,    1,  477, 2047,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,    1,  967, 1857,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  315,  787, 1849, 1766, 1767,  191,  439,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  638, 1932,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  176,    1,    1,  104, 1414, 2856, 3343,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1707, 3042,  161, 2146,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3265, 1987, 1414, 3230,   37, 1418,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 1009,   98, 1422, 2237,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1401,  219,  159,  242,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2246,    1,  939,  187,    1, 2565,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2504, 1529, 1333, 2837,  228, 1215,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  396, 1887,   45, 3374,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1484,   32,    1,    1,   37,  877,   54, 1503,  142, 1289,\n",
      "           28,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,    1,  687,    1, 1870, 1625,   37,    1, 1159,  938,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  531, 2216,  104, 1572, 1414,    9, 1583, 2891,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1832,   28,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3118, 2649, 2162, 1950,  176,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1818,  147, 1392,    1,   98, 1983,  815,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  657, 2065,    1,    1,    9,    1,    1, 2168,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758, 1958, 1697, 1013, 1522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2347,    1,    1, 3245,  105, 1090,  199,  484,  951,    1, 2807,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  115, 1702,    1, 1412, 2294,    9,    1,  327,  593,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1766, 1767,  193,  105, 2809,    1,    9, 3134,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3297,    1,   34,    1,    1,    1,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3012,  298,  105,    1,    1,  202, 1924,  105, 1488,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   32,  845,    1,   63,  581, 1463,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  861, 2091,    9, 3359, 1010, 3339,  741,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1090, 1829, 2748,  176,  365,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2423,    1, 1433,  193,  104,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2182,   39, 1778,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,  907,  187,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1731, 2735, 2834, 1822, 2446,  449,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  198, 3087,  868, 1850,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  683,  476,   37,    1,  166, 3103,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2004,  189,  376,  689,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1419,    1,   37,  883, 2973, 1764,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2741,    1, 3215,    1,  204,  321,  877,  460,   32, 2936,  175,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  381, 1236, 1327,  297, 1047,  467,  400,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   60, 1042,   37,  365,  810,  199,  340,  951,    1,   94,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1962,   37, 2303, 1623,   45, 1273,  259,   50,   32, 2020,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1592, 1248,  249,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102, 2338,  187,  104, 1588,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  395, 1500, 1184,  347,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3328,  738,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   83,   12, 1787,   32,  147,   61,   37, 2498, 1133, 1574,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2043,   45,  166,  442, 1158, 1021,  282,  517, 2071,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2104, 1082,  388, 1799,    9,  104,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  741,    1,  891,   32, 3343,  863,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  197, 1226,   98,  287,  408,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,  952,  132,   37,   77,  359,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  321,  631,  166,  978, 2423,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1237, 1658, 1117, 1525,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2094,  453, 1090,   37, 2592,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325, 1204,    1,    9,    1,  131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  420, 3103,  726,    1,  444,  683,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  417,    1, 1634,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   61, 1809,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974,  884, 2695, 2223,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  119,  293, 1236,    9,  116, 2441,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384, 2597,  105,  236,  237,    1,    1,   12, 1117, 1525,   37,\n",
      "         1678,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    9, 1354, 1370,    1,    1,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1140,    9,  388,  522,   37,  125,  596, 1793,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  316,  171, 1268, 1412,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  335,  424,   37,  166,  458,  166, 3132,  167,    1,  166,    1,\n",
      "          550,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  567, 1118,  581, 3117, 3271, 1090,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1647,    1,  202,  590, 2666,    1,  176,  903,    1, 1973,   46,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1497,    1, 1185, 3188,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294, 2860,    1,  163,    1,   12,    1,  622,  469,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2178, 1002, 1086, 1015,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2212,  861,  105,    1,    9, 2087,  433,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1853,  936,   74, 3336,    9, 3358,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640, 1737,  472,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,   60,   61,   85,    1,  202,  894,    1, 2135,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3045, 2856,  129,    1,   32, 2597,    1, 1527, 2664, 3340,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  894,  224, 1096, 2380,   32,    1, 2130,    1,  357,    1,    1,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,  633,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 2127, 1220,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428,    1,  603,  176, 2587, 1867,   98,  249,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  104,   65,    1,    1, 2001,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  134,  941,   12,  938,  220,  133,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141, 1090, 1829, 2184,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1953, 1924,  193,  449,    9, 2676,    1, 2136,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  971,    1,  479,  837,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3058,    1, 2548, 1267,    1,  297,  138,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  331,    1,  371,  703, 1661,  207,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  449,  401,  244,   28,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3128, 1310,   37,    1,    1,  163,    1,   12,    1, 2924,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3248,    1,  571,   37, 2760,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962, 3319,  470,  608, 1110,  528, 1340, 2907,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1292,   12, 1915,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2249,    1, 1976,   32,  430,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,  105,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,   58,  738,  572,  236,  237,  308,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,  779,  220,  861, 2043,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  103,    1,  677, 1114,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  365,  149,  994,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  784, 1876,   32,    1, 2232,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3051, 2024,   46,   26,  220, 2096,   98,  861,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3358, 2312,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  315,    1, 1698, 2462, 2978, 1539, 1567,  729,  465,   51,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2175,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  949, 1710,    1, 2095,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3369,  108,  539,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294, 3102, 3395,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1615, 1067,    1,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1536, 1961, 1952,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  593,   12,  553, 2177, 1027,  820,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,    1,    1, 1184,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1702,    1, 2232,   81,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  266,    1,  654,  875,  220,   75,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1305,  384,    1,  843,    1,    9,  810,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1452,    1,  619,  284, 2258,  917,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,  251,  911,    1,    1, 2549, 3004,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  658,    1,    1,  920, 1812,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1862,  297, 1527, 1705,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219, 3096,   37,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1183,    1,    9,  105,    1, 1592,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  439,   45,  166,  260,    9, 1087,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1955, 1203,    1,  895,    1,   32,  104,    9,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  191,    1,    1,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 1940,   12,  593, 1990,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  597,    1,  162,    1, 1175,    9,    1,    1,    1,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  116, 2542,  951,    1, 2994,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9, 1340,    1,  460,   12, 2626,  361,   37,  168,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  565, 1592, 1176,   32,  166,  815,   45, 2043,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1,    1, 1976,   98,    1,   32,    1, 2203,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1666, 1126,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2614,    1,    1,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1955,   37, 1155,    1,   32, 1771,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2043, 1164,    1, 2706, 1998, 2298, 2973, 1764,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3143,    1, 1313, 2134,  861,  231,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1554,  844,    1,   37,  335,    1,  389,  176, 2755,  878,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1090, 2677,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2638,    1,  569,   37,   52,  288,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   99,  387,    1,  471,   32,  346,  274,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1583, 2625, 1159, 3339, 2414, 3375,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1962,    1,    1,   12, 1101,    1, 1017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    5,    1,    1,    9,   49,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  388,    1,  565,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3200,    1, 3245,   37, 1306, 1602,   12, 1090,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1479,  647,    1,  315,  193,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2995,  218,  332,  953,  699,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  786, 2341, 2871,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,   22,  139, 1924,  344, 1260,    1,    1,   37,  104,  178,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1790, 2976,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2072,  166, 2196,  426,  169,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1934,   12,  622, 2153, 1399, 1725, 2153, 1444,  190,  221, 1750,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   37, 1279,  272,  176,  950,    1,  440, 1479, 1410,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  295,   37,  125,  541,  176, 2295,  405,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2854, 1825,   79,  187, 1914,    1, 2701,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2514,    1,    1,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  750, 1576,   32,  654,  776, 2286,   37,    1,  105, 1142,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3214, 1401, 1018, 1995,   98, 1123,   12, 2078,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,  614,    9,  671,   32, 2890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1645, 2404, 2405,   37,  854,   37,   92, 2471,    1,    1, 1428,\n",
      "          142,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1474, 1353,    1,   32, 1811,  404,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  397,  261,  104, 1822,  771,  111,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  123,  104,  691, 2471,  167,   52,   32,    9,  105,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  210, 1898,    1, 2332,  220, 2617,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  176,  339,  687,  444,   94,   98,  104,  448,    1,   69,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  861,  122,    1, 1106,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 1065, 1190,   32, 3369,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  561,  574, 2341,  161,  934,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123, 3117,  361,  730, 2614,    1,   32,    1,   84,    1,    1,\n",
      "         1750, 1515,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1176,    1,    9,  166, 2162, 1780,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2751, 1260,  622, 2791,   32, 1815,    1, 1056, 1530,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  187, 2571,    1, 1512,    1,    1, 1428,  580, 1797,  977,    1,\n",
      "           37,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  666,   66, 2051,    1,  763, 1999,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3236,    1, 1631,    1,   12, 2210,  356,  686,  813,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1707,  342, 2673, 2362,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  506,    1, 1272,  166,  207,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3347, 2594,  884,  631,   32, 1898, 1684, 1948,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2680,  884,   98,  388, 2650,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1454,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,   25, 1758,  503,   25,  670,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1409,  411, 2990,    1, 1264,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  912, 2285, 1228,   79,  822, 2904,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   37,  335,    1,  992,   32,  996, 2532,  220,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 1306,  199,  220, 3263,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1841, 1512,   32,    1, 3369,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2428, 1381,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   40,  162,    1,  220,  365, 2876,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   98, 3264,  939,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  502,  551, 1361,  765,    1,    4,   37,  854,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1340,  515,    1, 2808,  351,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  619, 2202,   32, 1133, 2915,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2427,   79,   37,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,  971,   32, 2339,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1778, 1718,    1, 1976,   37,   52,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1749,  220, 1410,   32, 2154,    1,  934,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,    1,  384, 1786, 2358,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1097,    1, 1165,   29,   16,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1084, 1317,  704,  104,  167,  109, 1104,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  282, 2693, 2393, 2264, 1243,  176,  629,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   82,   83,   37,   84,   85,   32,   86,   87,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,  455,    1,    1, 1207, 2532,  297,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1477, 2843, 1464,   37,    1, 1990,    1,  176, 2916,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1981, 2677, 2379,    1, 2951,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  762,  310,    1,  220, 1183, 2320, 3162,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3334, 2935,  166, 3116, 3217,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,  166,    1,    1,    1,  202,  453,  197,    1,\n",
      "           85,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  504,   32,    1,  863, 1160,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  557, 1583, 2151,  453, 1450,   37,  166,  403,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3185,  927,   51,    1,    1,    1,    1,  167,  664,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 1707, 2308,  474,   12,  645, 1384,  630, 2362,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1808,  361,  732, 1523,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1833, 1380,  453, 2143,   32, 1481,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  303,  163,    1,   12,    1,  321,  341,   69, 1251,   71,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1159,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1024,  919, 3120,  608, 3268,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3203, 1287,  176,    1,  229, 1787, 2148,    1,  191,  786, 1333,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  674,  166,    1,    1,    1, 1801,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  335, 1370,   32, 1658, 2312,  248,    1, 1260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3298, 2479,  103, 1569,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800,   12,    1,    1,  565, 2526,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2456,  202,  388, 1534,   45,  985, 2205,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428,   96,   37,  163,    1,   12,    1, 2924,   37, 2681,  453,\n",
      "         1346,   32,  531,   88,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2737,    1,   79,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1863, 2347,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,  597,   82,    1, 1654,    1,  548,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1232,    1,  477,  640,    1,  590,    1,   98,  449,   74,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1210,    1,    9, 1983,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  985,   13, 1670,  562,   37,   47, 1671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1900,  361,    1, 1018,    1, 2978,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  978,  600,  978,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   12,  808,    1,   37, 1814,    1, 2537,  104, 3397,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1263, 1211,  176,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196, 2652,  176,  551,  612,  613,  170,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  420, 1243, 1099, 1453,  533,    1,  902,  290,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426, 1690,  525,   15,   28,    1,  118,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  107, 1542,  220,    1, 1208,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1405,    1, 2286,   37,    1, 1142,   12,  724,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  228,    1,   98,  166, 3278,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  663, 1816, 1464,   37,    1,  787,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2778,  498,   37, 2024,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3097,  446,    1,    1, 2757, 1046,   79,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3209,    1, 3209,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,   12, 2755, 2751,    1,    1,   32, 1512,   32, 3118, 2517,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1633, 1205,    9,  331,  297,  604,  354,  396,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,   45, 2292,    1, 1316,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 374, 375, 387,   1,  98, 800, 378,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  407,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2871, 2347,    1,  190, 1306, 2119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  720,   32,  526, 2104,  102,   37,  439,    1, 2117,    1,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  156,  576,   25,  417,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  709,  136,  475,    1,    1, 1231,  220,    1,  133,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,    1, 2155, 2070,    1,  509,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2615,  726,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1, 3343, 2548, 2263, 2985,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  612, 1273, 2055,  449,  219, 1463,   45,  105,    1, 1074,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  168,  115,  220,    1,  477,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2942, 2813,   37,  726,  671,    1, 1086,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  619,    1, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  258,  160, 1161, 1993,   28,  707, 1159, 1104,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1, 2752,  429,   46,  297,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1290,  396,  245,  995,   37,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2137,  686,    1,    1,  187, 2774, 2782, 1258,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 1282,  912,  449, 1593, 1558,   32,  365, 2995,  443,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  872,  365, 2036, 1641, 1443, 2017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1498,    1,    1,  605,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  700,  951, 1547,   98,    4,  550,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   60, 1141,   37, 2035,  682,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1212,    1, 1878, 2534,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1100,    1,  326,  860, 2403, 1998,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2573,  744,   28,    1,   32,    1,   37, 1496, 2879,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   61,  166,    1, 1542,    9, 1718,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  754,   15,  120,   32,  385,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  199,    9,  166,    1,   45,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,  288,   37, 2122,  104,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 2024,  753,   32,  317, 3358, 1015,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 2003, 1585, 1950,  418,   37,  187,    1, 1027, 2758,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  858,   93, 1071,  586,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,    1,   10,  315,  822,  522,   98,  378,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  772,    1, 2905,    9, 1523,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  392, 1107,    1,   37, 2102,    1,  357,  242,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 1443,   81,   98, 1708, 2290,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  232, 3167,   37,  221, 3251,   37,  316,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  300,  861,  328,   37,  754, 2261,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3312,   37, 1046, 3308,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  560,  133,   27,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465,    1,  408,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,    1,    1,    1,    1, 2772,  344,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2877,  267,  531,  954,    1,  861,  719,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2343,  776,   37, 1174,   63, 2020,  863, 1147, 1190,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49, 2185,   50,   12,   69, 1356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  979,   37,  877,  247,  813,   98,  219, 3129,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  803,  112, 1986,   98,  996,   93, 1042,    1,  496,   30,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2974,  105,   95, 2017,  384,  331, 2223,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  361,  657,   37,   26,   28, 3044,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,   30,  395,    1, 1194,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  176, 3194, 3195,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1987, 1512,    1, 3186,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  632,    1, 2826, 2162,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  616, 1291, 2315, 1034,  220,  388,  682,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  251,    1,  176,  627,   45, 2738,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,   37, 1152,   45,  861, 2558,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885,    1,   74,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  964,  171,  681,  321,  142,    9,   49,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1717,    1,    1,  220,  424,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  777,  633,  224,    6, 1126,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683, 1293,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  647, 2483,  662,  220,  326,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2877, 1082,  593,   37,  764,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1194, 2132, 2388, 1249, 2388, 1022,    1,   32, 1913, 2138,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  761,  245,   98,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,  590, 2383,    9, 3130,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1, 1900,    1, 1159,    1,    9,  333,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1386,    1,   37,  419,  646,   93,  446,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2733,    1,   37,  119,  681,  600, 1107,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1242,    9, 2741,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  409,   25,  245,    1,   60,  242,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  759, 1845,   24,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  374,  375,  376,    1,   98,  377,  378,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  313,    9,  311, 1292,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,    1,    1,    1,   85,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1785, 1414, 2856, 3043, 3384,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 2231,  494,    1,   98,    1,  333,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3168,   30,    1,   98,  147,    1,  361,   32, 2712,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3130, 2034,  590, 2304, 1394,   32, 1918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1966,  398,  134, 1899,   32,  663,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1583,  850,   28,  433,   27, 3339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  787, 1178, 1231,  220,  840,  829, 1039, 2690,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  316, 2489,    9, 3246, 3154,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  593, 2301,  760,  453,    1,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2863,  149,  444, 2956,    1,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3141, 3152,    1,    1, 2457,  726,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1046,    1,    1,   32,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1359,   45,  777,    1,  105,  365, 1015,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994,    1, 2262,  207, 2738,    1,   45, 1147, 2751,    1, 2375,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  968,   81,   32, 1821,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  475,  162,  331,  384,  333,   37,  558,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3101,  267, 1255,  190, 1752,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,    1,  596,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426, 1070,    9,    1,   45,  695,   32, 1149,  149,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1617,    1, 1114,  176, 1515,  248, 1675,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1647,   61, 1532,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1497,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1668,  619,    1,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1530,  357, 2249,   32, 3121,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    8, 2073,    1, 2232, 1300, 1626,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,  317,  449, 1385,  140,   32,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1212,   12, 1183,  162,  881, 1632,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2720, 2796,  321,  612,  619,   37,  365, 1788,   32,  199,    9,\n",
      "            1, 1090,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2235,  159,  123,  417,    1,  220, 2163,   85, 1010,  410,   29,\n",
      "          297,  104,  954,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   27,    1,   12, 1633,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1818, 2861,    9, 2592,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  189, 1118,   72,  401,  156,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  176, 2738,   32,  166,    1,  506,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,  162,  562,   37,  125, 1149,  138,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  120,   45, 2597, 2292, 1554, 1530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   32,    1,    1,  754,   45,  166, 1913,  161,    1,  943,   61,\n",
      "           45,  531,    1,  193,  166,  890,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   57,  949,   45,    1,    1,  117,   12, 2078,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  324,  159,  701,  548,  326,  132,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2962,  857, 3299,  191,    1,    1,    1,  186, 2615,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3361,  193,    1,   32,    1, 2379,    1, 1929,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826,    1, 2007,   98,  287,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  552,  551,  517, 1203,  453,  792, 2872,    1,  792,  191,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1841,    1,  191, 2162,   45,  938, 1075, 3160,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  176, 1319,    1,   10,   37, 1604,   98,  403, 1447,    1,  864,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1707, 1448, 1749,  142,  943, 2099,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1100,    1,  270, 2385,  612, 2626,   32,  105, 1101,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1227, 1994, 1718,  117,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  844,    1,   51,   52, 1156,    9,    1,   37,    1, 1039,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  275, 2043,  529, 2026, 2401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1629,  108,   45,  981,  286,  293,  533,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  546,  648,    1, 1008, 1359,    1,  475,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  230,  122,   51,    1,    1,  493,    1,   27,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,   51, 1371, 2243,  388,  160,  643,  586,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  828,   81, 3359,   98,  469,    9,  380, 3339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 1190,  267,  949,   45, 3365,   32,  531,  729, 1610,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2533,    1,   98,  191, 1344,   45,  581,  913,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267, 1610,   37, 1083,  646,   93,   37,  419,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  449, 2725,   37,    1,   32, 1212,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1325, 2776,  777,  279,   95,    1, 1294,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2321,  729,    1,   32,    1,    1,    1,   45,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3139,    1,    9,  105,  119, 2513,  671,  361,  537,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  585,   23, 2977,   37,  211, 1821, 2978,  541,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  954, 1429,   85,  202,  288,   37,  186,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3333, 2151,  683,  187,  105, 2841,    1, 1086,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2459,  469, 1710, 2192,    1,  412,   37,  166,  974,  787,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2586,  176,  348,  187,  572,  156, 1253,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  166,  790,   32,    1,  548,  749,  287, 1484,    9,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  463, 1447, 1760,    1,  280,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144,  387,  241, 1287,  548, 3372,  741,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  453,  729,   32,  255,  637,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2658, 2269,  288,    9, 1583, 2318,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3061,    1, 1537, 1386,   45,    1,   37, 1403,    1, 1988,\n",
      "           37,  825,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3184,  765,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1327, 1454,    1, 3396,   73,   81,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3354, 2161, 1822,  193,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1117, 2208, 2402,  298,    1,  122,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  359,  474, 2153,  360, 2362,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,  590, 1131,   45, 1815,   98,    1,   45,    1, 2406,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  267,  190,  168,  115,  220, 2673, 2836, 1602,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,  730, 2614,  565,    1, 1123,   12,    1, 1463,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2111,    1,  388,  128,    1, 1675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1807,  105,  628, 3246,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,  103, 2576,  384, 1906,    9,    1,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,    1, 1708,  361,  166, 1811,  404,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  884,   98, 2102,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  331,   12,   32,   46,   37,    1, 2606,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2302, 2488,    1,    1, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1, 1173,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  108,   45, 2786, 2987, 2762,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  147,    1,  548, 1936,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2472,  650,    1,   79, 2041,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328, 1364, 1365,   12,    1,    1, 2018,   32, 2069,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,   14,   15, 1376,   32, 1275,   28,    1,  419,  384,  871,\n",
      "           37,  688,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   75,  908,  196,  142,    9,  176,  612,  613,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  407,  115,   45, 1087, 1230,    1, 2452, 1539,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  303,  845,    1,  734,  193, 1328, 1665,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   15,  475,    1,  415,  297,  105,  356,  548, 1997,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2885,  967,  665, 3258,   37, 1694,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1,  640,  463,  455,    1,    1, 2817,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   61,    1, 3177,   12,    1,    1,  838,  357,  193,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3108,   77,  163,    1,   12,    1, 1625, 2793,   32, 1764, 1990,\n",
      "         2069,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1087,  593, 1087,    1, 1118,   37, 1348, 1632,  367,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3156,    1, 1683,   56, 1890,  548, 1796, 2164,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    9,  364,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2163,   12, 2153,  551,    1, 1066,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3227,    1, 3326,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2445,    1, 2095, 1450,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1854,    1, 2827,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1095,    1,    1,   45, 1682,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  770, 2116,  897,   32,    1, 3339, 2791,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321, 1018,    1,    1, 2085,  168,  754,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1270,  297,    1, 2464,  267,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  871,  754,   15,  198,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  894, 1747,    1,  361,  753,   37,    1,  411,  631,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1094,   32, 3358,   12, 2162,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3142,    1, 1550,    1, 1924,  247,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2289,  967, 1922,    1,   32, 1250,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1778, 1901, 2996,  861, 2558,    1,  202,  460,   12,  193, 1762,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3349,  446, 1070, 3405,  193,   37, 1496, 3362,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1051,   12,    1,  739, 1115,  581,  401,   15,   93,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1577,  852,   37,    1,    1, 2515,   37,   92,    1,  260,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2573,   12, 3398,  794,  142,   37, 1048,  247, 2225,    1,  865,\n",
      "           37,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  286,  927,    1,   25,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2110,  921, 1834,    1, 1401,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1, 2018, 2153, 1174, 2024,   46,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  172,  369,    1,  190,  130,  457, 1429,  700,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2277,  786,    9, 2477,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2677,    1,  361, 3328, 1173,    9, 3308, 1990,   34,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1765,  593,   12, 1254, 1178,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1092, 1568,   37, 1753,  552,  552, 2633,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1547,   27, 1034,  340,  951,   60,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2491,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  987, 2405,  754,    1,  111,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1431, 1654,  149,  297,  769,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2807,    1, 1554, 1090,  220, 1987,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  415, 1936,  105,  271,  384, 1663, 1343,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  381,   12,    1, 2297,  518,    1, 1560,  475,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    6,    1,   37, 2568, 2214,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  103, 1569,    1,    1, 1748,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2477,  944,    1,    1, 2699, 3053,    1,  928,  176,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,  669,   37, 1335,  514,   37,  636, 1336,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3238, 1542,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388, 1118,    9,  487,  358,    1,   32, 2235,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2643, 1085, 1013,  760,  166,  116,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  449, 1180, 1151, 1069,  260,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2720, 2796,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   67, 2716,  176, 1661,  551,  704,  222,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,  885, 2113,   32,   75,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 1065, 1190,    1,   37,  907,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  160, 1161,  338,   32,  385,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  333,    1,   37, 2250, 2242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1530,   32, 2490,    1,  114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  468,  315, 1273,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  619,  166, 2500, 2589,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3186,  475, 2940,   32,  542, 1462,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1486,  267,  460,  967,    1,  166,    1,  528,  207,  354,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1199, 1411,  183, 1265,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,    1,  966, 1791,   32, 3114,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  517,    1, 2767, 1539,   45,    1, 1228, 1901, 3031,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  645,   37,   47,  331,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,  140,    1,  444, 2679,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  166, 1178,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,   28,  419,    1,  159,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1041,  331,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1000, 1167,  166,    1,   45,    1, 1394, 1515,  454,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3069,  566, 1415, 3144, 2471, 1232,    1,  140,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1,    1,   12,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37, 2228,   79, 1602,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  167, 1306,  437, 1267,   45, 3116,  922, 2007,   37, 1628,\n",
      "           81,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   68,  636,  338,  981,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1248,   10,   37, 1031,  531, 1058,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1633,  786,  172,   37,  125,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2104, 1082,  316,   37,  518, 2056, 1465,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,    1, 2902,  125,  102,   98,  116,   19,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  708,  179,   37,  843,   80,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3296,    1,    1,   98,    1,  220,    1,   81,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,   37, 1599,  522,   37,  299,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1926,    1, 1325,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37, 1075,  297,  334,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 350, 993, 994,   1, 150,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 705,  12, 967,  38,  32,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  177, 2705, 2797,   98,  567,  510,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1398,  612, 2589, 2310,  116,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  861,  590,    1,    9, 3343,  582,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  294, 1983,  170, 1960,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  136,   37,  130,    1,    9,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  442,    1,   37, 2463,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1396,    1, 1684,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2800,    1,  992,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2981, 2421,  220, 2604,   29,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  914,    1,  297,    1,  202, 1167,  833,  612, 2446,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  636,  186,  884,   79, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,  215, 2710,  458, 1268,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1797, 1002, 1313,    1, 3144,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3152,  683, 2740,    9,  914,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  146,    9, 3348, 1876,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12, 3137,    1,  202,  981, 1867,  110,    1,  774,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  405,    1, 1360,  612,  690, 1624,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783, 1713, 1577,  675,  365,  596,    1,  662,  210,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2175,   81,    9,  388,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  463,  464, 2153,  498,   37, 2122,    9,  522,   98,\n",
      "          403, 1447,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 2741,  951,    1, 1022, 2296,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1786,    1, 1099,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  196,   37, 1901,  613,   29, 1074,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,  288,   37,  151,    1,    9,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2899, 1359, 2384,  365,  912, 2285, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2513, 2132, 3297,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,   79,  293, 2453,   32,  572,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1759,    1,  646, 1353,    1,   98,    1, 1278,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  455, 2164, 2162, 1950,  640,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 2858, 1470,   25,  104,  385,  389,   93,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1165, 1278,   85,   32, 1332,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1891, 3399,  588, 1428,    1,   45, 3101, 2731,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2038,    1,   39,  331,   98,    1,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1, 1675,   45,  327,  593,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  103, 1317, 1638,  820,  191, 1958, 1906,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  103,  963,  176, 1023, 2472,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  342,  147,   98,  636,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2161,    1,  191, 1841,  193,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  980,  187,  977,  335,  244,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1249,  689,  202,  108,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  553,  104,  793, 1933, 1536,    9,  467, 1942,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,   45, 3144,  741,   32, 1820,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  183,  978, 1426,    1,  399,   98,  573,    8,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,  102,    1, 1714,   32,  365, 1788,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1157,  159,   85, 1282,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2736,   12, 1727,   37, 1691,    1,    1,  384, 2218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2827,  548, 3343, 2887, 1523,    1,    1,  650, 3338,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2968,  639,    1,    1, 1184,   32, 2375,   45,  350,    1,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  256, 2474,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1631, 3078,   32, 2172, 2291,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  547, 3395, 2496, 2952,   98,  105, 2041,  403,   45, 2597,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1290,  396,   28,   98,  805,   45, 1582,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  273,    1,  176, 2918,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1070,   37,    1, 3304,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  961,    1, 1348,  603,    9, 1389,   45,    1,  851,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1401,   74,   45, 1126,  682,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3352, 2856,  232,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  335,  297,  187,   82,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  548, 1164,   45,  216,    1, 2700,  774,    1,   61, 1954,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  695,    1, 2789, 1401,  411,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3298, 1401, 2498,   32, 2069, 2760,    9,  649, 1938, 3197,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649,  700,   37,  151,  326,   12,  327,  112,    9,    1,  131,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2658,    1, 1841, 1159, 3344, 1085,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1641,   28,  965,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  657, 1564, 1199, 2666,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796, 2644,    1,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 148,   1, 647, 693,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1, 897,  79,   1,   1, 540,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  812,    1,  548,    1,  726,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  213,   37, 2144,    1,  191,  864,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3271,    1,   37, 1306, 1411,  698,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 2116,   61,    1,   32,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1713, 2500, 1841,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2383,    9,    1, 1492,  335,  749,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3186, 2249, 2335,    9,    1,  427,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2792,  920, 1194,   32,  593,    9,    1,  805,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  447,  361, 2707, 2827,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1203, 2871, 1021,    1,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3337,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1436, 1321,  384, 3278, 1903,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3241,    1, 3219,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3226,    1,   39, 2119,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1106, 1297,  334, 2603,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810, 3130,    1,  590,  750, 2614,  335, 1264, 1090,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2523,   37,  865,   37,  103,   45, 1090,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   86,    1,    1,    1, 1833,   32, 3336,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3352, 2833,  336,   32, 2890,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1792, 2596, 1809, 2287,    1, 1159,  215, 3372,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2962,    1,  571,   37, 2925,  187, 2563, 1285,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 2050, 2376, 2024,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1708,  927, 1008,    1,  232,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   51,   52, 1411,  183, 1265,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  220,    1,  631,    1,  730, 2614, 1173,   37,  123,  132,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2619,   98,  484,  191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  207,  338,  159,  720,   98,  570,  125,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1378, 2500,    1,    1,   59,  537, 1490,  506,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  216,  176, 1313,  186,   32, 1853, 2856,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  702,  353,  197,  987,  640,    1,  372,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2102, 1107,  525,  942, 1268,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463,  464,    1,    1,    1, 2485,    1, 3207, 1625,   37,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 2634,  220,  845,  439, 2232,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363, 3390,   32,  187, 3343, 1009,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  449, 1173,    1, 2382,  775,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   37,    1,  261,    9, 1525,   37,  942,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3095,    1, 2729,  379,   45, 1997, 1121,   37,  335,  522,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2347,    1,    1, 3245,  105, 1090,  199,  484,  951,    1, 2807,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   61, 2623,    1,    1,   61, 1628,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640,    9,    1,  187, 3175, 2651, 3266,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  861,  509,   32, 2597,    1,  104,    1,  806,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  169,  353,  105,  354,    1,    6, 1698,  356, 1470,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2162, 1950,   32,  531, 1426,    1, 2174,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  650, 1976,  514,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  664,    1,  856,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3173,    1, 2779, 1911,  166,    1,   37, 1758,   37,    1,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  716,  720,   32,  737,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2078,    1,  357, 2395,  166,  974,  215,    1,  267, 2971,\n",
      "            1, 2896,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  398, 1707, 2998, 2819,  625,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  894,   52, 1370,   45,  644,   46,    1,  621,  267,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2918, 1167,    1,  411, 3024,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3349,  863, 2104,   32,    1,  187,  582,  939,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2638,    1,   28,  452, 2874,    1,  506,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123,  361,  453,  542,    1,  384,  477,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   42,  149,    1, 1126,  693,   37,  302,  479,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1, 2196,    1,  957,  686,  220,  885, 2738, 1465,  595,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1920,    1, 1976,   32, 3155,    1,   51,   52, 3347,    1,\n",
      "         1383,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  645, 1718,    1,  619, 2976, 2973, 1764,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  986,   79,   98,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2339, 1108,    1, 3043,  161,  133, 1551,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2126,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783,  744,    1, 1888,  693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  863, 2409,    1, 1013,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2802,  396, 2674,  726,   32, 3145,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2307, 3218,  656, 1061,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1427,   32, 1194, 1249, 3209,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  108,   45,  730, 1777,  861,  126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,  459,   28,    9, 2025,  784, 1069, 1208,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,  37, 619, 537,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  69, 921, 548, 163,   1,  12,   1,   1,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  515,    1,  714,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1,  469,  313,   37, 1289, 2604,  626,   37, 1219,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   37,    1,  388,    1, 1886,    1, 3076,  719,   37, 1805,   28,\n",
      "          453,  317,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,  538, 1211,   91,    1,  632,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   31,  423,  300,    1,  242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  365,    1,   32, 3379,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  315,   37, 1046,  166, 3322,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  353,    1, 1146, 1703,   71,   32,  601,  401,  244,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2246, 3120,  726, 2513,   32, 1559,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089, 2530,  176,    1, 1710,   52, 2502,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,  945,   69,  475, 1061,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  335,    1,    1,    1,  873,  171,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  437,  396, 1887,   45, 1056, 1485, 3365,   32,  531,  202, 1327,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  459,    1, 1658,    1,    1,  105,    1,    1, 1421,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  301,    5,  625,  788,    1,  972,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497,    1,   32,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  971,  477, 1401,   37,  436,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   37, 1313,   37,  395,  297,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  777,  773, 1685, 1378,  818, 1064,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  606,  547, 2427,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1583,  105,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1951,    1, 1539, 3163,   37,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32,    1,  336,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796,  458, 1713, 1523,    9,  674,   45, 2448,  386,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3171,  738,  220,  730, 2614,    1,  361, 3238, 1564,  105, 1330,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  375, 1536,   59,    1,  149,  444,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  885,  211,    9,  148,    1, 2750,  328,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,    1,  195,   27,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  946,   45,    1, 1086,    1,    1,    1,   45,  336,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,  140,  131,   24,    9,  179,  779,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1973,  671, 3126, 2315,    1, 1464,    1, 1463,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  198, 3087, 2478, 1850,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1053,   51,  317, 1427,    1,  996,   93,   32,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  367, 2402, 2549, 1220,   28,  995,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3340,  104, 3091,  820,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2803,  105,   74,   63,    1,   12, 2237,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1086,  211,    1, 2669,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302, 1712,  387, 2819,  792,  680,  674,  792,   32, 1056,  537,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3248,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302, 1963,  696, 1539, 1013, 1522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,    1,  218, 1166,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1587,   45,  163,    1,   12,    1, 2128, 2129,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  176,  177,  228,    1,    1,   32,  166, 1549,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  718, 2838,  872,  420, 1352,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  710,    1,    1,   37,  930,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  681,    1,    9,   22,   23, 1821,    1, 1604,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,  103, 2334,    1,  187, 2957,  953,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3014,   37,  877,  183,  978,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  304,    1,  818,   15, 1347,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  361, 2275,   37, 1046,    1, 2911,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1100,  936, 1560,   37, 2904,   28,  593,   37,  116,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 3102,  513,   37,    1, 1861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3191,  361,    1,    1,    9,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  750,  178, 1887,   45,  103, 3374, 1178,  190,    1, 2095,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  610,   37, 1204,  191,    1, 1786,  361,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640,  166,    1,  176,    1, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2164,    1,   51,    1,    1, 1687,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  420, 1087,   37, 2446, 2587,  657, 2336, 1151,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1920,    1, 2742,   12,    1,   98, 1095,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  284, 1937, 2676,   12, 2095,    1,  187, 2047, 1560, 1160,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 3109, 2390,    1,    1,    9,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  402,   98, 2650,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   37,    1, 1994,    1,  625,    1,  566, 1789,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  232,    1,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2700,  449,   32,  593,   37,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  424, 1981,   98,  844,    1,  538,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3253,   81,   37, 2315, 1262,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2230,    1,   32,  591,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2000,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  679,   69,  420,    1,  102,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228, 2572,    1,  583,   32, 1815, 1656, 2960,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 1594,   32,  758,    1,  220,  447,  297,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  342,  665,  296,   20,    1,   98,\n",
      "          429,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  715,    1, 1287,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1720, 1629, 2940,    1,  137,  335, 1318,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1412, 2287,  320, 2869,    1,  460,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1,  464,  232, 1800,  396,   45, 1610, 1461, 1463,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  529, 1251,    1,  340,    1,    1,  176,  795,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2034,   28,    1,  155,  570,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2278,  884,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  778, 1166,    1,  254,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1987,    1, 2807, 1247,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  490,  220,   22, 1260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,    9, 1527,  384,  876,  612,  574,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,   21,   22,   23,   24,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  562,    1,  320,    1,   61,  193,  105,    1,    1,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2681,    1,    1, 3265, 1857,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  358, 1070,   37,    1,  474,    1,    1,    1,    1,  869,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2347,   32,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1164,   45, 1568,  365, 1675,    1,  191, 2086,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1442,   37, 2929,    1,  150,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  103,  590,    1,  872,    9,  449,  199,  452,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2817, 2856,  176,  177,   32, 3349,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2489,  365,    1, 2866,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1602, 2305,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1236,  777,    1,  297, 2819,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  418,  548, 2275,    1,  104, 2823, 2107,   37,   10,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  354, 1052,  202,   79,  308,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  868,  166,    1, 1488,  763,    1,   10,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649,  535, 1004, 1429,   32, 2003,  230,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1531, 3079,  872,  420,  367,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  207,   85,    1,    1,  156,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613, 1702,   39, 1615,  328,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1700, 3006, 2572,   32, 1388,  220, 2018, 2924,   27, 3343,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 1138, 1152,   45,    1,   32, 1515,  156,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  806,   32, 1459, 1743,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2297, 2565,   45,  166,  356,    1,  361,    1,  483, 1493,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1310,   37,    1, 2604,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,  105, 1034,  303,    1,   60,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1008,    1, 1633, 1499,  475,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,    1,  294,  562,   95, 2032,   37,  470, 1325,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2,  69, 338,  37, 339, 340,  98,   1, 104, 341,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 517,   1, 331,   1,  12, 156, 565, 800, 315,  37, 125,   1,   4,\n",
      "          32,  91,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  632, 2924,   64,   36,  187, 3365,  271,   39,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1512,   32, 3118,    1,    1,    1,    1,  233, 1407,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1717,  700,  213,   37,  151,    1,   12,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465,  861,  496,  782,    1,  910,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2956,    1,  365, 1952,  278,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,    1,  542,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  314,   37,  815,    1,    9,  149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,   45,  166, 2107,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,  469,   98,    1,    1,    1,  736,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3037, 2109,  442,   32,  388, 2342,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2708, 2153, 2237,    1, 3358,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  407,   37, 1056, 1034,  845,   98, 1057,  600,  679,  529,\n",
      "          109,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2909, 2620,   98, 3391,    1, 2751, 1260,\n",
      "           32,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1480,    1,   37,  686, 2458, 1387,  228,  537,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2561,   98,    1, 1027,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  346,  996,   29,   37,   16, 1161,   85,    1,   31,   28, 1114,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2175,  460, 1167,    1,   37, 2264,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 2308,  907,   37,    1, 1263,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  773,  603,   37,  221,    1,  844,   12,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294, 2705,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3118, 2396,    1, 1407,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,  166, 1631,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1035,  400, 1508, 2221, 1976,  193,  514,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1254,  454,   37,    1, 1001,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  425,  426, 2055, 2333,  676,  117,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1542,    9,  331, 1821, 2286,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  746,    1,  758,    1,    1,    1,  361,    1, 1074, 2274,    9,\n",
      "            1, 2913,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1404,  513,  514,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,   96,  661,   37,    5,  625,  788,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2813,    9, 3088,    1,   45, 1090,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32,    1, 2137,   32,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3199,    1,    1,  140,  885,    1, 2107,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2317,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  454,  105,    1,   45, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1934,  622,  475,  288,    9,  232, 2784,   37,  854,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  400,   32, 1186,  190, 2199,  104, 2251,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  923,    1, 2999, 1994, 2819,  777,  778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1072, 2664, 3340,   32, 3339,  787,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  755,    1,  365,  111,  834,  778,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1844,   61,   81,   32,    1,  361, 3228,  565,   81,   32,  449,\n",
      "          913,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  566,    1,    1, 3328,   32, 2250,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3231, 1508,    1,    9, 1056,  388,  537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1024, 1831,   37,    1,  183,    1,  176, 1163,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567, 2095,    9,  215,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,   39, 2119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2551,  664, 1449,   37, 2961,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  716,  449, 1023,  207,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938,  992,   85,  176,  941,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1022,   43,    1,  444, 2858, 1263, 2819,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  160, 1161, 1226,    9,   72,  339,   32, 1352,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  636,    1,   37, 2051,  763,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3298,  140, 1796, 1938, 3197,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,    1, 2798, 2943, 1499,  220, 1539,   45,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2500, 2953, 2300,  338, 1315,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,   12, 1508, 2469,    1,    9,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  447,  190,  193,    1,  582,    1,  625,  528, 1004,  384, 3345,\n",
      "           32,  531,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  612,  613,   37,  693,    1, 2665, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1817,    1, 2629,  713,   98, 1023,    1, 1011,  260,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2470,  782, 2538,   32,  403, 2735,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777,  614,    1,   37, 1291,  365, 1644,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,    1,   45,    1, 1342,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  978,  769,  526,  548,  425,  426,  570,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,   45,  463,  464, 1300,    1,  477, 1604,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3069,  515,    1,   28,   37,  531, 2699,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2322,  288,  548,  829, 1443,  319,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2752,    1,    1,  798,   45, 1254, 1473,   28,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2239, 1027,   85,  102,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  715,  112,    1,   30,    1,   98,   93,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,    1,  116, 2542, 2928,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3013, 2540, 1440, 1022,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800,    1,  580,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1937, 1018,  439,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1412,    1, 1348,   37,  664, 1737,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2450,   37,    1, 2712,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,   90,  864,   37,  899, 2390,  210,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 2450,   37,  946, 2673,  529, 1017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 1698,    1,   45,    1,    1, 1822,   52,   66,   37,   52,\n",
      "            1, 1160,    1,  150,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,    1,  971,  420, 1121,  339, 1796,    1,  504,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2700, 1171,    1,  927,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  267,    1,   37, 1674,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3015,  782, 1354,    1,    1, 1724,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3241,    1,  548,  166, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  391, 1329,   37,  877,  810,    1,  974,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596,  640,  163,    1,   12,    1,    1,   32,  531, 1530,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2805,    1,  610,   37,  537,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  213,   37,  599,    9,  378,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2317,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  147,   57,  365,  741,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  191, 2936, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105,  183,  686,   32,  865,   37, 2340,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1204,    1,  166,    1,  361,    1,  203,    1,    1,  166,  183,\n",
      "         1574, 1821,    1,  150,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  218,   98,  119, 1844,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  502,  765,    1,   37,  854,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190, 1289,  259, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   22,   23,    1,    1,   45,    1,   44,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1009, 2055,   91, 2579,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1252, 3130,  162,  973, 2072,  260,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3172, 1090, 1829,    1,  176, 3166,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  649,    1,  224,  550,    1,  267, 1063,  437,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1723, 1542,   37, 1470, 1405, 1534,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3227,    1,   12,    1, 2760,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,   12,    1, 2908,    1,  108,   98, 2095,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 829, 134,   9,   1, 157,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 294,  22, 387, 131, 388,  32,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1645,  957,   37,  125,   48,   32,   22,  447,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  195,  321,   52,    1,  220, 1130,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  812,  484,   37,  168,  220, 2583,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2135, 1974,  285,   32,  531, 1969,    1,   45, 1527,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1854,    1, 2827,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  455,    1,  121,   37,  664,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1236, 2931,  923,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   28, 3238, 1564,  593, 2522, 2218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  503, 2257,    1,  195,  384,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2447,    1,   79,  198, 2497,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2352, 3194, 3195,  389,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796, 2024, 3397,   32, 1364, 1365,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  217,    1, 1055,  931,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   28,   98,  642,  643,  550,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3086,    1,    1, 2297, 2525,   45,    1, 1624,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,    1,  148,  279,    1, 1294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 2391,  176, 2539,  105, 3048,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  472,  193,    1,  384,  166, 3185,  947,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  325, 2618,   12,    1,    9,  104,    1,  331,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,  313,   37,  125,    4,    1,  720,  105, 1153,  361,  194,\n",
      "          138,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1231,  297,    1, 3005,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  402,    1,    1,  361,    1,   98,  166, 1264,    1, 1264,  777,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,    1,    1,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1631,   39,   45,  701,  187, 2615,    1, 2796,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2313, 2414,  547,   32,   36, 1939,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2341,  913,   32, 1411, 3116, 3217,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2977,   12,  627,   61,  677,  384,  166,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1343, 2155,   28,  187, 1684, 1625,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307, 1713, 2341, 1412, 1102,  841,  437,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  935,    1,  331,    9, 1273,    1,   32,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,   15,   71,   98, 2079, 1220,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  297,  864, 2108,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  716,    1,  118,  197,   92,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3286,    1,  691,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1136,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,  835,  613,    1, 1873,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1505,  669,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2161,  877,    1,   32, 1089, 1090,  293,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  822,  533,  125, 1159,    1,  260,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652, 1536,    1, 1350,  149,  444,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428, 2649,  582, 1564, 3118, 1727,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  862, 1443,  774,  365,  261,   51, 1251,  112,   17,  182,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 2308,  474, 1536, 2967,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  638, 1574,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1531,   12,    1, 1827,   39,   32,  166,  984,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1087,  162,    1, 1307,  460, 1259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1591,    1, 1126,  167, 1083,  152,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1056,  569,    1, 2651,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 1564,    1, 1173,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3377,   12,    1, 1564,  885, 1377,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   64,  120,  640,  163,    1, 1741,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2977,  880, 1702,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2331,  600, 3331,  627,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3013, 2850,    9,  698,  176,  365, 1212, 1282,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  952,   37,    1,   39, 2095,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  484, 1494,   32,  148,  951,    1,    1,    1,  148,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2920,   37,  698, 2791,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  347,  729,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  572,  156, 1150,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1789, 1550,    1, 1958,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,   61, 1542,    9,    1, 1159,    1, 1218,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1281,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  896,    1,    1, 2731, 1560,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2282,  722,  290,  765,   37,    1,  458,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  407, 1159, 1823,  662,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2637,  113, 1186,   37,   98, 2410,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,  810,    1,  220,  105,  227, 1990,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1718, 2232,   15,  686,  105,  365,  845,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  684,  420,  782,  590,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  331,   12,  332,  752,  288,  176,  552,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 1447,  396,  403,  967, 1465, 2964,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1001,  920,    1,    1,   37,    1,    1, 1916, 1428,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1586,  361, 2058,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035,   12,  611, 2349, 2099,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1751,  267, 1674,    1,    1,  612,    1,  191,  195,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2885,   12,  119, 2098,  914, 1258,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1405,   12,  508,   37,  606, 1056, 1916,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3204,  682,  581, 1385,  176, 2490,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 1306, 2565,  267, 1628,    1,   32,  166,  608,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,  155,  142,    1,  744, 1332,    1, 1757,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117,  741,    1, 2339, 1958,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  446, 1458, 2970, 1090,  290,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  340, 1722,    1,  114,   46, 1174,   32, 3339,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3266, 1670,    1,    1,  917,  920,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1448,  633,    1,    1,  778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   22,  298,  640, 3076,  872,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  972,   37, 1306, 2579,   45, 2468,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1000, 1019,    1,   32, 1212,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1089, 1675,   15,   28,  419,   32, 1332,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3384,  475, 1941,   32, 3101,  477,   32, 3339,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  542,    1,   37,  151,    1, 1767,    1, 2692,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  968, 1809, 1647,   98, 1228,  970, 1027,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3253, 2120,    1,  384,  163,    1,   12,    1,   26,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  140, 2161,   12,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1190,    1,  949,   45, 1537, 3365,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2213,    1,    1,  565, 2758,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   14, 1377,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   12,    1,    1,  705, 1069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,   69,  102, 1910,   25,  410,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  613,   29,   32,  105, 1101,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  564,    9, 2419,    1,  754,    1, 1443,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1665,  300,   69, 2066,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  162,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2975,  494,   98,  848, 2371,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1,    1,  384,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1966,  398,  134, 1899,   32,  663,  400,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504,    1,  232, 2162, 1950,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2883,  300,  195,    1,   37,  104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1439,    1,   12, 1368,  288,  176,  331,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2615,  335, 2522,  297, 3108, 3231,    1, 3260,  726,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  975,    1,  391,    1,  977,  866,   98, 2317,  357,  125,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3260,   81,   32, 2941, 2107,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,  140, 2161,   12,  680, 3096, 1684,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3021,  140, 1674,  199,  776,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   61,  105,    1,    1,  193,  105,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1405,  518,  475,  796,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485,  947,  877, 3109,   32,    1, 2262,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1, 1987,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3373,    1, 1976,   32,    1,   45,  440,  632,  880,  365,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  721, 1098,  796,    1,    1,  369,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1115,  433,  218,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 3155,  913,   45,    1, 1924, 2343,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2692,  164,    1,  166, 1255,  187, 1090,  614,   98,  333,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1778, 2762, 1396, 2987, 1748,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   47,  118,   48,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2395,    1,    1,    1,    1,    1,  395,   12,  365,  551,    1,\n",
      "         1740,  792,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  794, 1211, 2492,    1,  552,  552,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 1585,   27, 2877,    1,   32, 2597, 2414,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  760, 3155,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2039, 2354,  297,  795,   12,  365,    1, 1469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219, 1013,    1, 1013, 1522,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  606,   37,  168,   39,  361, 1421, 3177,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  420,  782,  590, 1534,   45,  531,    1,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  734, 1660,  176,  639, 1167,    1,  573,  315,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089, 2691,    1,  176,    1,    9,  449,    1,   45,  365, 2692,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3242,    1,    9, 2309,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1445, 2803, 3265,   32, 2760,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2705,   32, 3118,  167,  759,    1,    1,  104,  232,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1779,  614,    1,  220, 3189,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  565, 1284,  166, 1263,    1,  111,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  293,  420,  945,    1,   37,  429, 1611,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  393, 1858,  138,    6,   51,  193,   52, 2398,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   26, 1167, 1339,  460,   12, 2492,   98,  166,  221,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  625,   32,  649, 1223,  548,    1, 2856, 1312,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,   37,  125,    1,    4,    1,  335,   44,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  550, 2425, 2418,   28, 1883, 1228,    9,    1,  131,   32,  225,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  926,  400,    1, 2849,   98, 3405,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2899,   37,   47, 1273,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,    1,    1,    1, 1463,  851,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  487, 3222, 2562,    1, 1757,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  397, 1707,  105,  104, 1377,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  649, 1295, 3156,  548,  114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2670,    1, 1654,  856,   98,  225,  809,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2885, 2619,  123,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  420,   49,   37, 2199,    1, 1588,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2110,   37, 1468, 3141,  810, 1292, 1090,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144,  828,  498,   37,    1, 1506,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  681,  420,  183,  197,  641,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1228,    1, 1778, 2515,   37,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  654,  776,    1,  162,  466,  187, 1143,    1,   83,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479, 1203,  600,    1,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1232, 2226, 1851, 2582,  105, 1067,  105,    1,    1,    1,  105,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  828, 1210, 1603, 2078,   45, 1117,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   75,  313,   37, 1198,    1,  613,  259, 1281,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1043,   28,    1,  419,    1,  407,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1699,    1, 2612,  166, 2438,    9, 1811, 3024,  111,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,  182,    1,  590,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  667, 1407, 1563,  220,    1,   37, 2834,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  954,  897,  176,    1,   67,   32,  572,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3108, 2712, 2838,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3302,  680,   97,   37,    1,   39,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  187,   66,   98,  844,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3115,  193,    1,  202,  321,  168,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   12,  987,    1,  221,  167,  698,  468,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32,  298,   45,    1,  880,   32,  942,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  542,  588,  230,  207,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  938,   37,  319,  941, 1201,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1583,   37,    1, 1281,   98, 3344, 2708,  861, 1414,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3143, 1831,  812,    1, 1024,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  681,  686,    1,  220,  149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  880, 2421,   27,  691,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  515,  105, 2460,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  691,  919,    1,  861,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   11, 1158,    1,  590,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,  379, 1013,   49, 1132, 1219,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2871,    1,  967,    1,  247, 2308,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  411,  631,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  837,  124, 1281,  818,  862,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3384, 3149, 2774,  650,   37,  168,   98,  776,    9,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  582,   37, 1739,   37,    1,  622, 2377, 2063,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2977,  361,   20,  973,    9, 1480, 1975,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1661,  704,  222, 1536,  786, 2017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,  225,  418,  669,   37,    1, 1244,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2733,  920,  251, 1211,  116,  259,   19, 2560,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  528,  224,    1, 1366,  729, 1188,  227, 1410,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  293, 2896,  267,  677,    1,   51,  583,   93,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1, 1109,   50,  616,  104,  372, 1126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2380,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 2153, 2035,  442,    1,   32,  864, 2673, 2426,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1377,    9,  323, 2288,    1, 1281,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,  221,   61,  326,  330,   37,  151,   39,  136,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1776,    1,  333,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1885,   37, 2535,  192, 1463,  220, 1698,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  342,  147,   37,    1,    1,   12,  802,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1919,    1,    1,  187,    1, 1258,   32, 3349,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1343,  220,  777,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   28,   32,  218,  714,  548,    1, 1126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,  213,   37, 2707,    1,   46, 1411,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226,  331,  193,    1,    1, 3170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  642,  643,  245,  187,  644,   57,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  105,   74,    1,    1,  338,    9, 3079,    1,  166, 1223,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  458,    1,  209,  354, 1356,    9,  449, 1056, 2033,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2962, 3175,    1, 3256,   37,   27, 3220,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  167,  865,   37, 3209,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,    1,  197,   28, 1408,  570,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2779,   98, 1434,    9,   72, 1684,  220,    1,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884, 3077,   32, 2472,  455,   12,    1,  140,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  500,  420, 1158,   12, 3049,  686,  152,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2959,  688, 1957,   32, 3141, 2592, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  219,    1, 2192,  864,  915,  916,   37,   18, 1805,   98,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  861,  729,  383, 1139,  220,  460, 1604,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1937,  388,  495,    1, 1633, 1278,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12,    1,    1,  453,  449,  163,    1,   12,    1, 1273,\n",
      "         1074,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  487,    1,  588,   37,  439, 2114, 2884, 1281,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2722,    1,   37,    1, 2439,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2999, 2257, 2194, 3050,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2690,    9,  333,   98,  777,   12,  938,  218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  803,  992,    1,  183,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  997,    1,  384,  247, 1691,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1542,   37,  714,  220, 1971,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1904, 1149,  439,  477,   32, 1895,  787,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  108,   45, 2786,    1,   32, 2987, 1748,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  389,    6,   71,  981,   32, 1332,    1,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1997,  105,    1,    1,   98,  105,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 2414, 3374,   12,  103, 2596,   13,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 3264,  796,    1,  389,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593, 1990,    1,   37,  619,  388, 2172,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1100,  256, 1273, 2403,   37,    1, 2340,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 3109,    1, 2729, 2764, 2765,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,  365,   17,  565,   32, 1223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  301,    5,  132,  765,  115,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1000,    1,  150,  112, 1013, 1522,  256,    1, 2943,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1401,    1,    1,   37, 1194,    1, 2241,  957,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3175,  899,    1, 2198,  138,    9, 1694,   45,  914,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1277,    1,    1,  190,  865,   37,  163,    1,   12,    1,    1,\n",
      "          202, 1360,  612, 2446,  176,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777, 1008,  365, 1644,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1398,  612, 1844,  384, 1167,    1,    1,    1,  460,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  813,  954,  680,   10,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  580, 2081,   32,  487,  957, 2500,  663,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3169,   32, 1183, 2921, 2069,  548,    1, 1987,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2086,    1, 2354,  187, 2733,  776,  891,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564, 1735,  218,  714,  409,   88, 1332,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1955,   37, 1155,  365,    1,   32, 1771,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  375,    1, 2849,  297, 2498,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,   20,  232,  610,   32,   22,   23,   24,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2551, 3307,  860,    1,  202,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3326,    1,   39,    9,    1,   45,  914,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  127,   98, 3102,  798,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 1046,   45,    1, 1064,  187, 2821,  361, 2948,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   45,    1,   12,  572,  197,  407,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428,  663,    1, 1248,  927, 1159,    1, 2891,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2680,  200,  861, 2750,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 1396,  777,    1,  187,    7,   93,  274,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1585,    1, 1295,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2192,    1,  454, 1018,  823,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  313,   37,  470,  112,  997,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2, 590,  69, 636, 423,  63, 104, 806,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,  98, 224,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1029,   12, 1459,  140,  480, 1743,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1411, 2240,    9, 1317,  792,  704,  792,  104,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  868,  132,  220,  104,   32,  636, 1336,  927,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3215,  551,    1, 2297,   98,  593, 1863, 1139, 1638,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    8,    1,  304,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,    1, 3103,  202,  267,  204,   12, 1036,    9,  854,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   66,  699,  242,   69,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2599,    1,    1,   16,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  647,    1,   51,   52,    1,  148,   12, 1521,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,  972,   37,    1,   28,  347, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2, 305,   1,   1, 954,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 542,   1, 742, 142,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,    1,    1, 2921,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,  321,  427, 2427,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  612,  716,  131,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  848,    1, 1163,    1,    9,  455,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1867,  693,    1,  753,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2752, 3392,    1,  548,  531,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1672, 1464,   37, 2446,  832,   32,  331,  551,   12,   15,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  251,    1, 1013, 2310,  758, 1013,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1462, 3069,    1,  121, 1207,   37,   92, 1994, 2095, 2532,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1557,   37,  654,   84,   85,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   32, 1023,  191, 1740,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3188,  338, 1139,   32,  714,    9, 1110,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3359,   37, 1505,  365, 3057,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447, 1542,   37,  764,  388,   32,  531,  811,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3381,  437,    1,  786, 1796,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,    1,    1,  872, 1294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2226,  331,  590,    1,    1,  267, 3084,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2476,    1, 3347, 3340,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2357,    1,  191, 1339,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228, 1873,    1, 1666, 1126,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,   37,  427,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2942, 1231,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2476,  361,  492,  477,  671,   32, 3292,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141,  810, 1292, 2967, 1713, 1668,   32, 1700, 1863,  442,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3277,  891,  443,   45, 1886,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 2455,  744,   28, 2456,   32,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  479,   15,   79, 1114,   32, 1352,    1,  202,  669,    1,   98,\n",
      "          365,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  698,   28,  793,   57, 1117,   12,  187, 1370,   45,    1,  131,\n",
      "          132,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,   37, 1664, 3343,  229,  442,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  593,  830,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1100,  794, 1273,    1, 2403,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  936,  365,  340,  439, 2232,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1662,    1,  515, 1067,   37,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  174,    5,   37,   52,  125,  191,  402,   37,   92,  954,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  446,   32,    1,    9,  105, 1056,   74, 2237,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758, 1013,  614, 1273,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3101,    1,  491, 3339, 1223, 2708,  178,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2160,   45,  666,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  773,  693, 1735,  818,  157,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  162, 1217,  384,  647,  253,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  531,  741,    1, 1229,   98, 2462,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  867,    1,  552,  552,  725,  220, 2039,  361, 3109,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 2036, 2410,    1,    1,   37,  930,  384, 3192,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2802,   37,    1, 3072,    1,    1,  437,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2753,  187, 3120,  103, 3219,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  990,   12,  449, 2650,  400,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106,    1, 1013,   32, 2492, 1626,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1090, 2838,    1, 3079,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885, 2240,   32,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3042,  161, 2567,  437,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,  613,   37,  130,    1,  728,    9,  131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1191, 1515,  454,  378,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1, 1182,    1,  911,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  921,    1,  449, 2760,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   51,  504,   98, 1801,   65,  190, 1083, 1184,  347,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  778,    1,   32, 2741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2245, 3306,  387,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2725,  251,    1,  753,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1,   38, 3191,  449, 2712,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,  657, 2336, 2747,    1,    1, 1087, 2168,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51, 1389,    1, 2130,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   14,   15,   28,  699,  187,   76,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447, 1627, 3102, 1512,   46,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2881, 1778,    1,  166,  454,   37,  168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  149,   37,  168,   37,  776,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3025,   12, 2069,  844, 1727,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783,   76,   37,    1,    1,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  982,    1, 2699,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387,  417,   69,    1,  493,  568,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    7,  365, 2741, 1675,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2376, 2024, 2223,  855,    1, 2383,  706,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1457,  782,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497,    1, 1879,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147,    1,  163,    1,  903,    1,   98, 1338,   45, 1346,   37,\n",
      "         1527,   32, 2208,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232,  565,   85,  361,  588, 1198,  384,  542,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1862, 1167,    1,  321,    1,  166,  389,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1113,    1,   69,  550,   77,   25,  410,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2707,   81,   98, 1171,    9,  342,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3190,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1727, 2007,   32,    1,  225,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,   37,    1,  365, 3144,  863,  602,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  107,   37,    1,  805,   45,  104,  863,   98,   69,  102,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  830, 2327,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  200,    1, 1013, 2549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2263, 1532,   32, 1051, 1039, 2690, 2607,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1178, 1458, 3118,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1956,   12, 2158,  952,   37,    1,   85,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  337,    1,    1,   12, 2059,   37,   52,   98, 2661,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,   32, 2102,    1,  624,    1,  215,    1, 1559,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 790, 476, 365, 506,  45,   1, 195,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 395,  12, 324,  37, 151, 326,  12, 327, 112,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1204,   61,  388,    1,  763,    1,    9, 2658,   45,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,   37, 1876,    1,   12,   26,    1, 2232,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  315,    9,  531, 1891,  550,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  220, 3078, 1987,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3149,    1,    8,  304,   37,  121,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2890, 2826, 3261, 1831,    1,  812,    1,   45, 1033,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  715,   25,  504,    1,    1,  191,    1,    1, 1117,    1,   98,\n",
      "         1062,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 3372,   37,  698,  889,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2484,  794,  943,  920,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   45,  507,    1,   50,   32, 1153,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1658,  499,  275,  550, 1108,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2593, 1499,    1, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  442, 1852,   37,  927,    1,  442,    1,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1429,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3184,  695, 2789,    1,  449, 1920,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1355,  972,  187, 1771,    1,  741,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3200, 1508,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1960,   37,   52,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2000,  163,   45, 1007,   12,    1, 1090,  444,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1823,  535,  716,    1,  572,   15,  361,  197,   93,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 733,   1,  50,  37, 104, 615,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 978, 769, 670,  98,  69, 122,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1298,    1,   32,  428, 2800, 1002,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3214,    1,   37,  271,  640,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,   46,   37,  151,    1,  551,  517,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,    1,  636, 1637,  452,  465, 1014,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  864, 2673, 3366, 1806,  693,  105,    1,  163,    1,   12,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 3254, 2394,    1,  272,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  732,  475,  459,   98,    9,    1,  818,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  773, 1275,    1,   15, 1488,  763, 1999,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1123,  154,  741,   98, 3251,  221, 1961,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,   28,    1,  155, 1470,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3186,  140,    1,   37,  429,   98,   37,  581,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,  712,    1,   37, 1330, 1090,   45,  903,    1, 1007,    1,\n",
      "         1417,    1,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  113,   27,  119, 1722,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   98,   81, 2380,  187,   29, 1867,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   85,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  162,  590,  764,  384,  943,    1, 1308,   37,  241,  340,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  113,  530,  109,  509,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1042,  156,  689,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,    1,  191,    1,  229,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978, 3138,  151,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1711,    1,    1,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1187,  424, 2244,    1,   32,    1, 1926,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2279,  113,   98,    9,   72,  726,   32,  186,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,   32, 2839,    9,  449,    1, 1684,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  294,    1,   16,  105,    1,   45,    1,  361,  846,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171, 1297,  827,  826,    1,  142,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1932,  952,   37, 1289, 1933, 1712,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715,  996,  471, 1071,   85,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1056,  569, 2192,    1, 1832,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  592,  593,  954,  288,    9,    1,   93,   32,  537,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  748,  726,  671,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 2170, 3109,  786,   32,    1,    1, 2673,  927,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  284, 2703, 2644, 3102,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  500,    1, 1191,  877,  132,  232,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2104, 1082,  388, 1799,    9,  104,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  183,    1,   32, 1090,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,  340,    7, 1674,  865,    9,    1,  375,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2710,  650, 1484,    9,  531,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  864,  190,    1, 2673,  210,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1277,  365, 3334, 2565,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  733,    1,   48,    9,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1457,  782,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  854, 2281,  361, 1529,    1, 2222,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3207,  267,  204,    1,  612, 1210,   37,  332,  810, 1425,  671,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1973, 2125,  260,  456,   85,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  861, 2538, 1976,   32,  116, 2542,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3185,  927,   45,    1,    1, 1750,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  859,   37,  221,    1,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2800, 2468,  475,   32, 2107,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2962, 1739, 2652, 2872,   45, 2916,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  794,  365, 3391,  868,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  848,  700,   28, 2979,  617, 1151,  315,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1802, 2122,    1,    1,  566,  227,    1, 1288,  138,   71,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 2173,    1,  136,  759,  895,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  746,  251,    1,    1,  220,  105, 2155,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 3254,  105,  227, 2810,    9, 1971,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  261, 1167,  441, 1822,    1,  225,  809,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  683,  103,  449, 2760,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,  225,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  857, 1567,    1,  163,    1,   12,    1,   32, 3096,\n",
      "          593, 1990,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2185, 2073,  401,   93,   37,    1,   67,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1, 2673,  639,  738,   37, 2000,  864,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  176,  425,  426,    1,  166,  365, 1357,   61, 1358,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,  606, 1183, 2113,  362,    9, 1227,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3021,  267, 2322,  190, 1048, 1590,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1936,  166, 1374,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3272,    1,   37,  759, 2592, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181,  387, 1151,   15, 1115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  953,  384,  119,  845,   45,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 3203,  321,  612,  439,  726, 3106,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2107,    1, 1260, 1391, 2047,   45, 3070,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115,  688, 3250,  202,  664,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2053, 2055,  245,  419,    1,   32,  385,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   28,  187,   69,  102,  980,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1123, 1242,  176,    1, 2162,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1886,  321,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2707,    1,   37,  221,   98,    1,    9,  342,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  171, 2570,  171,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  835,  539,  667,  624,    1,  459,    1,  220,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  275,   12,  750,    1, 1114,  548,  140,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  964, 1579,   45, 3144,   12,    1,   32,  342,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1577,  675,    1,   37,  572,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  746,   37, 1706,  131,   32,    1, 1901,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 1313,  952,  650,   12, 1596,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  284, 2708, 3080,  899, 3136,  477,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087, 1810, 3193, 2855, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3118, 3396,  774,    1,  920, 2567,  187, 2791,    1, 1428,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2672, 3318, 1510, 2277,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,   10, 1108,   32,  129, 2681,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3235, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2062, 1009,  936, 1743,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3010,  884,  590, 3080,    1,  140,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  251,    1, 2284,   45,    1, 2232,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  736,  192, 1639,    1, 1355,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175, 1031, 2225,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3359,  267,  190,  588, 3057,  220, 1384,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,    1, 1839,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1117, 1525,  509,  617,  259, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  259, 1159,    1, 2973, 1764,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1287,  176,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282,    1,    1, 3001, 1758,  202,  547,  440,    1,  245,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  742,    1, 1178, 1179,  142,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,  415, 2072,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  413, 1396, 1158,   12, 2102,   17,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37, 1539,  365,  803,  112, 1228,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1273, 1107, 1108,  794,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2110, 1249, 2642,   37, 2428, 2069, 2941, 1569,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,   37,  843,  905,   69,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1273,  259, 2264,  168,  297,  166,   59,  813,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3299,   32,  865,    1,  190, 1306,  698,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1038,    1,    1,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3175, 1031, 2225,   37,    1, 2722, 3074,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  180,    1,  179, 2000,  170,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   93,  680,  570,   32, 1913,  401,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1, 2615, 1174,    1, 1523,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2695, 2223,  872, 1666, 1539,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,   37,    1,  365,  617,  618,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  868,  845,   36, 2800,  872,    1, 2347,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1963, 1770,    1, 1135,    9, 2024,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1597,    1,  852,  115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707, 1454,  315,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  134,  297,   98,  430, 1665,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   37, 1075,  906,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2999, 2612,  777,    1,  327,  593,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  438,   37,  183,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,   69, 2861,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,   95, 1064,    1, 2459,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  604,   15,    1,  509,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  425,  426, 2599, 1169,   14,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   26, 3179, 2560,  590, 2476,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,   34, 1994, 2095, 1553,  176,  803,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  159,  698, 1515, 1034,  417,   32,  409,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1414, 2596,  531,   12, 3391,    1, 2833, 3381, 2431,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,  166, 1645,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3064, 1401,    1, 1159,    1,  401, 3179,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1123,  841,  288,  733,    9,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1327,  952,  976,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,  187,  105, 1108,   61,  697,    9, 1376, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3186,    1,  191,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1583,    1,  105,  776,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   91, 2245,  191,   94,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   32,    9,    1,  341,  187,  651, 1031,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2252,  331,    1,  399,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2175,   81,   37, 1698,  223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3092,   37,    1,  297,    1,  176,  680, 1912,   32, 2468,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,    1,   10,   98, 1951,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1824, 3046, 1917,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  286,  927,  533,    1,  225,  186,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3374, 2966,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1008,    1,   82,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   69, 1315,    1,  529,  408,  686,  954,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2015,  891,   32, 2890,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 1411,  183, 1265,    9,  957,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 3160, 2572,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1503, 2022, 1554,  215,  217,  220,  999, 1396,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2821,    1,   55,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3103,    1,    1,  774,  166, 1360,  612,  361, 2768,  193,  319,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3251,  190,    1,    1,  978, 1602,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  882,   37,  194,  265,   45,   48,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1294, 2297, 1254, 2334,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2043, 2962, 3014,    1, 1048, 1048,  661,   29,    1,    1,    1,\n",
      "         3004,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  884,   98, 1658, 2355,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  108, 1973,   37,    1,   45,  316,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,  517,    1,  405,    1,  552,    1,   37, 1947,  993,\n",
      "          302,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  193,  320, 2056,    9,  104,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,    1,   85, 3375,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1374,   32, 1395,  102,   76,   37, 1121,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,  729,  967,  566,   98, 2695, 2223,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1586,  579,  544,  334, 2898,   45,  166, 2452,   12,    1,\n",
      "         2436,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,  559,   79,  139,  471,   50,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  425,  426, 1458,   86,    1,   15, 1396,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2507, 1695,    1,  891, 1165,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1248, 1281,   98, 3153, 2220,    1, 3153,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  460,  729,    1,  612,    1,   32,    1,   12, 2742,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1940,   12, 3282,    1, 2308, 1758,  176, 1880,    1, 1990,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 1034,   12, 2462,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1081, 1419, 2147, 1260,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,   12, 2122, 1066,  297, 1861, 1819,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1003,   37,    1, 2551,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,  159,  439,   28,  640,  845,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,   37, 1636,  219, 2102, 1411,  339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,   20,  927,  703,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  388,  763, 1530,   32, 3339, 2329,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  476,  107,   37,  865,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  384,  224, 1126,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  796,    1,    9,  502,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2041, 2655,    1,  190,  576, 1407, 1726,   37,  539,  458,\n",
      "         1411,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   45, 2710,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3323,    1, 2590, 2961, 3265,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018,    1,   96,  444,  195,  293,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2067, 1515,  888,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  343,    9, 1224,   45,  471,  176,  618,   50,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2003, 1585, 2162, 1950,  418,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2578,  738,  756,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2692, 2094,   32,   59,    9,  829,   98,  453,  449,   74,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1, 2112,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1802,  159,  439,   28,  176,    1,  845, 1572,  191,  395,    1,\n",
      "         2115,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  187,  531, 1002, 1708,  891,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  515, 1092,  105,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2192,   81,  166,  671,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  177, 2144, 1530,  384, 1656, 2596, 2960,   27,  104, 1967,\n",
      "          123,   37,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1, 2390,    1,  590,  412,   32,  968,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 3400,  162,  776, 2306,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1498, 2360, 1099, 1453, 2089,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  166,  302,  176,  730, 1571,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1234,  967,  590,  516,    9,   19,  163,    1,   12,    1,\n",
      "         1461, 1462, 2892,    1,  963, 2122,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  387,   79,    1, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1524, 2147, 2950, 3060, 1061,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,  370, 1353, 2604, 1069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1902,  159,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963, 2161,   12, 2701,  872, 1993,  104,   37,  726,   56,  497,\n",
      "         1990,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  650,  952,    1, 1929,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2543,  395, 1512,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  854, 1566,    1,    1,    1,   37, 1815,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3039, 2431,    1,  928,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3359, 1707, 3374, 2756,  693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   91, 2545,  600,   37,    1, 1515, 1623,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  124,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1214, 3236,  872,  420,  385,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,  945,  952, 1746,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   12,    1,  865,   37, 2276,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   32,  104,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649, 1009, 1082,    1,   37, 2446, 3346, 2770,    1,  860,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1330, 1031,  967,    1, 2963,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  469,   37, 1079,    1, 1277,   37, 1334,   98,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 1110,   45,    1,  565, 2175,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  836, 1736, 1564,  453,  714,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   26, 1298, 1382,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9, 3298,  187,  204,    1,   37, 1918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612, 2116,   39, 2843,  415, 1724,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713, 1766, 1767,    1,    9,    1,  777,  412,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1339,  293,  640,    1,  187,  460,    1,    1,  218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,    1,   37,  288,   28,  290, 1159, 1147,  443, 1530,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  355,  431,  399,  220,  342,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885, 1518,   32,   98, 2843,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  531, 1260, 2414, 3094,   45, 1763,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2125, 1734, 2794,    1,   37,  563,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3140,    1, 1430,  360, 1407, 2081,   45, 2471,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,    1,  191, 2333, 1530,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  393,    1,  453,    1,   98,  734,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  497, 1421,  449, 3341,    9,  342,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    9, 2674,  356,    1,    1, 1401, 1833,   32, 1805,   22,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  485,   32,   46,  220,  215,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1414, 2102, 2264,   37, 1901,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1, 1658, 2177, 1027,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  758, 1867, 1697, 1013, 1522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   83,  267,  204,    1, 1143,  495,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  614,   79, 1316,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1, 1601,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1170,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,  227,   37,  168,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 756, 757, 475, 796,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  69,   1, 297,  98, 889, 509,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1236, 2902,  361,    1,   12,  297,  365,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   61,   32,  105,   11,    1,    1,  453, 1009,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1364, 1365, 1176,  198,    9,  463, 2170,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3034,    1,    1,   37,    1, 2988,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  325, 1412,    1,  669,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 1447,  267,   37,    1,   85,    1,   45,  403, 1585,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  665, 2080, 1705, 1750, 1116,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3108, 1838,    1,  220, 2872,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  190,  606, 1748, 2695,    1,  763, 3015,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  340,  347,   92, 2053, 2210, 1841,  754,   15,  759, 2073,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  964,  459,  302,   37,    1, 1839,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,  166, 2063,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,   47,  649,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2650,   98, 2310, 2402,    1,  320,  579,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  311,   12, 2118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   52,    1,   37, 1134,  844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3261,  909, 1056,  388,    9, 1994, 3185,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1290,  396,   71,  191,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3115, 1403,   81,    1,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567, 1080,   37, 1817,    1,    1,    1, 1452,    1,  763,   76,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  729, 2331,   32,    1,    1, 3130,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2169, 3279,  565, 2536,  191, 2592, 1950,   61,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  342, 1458,    1,    9,  442, 2027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,  460, 1924,  297,  320,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3158,  950,  580, 1463,  951,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428, 1327, 1390,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1737,  765,  187,    1,    1,    1,  691, 2578,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273,    1, 2446, 1139,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,  125,    1,    4, 1232,  590,  630,  220, 1149,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1699,    9,    1,    1,    1,    1,   61,  105,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1607,    1,  619,  166, 1778,  351,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,    1,  150,   51,   52, 1044,  453,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1086,   32, 2250,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1094,  267, 3339,    1, 1924,  105,  270,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3028,    1,  820,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3006,  798,    1,   45, 1645, 3073, 1220,  447,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,   28,   98,    1,    1,  844, 1151,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,  267,    1, 2673,  132, 2011,  220,  342,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800, 2753,    1,    1, 1103,    9,  547, 2013,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  790,  991,    1,   12,    1,    9,    1,  505,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1855,  700, 2257,   39,   45,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1963,    1,    1, 1936,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1478, 2410,  402,    9, 2468,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1084,    1,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  286,  170,  932,   32,    1,   59,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1214, 1664,  375,  307, 2172, 2791,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1043,  338,  419,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  880,  119,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,  628, 2163, 1523,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2136,    1,  411,  741,   32,  403, 2926,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2658, 2269,   32,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  778, 2421,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  159, 1150,   98,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2476,  686,    1,    1,  818,  914, 1268,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1584,   85,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1445, 1345,  451,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  758,    1, 2489, 2155,   28,  187,  460,  325, 1107, 2610, 1108,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,  103,  389,  176, 2977,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1121,  361,  816,    1,  166, 2107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100, 2776,    1, 2670,   98,    1,  769,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147, 1065, 1190,  108, 3155,   37, 2192,   28, 2764, 3381,  357,\n",
      "         1046,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3350,   45, 2949,   90,   45,    1,  267,    1, 1924,    1,  220,\n",
      "            1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2754,    1,  140,  601, 1674,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2388, 2726, 2206, 2207,  171,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3134,  914, 1281,    9, 2811,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  950,  574, 1137,    1,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2384,  669,  361,  280,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1212,  936, 2507, 2620, 2049,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  487, 2286,   37,    1, 1771, 2482, 2911,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1029, 1190,    1, 1124,   32,  107, 1069,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2446,  166,    1,  361,  698, 1278,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123, 2246, 3236,    1,  512,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  647,  721, 1707,  148,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 2695, 2223,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,   70,    1,  548, 1520,   71,   98,  984,  403,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  321,  544,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  474, 2767,    1,    9, 1610,  477,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,  794,  365,  777, 1085,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  678,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1054, 1055,  384,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  288,   37, 2728, 2229, 2232,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  921,  739,    1,   69,  170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1700,  104, 3111, 2572,   32,  531, 2596, 1260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1, 2018,  429,   46,   98, 1815,  336,  345,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056,    1, 2684,  176, 1580,  656,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  121,   37,    1,  861,    1,  588, 2532,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  454,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2279,    1,    1, 2179, 1737,   37,  138,    1,   37,  901,    1,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2368,   98,    1,   98,  572,  304,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,   12,    1, 1346,  741,   37, 1195, 1604,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2962,    1,    1,    9, 3115,    1, 3188,    1, 3244,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,    1,   98,    1, 1196,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  996,   93,   67,  338, 1139,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,  267,   46,  454,   37, 1814, 2096,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2,  91, 186, 548, 163,   1,  12,   1, 335, 411,  44,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 572, 197,   1, 191, 596, 759,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  433,    1, 2650,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3272, 3001,  176,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3209,  688, 3260,   37, 1452, 2522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  641, 2913,  289,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2638, 1976,  548,  455, 3087,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  681, 1003,   37,    1, 1718,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1663, 1674,    1, 1268,  549, 1159, 3185,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1109,  200,  365, 1273,  259, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   28,    9,  139,    1,  274,  379,  729,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 1065, 1190,  738,  220,  219,  474, 2153,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,    1,   69,  493,    9,    1,   54,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1432, 3207,  267,  147,    1,  204,   12,  105,  792, 2965,  792,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1100, 1604,   98,    1, 2670,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2675,   12,  103, 3210,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1033,   93,   37,  686,    1,  458,  267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2005, 1632,   37, 3204, 1463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1847, 1245,   61,   98,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  744,  837,    9, 1411, 1778,  659,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1537,  844,  663,   28,    9, 2479, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1715, 2201, 1558, 1021,  250,  260,   28,   37, 1620,\n",
      "           79,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  593,   12,    1, 1178,    1,    1,  730, 2614, 2408,    1,  928,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1807,    1,  495,    1,  506,  267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  310,  275,   25,  186,    1,   60, 1993,   28,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2658,   45,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1895,  787,    1,  361,    1,    1,   98, 2073,   74,   45,  477,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1412, 2273,   12,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2918,  493,  167, 1021, 1658,  754, 2700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  912,    1, 2506,    1,  167,   52,  166, 1851,  454,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  567,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2787,    1,    1,    1,  191, 3307,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1018,    1, 2810,    9,  105, 1277,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1090,    9, 1100,  784, 1151,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  992, 1159,  166, 1551, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2548, 1710, 2856,    1,    1,  267, 2688,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  183,    1,    1,   37,   44, 1443,  388,    9,  260,  412,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523,  634,   37,    1,  220,  770, 1064, 2885,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2062, 1557,    1,   37,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2977,    1,    1,    1, 1530,  176,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1100, 2071, 1331, 2436, 1391, 1151, 2107,  220,  657,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  947, 1761,  420,   45, 2658, 2269,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1010,    1,    1, 3157, 1542,    9, 2823,  741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,   12, 1016,   32,   46,   98, 3057,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  437,  315,   37, 1313,    1,  973, 3076, 1750,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  558,   27,    1,  182,  132,   37,  151,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2507,  741,   98, 3339,  105,   92,    9, 3093,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,    1,    1,  446, 1564,  460,  105,  402,   37,  907, 2161,\n",
      "         1492,    1,   37,  576,  234,  182,  235,    1,    1,    1,  234,  182,\n",
      "          235,    1,    3,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2994,    1,    1,  378,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  770, 1976,   32, 3391,  193,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3381,  166, 2095,    1,  202, 1187,  204, 2595,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  500,    1,    9, 1935,    1,  636,  443,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,   37, 2365,   39, 1013, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  720,    9, 1194,   74,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  625,   51,    1, 2459, 1766, 1767,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  159, 1150,   98,  197,  550,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1965, 1006, 1000, 1112,  176,    1,  608,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1013,    9, 3393, 2137, 2986,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  547, 3123, 2308, 1673,  191, 1328, 3265, 3307,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   77, 1245,   98,  492, 2153,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1,  449, 1273, 1140, 2587,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  439,    1,  579,  636, 1507, 1508,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,  123,   37,    1,  849,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,  551,  105,  829,  475, 1213,    1, 2881, 1370, 1056,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  327, 1828,   28,    1,  202,  983, 2051,  320,    1,  506,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  954, 2612,  128,   32,    1,   65,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  176, 2206, 2435,    1,  446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321,    1,  764,  730, 2614, 2222,  619,  105,  726,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2838,    1,    1, 2496,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  387,  365,  845,   32, 1033,  442,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  437, 2189,  557, 2613,   37,  619,  111,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1920,    1,  191,    1,   32, 2755,    1,    1, 2726,   37, 1000,\n",
      "          764,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1994,  443, 1953, 1392, 1432, 3025, 1263,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,   12, 2255,    1,   98, 2254, 2351,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  864, 1360,  612,    1, 2673,  529,  210,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1652,    1,   28,  453, 2355, 1718, 1228,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  159, 2401,   98, 1230,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453,   42,  400,   32,  560,  126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  200,  365,    1,    9,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  191, 2066, 2695, 2232,   15,    1, 2433,  219, 2232,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2909,   32,  531, 2856,  176,  177,  361,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2490,   37, 1211, 2832,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3286,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  223,    1,   37, 2199,  589,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,  404, 1564,  105, 1734,   37,   77,  453,  142, 2341,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  300,  753,   81,  754,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1768,  161,  700,    1, 1137,   32,  714,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3213,   37,    1,    1,    1, 2191,  915,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1366,   51, 1188,   37, 1664, 2901,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1875, 3356, 2751, 1594,   32, 2108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  295,   37,  125,    1,    1, 1636, 1663,  541,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2707, 1702,  115,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1615, 1378, 1250, 1268,   98,  179, 1074,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3310,  251, 1018,  516,   37,  405, 3291,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,    1,    1,    1,  416,  105, 1046, 1198,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  978,  769,  670,  187, 2034,    1,   69,  335, 1950,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  216,   32,  854, 2856,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  964, 1564,  449, 2237,   37, 2707,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800,    1, 2297,    1,   45,  166,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  967,  410,    1,   98, 3252,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 3103,  168,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2, 121,   1,   1,   1,  37,  47,  49,  50,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,   12,    1,  619,    1,  131,    9, 1805,   28,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1273,   37,  288,   28,    1,  517, 1074,   32, 2592,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  693,    9,  310,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   26,  178,  777,    1, 2544,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1450,    1,    1,    1,    1, 1984,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  246,   28, 1503,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3375, 2856,  547,  176, 1583,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,  952,  976,    1, 2109,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1778, 2515, 1876,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  386,    1,  562,    1,    1, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  479,   37, 1155,  365,  250,   32,    1,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,  199,    9,  284,  542,   37,  138,  105,  845,  636,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1478, 1479,  195,   13,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  621,  387,  156,  677,    1,   98,  851, 1220,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  572,  551,  105,    1,    1,    1, 2179,  586,    1,   98, 1513,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2145,   37, 2035,    1,  214, 1757,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  667,  446, 1707, 2266,  396,  531,  443, 2189,    1,    1, 1428,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  477,  105,    1, 1318,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  560,  347,  720,   37,  339,  340,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   89,   21, 1891,  764,  444,   69,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   60, 1408,  682,  444,   94,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545, 2250,  220,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2918,  190,   52,  915, 2923,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,   96,   28, 1245,   98, 3080,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755, 2937,    9,  117, 1714,   32,  365, 1697,  778,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1558,  187, 2868, 2770, 3349, 3143,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2584, 2225,    1,  187,  582, 2565,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   65,    1,    1, 1470,    9,  677,  104, 1184,  347,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  180,   12,  197, 1672,  191,   32, 1913,  401,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3249,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,    1,    1,  191,  996,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1645, 2559, 2192,  663,  726,   37, 1158,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713, 3079,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1933,   95,  473,    1,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2173,  335,  400,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1645, 1190,   61,    1,   37,  588,  949,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 3354,  446,    1,  528, 1860,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  354,    1,  191,   71,   32,  983,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2474,  259,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3282,    1, 1417, 2373, 3173, 1249, 3168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  107, 1726,   37,    1,  568,    1,  423,  191,   28,   37,  786,\n",
      "           59,    1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  743,   12,  155,  158,    1,  159, 1473,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1918,  363,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  910,  703,   37,  119,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  475, 2216,  242, 1448,  361, 1085,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  187,  166, 1831,    1,  388, 1574,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  730, 2614,   81,   32,  166,    1,    1, 1936, 1003,  176,\n",
      "         3132,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,    1,    1, 1056,    1, 3116,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  647,    1,   98,  105,    1,  142,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388, 2703, 2816,  557,  540,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,    1,  572,  244,   98,   69,  636,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3113,    1, 3381,   32,    1,    1,  722,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  920,    1, 2777,  105, 1298,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2176,  341,  327,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  920,    1,  321,  619,    1, 2693,    1, 1176,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  461,   12,  845,  275, 2866,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  755,   37,   47, 2341,  161,    1,   37,  856, 2964,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  732,  851, 1564, 1193, 2585,   32,  942,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2467,   45,  105,    1,    1,  565,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1971,  501, 1625,   37,  606,    1,  533,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2269,    1,  798,    1,   12,    1, 1268,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1210,    1,  191, 2148, 3194, 3195,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  215,    1,  176,  629,  384,    6,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2246,    1,  140,  528,    1, 2069, 1385,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1848,   37, 1335,  514,   32, 1102, 1151,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 1149, 1000, 2492,  105,  410,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,   22,  438,  972,   37, 1083,  529,    1,   82,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2957,    1,  326,   32, 2334, 2107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 243,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3321,    1,    9, 1252, 2807,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,  681, 1421,  183,  802,  220,  395,  202,    1,  166,    1,\n",
      "         1167,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3079, 1285, 3236,   32, 1264, 2799,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,  808,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1359,   82,  939,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,   32,    1,  776, 1924,    1,    9,  317,  176,  183,  721,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  187, 1001,    1,    1,   12,    1, 2575,  245, 1139,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 3126,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    9, 2688,    1,  105,  400,   45,    1, 2518,  176,  449, 1881,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  138,   59,   37,  439,  290,   45,  574,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1304,  958,   59,  399,  220,  422,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  467, 2092,  267,  386,  719,   37,  125,   59,  388,   32,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  446, 2770, 2147, 2950,  778,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  792,  501,  841,  792, 1274,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  565, 1658, 1509,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1394,    9,  103,    1, 2925, 2954,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962, 1340,    1,  754, 1844, 2174,   32, 1110,  726,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  666,   51,  211, 2978,  541,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  485, 2243, 1651, 1597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614, 1089,  775, 1897,    1, 2789,   32,  273,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2898,   63,  334,    1,  166, 1868, 1172,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  415,    1, 1628,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98,  121,    9,  242, 1069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2231, 1070,    9, 2144,  537,    9, 2893,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2984,    1, 1748,   45, 2820,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  267,  104,  167, 1413, 2673,  210,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  326, 1564,    1,  399,   32,  823,    1,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  614, 2071, 2880,   98, 1766, 1767, 3004,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  176, 1273, 1560, 3004,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  793,    1,   33,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12, 1887,  105, 1641,   37, 2764, 2765,    1,   61,\n",
      "         2793, 3380,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1924,   37,   52,   98,    1,  851,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  460, 1924,  415, 2398,    1,    9,  920,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 2651,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  854, 1810,  103,   56,    1,    1,   32, 1033,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  945,   69,   82, 1061,   32, 1053,    1, 1148,    1,  220,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3129, 1035,    1, 1401, 2957,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  951,    1, 2486,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  220,    1,    1,    1, 2843, 2523,    1, 3258, 2579,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,  288,   37,  714, 1089,    1,  617,  259,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   71,   98,  383,   69,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1964,  729, 1965, 1966,   12,  270,  724,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1647,   32, 3379, 1585,  927,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,    1,   82,  648,    1, 1342, 1359,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   12,    1,  187, 2764,    1, 1185, 1624,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  180,  943,    1,  114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  709, 2548,    1,  597, 1009,   12,  754,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,   37, 2122, 1319, 2153,   98,  903,    1, 1447,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  222, 2789,    1,    1, 1593,  187, 3268, 1844,  608, 1717,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2295, 1782,   37, 2474,    1, 2530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3172, 1090, 1829,    1,  176, 2570,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  857,  720,  696, 2321,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  104,   67,   70, 1253,   98,    1,   45,   65,    1,   32,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3272, 2779,   37,  726,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,   26, 1116,  656,   32,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428, 1002, 2911, 1354, 1210,    1,  531,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3405,  315,   74, 2699,   37,  557,  540, 2431,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  614, 2723,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,   12, 1952,    1, 2789, 1563, 1953,  891, 1010,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,   37,  125,  102,  548,  594,   15,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1408,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1007,   37,  151,    1, 2688,    1, 1131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 3225,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  792,    1,  792, 1976,   32, 1081,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1712,    1,   37, 1330, 2580,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,  672,    4,   32,  942,    1,    1,   32,    1,    1, 1810,\n",
      "         2300,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2814,   45, 2586,  187,    1, 1584, 2161, 3365,  168, 1211,\n",
      "           37,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  547,    1, 1260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1022,    1, 2296,  176, 1214,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1486,    1,   12,  390,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1764, 1990, 3282,    9,  104,  361, 2468,    1,  105, 1298,    1,\n",
      "          797,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2885,   16,  193, 1724,  297,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178, 1011,  633,    1,  105,    1,  187,  166, 2179,    1, 1119,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1053,   12,  954,  897,  191,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  446,    1,  612,   55,   37, 1937,  677,   60,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   51, 1910,    1,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1901, 2222, 2055,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  508,   79,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  422,  484,   98,  224, 1126,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  754,    1, 1672,   37,    1,  152,   67,   32,  385,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  845,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 1527, 1896,   32, 3349,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,  431,  741,   98,  302,    1,  993,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  402,   61,   27,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1159, 1393,   15,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  548, 2148,  612,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   22,  395,  459,    1,    1,  131,  296,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 2182,   39,    1,  315,    9, 1013,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2052, 2191,    1, 1902, 1247,  967,  505,    1,    1,   39,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3253,    1,    1,  183, 2232, 2100,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3241,    1, 3152,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447, 3396,  619,  104, 1217,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  294,  922, 2941, 1090, 1829,    1,  176,  273,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2068, 1976,  514,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1515,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103,  971,   51,  193,  606, 2300,  389,  861,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3094, 1231,   32,  973,  444, 2819,  361, 2574,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1484,    9,  388,    1,  663,   32, 2707,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3292, 3021,  140,  199,  776,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  603,   37, 1377,   37, 1185,  249,    1, 2261,  565,  707,    1,\n",
      "          361,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2108, 2014, 1159, 3118,    1,    1,  774,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810,  566,  190,   52,   98, 2981,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3281,   61,   81, 1166,  204, 1827,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,   81,   32,  103, 1505,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  355,    1,    1,  361,  342,  759, 1350,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2448,  386, 1086,   46,  220,  742,   98,  214,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  428, 2343,    1,   69,    9, 1011,  210,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  612, 1273,  127,   32,  176,  730,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  485, 2463,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  444,    1,    1, 1517,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2448,  386, 1761, 3177, 2825,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2881,  108,  310,  379,   45, 1718,  767,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1420,    1, 1812,  331,    1,  934,   32, 1966,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,  830,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  727,  613,   37,  151,    1,  728,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  987,  507,  325,    1, 1541,    1,  733,   91, 1501,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 2162,   32,  649,  845,   36,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  750,   25,   71,   98,   10,  863,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3069,    1,    1, 1421,  132,   37, 1155,  365,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,   12,  365,  673,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  430, 3357,  650,  267,  132, 2011,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783,  251,  411, 1888,   37,  163,    1,   12,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  236,  237,   25,  439,  242,   98,  198,  669,  156,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965, 2982,  729,  176, 1604,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  492, 2047,  354,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1268,    1,   45, 1516,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1440,   61,  193,    1,  810, 1488,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2397,  267,    1, 2455, 1745, 1610,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2936,  361, 3313,    1, 1056, 2954,  634,    1,  907,   32, 1717,\n",
      "            1,  424,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 1185, 3096, 2308, 1664, 3038, 2130,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3238,  719, 1857,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2565, 1924,   32,   98,  166, 2709, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  634,  220,    1,    1, 2650,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  590,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2240,    1,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3271, 1421,    1,  375,   37,  786,  356,  132,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,    1,  326, 1149,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  542,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1167, 2293,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  884, 1003,  176,  926,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  200,    1,    1, 1153,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1184,  347,   76,   37,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  925,  967,  183,  315,    9, 1766, 1767,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 1042,    1,  674,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2962, 3247, 1413, 1497,   32, 3220,  220, 2138, 1918,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3153,  104,    1, 2226,  190,  193, 1540,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   91,  361,  223, 2135,  408,  583,  517,    1,  331,    1,  156,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1851,  454,   37,    1,    1, 2673,  400,    1,  267,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2114, 1905,   32, 2275, 1708,  117,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2314, 3358,  614,   37, 2197,    9,  351,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2676,   61,  105, 2204,   23, 2072,   10,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  535,    1,  142,   37,    1, 3310, 2078,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  575,  321, 1807,    1,  802,   98,  365,    1,    9, 2063,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3183,  661,  103, 1569,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  441,  970, 1677,   37,  705,    1, 1417,    1,  442,   16,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2596, 1585, 2414, 1700,   32, 2018,    1,  947,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  408,  576,   25,  677,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,   12,  597, 1407, 1190,    1, 2868,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,    1,  651, 2537,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    4,  420,  167,  288,    1,   45,  218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  910,   37, 1539,  525,    9,    1, 2161,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3204,    1, 1159, 1569,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2597, 1585, 2414, 1312,    1, 2646, 1345,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  389,  693,    1, 2583,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  187,  512,   45,  539,    1,    1,   98,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158,  738,  148,   12, 2759,  432,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  354,   37,    1, 1022,    1,   61, 2162,    1,    9, 3301,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1,  453, 2336,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    7,   69,    1, 1207,   37, 1636, 1069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 1230,   12,  365, 2739, 2528,   16,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219, 2122,  231,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  968,  232,  566, 2339,  622, 1536,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,    1,  460,    4,  901,  452,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  160,  102,   28,   32, 1332,    1,  187,  493,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  774,    1,    1, 1194, 1856,   28,   37,  105,    1, 1176,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,    1,  395,   67,  423,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2908,    9, 1359,   12, 2263,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  766,  200,  365,  526, 2104,    1,  844,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2571,  474, 2396, 1953,    9, 2024,   32, 3118, 1268,   32,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1835,    1, 1344,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2956, 3017,  791, 1563,  884, 1601,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1354,  754,  327, 2264,  176,  629,    9, 1260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141,   37,  288,  365,    1,  861,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1085,  197,  407,  118,   98,    1,  120,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,    1,    1,  628,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1487, 1353, 1412, 1107, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1419, 2366,  279, 2355, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  938,  315,    1,  182,    1,  149,  297,  941,  721,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 1252, 2807, 3159,  501,  827,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2897,   27,    1, 2708,  650,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,  166,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  667,  446,   37, 2237, 1081,    9, 2823,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1932,   82, 2682,    1,  625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   58,   12,  572,  156, 1270, 2316,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1429, 1648,   32,    1,  403, 1447,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2080, 2675,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 2908,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1073,  548,  121,   36, 2426,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  245,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  755,    1,    1, 1458, 3042,  161,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3070,    1,   12,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3051, 2774,    1,  267, 2024,   46,  606,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  359,   37, 2904,  383,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3359, 1458,  399, 1219,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2512, 2227,  872,  794,    1, 2514,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3247,  361, 3248, 2260,  548,  547, 2033,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1075,  395,   12,  449,    1,    1,  187,  105, 1662,   98,    1,\n",
      "         1273,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,   37,    1, 1021,  191,    1, 2670,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3253,    1,    1, 1483,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1841,  140,  290, 1159, 1887,   45, 3082, 2059,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,   32,  103, 1638,   45, 2342, 2458,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1861,   32, 1850, 1423,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1045,    1, 3276,  774, 1444, 1445,    1,   98,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   55, 2441,  267,    1, 3132,  619,  707,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2171, 2800,   12,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   37,  138,    1,  331,  422,  399,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,    1, 3319,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3343,  861,   98, 2393,  115,   45,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 3055, 1159, 3293,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1342, 2083, 1132,  548,  217,  125, 1084,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2464, 2744,  111, 1197,  533,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3228,    1, 2803, 3265,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  951,    1,    1, 2222,    1,  105,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  112,  289,    1,  191,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3173,    1,    1,    1, 3230, 1758,  176,   26,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,   12, 3034,  162, 1561, 1876,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294, 1456,  716,  197, 1124,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1583,  313,   37, 2199,    1,  220,  326,\n",
      "         1294,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  253,   81,  214,  142,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1,    1, 1660, 2232,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3132, 2935,  404,   98,    1, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1815, 2024,    1, 2361,   32,  854,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3194, 3195,    1, 1440, 1022,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1547,  980,  699,  548,    1,  186,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2922,  162,  365,  872,  202,  967, 1690, 2101,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2164,  640,    1,    1,  284, 3307,  898,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,  247,  502,    1,    1,    1,    1,    1,    1,  202,    1,\n",
      "          105,  821,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  187, 3191,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  906,   12, 2677,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  961,    1,  176,  177,    1,  131,  202, 2599,   98,    1,    1,\n",
      "          267,    1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,  439,  417,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,  292,    5,  591,    1, 2136, 2682,   10,  119,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  225,  338,  187,  332, 2300, 1660,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3236, 2107,  608, 3266,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2164,   51,  606, 1532, 3024,    1,  104, 2700,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  198,    1,    1,  455,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2918,  493,   51, 1368,   39,  626,    1, 3024,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1091, 2091,  109,   45,    1,  361,    1,    1,   37,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1778, 2580,  328, 1797,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  670,    1,  197,  937,  817,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2807,  449,  123,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  267, 1499,  603,  176,  158, 1563,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  858,   37, 2401,   32,  365,  342, 2064,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1, 1581, 1766, 1767,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1807,    1,  495,    1,  506,  267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  268,   37,  439,  857, 1469,  740,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294, 1456,   37,    1,    1,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1053,    1,  829,    1,  614,   26, 1039, 3031,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61, 1277,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2605, 1980,   37,  498,   98,    5, 1631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  204,  361, 2279,  498, 1444, 1822,  624,    1,   32,\n",
      "          433,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2708, 2572,   32, 1656, 1585,  187, 3101, 1414,  335,  674,   45,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713,    1,   45,  192,    1,  773,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1115,  532,  686,  715,   93,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,   37,  130,  463,  464, 1611,  700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  990,    1,    1, 1294,    9,    1,  923,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 2108, 1665,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1010, 1523,  220,  148,    1,  647,  546,  453,  475,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1412,    1,  764,    1,  125,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1619,  458, 1408, 2204,  600,  453,   94,  809,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3128,  833,  612, 1807,  521,  443,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2, 328, 161,   1, 225,  28,  98, 165,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 572, 197,  28,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  942,    1,   32,   98,  104,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,  949,    1, 2232,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,   39,   45, 2170,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  992,   37, 1473,   39,   45,  734,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  675,    1,    1,  365,   82,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2376, 2024, 2223,  855,  267,    1, 1924,    1,    9,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  640,   59, 2927,  813,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  794,    1,  361,  845,  846,    1,  931,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  535, 1110, 2123,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2326,  798,  187,  103,  356, 1691,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   51, 1046,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,   12,  721, 1229,  460, 1707,  148,  142,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1485, 2153,    1,    1,   45, 1527, 1149,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,  729,    1,  166,    1, 1247,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1353, 1228,    1,  210,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  333,   45,  326,   50,  833,  612, 1719,    1,  190,    1,   37,\n",
      "            1, 1160,    1,  150,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  615, 1937, 1851,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3228, 2303,   37, 2354,  463,  411,   37,  688,  567, 1118,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2229,    1, 1004,  363,  943,  361,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 1937,  996,   93, 1115,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,  315, 2943, 1499,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2783,  581, 2183, 1479,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 1809, 2218,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  293,  170, 1825, 1448,   25,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3014, 2232, 2812,   98,  326, 1718,    1, 3031,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1300, 1606,  669,   51,   52,   53,   37,  457,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  493,    1,  417,  548,    1,  104,   29,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3207, 1216,  204,  190,   52,    1, 1232,  204, 1654,  671,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  921,    1,   32, 3097,   26, 2963,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  498,   98,  356,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  310, 2778,  753,   37,    1,    1, 2183,    1,  232,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178,  147,   37, 2286,  732,    1, 1411, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32, 2455,   45, 2662,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567, 1582,   12,   23,    1, 1592,  191, 2050,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1143,  288,    9,  388,    1, 1602,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1118, 2851,  382,  328,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1095,  325,    1,    1,  150,    9,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1156,    1,    1,    1,   32, 1422,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  290,    1, 1902,  900,   82,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  517,   78,   37,  322,   79,  131, 1147,  734,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  630, 1810, 3144,   12, 2179,    1,  640,    1,  297, 2823, 2005,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1899,   37, 1734,  776,    9, 2772,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2835, 1679, 3101,   32, 3082, 2434,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  317,  863, 2453,    1,    1, 2085,    1, 1159,  166,  608,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2895,   32,    1, 2598,    1,    1,  880,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  876,    1,   10, 1301,    1,  540, 1896, 1897,  567,  914,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  162, 1292,   98, 1092, 1575,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3348, 1863, 1492, 2156,    1,  796,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2620,   76, 1316,  445,   45, 1833,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  397, 1268,  104, 2009,    9, 1973,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,  267,    1, 1563,   28,   37,  395,  115,   45,  517,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1310,  111, 1708,   37, 1865,  105,    1, 1521,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,   51, 1860, 1725,    1, 1720, 2862,  884,  297,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1068, 1069,  831,   32,  871,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  247,  449, 2784,   81,   37,  925,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468, 3109,  228, 3387, 2985,    1,    9,  522,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,  20,   1,   1,   1,  37, 872,  28,  98,   1,  88,   1,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 162, 275,   1,  37, 759, 388,   1,  88,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  588,  104,  187, 1967,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1472, 2325,   39,   45,  166,   65,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1023,   45,  350,    1,    1,  901, 1001,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3339,  477, 2414, 3384,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   66,  526,  220,   69,  530,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   87,  746,    1,  182,   32,  174,  962,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359, 2456,   32, 3339,  190, 1348,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,    1,  167,   52,  227,    9,  334,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1536,    9,  467,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3059,  176,  153,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314,   37,    1, 1469, 1629,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,    1, 1869,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  620,   81, 1311, 2886, 1294,   37,   52,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   47, 1021, 2273, 1541,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,   12,  166,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  560, 1274, 1556,  915, 1034,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 2682,  539,    9, 1427, 2461,   98, 3070,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  819,  693,  773,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707,   12,  342,  142,    1, 2814,   45,    1,    1,    1,  475,\n",
      "          267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141,  810, 1292,  571,   37, 2110,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  833,  612, 1937,  865,   37, 3103, 1371,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  474, 1360,  612,  477,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2498,   12,  365,  154,  665, 1513,  872,   32,  913,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1408,  460,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  466,    1, 2423,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,   37, 1289, 2675, 2581,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1141,   28,  548,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1656, 2596, 3060, 2572,   32, 3246,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,  159,    1,  238,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 236, 237,  76,  37, 120, 176,  26,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 202,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  272,   98, 1718, 1998, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  197,   98, 1032, 1220,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1564,  460,   73,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2414,   32,    1, 3392,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 1290,  176,  356,  340,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  865,   37, 2028,   98, 1602,    9,  195,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  374,   27,  526,  329,    1,   12,  552,   85,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2832, 2833,   69,    1,   32,  430,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2754, 3102, 1683,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 1447, 1216,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,  632,  232,  851, 2095,  972,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  460,   12, 2181,  903, 1675, 1114,  176,  584,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1968,  768,  149,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1390,  159,   28,   98, 1746,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  365,  294, 1537,    1,    1,    1,  565, 2793,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  715, 1557,    1,  342,  444, 2707,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835,  190,  949, 3101, 2968,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 1809,   45,  105, 3268,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 1465, 1466,   82,  513,  193,  514,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  316,  171,    1, 1353,    1, 1766, 1767, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  915,  916,    9, 3151,  914,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  121,    1, 1839,    1, 2055,   98,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  326,  710,   66,  187, 1411, 1465,    1,    1,   82,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  861,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1602,   12, 3167, 2246,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3314, 1249, 1728,    1,   37,  726, 1326, 1990,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,   12,  721, 1707,  148,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1785, 2044, 1760, 1273,  259, 2530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1354, 1085,  388,    1,   32,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  388,  763,  105,    1,  166, 1868, 1172,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,   69,    1,    1,    9,  920,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 2003, 2162, 1950,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   37, 1198,    1,    1,  384, 1411, 2020,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2102,  921,   59, 3049,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,   57,  119,    1,    9,    1, 2891,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1774,   39, 1230, 2528,    1, 2668,  220,  163,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1699,  105,    1,    9,    1,   28, 1658,  327,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  453,  207,  197,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  734,  442,   66, 2088,  115,   45,  104,    4,   29,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 1355,   32,    1,  361,  440, 1891, 2064,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1090, 1829, 1531,  176, 2748,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2761,    1,   32,  718,  361, 2307,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1,  187,    1, 1153,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 1818,  147,  475, 1786,    1,    9,  505,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  200,    1, 1228,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,  176,  177, 1530,   32, 1656, 2950, 1260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2114,   37, 1865, 2522,    9,  613,  618,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  161,    1,  162,  163,    1,   12,    1,  164,  195,  132,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144,   12, 1460,  863,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  718,  967, 1977,   37,  664,  951,    1, 3276,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  619,  105,  400,   45,  166,  613,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1051, 1353,    1, 2575,  220,    1,  151,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 1228, 2794,    1,   37,    1,   32, 1821,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612,  544,  166,    1,   32,  166, 3207, 2795,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   51,  764,  403,  464, 3396, 1910,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1256,  551, 1256,   32, 1026,  170,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169,    1,   32,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3132,    1, 3216, 2260,  548, 2799,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  140,    1,  442,  813,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 2924,  697,    9, 1995,   98, 3391,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   30,    1,   98, 3101,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  275,  494, 1862,  600, 1278,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,    1,  777, 2179,  406,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2885,   98,  103,   45,  166,  593,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  614,  224,   32,  166,  215,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  167, 1527,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283, 1545,  951,    1, 2448,  386,  105,    1,  897,   32, 2741,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1481,    1,    1, 1523,    9, 1893, 1002,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1355,  361,    1,   32,  166,  365,  219,  460,  218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   69, 1042,  885,   60,   98,  677,  109,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,  481, 1465,   15,   28,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1855,  446, 1921,  115,   45,    1,  342, 2396,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2171, 3134, 1923, 3272,  590,    1, 1739,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2696, 1702, 1325, 1437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  575,    1,    1,    1,   32,  367,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1297,    1,   52,    1, 1178,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2107,    1,    1, 2468,   12,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  189,  190,  125,    1,    4,    1,  377,  763,   76,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,   61,  105,    1, 1172,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,  140,  647,    1,  741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2751, 1174, 2375,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1178, 1333, 1530,   32,  942, 1734,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2701, 1863,   12,    1, 2356,   32, 2772,  722,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2070, 3249,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2990,  254, 1696,   37, 1844,    1,  506,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2222,    1,    1,  565,   32, 1171, 1381,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  108, 3140,   98, 3038,  336, 2137,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  148, 2767, 1479, 2706, 2232, 1901,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  948,  317,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 325,   1,   1, 700,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 733,   1,   1, 112,  37,   1,   1, 234, 182, 235,   1,   1,\n",
      "           1, 234, 182, 235,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2072,   98,  861,  202, 1809,   28, 1737,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1518,  225,  693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1360,  612,    1,  163,    1,   45,    1,  389,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129,  219, 1477, 1990, 3164, 3286,    1, 1264,  841,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,   37, 1616,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1,  104,  498,   37, 1195,    1,  442,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1087, 1396,  395,   12,  327,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1290,   67,  338,   37,  105, 1595,    1, 1146, 1703,  340,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  964, 1877,   37,    1,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,  614,  613,  220, 2687,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  354,    1,   32,    1,  191, 1390,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  684,  232,  387,  104,  954,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  105, 3126,   37,    1,  942,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,    1,  692,  214,  693,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  302, 1712,  163,    1,   12,    1, 1188,  193, 2047, 2311,  275,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,  475,   37, 1910,    1,    1,   79, 2107,    9,  389,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1460,  233, 3145,    1,    1,    1, 1160,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  588,  881,   45,    1, 1294,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  430,  529,  477,   37,  168,  115,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1178, 1492,    1,  105,  365,    1,   98,  247,   81,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  200, 1778,  535, 2522,    1, 1876,    9,  282,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  944,    1,   37,   47,   50,    9,    1,  372,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  447,    1,  121,   37, 1832,  176,   65, 1990,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   45,  507,  459,   32,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2615, 1194, 2783, 1131,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  864,   12,    1,    1,   16,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1932,  588,    1, 1712,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564,  282,  327,  791,    1,    1,  388, 3011,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2069,    1, 1090,    1,    9,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   32, 1797,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  556, 3034, 2988,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  647,    1,    1,  213,  148,  142,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,   12,  446, 1458,  395,  297, 1789,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  954, 1754, 1533,  388,    4,  763,   76,   32, 1352,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3349,    1,   64,  799, 2414, 3094,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1550, 3185,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2122, 1929,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3192,    1,   45, 1280,  384,    1,  187,  438,   77, 1625, 2793,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181, 1273,  259, 1102,  841,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2858, 1028, 1771,  171,  176,  903, 2433,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1614,  613,  769,    1, 1228,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1830,   37, 2155,  105,  383, 1292,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1538, 1174,  810,  854,  477,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1000,  837,   32, 2651,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  561,    1, 1091,    1,    9,  537,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  954,  160, 1161,    1, 2295, 1279,  245,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1023, 1204,  288,    9, 1169,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3356, 3357,  729,    1,  531, 3346, 1142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 1260,   98,  104, 3150,   32, 3383,  947,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  542,    1,    1,  166,  147,  357, 2498,  190,   52,    1,   37,\n",
      "          422, 2176,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428,  496, 2095,  856,   61,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2586,  176, 3243,  132,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  941, 1201,   37,  912,    1, 1371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  398, 1574, 1899,   98,    1, 1001,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  267,  983,  190,  688,  236,  237,  739,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  790, 1707,  842,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  794,    1,    1,  150,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 1594,   37, 3164, 1528,    9, 1477, 1990,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  439,  417,  187,  761,  361,   69,  817,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  903,    1,  904,    1,  700,   37,  335,  855,   45, 2408,    1,\n",
      "          142,  457,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3269,    1, 2614,   28,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  325,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,    1,  447, 1220,    1,  439,  557,  540, 2292,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  398,  134, 1899,   32,  663,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2765,    1, 3370,   37,  798, 3376, 1585, 2606,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  507,    1,    1, 2679,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613,  200, 1615,   12, 1351,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  156,  688,  308,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219, 1470, 1120,   61, 1433,  166,  104, 1654,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3167, 2307,    1, 2163, 2615,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   58, 2145,   37,    1,  163,    1,   12,    1,  331,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1000,    1,  150,  112, 1013, 1522,  256, 2943,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,  802,  183, 1641,   37, 3006,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  503,  494,    1,   32,  400,   45,  214,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1,  663, 3341,    1,   37, 1709,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1076,  671,   12,  332,  636,  680,   97,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1013, 2070,  365,  443,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,   12, 2877, 1862,   98,  740,    1,  890,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1833,  593,  830,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1059,  166,  625,  105,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3005,   51,    1,    1,    1,   74,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  676, 1261,  966,  176, 3127,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12, 2084,  787,   28,   32, 2108,  297,    1,    1, 1104,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,    1,   85,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1089, 2530, 1504,    1,  220, 1199, 2177, 1825,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2308,  914,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,    1,  298, 1478,   32, 3360,    1, 2640,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2800, 1090, 2052,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,    1,    1,  190,  114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428,  812, 1934,    1,  949,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,   37,  698,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,   12,  714,   32,  166,  225,  218,  300,  105,  410,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,    1, 2278,    1,  657,  361,  148,  260,   28,   98,  166,\n",
      "         1222,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 3160, 1156,    9, 1147,  966,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2451, 3096, 2565, 1310,   37, 2035,    1,   12, 2840,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  550, 1017, 1621,    1,   37,    1,  596, 1793,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  410, 1263,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  214,  142,    9,  487,    1, 1256,  635,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  558,   11,    1,    9,    1,  105,  332,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2032,    1,  411,   32, 1948,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  750, 1731,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2845, 3113,  916,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,    1,    1,  204, 1710,   52,  227,    9, 3228,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1082,  151,   45, 1158, 1396,  636,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,   45,    1,    1,    1,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  140, 1764, 1990,    9, 2468,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  627,   12,    1,    9, 1048, 1049,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  580, 1289,    1,   37,  433, 3145,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299,   37,   81, 1527,    9,  116, 2176,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2994, 2749,   28,  777, 2995,  593,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647, 2549,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  321,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3016, 1935,  682,    1, 1876,   32, 1523,  220, 2723, 2724,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1479,  922, 1123, 2415, 2016,  232,  513,    9,  388,  199,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   37, 1174,    1, 1772,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  446,  105,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2070,  861,  231,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  864, 1428, 2390, 1798,  972,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,  183,   98,    1, 1410,   37,  777,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1700, 2548, 2572,    1,   22,  868, 1687,  115,   45,   76, 3155,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1107,    1,    1,    1,   98,  786, 1863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2076, 1023,   45,  163,    1,   12,    1,  460,  285,    4,   37,\n",
      "            1,   32,  537,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1127,  325,    1,   32,    7,  596, 1437,  221,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,  863, 2306, 2758,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1527,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  890,    1, 2085, 1415,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2547,    1,   32,  166,  593,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  732, 2598, 1750,  105,    1,  889,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  167, 2192, 3087,  937,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3238,  967, 2133, 3288, 1857,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3226, 1523,    1,    1, 3263,  542,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,  844, 1167, 1866,   39,  105,    1,    9,  764,    1, 1704,\n",
      "          853,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296,    1,   37, 1787,   20,   12, 1117,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  189,  108,   45,  143,   15,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1940,  439,  356,    1, 3106,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  743,   12,  156,   71,    1,  225,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  249,    1,  176, 3039, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,  921,  957, 1638,   45, 1509,    1, 1639,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  670,    1,   14,    1,  518,  817,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  649,  777, 1013,  778,    1,  835,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 1135,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1139, 2845, 3226,  688, 3241,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1312, 2572,   32, 2764, 2765,    1,   32, 3376,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 132,   1, 477,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 626,  37, 151,   1,   9,   1,  54,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  897,  187,  651,    1,    1,  506,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3239,    1,   37, 1343,    1,  361,    1,  190, 1343,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 2319, 1046,   45, 2764, 2765,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  857, 1267,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2701, 1016,   46,   37, 1348, 1411, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1390,  113, 1460,   46,  220,  587,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  169,  225,  407,  187,    1, 2143,    1,   48,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  691,   12,    1,    1,  105,    1,  182, 2187,  191,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  953,  608,    1, 1923,    1,  590,    1, 1739,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1127,    1, 1117,    1,  331,   24,  220,  189,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  204,   12, 2440,    1, 1408,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3231, 2871,    1,    1,   32,    1,    1,  220,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  193, 2398,  289,   98, 2673, 2429,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 3356,   12,    1,    1,    1, 1896,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  657, 1008,  365,   82,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424,    1,    1,    1,   61,    9,  334,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12,    1,    1, 2889,    9, 1675,    9, 3185,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2163, 2527,    1, 1210,    1,    1,   12,    1,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2779,  140,   32, 1022, 1385,   45, 1447,   26,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1825,   37, 1918,   32,   26,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3378, 1707,  776, 1462, 1576,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   58,  155,  570,    1,  225, 1784,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  848, 2222,  200, 1018, 1234, 1912, 1107, 1863,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,  396,    1, 1641,   37, 2764, 2765,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  103,  379,  380,  381,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2692,    1,   32,   59,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1800,  943,   45,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2566, 1564,  227,  471,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  147,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1343,   32, 1212,   98, 3141, 2457, 2290,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  547,  104, 2548, 2572,   32, 3360, 3279,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  625,    1,   32,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2349,    1,    1,  968, 1698,   45,  327, 2633,  506,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727, 1353,    1, 2165,    1,   37, 1012,   28,   37,    1,   37,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1355, 1094,   98,    1, 2095,  345,  396,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 1680, 2759, 1821,    9,  365, 2264,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2380,    1,   32,  411,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2031,  315, 2157,   37,    1,  777,  778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  647, 1702,   17,   37, 1901,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1284,  166, 1357,   98,    1,  625,  384,  166,  103,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 2872,    1,   28, 2753,   45,  111,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  761,  321,    1,   98,  195, 2129,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3145, 1159, 3076, 3220,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2464, 1660,  607, 1942,   98, 1095,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  777,  778,    9,    1, 2070,   43,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 2137, 1789,  446,   12, 1665,   45, 1461,  477,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,    1,  864, 2673,   46,  439,    1,  590,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3386, 1940, 1634,  220,  105, 2717,   45,  312,  966,  565, 2297,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   12,  552,  919, 1206,    1,  604,  731,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,    1,   45, 2994,    1, 2677,  949,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  387,    1,   28,  419,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2107, 1618,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1236,  923,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2527,  164,   61,   81,    1,    1, 2047,   45,    1, 1810, 2990,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  510, 1554, 1183, 2290,   45, 1080, 2100, 1549,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1007,    1,  105,    1, 1236,  777, 1606,    1,    9,    1, 2012,\n",
      "            5,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1157,  954,  387,    1,  419,   93,   32,  572,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1, 1790,  872,   98, 1013,    1,   92,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2314, 2114, 1518,    1,   98, 2318,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  187,    1,  580,  163,    1,   12,    1,  622,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2597, 2696,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144,  650,  213,   98, 1553,    9,  264,  741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1447, 1585,    1,  105, 1165,  778, 3399,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   65,   12,    1,  387, 1735,   93,    1,    1, 1500,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2667,  105, 2315, 1265,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,   37,    1, 1093,  574,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1661,    1, 1007,    1,   46,   28,  593, 1990,    1,\n",
      "          193,  445,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 2829,  928,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  632,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  637,  681,   54,   32,    5, 1631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  395,  155, 1149, 1625,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  458,   45,  507,   12,  869,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2615,  665, 3108,   98,    1,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  403, 3165, 1237,  463,  464,   36,   32,  395,  420,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  231,    1,   32,  617,  618,    1, 1103,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2748, 2052,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  832, 1258,  187, 2024,  132,    1,   32, 2646,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1342,    1,   82,  548,    1,  939,   37, 1413,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1718,  387,  183, 2252,   32,  803, 1244,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3316,   12,   72,    1,    1, 1748,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3204, 2951,  163,    1,   12,    1,   26, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1312,    1, 2751, 2572,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  777,  293,  729, 2598,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  681,  187,  289,   96,   37,  163,    1,   12,    1,   29,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2925,    1,  683,   37,  907,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3321,    1,  220,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  538, 1182,  562,  207,  297, 1021,  847,  261,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826,    1,    1, 1010, 1675,  671,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2049, 1594,    1,   12, 2160, 1159,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  814,  672,  453,  605, 1469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428, 3067,  557,  540, 2950,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,  482,   98,  776,    9,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,    1,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 1572, 1379,  437,    1, 2187,   45,  849,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,  647,   12,  721,   37,  360, 2069, 2187,  693,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  937,    1,  590,   99,   67, 1119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  587, 1390,  562,  132,    1,    1,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61, 3161, 2484,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   10, 2216,    1, 2039,    9,  389,  533,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,    1, 1077,   32, 1165,  469,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,    1,  297, 3153, 1066,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  204,   12,    1,   37, 1734,    1,    1,    9, 1691,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  447, 1484, 1512,   46,  297,  531, 3365,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503,  475,   61, 2411,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3359,    1,   98,    1, 1094,   32, 1056,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358, 1478,  348,  394,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2857,    1,  361, 3181,  661, 1411, 1267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1158,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  446,   12,  233,  726, 1268,  711,  333,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310,   25,   71,  548,   69, 1042,  384,  119, 1326,  682,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  835,    1,  112,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1229, 2399,   37,    1,  134,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  774,    1,   37,    1,   45,  640,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   51,  606, 1194,  400,   45, 2623, 2624, 2130,    1,    1,\n",
      "          267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  864, 3032, 2596, 3357, 1267,   16,   45, 1565,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1,  891,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  844,   37,  335,  822,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 2206,    1,  548,   46,  220,    1, 1306,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1149,    1,    1,  627,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  818,  819,    1,  548,    1,  820,   32,  821,  525,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1755,  418,  187, 1187, 1950,   32,    1, 1537,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236, 1022,    1,   66,  677,  187,   69,  102,  670,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,   69,  102, 1298, 1382,   98, 2046,  550,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790, 2257,    1,    1,  328,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2828, 3205,    1,    1, 1401,  437,  191,  547, 1394,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3398,   12,  865,   32, 1088, 2325,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  331,  399,   32,  755,  133,  290,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2216,  851,  298,   98,  624, 1858,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1360,  612, 1584,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   85,  187,  109,  997,  470,    1,  977, 2022,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1388,   45,   14, 1110,  167,  362,  803,  821,  124,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,   39,    9,  166,  356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  136,  253,   81, 1499,  297,    1, 1816,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  979,  906,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2659,    1,  237, 2502,  187,    1, 2354,   32,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 2414,    1, 2803, 3360,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1592, 1152,   45,  116,  164,  165,  126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2328,  794,  365,    1,  853,  384,  584,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2708, 1513,   37,    1, 3358,   12,    1, 1404,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 2386,  829,   45,    1, 1470,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2826, 1939,    1,    1,    1, 1674, 1283,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  129,    1,   45,  549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  425,  426, 1408, 1690,  525,   15,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  113,  214,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  542,   37, 1096,    1,  774, 3219,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,   51,   52,    1,   37,  546,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2164, 2478, 1081,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,    1, 1333,  665,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  284, 1656,    1, 1900,  583,  191,  341,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746, 2239,   98,  829,   32, 1479,    1,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2677,   26, 2218,    1, 2078,   98,  260,   32, 1940,   12, 2069,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1112, 1559,  220, 1053,  297,    1,  108,  455,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 613, 275, 162,   1, 176,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 288,  37, 693, 658,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  105,    7,    1, 2549, 2054,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1417, 1627,  166, 1093, 2060,  166, 1868, 1172,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2707, 1830,    9, 2472,  652,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,   37,  508,   79,   45, 1346,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3342,   12, 1404, 1478,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796, 2924,   37, 1334,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  968, 1827,  603,    9, 2383,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 2122, 2868,   98, 2041, 2655,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3013,   12,    1, 1240,  193,  915, 1183,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1022, 1023,  197,  407,   98,  844,    1, 1107, 1501,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2221,  111,    1, 1239,  388,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3115,    1, 1210,   37, 1838,  389,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1517,    1,  385,    1, 1574,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3356,  213,   37,  439, 2646, 1512, 1147,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,   12,    1,    1,   45, 2162,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,    1,  681,    1,  365, 1799,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1509,  151,   12,  572,  156, 1473,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193,    1,  220, 3188,   12, 1647,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1563,   37,    1,    1, 2202, 1159, 2276,   98, 1833,   12,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2161,   32,   44,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  727,  613, 1353,  845,  846,   29, 1074,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3052,  186,  297, 3071,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  407,  384,  310,    1,   37, 1568,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 3187,  360, 3177, 1077,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2037,   32,  166,    1,  866,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092,  951,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1022,    1,  678,   12, 1760,    1,  872,  384,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  292, 1113,   67,  720,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  848, 2480,  140,   17,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228, 2458,    1, 1077,    9, 1674, 1675,   37, 3261,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 3109, 1056, 3374,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1824,    1,  111, 1908, 1557,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  220,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  316, 2757,  267, 1123,  132, 1270, 1530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1674, 2962,    1,  140,  166,  331, 1010,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2379,    1, 3158,  187, 3132,   85,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2533, 1216,   37,  683,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1290,  396,   28,    1,    1,  102,  504,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1557,    1, 3343,  863,  133,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766, 1865, 2071,    1, 1935, 3016, 1935, 2636,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  647,   12,  627, 2177,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2436,  361,    1,    9,  166, 1864, 1907,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2472, 2519, 1660,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1568,    1,  389,    9, 2974,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3355,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1855, 3365, 1025, 1683,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   82,  138,   32,  163,    1,   12,    1,    1,  187,    1,  897,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1539,  517, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1133, 1215,    1,  202,    1, 2582,   37,   52, 2740,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1518,   85,    1,  539,  778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3277, 1625,   45, 1545,  522,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  223,   37,  151,  449,  223,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1201,    1,   21,   59,  384,  840, 1354,   45,   48,   32,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,  147,    1,    1, 2059,   45,    5,  133,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  952,   37,  470, 2079,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,  387,    1,  763,  218,   93,   32,  572,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1811,  404,  934,   37, 1910, 2325,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3400,    1,  220, 1841,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1029,  459,  463,  294, 1416,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  558,   27,  132,   37,  151,    1, 1039,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1870,    1,   39,  176,   14,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 1585,  297,  535, 1281,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,  302,   45,  663,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3285, 1747, 1256,    1,  375,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147, 3006,  798, 1485, 1527, 2664, 1924,    1,  187,  105,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  636,  176, 1816,  220,  365, 2979, 2869,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  616, 2360, 1720,   65,  190,    1,   98,   67, 1500,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,   12,    1,  478, 2063,    1, 2837,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  730, 2614,   98,    1,   45, 2507,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  794,    1,  259, 1108,  315,    9,  786,  199,  278,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1766, 1767,  921,  131,  737,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2691,  439,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  258,  327,   15, 2449,  198,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,    1,  148,  142,    1,    1,  326,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,    1, 2115,    9,    1,   54,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,    1, 1824,  663,   37, 2741, 3192,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    9,    1, 2572,  191,  799,  388,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  151,    1,  150, 1627, 2212,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1105,  787, 1392,  727,   12, 1140,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  325, 2943, 1416, 1873,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  479,  353,  197,    1,    1,    1, 1114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1300,    9,  201,  529,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2132,  593,   12, 1354,    1,  954,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2267, 2866,   98,  912, 2285,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,  575,    1,   32,   37,    1, 2105,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1583, 2731,    1, 3374, 1957,  686, 1094,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 176, 166,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  69, 102, 686, 241, 119,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  856,    1,  220,    1,  361,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  734, 1324, 1552,  297, 2466,  315,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051,  387,  395,  187,  656,   45,  593,  275,  218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  347, 1719,  439,   45,  340, 1184,  408,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  236,  237,   25,  439,  417,   98,    1,   68,   69,  102,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2197,    1,    1,  384,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3361,    1,   37, 3346,  548,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447, 1070,    1,   37,  764, 1211, 3340, 3073,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,  27, 439,  45, 539, 540, 423,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 430, 391, 477,  51,  52,   1, 474,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2026, 2574, 1348,   37, 1192,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1517,    1,  446,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3348, 1906, 1713,  856,    9, 3102,   12, 1204,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   31,    1,    1,   69,  636,  423,    1,   71,   32,   25,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2533,   24,  484, 1961,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1298,   61,   37,   52,    1,    1,  445,  901, 1232, 3207,   61,\n",
      "         2270,   37,  332,  671,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  224, 1126,  580,    1,  670,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1405,    1,  373,   32,  132,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3160,    1, 3384, 2844,   32,    1,   45, 3339, 1345,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2238,   37, 1604,   98, 2979, 1151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  111,  700,   32,  166,    1,    9,  214,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1183,   98,  987,    1, 1139,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3113, 1485, 3365, 2793,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,   69,  102,    1,    9, 1411,  537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  171,  872,   12,  457, 2328, 2870,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   15,    5,  920,  105,  322,   79,   98,  961,  962,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  453,  449,    1, 1009,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649, 3102,    1,    1,  885, 2572,    1,  187, 3354, 2924, 2625,\n",
      "         3345,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1320,  894,  854, 2447,  449,  357, 2771,  449,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  996,   93,  898,  530,  570,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  167,   52,  266,  887,  837,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26, 1039,    1,    1,    1,    1, 1554, 1652,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,   51,    1,    1, 3375,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2427, 1542,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1702, 1836,   98, 2708,  741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1641,   37,  594,   78,  187,    1,    1,  734,  469,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2579,    1,  167, 1722,  166, 2498,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,  159,   28,  115,   45,  148,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2352,    1,    9, 3185,  924,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162, 1950,  418,   37,  395, 2201, 1585,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 2309,   32, 3144,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,   12,  645,    1,  152,    1, 1523,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1723,    1, 1258,   32, 3310,  400,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 2659,   37,   77,   79,  367,  687,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  312,  400, 2921, 1586, 1920, 2757,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  624,    1,   53,    9,    1,  131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3176,  614,  103,  220, 2041,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,  429,  631,  176, 2579, 3154,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  978,  769,   27,  526,  727,  246,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  153,  670,  191, 3206,   32, 1600,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1676,    1, 2430,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1994, 2693,  321,  612,  907,  365, 2429,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  341,  884,  674,   45, 2957,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  511,  261, 2735, 1246,  220,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  864,  267,  460,  190,  899,  202,  193,  439,  453, 3107,  210,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826,    1, 1249, 2942,  187,  163,    1,   12,    1, 2659,  671,\n",
      "          910,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  698,    1,  166,  550,    1,  365, 1788, 1654,   37,  730, 2614,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2136,  387,    1,  776, 1961,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,   68,  102, 1334,  530, 1146,  106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087, 2614, 1421,    1,   37, 1056,  356,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1117,    1,    1,  729,   32,  453,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  227, 1675,  115,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,    1,  560,  347,    1,  452,  411,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2971, 2896,    1, 2376,  855,    1, 1983, 2498,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  295,   51,  865,   37,  197,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2009,   26,    9, 2670,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  947, 1013,    9,    1,   37, 2147, 2950,    1, 2587, 2971, 1867,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 1070,    1,   37,  439,    1, 1446,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1775, 2264, 2867, 1211,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  155, 1194,  401,   15,  570,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 1101,  279, 1230,  384, 1158,    1,  193,  320, 2056,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 3018,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2313, 2850, 1530,   56,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3170,   37, 1306,  449, 1463,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  927, 1781, 1159,    1,  632, 2003, 1585,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2602,    1,    1,   32,  915,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  121,   37,  163,    1,   12,    1,  147,   49,  193, 1658, 1406,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3354,  446,   37,  907,  220, 1861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1050, 2700,    1, 2663,   45, 1019,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12, 3137,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  673, 1778,  614,   37,  854,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1459, 1082,    1,   37,  690, 2712,    1,    1,  176,  133,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,   25,  832,  159,   45, 1138,  361,    1,    1,  276,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2691,  260,   28,   37, 2428, 2692,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1051,    1,    1,  872,   98,  845,  439,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1879, 1421,    1,   37, 1504, 2347, 2815, 3229,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3079,  774,  792,  590,  792,   37, 2771, 1077,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  794,    1, 1117, 1525, 1900,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2, 484,  27,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  69, 636, 288,  37, 245,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2613,  726,    1,    1,  721,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2777, 2628,   37,   47,  219, 2152,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  147, 1458,  242,    1,   45,    1,  615,  354,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835,  566, 1610,  865,   45, 3030,   37, 1094,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  163,    1,   12,    1,    1,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2405,   51, 2365,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  150,  267,  829,    1, 1534,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  920,    1,    1, 1772,   98,  224,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  700,   61,    1,   32,  290, 1159,  137,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1007,    1,  244,    1,    1,  173,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  176,  915,  916,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1090, 1829,  365, 1546,  176, 3013,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1108, 1779,    9, 1778, 2232,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 3350,  396,  270,   32,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 148, 325, 647,   9,   1, 131,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  15,  66,  45, 905, 815,  37, 104,  22,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,    1, 1772,  384,  366, 1410,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   83,    1,    1, 1092,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1230,  696, 1198, 1158,   12,  601,  401,  197,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1993,  608,  308,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,    1,    1, 1624, 2409,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2173,  774,    1,  254,    1,   37,    1,  166,    1,   45,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2615,  361, 2685, 2434,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  477,  449,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3309, 2395,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  733,   59,    1,   98, 2102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1720,   37,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,   81,  612,  111,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1940,   12, 3134,    1,   45,    1, 2667,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925,    1,  403,    1, 2413,  288,    9, 1479, 1031,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  203,   37,  877,  259, 1484,  111,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 3395, 2496, 1976,  403,   45, 2597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  787,   45,    1,  640,   81,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  395, 1465,   13,  835,  326,  327,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  574,    1,  436, 1172,  361,  247, 1001,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1079, 3063,   37, 1539, 2355, 1013,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3189, 2803,  247,    1,    1, 3131,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  386,  313,   37, 1504,  573,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3328, 1831, 1542,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 3397,    1,  454,    9, 3363,  726,   32,\n",
      "         3343, 1002,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 1290,  396,  245,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  441,   37,  875,  768, 2039,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1043, 1086,  526,    1,   69,  122,  817,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2090,    1,    1,   37,  130,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3045,    1, 1316,  531,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800,  386,   12,  542,  619,  810,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  864,    1, 1461, 2320,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1108,  300, 1225, 1748,   37,  617,  259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3070, 1089,   45,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  915, 1140,    9,  166,    1, 3032,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 1798,  891,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3094, 1530,   32, 3367,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  422, 1627, 1603,    1,  927,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596,    1, 1337,   95,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  947,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1312, 2512, 2227,  872, 2677,    1, 1796, 1938, 3197,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1971,    1,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,   37,  417,  723,    1,  636,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2327,  166,    1,  288,  166, 1267,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  931,    1,    1,  162,    1,  698,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2942,  140,    1, 3126,  176, 2890, 1675,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1,  453, 1109,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  189,    1, 1961,   37, 1169,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  211,    1,  484,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  709, 3176,    1,    1,   98, 3123,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2939, 2951,  413,   37,  726,    1,    1,  176,  593,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1789, 1625,   37,    1,   39,  730,  114,    1,   32,  537,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203, 1187,  105, 2859,   12,    1,   45,    1,  764,  104,    1,\n",
      "         2500,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  868,  132,  220, 2862,    1,  297, 1791,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1880,  325,  163,    1,   12,    1,   14,  458,    1, 1680,  158,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1270, 1023,  219, 2715, 2946,  176,  629,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  959, 1176,  123,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1801,    1, 1224,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   81,   32,  599, 1505,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  602,    1, 2710,  650,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  468, 1362,  251, 1273,  861,    9, 1211,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    9,    1,    1,  105,  400,   45, 1176, 1211, 1819,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773, 1830, 1981, 1539,   45,  365, 2480,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2658, 2269, 1360,  612,  774, 2602,    9,    1,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496, 2294,    1,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 1011,  639,  992,   28, 3369, 1527,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,   44,   98, 2234,    9, 2071, 1331,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1262,   37,    1,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  409,   25,  670,    1,   60,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,    1, 1212, 1508, 1422,  895,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1050,    1, 1559,    1,   98,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 3397, 2682,    1,  446,   98,  443, 2938,\n",
      "            1,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   56, 1994,    1, 1347,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  632,  221,  991,  454,   37, 1403, 1839, 1159,   23,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  818,  834,  157,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  458,   45,  942,  155,    1,   67,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826,  671, 3126,    9, 2890,  861,  220,  105,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    7, 2329,   32, 2741, 1917, 2846, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1583, 3400,    1,  820,   32,  455,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  315,  104,  331, 2131, 1708,    9,  453, 1234, 2308,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3009,  187, 2741,  726, 2522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  600, 1718,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1440,   51,   52,    1,    9, 2746,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2800, 1178, 1179, 1178,  787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187, 2087,  433,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  705, 1458, 1532,    1, 2309,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  108, 3215,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2754, 3102, 1683,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1013, 1765,  466,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  316,    1, 2016, 1149, 1313,  166, 1064,   37, 1600,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1402,    1,   37, 1031,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1349, 1170,  476, 1590,  920,    1,  202,  590,  315,   37, 1253,\n",
      "         2887,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  422,    1,    1,    1,    1,    1,   12,    1,   87,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1343,   32,    1, 1463,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  151,  902,    1,   12,  332,  120,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  717, 1417, 2420, 1273,  777,    1,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358, 1216, 3375, 1532, 2958,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  215, 1437,  696, 1198,    1,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  365,  808,   61,    1,   39,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  159,  526,   98,  417,  157,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2452,  517,  105,  449, 1173,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  720,   27,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  315,  219,  117,    1,   37,    1, 2102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1592,  973,    9,  388,  163,    1,   12,    1, 1465,  861, 1896,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,  418,    1,  118,   63,  862,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2017,   98,  112, 1678, 2072, 2008,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  572,  197,  388,  763,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   22,   23,    1, 1495,    1, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9, 1031,    1,  994,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  879,  186,   98,  679,  509,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  803, 1279,  682, 1316,  166,  721,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  434,  105,  433,  220, 1095,    1,    1,  191,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   66,  526,  187,   69,  640,  365, 1653,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  506,    1,  565,    1,   37,    1,   39,  505,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,    1,    1,   32,  593, 1990,   45, 2701,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  224, 2753,  147, 1918,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  919, 3142,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  113,   27,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,  256, 1210,  460,  920, 2560,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  744,   28,  637,   98,    1, 1463, 2363,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1206,  954,  190, 1937,   93,   32,    1,  202, 2124, 1552,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  204,   12,  590, 1990,    1,  176,  166, 2630,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3263,  838,   79, 1245,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  356,  560,  347,   71,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3199,  140, 3154, 1523, 2369,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1115, 2053,  218,   51,    1,   31,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1906, 2405,   37, 3099,   32, 1013,   45, 3369, 2024,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 2845,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  764,   26,  903,    1,  331,    1, 1465,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  331,  267,  244,  490,    1, 1464,   37,    1,  218,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1818,  147,    1,  544,  193, 1140,  695,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,  622, 1017,   32,  531,  443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 2282,    1, 1576,  774,  729,  590,    1,   37, 1988,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1851,   32,  215,  535,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2680,   12, 2980, 2485,    1, 2683,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  183,  404, 1586, 3166,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2477, 2908,    9,  365,    1, 2291,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1043, 1276,  185,    1, 1448, 1091,  245,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649,    1, 1563,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 3349, 1554,  786, 1530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3227,  132,    1,    1, 3189,  562,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  657, 1458, 2017,  384,  844,  769,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  503,  105,    1,   98,  195, 2054,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2097, 3119,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,  460, 1149,  388, 1862,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  487, 3102,   12, 1841,  146,   37, 1861,   37, 1154, 1590,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  520, 3140, 1430, 3146,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2042,  113, 1994,    1, 3136,  477,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   28,    1,  202,    1,   66,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1249,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2321,    1,    1,   39,  220,    1, 1987,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 1134,   45, 2258,   37,   18,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  614, 1092,  166, 1868, 1172,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,   22,    1, 1085,  474,   32, 1384, 1259,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2161,    1,   37, 1752, 2308,   32, 1089, 1090,  293,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1702,    1, 2146,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,   12,    1,  361, 1944,   98,  403, 1447,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  648,    1,    1,  148, 1160,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61, 2297,  810,  294,    1, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1497,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  159, 1253,  548,   15,   45, 2168, 1376,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1701, 1753,  116, 1662, 2633,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   52, 2073, 2132,  233,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3264, 1293,   32, 2792,  389,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1433,  334,    1,    1,  361,   55,    1, 2212,  861,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  792, 2603,  792,  884, 1357,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1019, 2527, 2663,   51,    1,  345,  220,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  251,  445,  658,   29,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3170,    1,   37, 2277,  388,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3364, 1288,   37,    1,  220, 3140,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1840, 1635,    1,   98,    1,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1092,  868,   81,  867, 2039,    1,  892,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613,  200, 1615,   12, 1351,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  460,   12, 1745, 1176,  411,   37,   52,    1,  600, 1888,  415,\n",
      "         1079,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  920,   32, 2573,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3247,  125, 2469,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  606,    1,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2851, 1628,    9, 1658, 2725,   97,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1584,  166,  365, 1914,  138,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2823,  863,    1,   32, 3360,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 2344, 1560,   37, 1876, 1234, 1536,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  460, 1924, 1048,  166, 2605, 2556,  166, 1477, 1990,  388,  763,\n",
      "          166,  104,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    1,    1,    1,  384, 1019,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  395, 1082,  342,  193,   37,  665,   28,    1,  442,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  621,    1, 2202,  297,  673,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   61,  224,    1,  105, 2995,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275,  996,    1,    1,  612,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2137, 2747,  501, 2060, 2856,  176,  177,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2764, 3356,   12, 3357,  868,  132,  220,  104, 1414,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1, 1192,   37, 1637,  452,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1123, 2671, 1573,  105,  365, 2027,    1, 2500,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  116,    1, 1108,  205,  191,  746,   32,  411,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3207,   45,  163,    1,   12,    1,  140, 1940,   12, 3208,  810,\n",
      "         1425,  671,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,  829,  132,  162, 1698,  342,  290,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,    1, 3144,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  861, 1901,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 1436,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  593,   12,  103, 1056, 2308,  759, 3293,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2032,    1, 2753,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  391,  267, 1117,    1,  552,    1,  105,    1,  804, 2141,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,   32,  166,    1,  894, 2617,    1,  580,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,   72,  401,  156, 1253,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3007,    1, 1412, 2382,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2962,    1,   12,  857, 2210, 1401, 2615,  608, 2838,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861,  681, 2123,   37, 1505,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1161,    1,   32, 1108, 2054,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2929,   37, 1539, 1273,  259, 1108,   32,  179,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   63,  166,  862,    1,    1,  148,  245,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   37, 2122,  163,    1,   12,    1,   98, 2924,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3274,  288,   37,  865,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  220,  166,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1,  171,    1,  365, 1546,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,    1, 1213,    9, 1943, 2541,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  592,  232, 1082,  497,   98, 2170,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,   28,  951,    1, 1354,    1, 1547,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   33,  625,   37,  226,  127,  658,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  829,   37,  877, 2997,  388,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  959,  786,   32,   56, 1244,    1, 1228,  327,  593,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3287,    1, 2290, 3259,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1894,   44,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  232, 2572,   32,  632, 1512,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401, 3120,  297, 3268,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1444,  606,  604,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,   90,   17,   37, 1000,  365,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3198,    1, 3253,   37, 1594, 1245,   98, 3257,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  375,    1, 1187,    1,   12, 1719, 2205,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2960,  640,    1, 1606,    1, 2900,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978, 3138, 2368, 1045,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2500,  663,  437, 2137,  365,  104, 2735,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196, 1518,  372,    1,  613,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,   28,   98,  844,    1, 1603,  117,   93,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1539,  853,  538, 1049,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2226,    1,  182,    1,  331,    1,    1,   79,  354,   45,  105,\n",
      "         1108,   24,  460, 1728,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2076,    6,  601,  401,  327,  570,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056, 3111,    1,  786, 3160, 2572,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1236,    1,  297,  787,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1628,  312,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340,   37, 2449,  220, 1110, 1632,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1762, 2568,  879, 3176,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  421,    1,  365,  693,  176,  552,  332,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2751, 2253,   37, 2856, 3347,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 2587,    1,   37,    1, 3107,    1,  437,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,   37,  865,   32, 2295,    1,    1,\n",
      "            1, 1360,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,  107,   51,  125,   69,  568,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  951,    1, 3188,  590,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1674,    1, 1086,  220,  163,    1,   12,    1,    1,  667, 2078,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1235,  102,   28,    1,  419,    1,  626, 1042,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393, 1243,  453,  315,   37,  125,    1,    4,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2297, 2513,    1,  787,   32, 1833,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,  794,  327,  260,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3310,  776, 1268,  220, 1723,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3113, 1277,  531,    1,    9, 1002,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3288, 1987,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  921,  166, 1509,   45,  166, 1981,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2800, 1545,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343,    1, 2726, 1585,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  952,   37,   62,  443,   45, 1886,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296,    1,   20, 2096,  972,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2158,    1,  854,  220,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  520,  241,  693,    9,  421,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1725,    1,  269,  993,    1,   37,    1, 2834,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  743,   12,   82,  992,   85, 2007,   37,  505,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  800,    1,  420, 1394,   37,  729,    1,  104,  954,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785, 2044,  838,   98,  107,  568,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   10, 1708,  777,  778,    1, 1407,  412,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37,  764,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1576,    1, 1159,  281,  282,   12,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1662,  293, 1236, 1935,    1,   13,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  938,   32,    1, 1358,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1011,  102,   71,   98,  581,   74,   45, 2782,   45, 2752,   12,\n",
      "         1633,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  592,  590, 1421,   45,  433,  636,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358, 1070,  359,    9,    1,  125,   32,  138,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2217,  716,  365, 2527,  164,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 2631,  544, 2398,   37,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  531, 1518, 2764,    1,  756,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,    1, 1587,   45, 2071, 2024,  226,    1,    1,   85,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2988, 1665,    1,   28,   98, 1778,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   95,  473,  360,  104,   22, 2362,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2753,   56,  187,  104, 2540,  121,   32,  593, 1990,  401,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1473,   98,  720,   32,  160,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 326, 140, 199,   9,  46,  32, 573, 400, 428,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 180, 361, 727, 875, 822,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,  155,  347,   37,  838,  453,  954,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713,    1,   32,  411,  395,   26,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1578,    1,  810, 1628,    9,  104,  140,  437,  548, 1832,  220,\n",
      "         2427,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  908,  381,  399,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  755,    1,  829,   12, 3042,  161,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1468, 3092, 1990, 1286, 3179,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158,  244,  120,   98, 1230,    1, 2400,   15,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1337,  225,  949,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3264,    1,   39,  191,  542,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,   15,  973,    9,  634,  971,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2798, 1718,    1,    1,   15, 1021,  198,  730, 1777,  401, 3031,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  681,  439, 2096,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3385,    1,    1,  220,  864, 3146,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,    1,  100,   37, 1496,  211, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  696,    1,    1,  777,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,   26, 1039, 2079, 2798, 1542,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 3160, 1156,    9,  531, 2772,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1199,    1,    1,  288,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2700,    1, 1056,  365, 2025, 2604, 2983,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162, 1950,   32,  395,   12, 2201, 2003, 1585,   76,   37,   71,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  597, 3141, 1863,    1, 1550,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1640,   57,    1,   32, 3071, 1223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 1322,    9,  742,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,    1,   37,  125, 2128, 1397,   32, 1850, 1423,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2555,    1, 1684,    1, 3278, 1569,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1408,  822,  809,  444,  756, 2157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2633, 1451,   37, 1306, 2073,   73,  698,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  421,    1,  213,  214,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 994,   1, 150,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 622,   1, 166,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  684,  526,  548, 1958,  339,  340,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1024,  332,  631,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   60, 1141,   27,    1,  687,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  407,   98,  391,   93, 2187,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2946,  335, 1130, 2100,    1,  506,  782,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,    1,   37,  829, 2215,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   15,  361,  244,   92,  176,  306,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294, 1456,    1, 2523,  566,  601, 1684,  548,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3066,    1,    9, 2836,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596,  361,    1,    1, 1140, 1671,  105,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1238,   22,  353,  737,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,   45,    1,  319,    1,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1050,    1,   32,    1,  297,  873, 3065,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26, 1039,  293, 1355, 2076,   98, 1718,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018,  361,  854,   37,  698, 2673,    1,    1,  590,  132,   98,\n",
      "         1461,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,  582,   45,   69,    9, 1011,  210, 1988,   45,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  384,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3254, 2781,  187, 2468, 1285,  115,   32,  593, 1990,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  455, 2164, 2986, 1046,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  123,  410,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2631,  288, 2925,  119,  220, 1194,   73,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2932,    1, 1188,  388,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  183,  978, 1654,    1,  486,   24,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   12,  183,  978,   81,   98,  103,  187,  593,   12, 1254,\n",
      "         1465,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  546, 2800, 2565,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1800,    1, 1638, 2118,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2949, 2640, 2440,  548,  114,   79,  166,  540,   45, 1423,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1097,    1, 1165,   29,   16, 1735,   93,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  166, 2334,  846, 2107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,  865,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1,  829,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  877,  815,   45,  829, 2690,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1725,  497, 1207,   37,  981, 2949,    1, 2532,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2817, 2856,   32,  395,    1,  590, 1584,   28,   32, 1881,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   68, 1518,  530,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  355,   12,    1, 1366,  606,    1,  452,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  294, 1456,  197,  418,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1266,    1,   37,  125,    1,  388,    4,   32,  283,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3182,  429,   79, 2321,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  777,    1, 2155,  365, 2842,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1780,   98,    1,    1,   32,  439, 2060,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   72,  401, 1924,  227,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2523,  884,  411,  631,  176,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2236,    1,   12, 2309,   37,  335,  297,    1, 1748,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2672,    1,  459,   37,  439,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,  537,  452,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   28,  220, 3075,    9,  183, 2489,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  354, 1809,    1,  614,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1, 2835, 2434, 3080,   32, 1421,   45,    1, 2471,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106,  951,    1, 1158, 1381,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  755,   37,  606, 2355,    1,   32,  365, 2995,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105,    1,    1,   32,  166, 3131,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  810,  166,    1,  176,  474,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  640, 2381,  339,  687,  951,   94,    1, 1547,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1766, 1767,    1,  894,    1,  365, 1204, 1159,    1,  105,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2990, 1696,   37,   52,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  920,  251,    1, 1876,    9,    7, 2993,  280,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  862,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  491, 2503,  787,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386, 1070,  147,   37,    1,  138,  125,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  885, 2596, 2870,   32, 2490,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12,  223,  898,   37,  606,    1,  995,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  584,    1,    1,    9,  567,  799,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2528,    1, 1090,   98,    9,  275, 2287,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1524, 2132,  584,  171,  113,   79, 2160, 2049,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2837, 3047,   32, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1108, 2775,    1,  135,    1,    1, 1525,  361,    1,  625,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056, 1147, 1726, 1878, 1450,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974,    1, 2977,  719,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1628, 3288, 1380, 2685,    1,   98,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2592, 1949,  829,  132,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   55,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  954, 1032,    1,    4, 2139,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  447, 1396,    1,   22,   23,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  167,   52,   39,  191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1484,   79, 1539,   45,  938, 2454,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962,    1,   98,  114,  187, 3260,    1,    1, 2633,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  581,    1, 1380, 3260,   28,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3005,  190, 2654, 1018,    1, 1104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2114,  859, 1212,  947, 1805,   28,    1, 1355, 2757,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  238,    9, 2843,    1,  987,   98, 3332,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  447,  193,    1,   37,    1,    1, 2429,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  655, 2317,  297, 3339, 1939,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3142, 1289,   37, 3152,  533,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  493,  636,  640,    1, 1722,   32,  257,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3308, 1990,    1,  959, 1221,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1183,  901,    1,    1, 1928, 2952,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2579,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1712, 1228,    1,   37, 3030,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1536,    1, 1126,  469,  220, 1498,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  744,  478, 2568,   45,    1, 2232,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  580,  365,    1, 1355, 2973, 1764,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187,    1,  991,    1, 1411, 2329,  565, 2179,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   46,   98,  557,  540, 1348,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  891,   37,    1, 1663, 1821, 2190,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1926, 1927,  193,    1,   98, 2018, 2735, 3350,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1955,  244,  720,  187,   15,  698,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  691,    1,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1364, 1365,   12,  116,   85,  548, 1080,   37,    1, 1842,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  572,  244, 1124,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1650,   45, 1821, 2747,  166, 1821, 2190,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  341,    1,    1,   15,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2859,  515,   28,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2475, 1046, 2769,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,    1,  714,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2166,  856,    9, 1675, 1714,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3257,   32,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2433, 2153,    1,  964,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1990,  967,  453, 2776,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2685,    1, 3237,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,   61,    1,   37,   94,  741,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,  200,  365,    1, 2320,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3320,   98,  166,  221,  548, 3328,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1321,  195, 2544,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  517, 2860,  498,  531,  734,  591,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2962, 3316,   64, 2335, 1394, 1048,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1899, 2430,   98, 2500,  663,  134,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   98,  166,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  200,  453,    1, 1354, 2529, 2334,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2990, 1827,    1, 2840,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2634, 2767, 2871,    1, 1933, 2177, 1825,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3228,  949, 1022,    1,    1,    1,  221,   28, 1247,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3069,  475,   37,   26, 1891,    1, 1027,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2890,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1270,   32,    1,  248, 1273,  259,  496,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1551,   32,  365,  356,  220,  388,    4,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1,    1,  176,  224,   12,    1,   98, 2215,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  584,    1, 2771,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1142,    1,    1,  191,    1, 1926, 1927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3253,    1,    1,  187,    1,  796,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,    1,  166,    1, 1255,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1008,  678,    1,  453, 1644,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1321,  384,    1, 1984,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3013, 1380,  460, 2017,  411,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1543, 1658,  248,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2962, 3238,  696,  730, 2614,   77, 1245,   98, 2615,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  227,   37,   52,   81,    1,  267, 2472,  855,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118,    1,    1,    1, 1428, 3397,  108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,  183,  726,    1, 2009,    9,  105,  183,  132, 1379,   12,\n",
      "          112,  499,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1, 1821,  656,    9,  510,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32,  854,    1, 1815,   63,  446,   12, 2237,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2265,    1,   32, 2597,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  221,    1,    1,  542,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1202,    1,   28,  191, 1730,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  107,    1,    1,    1, 2764,    1,  187,  105, 1009,    1, 1124,\n",
      "           69,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3379, 2147, 3035,  193, 1810,  166, 2335, 2372,  947,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2721,    1,   32,  401, 3179,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  225, 1137,   98,  572,  156,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3114, 1830,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228, 1439,   32, 1405,  373,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   27,  439,   45,  539,  540,  423,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 1107,  542,    1, 2102, 1402,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,  108,   45, 1038,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111, 1688, 1205,    9,  840, 1792,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  166,  931,    9, 1307,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2469,    1,    1,   37,  582, 1170,  538,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  348,  156,   28,  118,   32,   72,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,  952,    1,   45,  207, 1107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  388,  763,    1,  663,  176,   48,    9, 2388,  361, 2388,  171,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548, 2963,    1,    1, 1822,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   29,  353,  242,  572,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  873, 1717,  879,  631,   32, 3235,  539,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,   45,  166, 2249, 3373,  105,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  150,   81,    1,  437,   96,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1051,    1,  829, 2123, 2348,    1,  220, 1872,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  342,  132,    1,   37, 1647,   32, 2390,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  884, 1183,  454,   37,    1,  176, 3190,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  548,  865,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1810,    1,    1, 1211,  639,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,    1, 2695,  361, 2695, 1917,    1,  327, 2407, 2246,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  715, 2313, 1231,  220,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  945,  856,    1,    1, 1645,  715, 1246,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3343, 2548,   64,  611,   37,  439, 2426,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  999,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  976,    1,    9, 3385, 2532,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  282,    1,  210,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1718, 2146,  256, 1417, 1876,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1523,    1,   98,  166, 1412, 1107, 1030,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  916,    9, 2056,  698, 1750, 1684,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178, 3382,    1,   12,  776, 2055, 1893,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1283, 1971, 3290,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1722,  835,  179,   12,    1,    1,  116,  412,  112,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3241,    1, 1114,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  344, 3403,  868,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1229,    1,  365,    1,   32,  903,    1,\n",
      "         1447,   46,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282, 2149,  114,    1, 1908, 2468, 1722,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1340, 1426, 2174,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,  140,  768,   43,  444, 1361,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1662,    1,  384,    1,    1, 1160,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1435,  691,   12, 1436,    1,   98, 1437, 1438,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2031,  315,  248,  777,  778,  187, 2157,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,    6,   69,  532,   37,  395,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1060,   45,    1,    1,   76,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2347, 3180, 3164,    1,   39,   45, 2784,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  716, 1168, 1253,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  987,    1,    9,  923,  726,  905,  990, 1322,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  733,    1,    1,   50,   37, 1680,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 1048,   98,    1, 2909,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  848, 1465,    1,    1,    1,   45, 2759,  321,  119,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  726, 1523,   45,  166,    1,  297,    1,  171,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1675,  949, 1411,    1,   45, 2947, 1938, 2607,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  325, 1412,    1,  669,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2, 657,   1, 854, 187, 883,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 460,  39,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  885,  889,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2223,   37,   52,    1, 1332,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,  151,   28,   37,   45,  121,   12,  141,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1867,    9,  730, 1571,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1247, 1988,   45, 2214, 1340,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2145,   37,   77, 2838,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1362, 2627, 1107, 1863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  177, 2572,   32,  344, 1260,   32,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 531, 741, 105, 402,  45,   1, 428,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 107, 475,   1, 220,  69, 636,  71,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788,   12, 1629, 1236,  286, 1630,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1957,    1, 2959,  187, 3141,    1,   37,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1833,   12,  883,    1,   30,    1,   93,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1042,  315,   37,  877,    1, 1151,  105, 1766, 1767,  412,\n",
      "          402,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   37, 1075, 1282,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1242,  187, 1956,    1, 1827,   37, 2844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  994,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1290,  396,   85,   32,  645, 1034,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  220,  786, 1204,   37, 1824,    1,  166,  730, 2614, 1210,  460,\n",
      "          920,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 2170,  726,  581,    1,  497, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2699,  288,    9, 1539,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  716,  136,   51,  836,  134,   32,    1,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2, 374, 375,  37, 151,   1,   9, 331,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  63, 166, 862, 657, 338,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 2463,  424,  199,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485,  947, 1988,   45, 2148, 2832,   37, 1734,  776,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2420,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984,    1,   81,   29,   98, 2662, 2918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1194, 1843,  197,  418,   98, 1633,  616,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 1009, 3363, 2726, 3040, 2564,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   12,  786, 1056, 1136, 3018,   32,    1,    1, 2248,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,    1, 1267,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  176, 1428,    1,   10, 1454,  443,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,  267, 1913, 1843,  983,  190,  245,  384, 2073, 1843,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   98,    1,   12,   81,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1530,   32,  433,  546,   32,    1,  361, 1531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  799, 1949,  978, 3138, 2720, 2796, 1090,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,    1,    1,  614,    1, 2745,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2065,   78,   37,  588, 1067,   32, 1345, 2095,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777, 1680,  861,    9, 2798, 1718,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  773,  420, 1595,  682,   32,  385,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1312,  388, 2572,   32,  531, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1823, 2694,  590,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1674, 3134,    1, 2681, 2850,   85,  163,    1,   12,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 3149,   12,  724,  384,    1,    1,  650,   37,  166, 2095,\n",
      "           45,  121,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1060,   37,  186,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1675,  112,  719,    1,    1,  636,    6,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1064, 3042,  161,    1,  755,   81,   98,  721,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 3141, 3009, 1758,  191,    1, 2468,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  469,    1, 2699,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2528,   45,  596, 2691, 1388,    9,  987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,  953,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   28,   32, 1125,  442,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,   12,    1,   45, 2676,   12, 3153,    1, 2070, 1520,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,   66, 2587,  342,   37,  151,  199,   37,  619, 3032, 2596,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  191, 2427,    1,  330,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  982,   37, 1835,    1, 1273,  259, 1732,    9, 2801,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2442,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,  197,  202,  159,  245,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2069,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1326,   37, 1427,  104,  109,   45,    1,   37,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758, 2567,   98,  365, 2436,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 938,   1,   1, 384, 395,   1, 298, 778,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 148,   1, 647, 721,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  501,  729,    1,   98,    1,    1, 1675,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1539,  365, 2227, 1656,   32, 2573,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 2800,  696,    1,    1,   98,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273,  259,   17,  619,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  812,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160, 1161,  948, 1114,   32,  385,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  386,   78,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 3111, 2702,    1,    1, 2095,   23,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   12,    1,  464,    1,  774,  434, 1604, 2072,  403, 1585,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2170, 1488,   32,    1, 1215,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2614, 2561, 2405,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3010, 1465, 1634,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3117,  664,  885,    1,   37, 3296,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,    1,    1,  191,  306,  361,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   25,   71,  187,  615,    1,   98,  197,  716,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,  197,  418,  187,   15,  688,   93,   67,    9,  293,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 1173,  176, 2823,  736,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 3293,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  203, 1744, 3361,  565,    1,    1,  191,  786, 2116,    1,   32,\n",
      "          105, 1034,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2352, 2494,   61,  297,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  299,  300,   10,  301,    5,  302,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,  166,  487, 1938, 3197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  103, 1884,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1494,   81,  548, 1404,   12, 1857,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2870,   32,  792,  100,   45,    1,  792,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 1523,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  381,  287, 1401,  217,  417,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 1114,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   49, 1550,  315,   37,   47,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3052,   64,   36,   51,   52, 1530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1583,    1,    9,   10,   37,    1, 1461,  750,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2883,  267, 2774,  650,   51, 1911, 2251,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2640, 1830,   37, 1910, 1821, 2190,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1046,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,  354,   37, 2658, 2719,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652, 2593,  365, 1499,  353,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,    1,    1, 1417,   12, 1526, 3259,  176,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779,   37, 1343,  176,  455,   26,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2280,    1, 1792,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1326,   37,  877, 1736, 1975,   32,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2995, 2762, 1554,  111,  819,   26,   37, 2026,  126,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310, 1682, 2518,  526, 2186, 2105,    1,  202,  517,  618,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2476, 2286,   37,    1,  166, 1477, 1990,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,   52,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1081,   57,  861,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1885, 2185,  572,  197,  157,  242,    1, 1114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3222, 2954, 1937,  730,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 1923, 3090, 2716,  384, 2307,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2787,   61, 1542,    1, 1232,  105,  784,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  398, 1566,  805,   45,  829,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  942,    1,  220,   69,    1,  202,  460,   12, 1133,   37,  619,\n",
      "          176,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1665,   37,   49,  728,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,  191,   81,   37,   36,  997,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  680,  549,    9,    1, 1772,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,  12, 469,   9, 594, 497, 734,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  60,   1,  27, 687, 115,  45, 517,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 2066,  529,    1,  134,  973, 1375,   37,  354,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  692, 2086,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 2036,  140,  671,    1, 2505,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100, 1419, 1243,   45,    1,    1,    1,    1,  769,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  941,    1,    1, 1590,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,  147,    1,  544,  193, 1140,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2615,  123,   37,  132,  220, 3171, 1451,   37,  730, 2614,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1040,    1,   37, 2237,    1,    1,  403, 1447,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 1484,   98,  903,    1, 1447,   37,    1,\n",
      "          453, 3032, 1545,   88,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2190, 2640, 2270,   37,  125,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1178, 1333,   37, 2162,  191,    1,  947, 2582, 2218,   45, 2292,\n",
      "           32,    1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280,   61,  472, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1189,  190,  193,  907, 3101,   32, 2826, 2007,   37,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  598,   37,  698, 1517,  176,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1771, 1022,    1, 1414,    1,   37,  103,  903,    1, 1417,    1,\n",
      "         1022,    1,  428,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1830,  501, 1125,    9, 2707,   12, 2927,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2037,   32,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,    1,  626,  628,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1090, 1372,    9, 2975,  424,  356,  161,   82,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  527,    1,    1,  498,   37, 2035,    1, 1890,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1140,    9,    1, 1013, 1522,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1407, 1429, 2714,   32, 1446,  446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  156, 2393, 1718, 2367,   15,   92, 1652,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,  147,  134,  655,    9, 1939,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  299,  431,  432,   45,    1, 1879,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465,  744,  593,  846,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1725,  105, 2284,   45, 2532,  361,    1, 1165,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  619,  252, 1632,  224, 1126,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2709,  166,    1,   45, 2143,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  931,    1, 3260,   37,  726, 3201,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2, 193, 810, 638,   1, 254,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,  37, 582, 233,   1, 428,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   51,    1,    1,   32, 2161,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  809,  472,   39,  187, 2646,   46, 1686,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    1,  443,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387,    1, 1450,    1,  487,  750, 1190, 2770,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  150,    1,   28,  861,  220,  331,  887,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   39,  726,  297, 2321,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,  365, 1173,  176,  203, 2983,  565,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3190, 2871,    1,   81,   32, 1505,  444,    1,  171,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  294,  753,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3117, 2712, 3271,    1,    1,   32, 3235, 1798,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2018, 1065, 1190,    1,    1,  232,    1,   32,  191,  890,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 1411, 1875, 2119, 1460,    9,  903,    1, 1423,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  950,  361,    1,   12,    1, 2775,  105,    1,  724,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1388, 2094,   81, 1628,    1,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  671, 2146,  590,  388,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1,  195,  533,  576,   25,   85,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  657, 2239,   79,    1,  844, 1151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  935,  200, 1821, 2057,  315,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3177, 2753,  547,   32, 1178,  163,   12, 1918,  297,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3187,  721, 1953, 2052,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1509,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,    6,   69, 1069,  570,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3369, 1800, 1428,  861, 1906,    1,   98, 3118,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2960,   32,  531, 2414,    1, 2803,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1159, 1465,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783, 2023,  662,   37, 1787,  326,   12,  596, 1085,  112,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  475, 1010, 1786, 1535,  927,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 2450, 2927,   37, 1759,  309,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  683,   37,  698, 1090,   45, 3220,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1458,  365, 2880, 1527, 2210,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1652,    1,  829,   12, 1718,    1,  220,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  961,  573,  639,  952,  388, 1021,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  316,    1,  405,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564, 1354,   45,  581,  916,   37,  563,  104, 3141, 3009,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  151,    1,  150,    1, 2212,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,   28,  187,   69,  431,  119, 1653,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3176,  719,   37,  335,  225,  405,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144,   12, 1557,  387, 1438,   37, 1918,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   35,  193,   37, 1377,  438,  484,   98,   22,  438,  662,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437,  431,  132,    9,    1,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2559,    1, 1912, 1718, 2264,   37, 1124,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2236,   37,    1,  166,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785, 3395,    9, 1939,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  709,    1,    1,    1, 2171, 2565, 2430,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 2716,    9, 3266,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 2645,    9,    1, 2924,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1111, 1010,  386,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1545, 2800, 1218, 1831, 1231,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  384,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  848, 1419,  754, 2232, 1167,  124,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2042,  140, 2376,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,   91,  442,  379,   37, 2000,  296,   20, 2096,  104,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485,  872, 2145,   37, 1343, 2198,  542,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1558,   32,  925,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2553,   81,  361, 1075,  166, 3024, 2844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2339, 1108,    1,   32,  111,  133,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   25, 1810, 2084,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  497,  903,    1, 1447, 1324, 2385,  612, 2390, 1585,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3118, 2751, 1066,   98, 2024, 2467,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1452, 1232,  463, 1447, 2768,  193,  912,  105, 1313,\n",
      "         1897,  166, 2630,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2249,  819,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3094, 2572,   32, 2018, 2137,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1077,    1,  187, 3327,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1451,    1,    1,  163,    1,   12,    1,    1,  244,   71,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,    1,    1,  297,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  919, 2741,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  828,  588,   37,    1,  885,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3115, 1133,   39,  105,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,   12,    1, 1607,  313,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2633,  498,   37, 1145,  220,    1,  361,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2602, 3207,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326, 1294, 2297, 1254, 2334,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  878,  716, 2154,   29,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3358,   51,   52,    1,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  700,  325,    1, 1446,   50,   45,    1,  551, 1185,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  344, 3403, 2414,  187,    1, 1413, 1147,  947,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  614,   98,   11,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,  736,    1,  460,   12, 3188,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2288,    1,  193, 2312,  323,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  437,   32,  531,  267, 2414,  581,  163,    1,   12,    1, 3102,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  633, 1994, 2650,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1009,  292, 1789,  187, 1509,  129, 2225,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  931, 1073,   39,  705, 1458,    1, 2935, 3235, 1619,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   17,    1, 1064,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,  838,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   37,    1,  357,  193,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3238, 2051,  763,    1,    1,  202,  460,  833,  612,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3369, 1574, 1492, 3118, 2705, 1347,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2971, 1534,   32, 3311, 3310,  400,   51,  606, 1846,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1, 1776,  186,  489,   39,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   51,    1,  878,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  777,  773, 1685, 1378,  818, 1064,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3045,  837, 1147,  947, 1530,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1773,    1, 1425,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1841,    1,    1,  372, 1448,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3005,    1,   37,   52, 1104,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  519, 2158,    1,   39,  220,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  375,  183,   74, 1924,   32,  166,  931,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2234, 1144,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1428, 3406, 1333,   32, 3349,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,    1,    1,   98, 2143, 1816,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1212, 1874,    1,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  755,  765,  760,    1,    9,  777,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   37, 1717,   32,    1,  187,  880,    1,  846,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  494,  792,    1,  792,  797,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  144,  145,   12,  342,  132, 1770, 1296,   28,   45,   15,   61,\n",
      "          311, 1265,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,  640,  365,   94,  340, 1043,  338,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  162,  786, 1090, 2836,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  531, 2162, 1950,  640,    1,    1, 1056,\n",
      "            1, 3338,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  327, 2264,  420, 2205,  220, 3068,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1001,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,  136,  475,    1, 1905,  176,    1,  275, 1929,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  204,   12,   32,  105, 1280,   45,  247, 3215,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1497,  837, 3381,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,  315,  365,    1, 1219,   32,  717,    1,  458,  178,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,    1,    1, 2275, 1708,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   96,   98,  166, 1021,   37,  335,  671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12,  526, 2186,  844, 1091,  680,   97,   37,  125,  408,\n",
      "         1721,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 1527, 2664, 3338,   32,  531,  513,    9,  949,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  741,  856,  431,  845,  147,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  837, 1284,    1,    1,    9, 2093,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1086, 3286,   12, 1787,  176, 1194,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147, 3006, 1211, 1364,    1,    1,    1, 3365,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885, 1090, 1754,   37,    1, 2836,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2179,  627,   32,  166,  637,   45, 2911,   32,    1,\n",
      "          863,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447, 1484,   10,  792, 2500,    1,  792,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  931, 2341,  593, 2522, 1388,  220,  730, 2614,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2173,  927,    1,  176, 2163,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2389, 2390,  460,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1342,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2159,  155, 1998, 2412, 1728, 1114,  220,  365,    1,   37,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12, 3137,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3286,    1,    1, 1260,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2747,  482,  319,  314,  721,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  198,  411,   32,    1, 1002, 2116,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808, 1895,    1,   95, 1478,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3387, 2702, 2596,    1,    1, 1224,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1062,    1,   37,    1,  612,  111,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2170,  447,    1,    1,  384,  557,  540,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1149,   37,    1, 1718,  192,   41, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3344,    1, 1406, 3051, 3396,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  562,  191,  104,    1,  774,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  481,  327,  218,   66,    1,  191,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1151, 1593,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962,    1,  640,  726,  813,  187, 3117,  103, 3248,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   28,    1,    1, 2522,  270,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  314,  551, 1692, 1042, 1469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  457,    1, 1554, 3024,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,   12, 2529,    1, 1910, 1530,    1,   56, 2249,  947,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1166, 1924,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  594,    1,    1,    1,   77, 3349, 2372,  384, 1527,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2173,    1,   20,  750,  475,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2225,   45,  316,  872,   37,   52,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885, 3121,   27,  455,    1,  541,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3001, 1976,   27,  351, 2152,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   63,  166,  862,    1,    1,    1,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  510,    1,    1,    1, 2414,  176,  177,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,  693,  384,  632, 1448,  633,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  384,  938,    1,   37,  105,  501, 1389,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2700, 1173,  176,    1,    9, 1534,   45,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1603, 1170,    1,  528, 1481, 1349,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  200,  365,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1273, 1713, 1414,  220,  176,  551,  612,  613,   37, 1539,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  838,    1, 2528,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  978,  769, 1180,   28,    1,   69,   71, 2032,  682,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3147,   37,  211,    1, 2025, 2924,   37, 3118,  191,  786, 1034,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  218,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,  140, 2224,  741,   98, 3339,    1,  365, 2625,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3247,  712,  917, 1144,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1840,    1, 3235,  512,   45,  166,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,  288,   28,  704,  551,  705,   50,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  794,  306, 2304,  825, 1013,  112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1079,    1,  885, 1918,    9, 3276,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3317, 2226,  331,   81, 1371,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  328, 1471,    1, 1149,    1,    1,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1149, 1685,  508,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,  777,  778, 2794,    1,   37,  764,    1,  166,    1,   45,\n",
      "            1,   37,  759, 3000,    1,  150,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  903, 2165,  254,    1,    1, 3399,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3096, 1654,  856,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275, 1562,   10,  361, 2676,   98,  352,   12,  531, 1495,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,   79,  548,   65,  423,    1,   31, 1470,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2650,  680, 1260,  191,  957,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,  814,   50,    9,  152,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2699,   61,  297,    9,  103, 3053,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  256, 1768,    1,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  150, 1000,  166, 1762,  209,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  103,   32,  428, 2161,   12, 1002, 1293, 1690,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388, 2980, 1699,    1,   28,    9,  166, 2894,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3369, 2357,  176,  342,  909, 1665,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1414,  221,   37, 2446, 2490,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2764, 3381, 1928,    1,   45,    1,  163,    1,   12,    1,\n",
      "         1572, 1414,   32,  531,  963, 2122,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  123, 1056, 1178, 2107,    9, 3097,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2990,  565, 1284,    1,    1,  202, 1366,  729,  817, 1176,  445,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2175, 1371,   37, 1018,    1,   27,  334,    1, 2819,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  224, 2567,   37,    1,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  265,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  755, 2593,  453,  248,    1, 1228,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,  140, 1394, 2107,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1100, 2055,    1,    1,  769,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233, 1579,  993,  302,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  321,  596,  954,    1,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  575,   51, 1937, 1879,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,   12, 3372, 2450,   37, 1947, 1133, 2673,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  592,  433,  636,  304,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2634,   12,  183, 1510, 1288,  388,  763, 1021,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,  245,  995,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  844,    1, 1713,  632,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2045, 2441,  361,    1,  187, 1054, 2003, 1953, 1268,   32, 3099,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2966, 2595,   61,  363,    1,  506,   30,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1748,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37, 2284,  906, 2539,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2176,   37,  619, 2604,  626,  675,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  288,   98, 2093, 3260,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,    1,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  942,   51,  193,   38,  903,    1, 3165,  297,   37,  395, 1371,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100, 1713,  973,    9,    1,    1,  388,    1, 2232, 2012,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1278,  831,    1,  227,  550,    9,   93,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  103,   32,   74,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  374,  375,  325,    1,    9,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1029,   34,  962,   98,    1,  802,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1334,   32,  611, 1444,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,  338,    1,  108,   98,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  567,  510, 2682,    1,    1, 1887,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  225,   70,   71,  187,   69,  102,  470,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  446,  859,  121,  190,  907,   69,  569,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,  142,    9, 1065,  199,  220, 2410,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  183,  547,  877,    1, 1377,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1471, 1635,  709, 1548, 1213,   37,  582,    1, 1589,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,    1,  476,  726,  193,  341,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  398,  948,   37,    1, 2150,  149,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1814,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2843, 2523,  476,   39,   45,  166,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2844,   32,    1,    1, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2103,  617, 1116, 2867, 1211,   45,   44,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  799,    1,    1,    1, 2405, 1750, 1817,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2723, 2724,    1,   37,  949,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  861,    1,    1, 1499,  361, 2094,  829,    1,   37,\n",
      "         1468,  412,  220, 2025,    1,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  155,  347,   37,  838,  453,  954,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1425,  220, 2103, 2727,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1583,    1,    1, 2649, 1219,  123,   37,    1,  399,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1147,    1, 1484,    9,  890,  211,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  784,   45, 2218,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   12, 1994, 2819, 1705, 2572, 1010,  768, 1559,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2347,    1,  820,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3224, 1625,  193,   37, 1306,  837,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  113,  449,    1, 1002,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2238,   37, 1021, 1411,    1,  848,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962,    1, 1825,   32,  228, 2202,  187, 3232, 2651, 3296,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1353,  417, 1251, 1778, 2580,  210,   37,  854,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,  331,  686,  187,  460, 1564, 1647,   98,  797,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  744,  119,  187,  365, 2292,    1,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3108,  877,  460,  232,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087, 2614, 2446, 3236,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  179,   37,  151,  180,   32,  131,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,    1,    1,   32, 3383, 2262,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1973,    1,    9, 2472,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2384, 2355, 1013, 2560,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1481, 1800,  531,    1, 1559,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   81,   98, 1171,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2092, 2118,   98,  296, 1859,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  744, 2306,    9,  365, 2043,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  232, 2265, 1386,    1, 1532,   32,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2114, 1484,    9,  147,  231,   45, 2461,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  455, 3121, 2414, 2449, 2249,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2548,   64,  632,   36, 1623,   45, 3365,   61,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   63,  166,  862,  262,  263,   85,  419,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 3382,  891,   32, 1081,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  741,    9,    1,    1, 2409,  267, 2289,   12,  415,  166, 2247,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,   12,  405,    1,   37,  907,  649, 1821,  639,  475,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  162, 1695,   33,   28,  361,    1,   12, 1876,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2877,  230,  396,   39,   45, 2589,  220, 2276,  774, 3361,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1545, 3164,    1,    1,    9,  386, 1388,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1993,   28,    1,    1, 2156,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   85, 3271,   32,  449,   45, 1056,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  916,    9,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2360,  600,  912, 2225,    1,  967,  105,  938,  361, 2087, 2259,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492,  103, 2954, 1493, 2613,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,  144, 2152, 1229,   37,    1,   32, 2883,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  121,    1, 1411, 2640,    9, 1821, 2190,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1674, 3134,    1, 2681, 2850,   85,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1299,    9,  166,   72, 2186,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1764, 1990, 3282,    1, 1337, 1645,  142,    9,  411,  631,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  244,   71,   37,  331,    1, 1698,  356,  156, 1253,   37,\n",
      "            1,  182,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3190,   12,    1,    1,  140, 3193, 3217,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  312,  134,    1, 1428, 1414,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  297,  224, 2995,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,  123,   28,    9,   72,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3186,    1,  405,    1,   12, 3158,  119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2726,    1,  187,    1, 1585, 2414,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1095,  256, 1210,  460,  920, 2560,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2550,    1,   28,  220, 1742,  987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1012,    1,  921,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1454,  531,  443,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3355, 1114,  261,   39, 3025, 3353, 1903,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1707,  219,  693,   98, 2439,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  580, 1700,  257,   39,  220, 2347, 3131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2314, 3358,  580, 1890,   45, 1983, 1867,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  773,   28,   32, 2108,    1, 1753,   37,  222,    1, 2109,\n",
      "           98,  395,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   79,   37,    1, 2051,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3358,   51,  606,    1,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  361, 2153,   45,  255,  199,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  168,   98,  776,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2573,   12, 3398, 1654,  142,   37, 1198, 2179, 1281,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  290,    1,   98,  669,  220,   22,   23, 2471,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  934, 1702,   81, 1539,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,   12, 1811,  404, 2699,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  744, 2306,    9,  365, 2043,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  409,   25,  123,  242,    1,   60,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1024, 2865,   39,    1,  375,   32, 2513,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  636, 1086,  417,  548, 1253,  297,  104,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,  641,  453,  693,  636,    9,  647,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1022,    1, 3008,  967,  553, 3087,  452,  465, 1352,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3235, 3252,   45,  166,  356,    1,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 2257,    1,   98,  844, 1151,  315,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  422, 1484,   98, 1099,   37,    1,  156,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169,   32,    1,  176,  104,   26,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  768,  856,   51, 1121,  538,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614, 2428, 3122,   12,    1,   45,  166,  356,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,  420,    1, 2786,   45, 2707,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  678, 1863,   37,  508,   79, 1149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2455,   37,    1, 3016, 1935, 2294,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 2612,  365,  769,  220,    1,  226, 1017,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3117, 1306,   39, 1114,  424,  356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3387, 1297,   79,  803, 2909,   32, 1312, 1050, 2458,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  395,  894, 1083,  347,   37,  838,  954,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  590,    1,   37, 3144,   32,  342,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   75,   51,  729,    1, 1481,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2932, 1664, 3088,    1, 2690,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1372,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,   14,   15,  276,    9,  449,  199,   32,  297,  105,  356,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  315,   37,  130,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,   37,   92,   48,   32,  463,  464,  700,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  365, 2036,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2837, 2844,   32,  851,  298,   32,  667,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 747,   1, 372,  71,  32, 362, 408,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 355,  37,   1,  15,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  150,  354, 1660,   98,  408,  159,  701,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3206, 2067,  227,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  694,  850, 2213,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3256, 1676, 1740, 1231,  297,  195, 1867,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  108,  750,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  366,  460, 2718,  949, 2665, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1797,  361,    1,   45,  460,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  495,    1,    1,    1,  187,  389,    1, 1031,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2835,   22,  361, 1549,   22, 1421,  955,  662,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  468, 1362,  515, 2017, 1273,    1, 1228,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   55, 1515, 1939, 2681,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497,  340,    7,  600, 1798,  220, 3276,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2751,    1,  191,  178,   32, 3140,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2499, 1249,    1,   32,  593, 1990,    1,  548,  594,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 2527,    1,   32, 2140,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3111, 2905, 1479, 1995,   32, 3155,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3117, 3271,   37, 1343, 1056,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2606, 1089, 1229,   37,   16,    1,   45, 3340,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1419,  365,  659,   45, 2255,    9, 2168,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,    1, 1423, 1539, 2069,  903,    1, 1973, 2024,  973,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  365, 3316, 1641,  187,    1,   39,    9, 1700,  257,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2614, 2561, 1809, 1330,    9,   10,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  522,   32, 3369,   61,  110,  920,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2302, 2185,    1, 1347,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  634,    1,  361,    1,  686,    1,    1,   32, 1981,    1,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1,   37,   47,   56,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2406, 2885,  952,   37,    1,    1,  646,   93,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1742, 2107, 3196, 3009,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  864, 2744, 1461,   37,  453, 3344, 1414,  548, 2133, 1463,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  986,    1,   54,    9,    1,   50,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1568,    1,    1,  551,    1, 1332,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 2767,  449,    1, 3044, 2232,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  943, 3076,  220, 2805,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2569,  957,    1, 1583,  475,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  186,   98,  417,   69,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1128,    1,  326, 2686, 2687,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3151,   76,   37,  360,  474, 2362,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1640, 2774,  267,  190,  946, 1602,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1133,  365, 1506,   98, 2095,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1, 1554, 1530,    1, 2249,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   65,   98,    1, 1438,    1,    1,  191,   69,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   91,  361, 1573,   98,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   68,   69, 1298, 1382,  548,  383,   98,  677, 1147,  568,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 1976,  323, 1387,  539,    1, 2378,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3029, 3027, 1478,   98,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,  181,    1,   32,   91,    1,    6,    4,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1024,    1, 1159, 3220,  220,    1,    1,    1,   98,  247,  175,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   47,  176,  612,  207,  259, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  105, 1841,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800, 3213,    1,   28,   37, 2857,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1913,  401,  354,  703,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  548,    1,  653, 2671,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  848,  572,  207,  197,  418,    1,    1, 1269,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746,  376,  858,  102,    9,  365,   17,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1110,  361, 2551,   16,    1,   61,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1271,  297,    1,  395, 2108, 3368,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1743, 2536,    1,    1,  852,  115,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 1070, 1479,    1,   37,  949,  987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2137,  686,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303, 1310,   37,    1, 2053,  509,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  455, 2164, 2986, 1046, 2620,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 1564, 1674, 2666,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2597, 1656, 2950, 2414,  249, 2083, 2611,    1,  101,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2314, 3230, 1249, 3001,   32,    1,  427,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1236,  681,    9, 1228,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497,  619,  581, 1023,  120,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  171,  140, 1114, 2198, 1292,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 3202,    1,    1,    1,  542, 1897,    1, 1090,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  384, 2041,    1,   37, 2408,    1,    1,    1,  884,  105, 2148,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181, 2120,  982,  384,  590,    1, 1569,    1,  202,  166,  197,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  487, 2932,    1,  678, 2275,   12, 1841,   81,   37,  219,    1,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2279,  267,  247,  442, 2385,  612,  166,    1,   45,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,  220,  903,    1,  464,  927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585, 2414,   98, 2835, 3101, 2735,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,    1, 2829,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796,   64,   12,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,    1,  176,    1,    1,    1, 3011,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504, 1065, 1190,    1,   37,    1,    1,   32, 2755,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1035,  361,  386,  619, 1253,   32, 2941,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  206,   12,  197,  418,  202,    1,  308,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  395, 2609,    1,   12,    1,    1,  455,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746,   37, 1155,  116,  259, 1294,    9,  479,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  867, 1936, 1003,  176, 2232, 1182,   32,  443,   98, 2086,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485, 2924,   37, 1334,   98,   32,  531,  528, 3102,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  790, 1579,  815,   45, 1151,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1582,  193,  187,    1,  187,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962,    1,    1,  405, 3291,    1, 1245,   37, 1194,   73,\n",
      "          726,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   42,  961,  549,    9,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2055, 1090,    9,  730, 2614,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  686,   81,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2563,  664,    1,  320, 2275,  894,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  225,  218,  186,    1,  191, 1507,   69,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  156,   71,  158,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 1756,   12,  449, 1034,    1,  590,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  602,   12,    1,    1,  361,  247, 1404,    1,  632, 3065,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1090, 1829,  365, 1788,  176, 2206,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1697,    1,    1,  187, 1370,   45, 1515, 2181,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,   51,  582,    1,  721,   45,  442,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2934,    9,    1,   45, 2218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,   37,  151,  294, 1983,    9,  152,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  220,   81,   37,   81,  140,    1, 3276,  565,   81,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1,  872,   32, 3369,   37,    1, 3148,  716,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1173,   37, 2391,    9,  753,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835,  387,  221, 2029, 1094, 2708, 2024,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  105, 1173,  176, 2703, 2644, 3102,   32,  531,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  929,  796,  425,  426, 1160,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  614,  501,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2434,    1, 1714,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  732, 1949,    1,    1,  541,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1834,    1, 3341,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1123, 2615, 1289,    1,   37, 1183,  730, 2614, 2775,   45,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1183, 1314,   37, 3018,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977,    1,    1, 1167,    1, 3027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2676, 1707, 2275, 2081,   98,  531,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1147, 3356, 2892,    1,   27, 2646, 3133,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3087,  686, 1081,    1, 1887,  361,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,   28,  187,  889,  679, 1588,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 1625,   37, 1155,  633,    1, 2382,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,   81, 3018,  315,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1,  603,   37,   47,   56,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2442, 2911,  360,    1, 2362,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  650,   45,  487,    1,   61,    1, 1816,   45, 2143,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1973, 2565,  167,  877,    1, 2218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3152, 1025,  435, 2967,  442,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1340,  894,  619,  247,  916,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  550, 2165,    1, 1822,  860, 1889,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3343, 1009, 3067, 2292,  444, 1527, 1149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 1447,   12, 1009,   37, 1504, 1700, 1726,   32,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,   12,    1,    1, 3344, 2735,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,   37,  907,  242, 1633, 1567,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2801,  361,  982,   32,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671,  640,  356,  845, 1018,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    9, 1183, 2113, 2788,  932,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1824,    1, 2232, 2175, 1837,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  600, 2269,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2895,    1,   51,    1, 2855, 1377,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,  531,  957, 1631,   79, 3391,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  581,  617,  697,    9, 1081, 1260,    1,  691,  267,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3151, 1949,  810, 1292, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  888,  729,    1,  257,  548, 2936, 2909,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3089,  921,  428, 1002,    9, 2073,   73, 1034,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2902, 2287,   28,    9,   80,  297, 1766, 1767,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   65, 1702,   28, 1184,  347, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 1785, 1313,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1428,    1, 1152,   45,  323, 1512,   32, 3339,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,    1,    1,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  727,  515,  846,   92,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1286, 1245,    1,    9,  375,    1,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  375,  387, 3119,  856,  187, 1284,   81,   28,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   52,  220, 3320,    9,  228,  388,  537,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1645,    1,  140, 1940,   12,    1,    1, 1684,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1962,    1, 1431,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2178, 3382,    1,  776,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  167, 1251, 3199,    1,    1,  388,  763,   59,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2615,  123,  220,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  505,  195, 2260,   37,  388,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3177, 2825,  167,    1, 1684, 2107, 3213,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1920,   12,    1, 2134, 1656,  230,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1596,  190,  470,  166,  888,   45,  503,  615,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1413,   32,  365,  693,    9,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  449,    1, 3186, 3224,  894, 2553,   39,  105,  356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  804, 1031,   32,    1,   51,    1,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  424,  302,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1757, 1665,    9,  531, 3365,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1010,  105,    1,   45, 1031,    1,    1,  571,   37,  247,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1028,  395, 2776,    1,    1,    1,   37,    1,  652,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  171,  546, 2800, 2565,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982, 1867,  331, 1943,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   10, 1648,   37,  619,   37,    1,  220, 2972,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2536,  187, 2551, 2565,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  315,  665,   98,  429,    9, 2193, 2031, 2606,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,   37,  130,  552,    1,    9,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3113,  794,  116, 1074,   37,  345,  171,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,    6,  377,    4,    1,    1,  311,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1, 1363,  973,    9, 2255, 2461,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1899,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  171,   45, 1193,    1,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  728,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1585,   32, 2835, 1094, 2735, 1606,    1, 2596, 3043,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870,   12, 2261,    1,    1, 2812,  176,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,  359,  474,    1,   37, 1195,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   68,  640,  119,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3298,  140, 1909, 2227, 1684,  548,  581,  913,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  119, 1722,   45, 2476,  193,    1,   98,  223,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1910,  730,  171, 2142, 2072,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2476, 2047,    1,  388,  763, 2964,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  405,   12, 1508, 2469,    1,    9,  914,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1744,    1, 1338, 1452,  105,   56,  356,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  593,  442,  656,    1,  162,   92,  384,  961, 1723,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1791, 3343, 3353,    1, 1061,   32, 2018,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  729,    1,    1, 2221,  267,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  619,    1, 2334,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,   37,  138,  331,   37,    1,  875,  573,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2557,   37, 1861, 1791,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3132,  168,   28, 3232,  726, 3201,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785,    1, 1760, 1273,  259, 2530,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3115,  565, 1166,  166, 2551, 1210,   37,   52,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  598,    9,  581, 1463,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1024, 2619,   98,    9,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,    1,  754,   45,    1,  344, 3403,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  116, 2542,  162,    1,    1,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1,  680, 2106, 1075,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  547,  730,  931,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 1414, 2833,    1,  237, 2416,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,   81, 3018,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3298,  140, 1796, 1938, 3197,    9, 1194, 1918,   45,  914,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2919,   45, 2846,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545,   12,    1,    1,  763,    1,   12,    1,  267, 3277,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,    1, 1343,  191, 1969,    1, 3275,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1838,    9, 3196,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1497, 2787,   39, 2119,  220, 3131,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  171, 2565,  884, 1983, 1910,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,  856,   45,  166, 3025, 1841,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1518,  777, 2641,    9,  861,  231,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1889,  802,   37,   92,   33,  402,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  779,    1,    1,  408,    1,  487,  460,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  838,    1,   62,    1, 3145,   37,  671,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1824, 1477, 1990,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2807,    1, 1554,  220, 1827,    1, 1987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  375,    1, 2551,  321, 1844,    1, 2222,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1648,   37,    1,    1,    1, 2751,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,    1, 1672,    9, 2513,  401,    1, 1148, 1437,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3345, 1211, 2002, 3096, 1292,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984, 2981,  884,  105,  123,   28, 1173,  176, 2662,   12,  633,\n",
      "         2918,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  306,  952,  332,   45, 2937,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1189,  307, 1094,  427,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2335,  249, 1530,   32, 3043,  344, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1, 2414, 1711,    1,  384,    1,    1,   32,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2871,  971,    1,  105,    1,    1,    1, 1176,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   12,    1,    1,   28,  191,  208,   12, 1009,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  565, 1584,   79,  166, 2904,  191, 3115,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   45,    1, 1018,  105,    1,    1, 1018,   12,    1,\n",
      "            1,  105,  612,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3250, 1421,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2048, 1685,  869,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3321, 1584,   39,   45, 2611,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  921, 2933, 2601,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977,   37, 2354, 1821,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  459,   28,   37, 2723, 2724,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1223,    1,   32, 1957,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  435,   69,    1,  949,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1307,   37,  693,   40,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,   12, 2933,   74,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2227,    1, 1417,    1, 1417,    1, 1579,  196,  132,   37,  151,\n",
      "          176,  612,  613,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708,  446, 1070, 1645,    9, 3358, 1983,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1292, 1576, 2230,   32,   59,  768,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 1082,   91,    1,  104,   37, 1604, 2444,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1233, 1149, 1415,   37,  477,  522,  297,  389,    6,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   26, 3169,  640,  103, 2287,    1, 3168,\n",
      "         1177,   98,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  487, 2924,  582,  403,    9, 2699,   27, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2890, 2247,   15,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,    1,    1,  920,  415,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,    4, 1754,   32,  367,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,  584,  365,  567, 2405,   37, 2288,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1039,  267, 3327, 1036,   37,  463, 2926,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1477, 2494,    1, 1765,  105,    1,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479, 1203,    1,    1,   37, 2324,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2480,  772,  614,  613,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1, 2424, 3229, 1463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3248, 2761,    1,   39,    9, 1694,   45,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2694,    1,  625,    1,  104, 2909, 3391,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2222,  162, 1194,  726,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2751, 1207,   37,  815,    1, 2375,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2232, 1828,  361,  983, 1124,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  193,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2, 198, 567,   1,   1,   1, 584,  88,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 326,   1, 331,  32, 192,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1223, 1765,  613,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1425,  166,  593,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 2997, 1044,   39,   37, 2994,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,   27, 1547,    1,   94,  687,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3238, 1542,   37,  184, 1114,   32, 3220,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,  140,    1,  132,    9,    1,  104,    1, 1346,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3207,  695, 1544,    1,  202,    1,  176, 1930,  418,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  442,    1,  619,    1,  176,  397,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1613,  361,  829, 1413,   98, 1273, 1117, 1525,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  838, 1107,    1,  361, 1221,   12,  105, 1089, 1090,\n",
      "            1, 1176,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,    1,   32,  593, 1990, 2069,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2197, 1566, 1718,  221,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  171,  879,   24,   45, 2800, 2565,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1449,   37, 1083, 1270,    1,  131,  104,   32,  457,  394,   37,\n",
      "          138,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1156,    1, 1713, 2708, 2823, 2107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  375,  580, 1281,  361, 3126,    1,  548, 3251,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  442,  910,  703,    1, 1068,  568,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,   37, 1463,  395,  361,  121,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  213,   37,  151,  602,   12,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  647,  105, 2740,  132,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2, 822, 681, 498, 596, 170,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 335,   1, 384,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1306, 2741, 1675,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3297,   32,  472,    9, 2771, 1090,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  236, 1022,    1,   66,  410,  647,   66,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  433,  636,  418,  699,    9,  581,  339,   32,  385,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3190,    1,  113,   79,  878,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2751,  837,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  119, 2098, 1545, 2872,  608, 2982,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 2170,   32,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  422, 2008,  284, 1476,  574, 1469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  213,   98,    1,  573,  399,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1147, 2153,  907,   32, 2024, 1705,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,   12,  365, 2869, 2510,  105,  183, 1031,  384, 1090, 1667,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3110,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  376,  367,   15,  570,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3337,  603,  227,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236, 1022,    1,   76,   37,   26,  699,  417,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2018,    1,    9,    7, 2764, 2765,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  191, 1417,    1, 2226,    1,  105,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2570,  921,  428, 1002,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  869, 1465,  595,  166, 2491, 2085,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  444,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1685, 1260,  384, 1384,    1,  297,    1,   46,  220,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2942,    1,   61, 1960,  105,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3120,    1,    1, 3083,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1477, 1990,   91, 2783,  166,  449,  402,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2160, 2049, 1042,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1140,    9,    1, 2162,  290,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 1300, 2492,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  766,  767,    1,    1,   45,  768,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1061,  220, 2196,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2, 409,  25, 245, 187,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 217, 162, 422, 290,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1352,  495,  288,  198, 1224,   45,    1,    4,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2305,  548, 2125, 1394,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1548, 1203,    1,    1,  297, 1665,   45,    1,  114,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  430,  315, 2699,   37, 3118,  187, 3369,  859,   37,    1, 2024,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1509,    1, 2491,   32,  844, 1123,    1,  187, 2614,    1,\n",
      "         3132,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,   51, 1195, 2875,  541,   32,   51,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2688,  280,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428,    1, 2506,  600,    1,  931,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  449,    1,    1,  256,    1, 1243,    1,   82, 1435,\n",
      "            1,  225,  636,  361,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,    1,    1,  648,  187,   82,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   22,    1,  122,   37,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1842,    1,    1, 1749,  220,  179,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2286,  424,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1258,    1,  857, 1505,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1398,  612, 1140,  460,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  461, 2871,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  162, 1437,  872,    1,    1,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1114,    1,    1, 1203,  388,  259, 1871,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  200,    1, 2948,  210,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  474,  907,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1762,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  267,  460,   12,    1,  384,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  434,  105, 2341,  777,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1,    1, 1530,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2, 355, 108,  45,   1,  15,   9, 105, 356, 357, 320,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  12, 181, 100,   1,  45,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  964,  765,   37,    1, 2106,   12, 1021,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2977,    1, 2974,  361,  440,  457,    1,  321,    1,   37,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  251,  441,    1,  861,  420, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 1739,  400, 1634,   37,  211,    1, 2231, 1874, 1381,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1133,    1,    9, 3132,  415,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  876,   12,  469,   37, 1289,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2974,  140, 2695, 2223,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  415,  774,  590,  994,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1412, 2521,    1,  334,  894, 1847,  600,  486,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1502, 1008,  453,  518,  940,  187,  365, 1503,  475,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2752,    1,  555,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3249,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,   12,    1,   37,  151,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1751,  702,  197, 1297,   82,  544,  388,  220,  388,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3213, 1231,  220,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  973,  361,  489,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1075, 1484,  199,   98,    1, 2937,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,  187,  218, 1489,    4,   29,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1103,    9, 2476,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,  947,  877,  449, 2147, 2950, 2263,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1472,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479, 1500,  197, 1470,    1,    6, 1233,    4,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2378,   90,   45,  608,    1,    1,    1, 1019, 1204,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   82,  948,  138,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1899,  680,  433, 2263,   32, 1966,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 2073,   73, 2295, 2472,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1333, 1187, 2739,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1988,   45,    1, 2819,  428,  172,  550,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  592, 1484,   98,  395,   37,  720,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 2221, 1562,   10,   98,  596, 1793, 1563,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2932,    1,  323,    1,  680, 2206, 2989,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3225, 1421, 3224,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1656, 3035,  477,   27,  501, 2060,    1, 1530,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,   98, 3042,  161,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1273, 1675,  619,    1,    1,  388, 2212,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,   37, 1982,    1,  600,  111, 1107,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   32,  750,   45,    1,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1414, 2856,   56,   32, 3360,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1973,   12,  594, 2731, 1705,   32, 2073, 1023,  515,  694, 1204,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1257,  439,   46,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962,    1, 1164,  764, 3263,  439, 1826,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1702, 1013, 1017,   37,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,   12, 1733,  884,  297, 3344, 1414,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  621,  325,  622,  623,  624,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  691,   90, 1081,    1,  868, 1372,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  914,  166,  356,  584,   12,    1,    1,   39,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,  645,  649, 1347,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3297,   61,  972,  166,    1,  872,   39,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  577,  157,    1,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1523,    9,    1, 1398, 2959,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    4,   51,  168,   32, 2813,    9,  365,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425,   51,  151, 1883,    9,  297,  131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    9, 1383, 2027,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2457, 2332, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2767,  388,    1,    1, 2165,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2819,  625, 1463,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  446,  544,  193,    1, 2573,  220, 1656, 2950,   32, 3379,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 2596, 2414, 1056,  104, 2548,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,  952,   37,    1,  616,   98,  347,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766,   37, 1504,  436,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3352, 2856,    1, 2833, 2375,   32,  121,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  709, 3228,    1,    1,  187, 3194, 3195,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   58,   82,   37,  631,  293,  861, 2082,   23,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   37,   47,  183,   49,   50,  176,  340,  439,  636,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1935, 2071,    1, 3016, 1935, 1935, 2294,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3343, 3396, 1000,  105,  754,   32,  942,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1211, 1994, 2693,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1286,   21,   15,   37, 1269,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  336, 3389,   32, 1094, 2856,  176,  177,  361,    1, 3094,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 2751, 1734,  191,    1,  114,  528,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 1201,    1,  267,  460,   12,  435,  333,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1906,  520, 3369, 3146,    1,  104,   37,    1,   98, 3148,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,  81, 267,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 328, 144, 145,   1, 197, 338,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   39,    1, 2161,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189, 1114, 1118, 2092,  172,  932,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1390,  431,  885, 2786, 1384,  895,    1,  424,  199,  220,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  686,  220,    1,   32, 2884,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3322,  750,    1, 1628,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2754, 1462, 1190, 2070,    1,  297,  531, 2128, 2271,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2845, 2507, 1211,    1,   37,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,  293, 1066,   32,  453, 2179,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   12,    1,    1, 1597,   37,  938,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  957, 1278,   28,  995,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1173, 1492,   12,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1459, 2860,  361, 1557,    1,    9,    7,  353,  187,    1,  741,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  303,   12,  100,  190,   52,    1,   37, 2535,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,    1,   37, 2510, 1220,  187,   57,    1,  332,  636,   71,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  550,  369,    1,  936,  469,   37, 1496,  253,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810, 3065,    1,  872,  933, 1089, 1675,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  770,   45, 3340,    1, 1976,   32, 3360,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,   25,  698,  176,  339,  845,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  578, 1509, 1724,   37,   18,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,    1,    1,  166,    1,    1, 1594,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2504,  446,   37, 2653, 1833,  187,  388, 2909,  135,  463,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826, 3185, 1676,  535,  665, 1255,   12,    1,  530,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  864,   37,    1,   37,  219,  693,  187, 2673,   46, 1195,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,    1,  808,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1,  861, 1897,  166,    1,   45,  166, 2708,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2104,  251,    1,   98, 1345,  596, 2429,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1459, 1877,   37, 1000, 2231,   12,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1766, 1767,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2178,  147, 1268,    1,  776,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102, 1269,  187,  122,  470,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3116, 3217, 1618,   28, 2861, 1159, 3293,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,    1,  220,    1,  176, 3102, 1887,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  852,   37, 1636, 1778,  176,  754,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1269,   98,  160,  174,  420,  550,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2855, 1343,   98,  997,   45, 1450,    1, 1681,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 1037,  275,    1,  590,    1, 2748,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2222, 2202,   39,   45,  493,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,    1,  104,   37, 2000, 1700,  454,   46,   32,\n",
      "         1837, 1043,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275,    1,   98, 1992,   37,  403, 1447,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993,    1, 2994,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  515, 3260, 2522,  631,  297,  931,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  967,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  338,  548, 1819,    1, 2098, 3265,  361,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   12,  734,  469,  155,  122,  104,  358, 1384,  132, 2007,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  970, 1876,    9,  715,  471,  953,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3252,   61, 1120,   37, 1334,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  746,    1,  747,   37,  151,    1,    1,  150,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,   32, 2138,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1104, 2215, 2554, 2693,  774, 2425,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387,  932,  530,  308,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  242,  187,   69,    1,  384, 1653,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  884,  166,  631,  297, 2473, 2367,    9,  166,  449,  199,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2214,    1, 1937, 1443, 1936,  377,  618,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  663,  379,   46,   45,  443, 2938,   32, 3118,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3318,  608,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  267, 1147,  957,  762, 1044, 1876,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  179,    1,  180, 1982,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3117,    1, 3271,   37, 1066,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,   12,  964, 1454,  221,   37,    1, 1021,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112, 1470,  460,   12,  603,   55, 2936,  357,    1,    9, 1503,\n",
      "          590,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1039,  668,  293,   37, 1753, 1465, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2762, 1268,    1,   32, 1778, 2168,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1128,  459,  331,    1, 1085,  132,  220,  212,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2737,  825,    1, 3311,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2489,  915,    1,   63, 1857,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092,  992,   28,  856,  444,  111, 2086,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  657, 1702,    1,  220,  388,    1,    1,  417,  102,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,   60,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1755,  176,  900,  187,  574,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,   28,  202, 2449, 1315,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 163,   1,  12,   1, 246,   1,  69, 384,   1, 428,   1,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 829,   1, 915,   1,  17,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2196, 2780,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  223, 2135,    1, 1056,    1,    1, 1294, 2253,   37,    1, 1384,\n",
      "         2096,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2, 657, 376, 737, 570,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 455,  25, 526, 548, 236, 237,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1495,  220,  150,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   85,    9, 1645, 3365,    1,  531,  957,   32,  861,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1041,  119,  331,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  683,    1, 2709,  384,    1,    1,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,    1,  469,   37,  576, 1178,   37, 2918,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1523,    1,  297, 2206, 2435,  826,  408,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  311,   37, 1864, 2596, 1665,  427,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169,    1,   28,   32, 2304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  190,  930,    1,    1,    1,  361, 1608,  865,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  812, 2422,  176,  985,   45,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1245, 2651, 1139, 2845, 1668,   32, 3332,   12,  714,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   25,   26,  699,  242,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2504, 2736,   12, 1727,   37,  439, 2292,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3238, 1408,  661,   98, 3288,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343,  863,  729,   26,  774, 1443,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  189, 1635,    1,   37,  764, 2324,  596,  172,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1396,  388, 2311,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,  342, 1814,   37,    1, 2834,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   37,  877,  647,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2707, 1822,    1, 1511,   37,    1,   93,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,  105,  278,    1,  105,    1,   45,    1,    1,  943,  361,\n",
      "         1089,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   60, 1276,  115,   45,  303,    1,    4,   29,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  128,    1,    1,  972,  176, 1687, 1022,    1, 3008,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 2151, 1996,  987,    1,  573,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  381, 1654,  547, 1682,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788, 1401,  104,   32,  962,    1, 1252,   61,  915,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1725,  893,  469,  105, 2210,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  496,  460, 1278,   37, 1192,    1, 1411,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    1,  135,   98,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3204,    1,   37,  166, 2010,   32,  726,  297,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671, 1078, 1654,  601, 1076,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,    1,    1,  164,  165,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  845, 2395,  938,    1,    9, 3249,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1815,    1,  469, 3136,  477,  297,  966,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,   85,  548,  411,  504,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   45,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2448,  386,  159,  720, 1010,  420, 1167,   46,  606,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,   37, 1706,   59,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,  559,  854,   37, 2712,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3257, 2493,  204,   12, 1533,  384,    1,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  341,  640,  144,  145,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3196,  140,  395, 1938, 3197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  267,  799,    1, 1298, 1080,    1,  202, 2978, 1604,  388,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1273, 2639,  794,  411, 1267,    1,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1748,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  144,  145,  794,  142,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  182,    1, 1417,    1,  162, 2613,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  831,  548,  531,  965, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3069,    1,  121,  386,  444, 2834,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2, 982, 835,   1, 428,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 395, 859,   1,  45,   1, 372,  32, 208, 328,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2424,  166, 3024,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1107, 1863, 2382,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  297, 2851,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2292, 1258,   32, 3155,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2038,    1, 1877,    1,    9,    1, 1492,    1,    1,    9,\n",
      "          247,  389,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2193, 2800,    1, 1380,   98,  105,   16,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  355,    6,   93,  569,    1,    1,  460,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597, 2224, 1190, 1941,    1, 2886, 2572,   32,    1, 1656, 2950,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101,    1, 2708, 1726,  907,   32, 1327,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2811, 1965,  439,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,    1,  660,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  217, 2506,  444,   98,  260,  133,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1898,  220,    1,   37, 1413, 1317,  704,  104, 1611,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359, 2361,  539,  458, 1165,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1850, 3343,    1,    1, 1711,    9, 2823,  186,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,    1, 2314,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   46,    1,  187, 1345, 2478, 2646,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1486,  155,  570,  548,  198,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3204,    1,  608, 3253, 1159, 3293,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1458,    1,  423, 1232,  102, 1334,   28,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1518,    1, 2147,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2161,   12, 3282, 3174,  288,    9,  885, 1684,  548,  104,   26,\n",
      "          726,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1538,   37,    1,    1,  981,  284,    1,  379,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,  163,    1,   12,    1, 2501,  861,  475,  387, 1598,   98,\n",
      "         2026,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1950,  665,  176,    1,   32, 2891,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,  670,    1,   60,  242,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  191,  865,   37,  244,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,    1, 1070, 3361,   37, 1173,    9, 3102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   79, 2378,    1,  247, 2344,  565, 1286,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,   12,    1,  119, 1628,  232,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1183, 2626,    1,  202, 2971, 1564,  284,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3308, 1579,  815,   45,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2551, 1822,  544, 2198,  375,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61, 1708,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1114, 3117,    1,  191, 2685,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  282,    1, 1525,    1,    1, 2759,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   18,  361, 1413,  104, 1082, 1481,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61, 1888,    1,  202,    1,  612,    1,   39,  865, 2256,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  112,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,    1, 3116,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3213, 2489,   85,  898,    1,   28,   98, 1545,  872,  336,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1963,   12,  724,   34,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  103, 2132, 3190,  113,   81, 2906,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671,  357, 1977,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,  632,  876,  612, 1579,  170,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  857,  120,  919,  104,  608, 2427,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2924,  665, 1133, 1574,   37, 3128,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  208,  140,  449, 1674,  671,    9,  537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  166, 2391,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835,  429,   79,  857,    1,  186,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  741, 2478, 1759,  309, 2746,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 1881,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,    1, 1514, 1178,   37,  631,  922,  187, 1756,    1,\n",
      "           98,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 1658,  637,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  123,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,    1, 2706, 2232,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3276, 1937,  590,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   22,   51,    1,  710,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,  476,  260,    1,    1,   37,   52,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  315,  365,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37, 2284, 1411, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1021,   98,  176, 2396,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2596,  640, 3379,   12, 2197, 2147,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1236, 2931,  923,  297, 1247,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1384,  474,  936,  439,   37, 1300, 2054,  477,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,  395,  590,  805,  384,  395,  945,   69,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1228,  108,   45, 1985,  365,    1,   32, 1778, 2580, 2851,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  544,  166,    1, 2595,  606,  105,  469,  182,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1110,  729, 1188,  183, 2447, 2072, 1340,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  920, 2202,  890,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2902,   32,  132,  220, 1051,   32,    1,  973,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1592,  176,    1,   37,  764,  927, 1159, 2764,  186, 2137,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1314,    1,    1,  583,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260, 1398,  612,   55,    1, 2643, 1890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  107, 1587,  187, 1588,  817,   98,   69,  636,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1137,   37,  365,  119,  297,  104,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  770,    1, 1796, 3102, 1976,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,    1,  588,  201,  525,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  571,   37,    1,  147, 1602,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,   12,    1,    1,    1,  220, 1852,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2050,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3303,  140,  119, 2674,  427, 1343, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  387,  198, 1168,    1,    1,   93,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1327, 1489, 1717,    1, 2410,  220,    1,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 190, 151,   1,   9, 331,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 166, 601,   1, 356,  98, 119, 428,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   61, 2145,   32, 1095,   15, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3190,    1,  103, 1569,   32,  428, 2800, 1002,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,  418,  239,  720,    1,    1,   37,  759,  786,  339,  340,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  582,  190, 1910, 1351,  220,  445,   37, 1814,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  920,  334,    1, 1176,    1,  321,  248, 1340, 1194, 2907,  873,\n",
      "         1232, 1851,    9,  105,  234,  182,  235,    1,    1,    1,  234,  182,\n",
      "          235,    1,    3,    0,    0],\n",
      "        [   2, 1110,    1,  162,  726,  297, 2563,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1874,    1,   37,    1, 1638,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492,    1, 2701,  726,    1, 2018,  563, 1447,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3198,  986,  636,    9,  857,    1,  176,    1, 1990,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1084,  841, 2575,  897, 1159,  105,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   32, 2104,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  883,   93, 1071,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1436, 1631,   79, 1903,  220, 3278,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  313,    9, 1254,   95,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,  163,    1,   12,    1,  498,    1,   45,  284,    1,\n",
      "         1196,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3109,    1, 1769,   37,  759, 2468,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2765,   37, 2564, 1479, 2688, 1260,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,   28,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2918,    1,    1,    1, 3064,  565,    1,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,    1,  384,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  726,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965, 2982,    1,  722,    1,  836,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2373,    1, 2403,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  134, 1665,   37,  104,  218,  519,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962,    1, 3296,  877, 3209,  713,    9,  404, 1684,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1237, 1658, 1117, 1525,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3269,  884,  460,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1583, 2731,    1, 3374, 1957,  686, 1094,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2494,  872,    1, 3077,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3281, 2386, 3306,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3178, 1918,   32,    1,    1,    1,  801,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1784,   37,    1,    1,  176,    1, 2284,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  199,    9, 3278,    1, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 2962, 1245,    1,    1,   37, 2035, 2315, 1045,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    9,  403, 1447,    1,    1, 2493,  105, 1056,  454,  237,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  985,   13, 1670,  562,   37,   47, 1671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  430, 1426,    1,  114,  220, 2751,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  409,   25,  439,  417,   98,  197, 1936,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2974,   37, 1539, 1114, 1602,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  581, 2175,  176,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  433,  636, 2401,    1, 1186,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,    1,  764,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1809, 2997, 2219,  361,  388,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2026,   98,  166, 1124,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1537, 1228,  633,  159,  698,  605,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1940, 1833,   12, 1509,  140,    1,  191,  998,   79, 2142,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  758, 2937,    1,    1, 1176,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,  908,  196,    1,  176,  612,  613,  170,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 2673,    1, 1542,   37,  865,   37,  531,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,   32,  365,  613, 1597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158,   12, 2452,  517,  775,  187,  593,   12,    1, 2355,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  155, 1128,   12, 2183,    1,  734,  731,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1212,   12,    1,    1, 2288,    1,  877,  105, 2457,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766,  936,  166, 1411, 2273, 1935, 2294,    1,  191,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   15,   28,    9, 1772,   98,  163,    1,   12,    1,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3203,   12,    1,    1,    1,    1,  384,  403,  464,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1700, 1976,  514,   32, 3386,  966,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,  884,    1,  176,  829,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3111,  384,    1,    1,    1,  274, 2572,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,  359,   81,    1, 1213,    1,  125,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1988,   45,    1, 1350,  625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 1009,    1, 2404,    1,    1, 1896,   37, 1211, 3365,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1189, 3372, 1579, 3107, 3366,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  284,  352,  589,    9,  531, 1085,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1053,    8, 2596, 2393,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  923,    1, 3042,  161, 3031,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  102, 1253,   32, 1352,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3317,    8,  304,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  256, 2890,  671,   37,    1, 3077,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3039, 1089, 1090,  640,  166,  116,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  328, 3123,  856,   81,   37,  688,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2280,   12,    1,  726,    1,   32, 1962,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,  338,   37,  365,  119,  340,  951,   94,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545,    1,  176,   71,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 2497, 1396,   32, 3155,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1066,  724,    9, 1244, 1897, 1209,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321,  612, 1366,  810,  415,  619, 2100,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,  210, 1297,  249, 2436,  705,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3038, 1585, 1965, 3149, 2208,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,  143,  187, 1547,  246,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  884,  631,   32, 2419, 1828,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1440, 2642,  872,  420, 1352,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  304,   98,  593,    1,   74,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3345,    1,  792, 1103,  220,  105,    1,   45,    1,  792, 1897,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  219,    1,   96,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3169,    1,    1,   37,  759,  915, 2144,  176,  163,    1,   12,\n",
      "            1,   26,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  777, 1085,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1100,    1,   39, 1101,  315,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 3365, 1229, 2793,    1,    1, 1281,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2238,   37,  665,  388,   23, 2072,  657,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 1304,   82,   51, 1046,  521,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3160, 2780,    1, 1204,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  375, 2257,   39,   45, 2743, 2213,  922,  907,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3120, 2712, 2290, 3259,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1457,   45, 1743, 1441, 1459,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3177,  140,  625,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  774,    1,   37,  166,  199, 2596, 2988,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1668,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2828,  753, 1278,  986,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1821,    1,    1,  220,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3119, 1445,  459,    1,   37, 2381,  356,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  917,  199,    9,  365,  105,   12, 2773,    1,   12, 2907,   32,\n",
      "         2513, 1631, 1832,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0],\n",
      "        [   2,    1, 2677, 1178,  386,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  856,  297, 2631,    1,  111,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2685,  665,  885,    1,   32, 3117, 1625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,  558,   27,  132,   37,  151,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2356,   45,    1,  966,  134,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 1571,    1,    9,    1,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12, 1447, 1760, 1196,   45,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1307,  200,  449,    1,  259,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2355, 1013,  884, 1003,  176,  829,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3076,  919,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  829,  267,  460, 2556,   37,  332, 2690,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1440,    1, 1760,    1,   15,  176, 3283,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3045, 2856, 3340, 2548,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  754, 2202,   51,  606, 2626,   37,  247,  582,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564,    1,   32, 1183, 1253,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   78,  663,  664,   39,   37,   80,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98, 3020,   45, 1350,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2881, 1484, 1718, 1665,    1,    1,  292, 1647,  220,  756,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1509,  151, 1702,  453,    1, 1589,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  531,   12, 1065, 1190, 1877,   37,    1,   37,  863,    1,  528,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  796, 2382, 1662,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1327, 2565,    1, 1454,  484,   37,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1140,    9,  522,   98,  116,  126,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2279, 2386,    1,   45, 2179,    1,  297, 3153, 2220,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1008,    1, 1185,  187,  590,    1,  460,  710,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  449,  540, 2377, 1706,    1,   59,   32,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1159, 1089, 1675,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  943,   32,  166,   22,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1619, 2597,  686,  191,    1, 1450,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2644,  384,  547,    1, 2095, 2985,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1723,  261,   32,    1,   45, 2254,   32, 2096,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 1203,    1, 2400, 1021, 1501,  481,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  231,  365,  535, 2308, 1176,  803,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1813, 1178,  386,  361, 3328,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  729,  476,   37,    1, 1114,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  503,  852,  115,  528,  749,  767,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  351, 1464,  776,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  273,   12, 3238,  449,   37,  140,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2333,    1, 2738, 3083,    1,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1776, 1651, 1597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  612, 1273,   37, 1523, 1230,  220, 1107, 2474,  259,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1, 3343, 1414, 1260, 3370,  115,   45,\n",
      "          741,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1963,   32,  227,    1,   63, 1857,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  716,   51,    1,  903,    1, 1447, 2673, 1463, 2163, 1215,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  484,   37,    1,    1,  105,  984,  786,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1087,  197,  921,    1,  570,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    8, 1727,   98,  104,  909,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1764, 1990, 2468, 1401,  163,    1,   12,    1,  187, 3230, 1654,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1236, 1783,  297, 1872,   24,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2161,   32,  112, 1046,  166,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,  582, 1454,  453, 2089,   37,  433, 2104,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  758, 1867,  466, 1013,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,  232,  932,  384, 1970,   12,  863,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  107,   21,   69,  102,   37,  245,   37, 1146,  106,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  704,    1,  683,  167,   52,    1,   37,  698, 1411,  914,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2694, 1193,  187, 2620, 2414,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  754,   45,  166,    1,  361,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  199,   37,  774, 2645,    9,  389, 1103, 2740,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 2204, 2139,    9,  166,    1,  741,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  305,   85,    1,  303,  108,   98,  347,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1853,   12, 1557, 2789, 1484,    9,  885,  477,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  691,  744,  593, 1139, 1434,  119,   32,    1, 3163,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1998,    1,  193,    1,    1, 1822,   52,    1,   12, 1565,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1312,   73,    1,    9, 3132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  693,    1,   37, 3237,    1,  206,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   26, 1039,    1,  449, 1144,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1303,  571,   37,  737,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1619,  458, 1075,    1, 1360,  612, 1031,    1, 1058,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384,    1,  726,   37, 2712,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1643, 1478,   59,  317,  756,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1189, 2673,  315,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  777,  778,  884, 1003,  176, 2108, 2107,   45,  559,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3203,    1,  872,  808, 2353,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  494, 1010,   93,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  395,   12, 2458,    1,  105, 1594,  384,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  857, 1567,    1,  903,    1, 1423, 2250,  444, 2637,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129,  975,   32,    1,  214,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,   12, 2673, 1816,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  571,  632,    1,    1,  191, 3075,  678, 1432,   37, 2445,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  818,  275,   11, 2495,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310,  159,  245,   98,   60,  671,    1,   69,   28,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1123,    5,  155, 2360,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   64,   12, 1121, 1992,  277, 1154,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,  79,  50,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 160, 102,   1,  28,  32, 367,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2004, 1718,  949, 2524, 1778, 1876,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  742,   32, 2027,    9,  214,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  691, 1195, 1948,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  614, 1273,  220,    1,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158,  200, 1230, 2528,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3160,  514,   45,    1,    1, 1147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,  588,   48,   32,  141,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  431,  949,   45,  784, 1778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2707,    1,  191,  342,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  612,    1,    1, 2317,  581, 1090,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1163,    1,   37,  737,   93,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,   37,   47,  365,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  166,  631,   98,   74,  786,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1650,    1,   37,  470,  442,  122,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 950,   1, 183, 199,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 711,  82, 992,  85, 297,   1,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3188,    1, 3189,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  338,  187,  442,    1,    1,   29,  817,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2476,  245,   98, 3282,  147,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  612,  302,  347,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1818,  147, 1650, 2150,    1, 2039,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  166, 1133, 2882, 1787,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  649,  853, 2421, 1159,  433,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2217,   12, 1277,    1,  187,  365, 2179, 1512, 1552,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  709,    1,  710,  884,  103,  518,  389,  176,  150,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,  693, 1994, 2650,   32, 2020,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3323, 2583,    1,  951,    1, 3059,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550, 1994, 2693,    1, 1454,  389,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  463, 1447,    1,    9,  411, 1352, 2673,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2820, 2918,  113,   98,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3290, 1343,  472, 3318,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2057,    1,  548,    1,  567,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  729,  606, 1604,   37,  544,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,  123,    1,   12,    1, 1097,   32,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  951,    1, 3100,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3356, 3357,   32,    1,   37,   38,  297, 2646, 3346,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1920,    1,    1,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1398,  612,  804,  460,   39,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1292, 1542,    9, 1989, 1990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1523,   45, 1691,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2960,   32, 2752,   12, 1633, 2766,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12, 1404, 2386,    1,   45,    1, 1590, 1530,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1910,    9, 3402,    1,   37,  693,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1148,    1,   37,    1, 1763,  600, 2734,   32,    1, 1033,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,    1,  384,   69,  636,  120,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  200, 1228,   37, 1000, 1536,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3108, 2935, 2764, 1619,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2479,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,    1,   61, 1844,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  176,  177, 1700, 2119,  220,    1, 1987,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  395, 2003, 1585, 2414,    1, 1625,    1,    9, 2986,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  884,  389,    1, 1263,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    9,  327, 1494,  220,  284,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1509,    1, 1187, 2398,   37, 2449,  166,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1263,    1,   32,    1,  361, 1694,   45,  942,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2476,    1, 3347, 3338,   32,  531,    1, 2703,    1,  365,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  384, 2433,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2868,   37,  429,   46,   32,  455,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1901,  357,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,  105,    1,   45, 1744,  123,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  613,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  813, 2410,   45, 1147, 2179, 1929,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3096, 2857,   12, 1918, 1408, 3191,   32, 1881,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1,    8,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2, 506,  30,   1,   1,   1, 505,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 433, 840,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  333,  190, 1505,   72,  553,  104,    1,  700,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2107,   61, 1849,   26,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  942,  458,    1,    1,  943,  182,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  954, 1754,    1,    4,   32,  367,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2902,    1,  171,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   16,   45, 1565,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2414,    1, 2803,   32, 3354,  787,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,  431,  887,   45,  180,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  238, 2160,   28, 1140, 2562,  191, 1428,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861, 1075,    1, 1314,   32,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  168, 1412,   37, 1171,  378,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  104,  560, 1274,  245,  915, 1034,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1433,  166, 3024,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  796,  327,  883,   32,  331,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,   22,   23,  607,  162,  257, 1038,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,  227,  219,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2450, 2251,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  381,    1,    1,  131, 1084,    9,    1, 1663,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1655,    1,    1, 1828,  361,  117, 1708,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1718,  476,   37, 1493, 1658, 2143,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  155,  308,    9,  401,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 2673,    1, 1542,   37,  865,   37,  531,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 3001,  220,  105,    1,  636,   98,  453,  582,  288,   37,\n",
      "          726,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  191, 2106,    1,  103, 1682,   45,   49, 1910,  121,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  546,  518,  494,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  491,    1, 1346,  384, 1622,  393, 2299,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311,    1, 2401, 1258,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,  915, 1357,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 2263,  297, 3379, 2950,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3128,  830,  121,   98, 1119,   45, 1414,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,  978, 3138,  512,    1,  928,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  268, 1887,  857, 1469,   98,    1,    1, 1675,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  885,    1, 3395,   32, 2504,  463, 2966,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115,    1, 3245,    1,  103, 3200,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 1203,    1,  105, 1975,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2617,    1, 3358,    1, 3404, 1096,  164,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,   12,    1, 2055,   37, 2785,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2008,    1, 2728,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2500, 2955,  640,    1,  813,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3100,   37, 1706,   32, 2103, 2727,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1, 2196,    1,   12,    1,  708, 2076,   37,  764,  469,\n",
      "          182,  460,  788,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1213,   76,   37,   52, 2297,  136,  475,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2053, 2055, 1376,  995,   32,  871,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1,  904,    1, 1920, 1931, 1284,  411,  949,  384,    1,\n",
      "         1038,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,  741, 2306,    1,  528, 3038, 2292,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3264, 2126, 1862,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1896, 1687,   37,    1,    1,   37, 1334,   98,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  838, 2043, 1107, 2308,    1, 2382,  259,  361, 2519,    9,  105,\n",
      "         2419,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  777, 2232,    1,  653, 1819, 1665,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  539, 1037,    1,  405,    1,   12,    1,  714,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3181,  477,    9,  166,    1,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3401,  140, 1081, 1002,    1, 1578,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3232, 1445, 1421, 3224,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1, 2414,   32,  455,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,  388, 2769,    1,  202,  590,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3035,    1,  166,  236,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  491,    1,  787,  220,    1,  492,  170,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1189,  650,  261,   39, 2199,   32, 3107, 3366,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 3226, 1210,   37,  289,   98, 1894,    1,\n",
      "          193,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,    1,    1, 3062, 1183, 1253,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2225,   51,    1,   82,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  606,    1,   37,   52, 1587,   45,  590,    1,  539, 1037,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1723, 1270,  288,    9, 1405, 2281,  776,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2811,    1, 2308,    1,  542,  176, 3263, 3226, 1090,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2754,    1,    1, 1098, 1465, 2086,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  108, 3144,   37, 1267, 1211,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2055,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  793,  794,  449,    1,   95,   37,  451,  452,  443,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,  288,   37,  804,   98,  148,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 2080,    1,   37, 1251,    1,  372,    1,  388,  763,  205,\n",
      "          621,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 1068, 1069,  418,    1,  118,   32,  871,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  146,   37,    1,    1,   32, 1645,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  884, 1267,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  261,    9,  148,   32,  647,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   10, 1484,    1,  600, 1994, 2275,  378,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  534,   12,  331,  365, 1788,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,   37, 1539,  453,  365, 2522,   32, 1314,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 2676,   12,  223, 2298,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1414,   77,    1,    1, 3006,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2877,  108, 3155, 1995,   61,   27,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 837, 353, 242, 737, 197,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,   12,    1, 1077,  131,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299, 1380,    1,   32, 2730,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  147, 1771,  894,  606, 2827,  863,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  261,  912, 2285,  822,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  555,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947, 2625, 1791,  191, 3025, 2068,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1193,    1,    1,  736,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 1089,   30,    1,   45, 1178, 1229,   37,   52,  294,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  488,   37,    1,    1,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,   98,  105, 1488,    1, 2706, 2232,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2615,  132,    9, 1024,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  958,  310,    1,    1,   32,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2862,  446, 2526,   37,    1,  622,    1,  171,  535,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2125,    1,    9, 3138,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1, 2366,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2292,    1, 2357,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1257,    6,  365,  132,   37,    1,  734,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2924,   32, 3155, 1000, 2095,  437,   12,    1,  656,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  116,  167, 2200,   71,   32,  344,    1, 2221,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861,  700,    1,   37,  597,    1, 2572,  191, 2597, 1957,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1484,    9, 3369, 2375, 3368,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1940,   12,  105, 2872,    9,  166,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1538,  477, 1627,   72,   74,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1421,   45,    1, 2690,    1, 1778, 2987,  861, 2762,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1092,   12,  786,  477, 1563,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   82,   12,  138, 1924,  921,   32, 2244,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1537,    1, 1585, 2803,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3281, 2808,   98, 3306,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   49, 1536,    9,  467,   32,  163,    1,   12,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1450,   98,  654,   12,   83,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,   14,   15,   28,    1, 1146, 1703,   32, 1169,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,    1,  400,   45, 2527,  164,    1, 1813, 2990,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1624,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1292,  476,  199,   79,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2856,   32, 3343, 2887, 1523,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  666,  697,   37,    1,    1,   32,  584,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  224, 1772,  361, 3034,  315,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  245,   98,  677,  104,    1,    1,    1,  430,  997,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3259,    1, 1041,    9, 2249,   95,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  358,    1,  764,  220,   33,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 2185, 2073,  401,   93,   37,    1,   67,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 2959,    1,  244, 2928,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   94,  176,  119,  845,  444,   60,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,  951, 1547,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2741,  542,  619,  449,    1,   45, 1956,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 2837, 2572,   32, 2597, 1585,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 1376, 2029,  119, 1653,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3376,    1,    1,  776, 2361,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   46,  220, 2018,   98, 1815, 1809, 1647, 2406,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,    1,   55,   37, 1281, 1925, 1583,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  790, 2221, 2386,  639,  297,  749,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  334,  254, 1120,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  565,   98,  813,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1, 3055,   37,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1765, 2742,  115,   45, 1477, 1990,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  300,    1, 2924,   37, 2735,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3302,  894,  686, 2468, 2177,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1743, 1464,   37, 2192,    1,  388,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  980,  187,  531, 2361,  532,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  323,  805, 1921,   32,  584,   37, 2905,    9, 1539,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821,    1, 1140, 2699, 2133,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2448,  386, 2800, 1218, 1761,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3303,    1,  176, 3258, 1058,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  477, 1408,    1,   56, 1394, 1048,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3310,   61, 2602, 3332,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  300, 2468, 1159, 1764, 1990, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2561,    1,    1,    1,  314,  551, 1692,    1,  494,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2868, 2770,    1, 2117, 2658,    1, 1082,  593,  764,   37,  674,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  626,  408,    1,  954,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  204,  162,  284, 1084,    9,  424, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962,    1,  868,   39,  187, 2633,  439, 3260, 1844,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  982,   37, 2346,    1,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  936, 2174,    9,    1,  769,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2409,  590,    1,    1, 2210,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 1844, 1086,   32,  590, 2360,    1, 1185,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,  151,   81,    1,  124,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  891, 3369,  861, 2699,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1408, 3322, 1568,  176,  754,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187,   97,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2838,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1778,    1, 2865, 2473, 2367,   79,  166,  103, 1569,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   32, 2114, 1444, 2143, 3326,    1,   98, 2565,   37, 1594, 1425,\n",
      "          698,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  214, 2195,    9,  742,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  335,  382,  436,    1,    1,    1,    1,  361,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1232,  460,  810,    1,    1,    1, 1221,   51,   52,\n",
      "          105,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3141,    1,    1, 2307, 2138,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2783,    1, 1684,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  374,  375,   42,    1,   43,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3270,    1,   28,   37,  365, 1355,   37, 2449,    1, 1277,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  316,    1,    1, 2405,  463,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  702, 1342,  365,   82,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3089, 2565,    1,    1,  220, 3103,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,  183, 1008, 1632,   37, 3308, 1990,  437, 1267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  593, 1990, 3275,    1,  361,    1,  631,  104,  608, 2379,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1585,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1247,   37,    1,  529,    1, 1124,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  891,   37,    1, 1565,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1178, 2827,   32, 2741,    9,    1, 1051, 2690,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 2744, 1961, 2976,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  199,   37, 1978,  166,  460,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  232, 1708, 1268,   32, 3343, 2823, 1002,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1310,   37,   47, 3304,   37,  683,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   12,  365, 1230, 2420,  365, 1607, 2575,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,  168,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2514, 1509,    1,   32, 1134,   37,  429, 1787,   45,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,  317, 3358, 1015,    1, 1183, 1490,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2954,    1, 1081,  851,  298,  778,    9, 2986,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   32, 2197,    1,  105,    1,    1, 1310,   37, 1344,    1,   37,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   58,  197,  407,    1,  157,   61,  969,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1882,   37,  567,    1,  584,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1625,   45,    1, 1016,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,  267, 1340, 1991, 2901,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,  439,   85,    1,  118,   98, 2353,  996,  157,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   12,    1,  705,    1,    1, 1231,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1942, 1727,    9,    1, 3001,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1, 1192, 1691, 2444,    9,  386,   78,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,    1, 3020,    1,  166, 1526,    1,   63,  166,  770,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  741,   32, 2823, 1844,   79,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1795, 2279,  197,  407,   32,  401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  794,    1, 1117, 1525, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,  680,  290,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3003, 1396, 2547,   32,  365,  912,    1,  767,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3118, 2751, 1066,   98, 2024, 2467,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3051,    1,  114, 1631,  548,  365, 3279,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   61,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2658,   45,    1, 2308, 1472,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2136, 1484,    9, 2678,   98,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   15,  670,   98,  800,  949, 2462,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,  388, 3141, 2195,  166,  915,    1,    9,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  381,    1,    1,   37, 1644,  317,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3320,  726,    1, 1824,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2167,    1,  792,    1,  792, 2060,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707, 1702,  115,  220,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1042, 1377,   45, 2836,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2442,    1,  733,  215, 1204,   50,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1591,  315, 1300,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  212,  174,  897, 1114,   98,   57,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 735,   1, 256, 114,  37, 736, 297, 301,   5, 302,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 870, 746,  37, 125,   1,   4,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3174, 1249, 2779,   32,  810,  632,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 2005,  608, 2028,   32, 1123,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  270,    1, 2340,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,  469,  338, 1139,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,  225,  333, 1961,  187,  422,  833,  612,  100,   98, 1126,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3168,    1, 3178,  759, 3295,   32,  602,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,  261,   39, 2177, 2585,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325,   39,    1,   50,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,   65,    1, 1240, 1389, 2205,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 2170, 1702,  115,  220,  453,  142,    9,  105, 3222,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  786,    1, 1056,    1,    1,    1,    1,    1,    1, 1176, 1744,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1346, 1585,  379,    1,    1, 2266,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  501,  868,  671,   32,    1, 3329,   32,  691,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,    1, 1008,    1, 1009,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1159,  522,  176,    1, 3329,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171,   12,  954,  490,   32, 1352,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2804,  820,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 2404,  113,   46,  220,    1,   37,    1,  454,    9,  811,\n",
      "         2237,   37,  976,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,  159,  759,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1035, 1536, 1377,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3183, 2225,    1,  590,    1, 3284,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,   32, 1407,    1,  384,  557,  540,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  647,   26,   37,  148,  142,  940,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,    1, 1307,  872,   28,   37,    1, 1273, 1228,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2925, 1974, 1751, 1056, 1675,    9,  195,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1, 1822, 2192,    1, 2058,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2208, 2402,  967,  776,  191,  114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,  619, 1452,  220,  931,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2734, 2700,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,   37,  698, 3188,  444, 2926,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  593,  199,  776, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1,  683,   12,    1,  565, 1532,    9,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2883,    1,  220,  593, 2522,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  166, 1116,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  681,    1,    9,  976,   69,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2753,    1, 3300,  726,   56,   73,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1110, 1140,   28,    1,    1,    1,  547, 1130,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  520,    1,  721,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  487,  493, 1879,   37,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 3125, 2556,  104,   59,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   91,    1, 2918,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  313,    1,  176,  166,    1,  288,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    9,  331,    1,  368,    1,  256,   50,   37,  525,    1,  187,\n",
      "         1103,  187,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2171, 3134,  511,  275,    1, 2160, 2049,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,  936, 1775,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3356,    1,  897,    1, 1452,  187,    1,  571,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  306,    1,  829,  872,    9, 2819,  767,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20, 1064, 1499,   32,    7, 1131,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1360,  612,   52,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1454,  522,  444,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1585, 2414, 1056,  104, 2548,   32, 3360,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,  927,   37,    1,  114,    1, 2162,   45, 2949,  655,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401, 1050,  701,   32, 2936,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1246,  765, 1159,    1,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2275,  640,   10,   98,  223, 2135,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  733,  453,   48,   32, 1369,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2490,    1,  444, 2527,  164,  165,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1257,    1,  498,   98,    1,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1861,   37,  606,    1,  985,  351,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510,    1, 1750,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1622, 1009,   57,  636,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2948,    1,    9,  581, 2113,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3270,    1, 1818,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  315, 2355, 1013,   37,    1,  220,  224,    1,  829,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1911, 1994,  104,  943,    1, 1459, 1373,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1530,    1,    1, 2335,  487,    1,    1,   32, 3113,  336,\n",
      "         2291,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  506,  861, 1553,    1,    1, 2500,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3340, 1485, 1683,   32, 2755, 2140,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  342,   37,    1,   37,    1,    1,    1,   39, 1757,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  539,    1,    1, 1831,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2942,  140,  449, 3126,  548, 2890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1244,    1,   71,  871,   15,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  105, 1928,    1, 1333,    9, 1340, 1194, 1710,   52,  415,  600,\n",
      "          917,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1187, 1658,  259,    1,    1,    1,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1168, 2534,    1,  162,  851,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,  105,    1,   82,    1,  365,  861,  669,   12,  315,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  306,   12, 2305,    1,    1, 1890,    1,  361,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 2170,  267,  590, 2251, 2099,    9, 3342,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,    1,  434,  864, 2673,  250,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2374,  272,  608,    1,    9,    1, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1266,   12, 1913, 1843,  207, 1042,   98,  377,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1343,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 2769, 2593,    1,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1090, 1829, 2748,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3373,  901, 1897,  861,    1,  176, 1645, 1325,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12,    1,   96, 1159, 1021, 2139,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 2072,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1021,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,   25,  832,  187,  510,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1854,  571,   37,  215,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1229,   37,   52,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1216,    1, 2772,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 3005,   98,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,    1,  121,    1, 2707,  661, 1015,   45,    1, 2471,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,  693,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 1090, 2677,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  295,  680,   97,  384, 2066,  529,  636,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178, 1179,    1, 1046,  105,  677, 1787,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  584,  669,  251,    1,    1, 1821, 1697,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,  315, 1651,  691,  517,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  389,    6,  176,  339,  845,   32,   86,\n",
      "            1,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   66,  417,    1,   65, 1953,   98, 1978,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  170,  105, 2740,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1027,  927,  288,    9, 3048, 2818,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  215,   69,  700,    1, 1159,  903, 1447,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   45,    1, 1702,  115,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   98, 1791, 2468,  722,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,   12, 1704, 1713,  784, 1151,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  716, 3194, 3195,    1,  220,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3196,  140, 1383,    9, 1485, 3222,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1789,    1,    9, 3121,    1,    1,  616,  123,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   37, 1343, 1698, 1565,  872,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  422, 1554,  224, 1555,   98, 1126,  168,  115,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   39,   45, 2124,  379,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  408,  294, 1939,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  300, 2673,    1,   37,   12,    1, 1447,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3303,   30, 1280,   32, 1090,   45, 2155,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,  105,    1, 1009,    1,    1,   98,    1, 1499,    8,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1550,  611, 2705,  798,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1458,  198,   60,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3361, 2572,    1, 2347,    1,   32,  104,   22, 1260,   98,\n",
      "         3391, 1602,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 1128,    1,  183,  368,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3391, 2751,  856,   98, 3279, 1316,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  469, 1710, 1066, 3104,    1,  125, 1474,  674, 2295, 2302,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1778, 2580, 2851, 1108, 1779,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,   82,  606,  334, 2085, 2582,  105, 1628, 2494,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 446,   9, 858, 543,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 335, 460, 786, 176, 105, 199, 428,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3168, 1111,  297, 2457,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1822, 2446,  424,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2232, 1182, 1205,   32,  142,   37,    1,  111,  912, 2285,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 2239,   79,    1,  844, 1151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,    1,  131,   32,  531,  734,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1926, 1927, 1394,    1,  176, 1785,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  424,    1,   61,    1,  810, 1628,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  295,  315,  389,    6,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3266, 2651, 2615,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1811,  404, 2299, 2572,  915,  339,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,  25, 288,  37,  26, 417, 187,  69, 418,  88,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  35,  34,  95,   1, 187, 529, 102, 554, 328,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1462,  513,    9,    1, 1175,    9,    1,    1, 1492, 1333, 3082,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 3365,    1,    1,    1,   37, 1604,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2429,    1,  698,   45, 1081,  863, 1708,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  613,  132,  190, 1296,   28,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    9, 2275,    1,    1,    1,    1,  176,  105, 1185,  823,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3079,  753,   37,    1, 1044,  468,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  560, 1274,   71,   32, 1034,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1787,  848,    1,  170,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  845,  147, 1392,  400,   98,    1, 1393, 1828,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1717,    1, 2962, 3316,  168, 1394, 1048,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1352, 1235,  102,   71,  166, 1354,  452,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1691, 3229, 1564,    1,  220,  365,  872,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1433,  544,  245, 1554, 1031,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  354,  967,    1,    1,   37,  429, 2069, 2941,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1583,    1,  352, 1358,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3322,  365, 1173,  603,  227,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   21,  449,  572,   15,  720,  452,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  614,  548,    1,  220,    1, 2168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2964, 1413,    1,  861, 1705,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   52,    1,    9,    1,  131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 1771, 1022,    1,    1, 1771,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  710, 1659, 2094,    1,   37, 2255,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   25,  526,  187,   69,    1,  297,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2881,  829,    1, 1718, 2264,    1, 3018, 1960,  713,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1563,  475,   37, 1540,  384,  317,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  220,   81, 2537,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32, 1056,  191,  638, 2087,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  857, 2155, 2554,  519,  608, 2807,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  147,  261,  284,  912, 2285,  441,  565,  193,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2158, 1380, 1956,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   66,   28,  187,   69, 1276,  647,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777, 2798, 1718,   37, 1876, 1537,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977, 3012, 1821,    1,    1,   37, 1206,    1, 2616,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1082,    1,   37, 1865,  258,    1, 3000,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1304,    1,    1, 1636,  853,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,    1, 1710, 2192, 3260,  445,  110,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  626, 2541,    1,  315,   37, 1540,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,    1,   77,   28, 1450,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2691,  619,  105, 1173,  176, 2979, 2869,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 2222,  162,   32, 2866,  220, 1234,   12,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1227, 1468, 1416, 2232,   61, 2119, 2017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  682, 1227,  195,  432,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094,   12,    1, 1770, 1064,   37,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2140,  673,  448,  972, 1315,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1319, 1726,  698,  442,    1,  861,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3150,    9,    1,  861,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018, 1583,  267,    1,    1, 1425, 3006,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,   21,  198,   15,   93,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  548,  596,    1,    1,  957, 1042,  315,   37,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1331,  361,  730, 1777, 2798, 1718,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1128,  775,    1, 3044, 2232,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2855, 1523,    9,    1,  361,    1,   32,  166, 2948,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3306,  580, 1056,  356, 2836,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1542,    9,    1,  220,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1211,    1,  250, 1976,   32,  337,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,  830,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  398,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035,   37,  398,  611, 2349,  920,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1818,  147,   37,  231, 1842,  116,  400,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1, 1749,  220,  813,    1,    9,  365,  914,   45,  166,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1009,   12, 2789, 1401,    1, 2208,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777,  387, 1023,   45,   15, 2083,  163,    1,   12,    1,\n",
      "           32,  105,  356,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1186,   12, 3046,   98, 1434,   37,  726,    1,  628,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,   25,   71,   69,  102,   92, 2054,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  397,   37,    1,    1,  331,  599,   98,  104,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1487,  197,  738,  308,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051,   37,    1,   59, 1714,    9,  116,  259,  700,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,    1,    1,   37,  619,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2967,  459,  220, 1497,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  140, 3023,   45, 3116,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2909, 2856,  104, 2924,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  936,    1,   32,  326,    1,  293,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  818,   15,  157,    1,  220,  773, 1169,  932,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  773, 1332,    1, 1690,  525,   15,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  818,   15, 1539,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3214,    1,  228,  640,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1854,  140,    1,  400,  951,    1, 2931,  778,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  515,    1,  726,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,   14,   15, 1473,    1,  118,   32, 1169,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275, 1278,  157,    1,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  474, 1355, 2925,  983,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1674, 2871,    1,    1, 2422, 2622,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   48, 2552,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   92, 1766, 1767, 2320,  191,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  465, 1291,   51,  193,   52, 1851, 2309,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  884,  674,   45, 2336,  384, 1087,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1497, 2967,   81,   32,  166,    1,    1, 1245,  361,  810,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2452,  517,  775,  187,  593,   12,    1, 2355,  918,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1309,   37, 2122,    1,   98,   43,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1353, 1039, 2690, 2285,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2371,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  418,   32,  218,  714,  548,    1, 1126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,   12,    1,  686,  191,  331,  798,    9,   81,  962,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  879, 2651,    1,    1,  297,  395,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,  365,    1,    9, 2543, 2177, 1825,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2862, 1679,    1, 2179, 3080,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,  326,    1, 2801,  973, 1273, 1671,  861,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1419,    1,  414,    1, 2973, 1764,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2724,    1, 3239, 1673,    1, 1641,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,  203, 1444, 1360,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2991, 2373,    1, 2657, 2549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1841,    1, 3305,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 2921,  418,  384,  166,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1640,    1,    1, 2774,  650,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,    1,   37,    1, 1717,  220,  813,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,   37, 1539, 1778, 2580,  949,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978, 3138,  753,   37,  168,    1,  220,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1, 2203,  671,    1,  477, 1912,  170,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  125, 1649,    1,  138,  521,  599,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  193, 1542,   37, 2225,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3198, 3329,    1,   32, 2936,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3310,  162,  449,  726,  176, 1739,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994, 1408,    1, 1159, 2997,   12,  332,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  321, 1430,  341, 1610,  996,  909,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  877,  221,    9, 2846,  512, 2912,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,   12, 1126, 1961,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,  511, 1178,   12,    1,    1, 2047,   96,   37,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2926,    1, 2236,    1, 1857,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   90, 2563,   37, 1604,   39,  357,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2948,    1, 1033, 2830,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2752, 1518,    9,  112,  187,    1,    1,  125,   79, 1633,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  673,    1,    1,  315,   37, 1250,  105,   12,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2615,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  105, 2962,    9, 3207,  361,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2844,   32, 1656, 2578,  298,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2178,  947, 2263,  667, 2147, 2950, 3060,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596,  539,   45, 2597, 2414,  786,    1, 2766,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,   91,   25,  242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  140,  166, 2579, 3154,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,  657, 2043, 1844,   98,  413,  769,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  493, 1654,  105,   59, 2264,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  306, 2418,   28,  395,   12,  553,  777, 1885,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1194,  593, 2522, 1684,    1,    9, 1022,    1, 2296,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3042,  161,  682,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 1023,   45,  317,  589,    1,  384,  286,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  669,    1,  365,    1, 2836, 1294,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1728,    1,    1,    1,    1,   98,    1, 1069,  260,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   54, 1204,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  588,  754, 1844, 2306,  176,  878,  873, 2578,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2838,    1, 3266,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  190,  193,  865,  671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1428, 2791,    9,    1, 3396,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  523,  837,   45, 1786,  927,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  215, 1994, 2095,  947,  429,   56,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  558,   37,  151,    1,    9,    1,  182,   32,  987,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1021,  282,  517,    1,    1,  328,    1, 3011,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1458, 3359,   12,  469,    9, 3057,  220, 1384,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3348,  437,  396,    1, 2197, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2071,    1,   37,  631,  657,   16,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018, 1867, 1139, 2320, 2673, 3085, 1461,    1, 1583,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  645,  704,    1,    1,    1, 1231,  220,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2347, 3204, 2257,   39,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,  952, 2842, 1021,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1230, 2528,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3229,    1,  872,    9,  119, 2318,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  148, 1380, 2976,   98,  105, 2462,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  154,  469,   37,  125,    1,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   74,    9, 1005, 3298,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 2061,    1,   98, 1700, 2789, 2673,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1830,    9,  627, 1821,    1,  629,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  666,    1, 1821,   95,   12,    1,  865,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  120,   32, 1656,   15,  902,  954,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    6,  572,  207,  174,  191,   59,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  190,    1,  170,  132, 2709,  357, 1980,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  176,    1,  220,  647,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   59,    1,  855,  590,    1,  579, 1494, 1411,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 3395, 2496, 1976,  403,   45, 2597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3180, 2365,  386, 1141,   37, 1832,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  897, 2148,  985,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3167, 3009, 1372,   37, 1343,   32, 2826,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1302, 1464,   37,    1,    1,    1,  997,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3192,    1,   81,   37, 1046,  438,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2531, 1470,   45,    1,    1, 1514,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2275, 1310,   37,    1,  805,   45, 2081,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1487,    1,  453,    1, 2008,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  398,    1,    1,    1,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973,    1,    9, 2689,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  602,    1, 3043, 2764, 3394,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  761,   37,  875,    1,  396,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  102,  245, 1010, 1986,  297,  104,   69,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2484,  300,  694, 2017,  220,  105,  354,    1,  515,    1,  105,\n",
      "         1333,  176, 3278,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1805,    1,    9, 2741,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,  140,    1,   37, 1174,  914,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1116,   37,   26, 2616,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1293, 1568,    1,    1,   39,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  395, 1877,    1,    1,    1,   28,   37, 1204,   32, 1038,    1,\n",
      "            9,  116,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 1795, 2279, 1454, 2754, 1429,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 1929,  721,   12, 1279,   45,  366,  996,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845, 2326,   32, 1869,  951,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2994, 2995,  884,  218,  332,  384,  829,   12, 2997, 3031,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  936, 1888,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   61, 2869, 1089, 1542,    9,  453,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176, 2063,    1,    1,  943,   61, 2085,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2685, 1421, 1695,    1,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2698,   81, 1994,    1, 1708,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  546,  629,  304,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 2260,    9,  631,  176,    1,    1,   26,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1604, 1400,    1,    1, 1082,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  891, 2456,   37, 2884, 3370,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  191,  166,  721, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973,  565,   32, 3013,   37,  943,   37, 3305,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,    1,  458,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596, 1395,    1,   37, 2284,   32,  572,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3226,    1, 3218,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  276,  361,  245,   45,  942,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3087, 2478,    1,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,    6,  570, 2007,   37,    5, 1559,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,    1,  587, 1388,  297, 1715,  138,  125,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12, 1481,   37, 1708,   98,  119,    1,    1,  859, 1031,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1447,  996,  909,  786, 1144,  455,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2115, 1236,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1105,  787,  353,  999,  737,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 3005,  884, 1658,  173,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 3288,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   45,    1,   37, 1937, 1340,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1380,    1,  356, 2072, 1590,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428, 2673, 1063,  475,  267, 2673, 2834,  105,  311, 1665,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  542,    1,  114,    1,  187, 1957,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  245,   37,  187,  531,   69,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3191,    1,  311, 2936,  726,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,    1,   98,  166,  323,    1,  323, 2354,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1127,  733,    1,  853,   48,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  370,  253, 1220, 1064,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3356, 1484,    9,  439,   45, 1345,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,  726, 1689, 1090,  444, 2720, 2796,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2192,    1,  105,    1,  916,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978, 3138,    1,  405,   12,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2534,   32,  662,  220,  842,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  384,    1,   12,  625,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  777, 2232,    1,  653, 1819, 1665,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2681,    1,    1,   37,   10,   12, 2742,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  129, 1945,  957,   76, 1387, 1890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1173,  183, 1620,    9,  803,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  903, 3165, 1061,   32, 2592,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  608,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1481, 1564, 2218,  220,  691,  726,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1236,  923,    9,    1,    1, 1525,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  147, 2151,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453, 1564,  132,    1,  202,  388,  839, 2007,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   91, 1822,    1,   98,  651,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1185,    1,    1,  166,    1,   98,    1,   74,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1088, 2789, 1360,  612,  606, 3398,   81,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1629,   12,  645,  149,    1,   55, 1130,    1, 1261,    1, 1117,\n",
      "         1525,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2406,   37,  429,   46,  220,   10,    1, 3380,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  410,   98,  198,  156,  716,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3328,    1, 3187,  705,    1,  317,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835,   37, 1463,    1,    1,    9, 1389,   45, 2162,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1523,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1321,  157,    1,  515,  590,  308,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  705,    1, 1417,    1,  200, 3283,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2364,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2862,    1,  442,  802,  176, 2396,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  515,    1, 2264, 1876,   92,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2504,    1, 2862,  446, 2270,   37,  319,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,  856,  444,  116, 2931,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2090,  872,  548,  166, 2250,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   27,  687,   98,    1,    1,    1,   29,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  199,    9, 1104, 2209,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1033,   50,  831,  548,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,    1, 1407,   49, 1077,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,   82,  267, 1711,  565, 2825,   28,   37,  335,   95, 1159,\n",
      "         1821,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  657,    1, 1412, 2586,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1867,   16,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3101, 3057,  132,   76,  187, 2924, 2856,  176,  177,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1484, 2275,  223,  469,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1973,    1, 1281,  361,  715,    5,  335, 1950,   45,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,    1, 3146,   98, 3369,    1,    1,  191, 1527,    1,  187,\n",
      "          800,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  665,  680,    1,   32, 1417,    1, 2226,    1,  105,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  801,   32,  647,  214,  856,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2844,   32, 1260,   98,  104, 3150,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  571,   37, 1505,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1, 2099,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777, 1342,  365, 1644,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,    9,  166,   72,  593,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 1587,   45,   69,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1170,  159,  245,   98,  586,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  790,  908,    1,  659,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  393, 2328, 1380,   98,  857, 2539,   16,  220,    1, 1539,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1823,  662,    1,  326, 1086,    1,  361, 1713,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  664, 2761, 2236,   37,  985,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2531,  429,  631,  528,    1,   12,  856,   81,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  386,   22,  315,   54, 1251,    6,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3214,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  524,  525,   15,   71,   32, 1893, 1034,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1679, 3080,   32, 1934,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1518,    1,  131,  626,  574,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  251, 2179,    1,  856,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,    1, 1998,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843,   12, 2482,    1,    9,  449,  726,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  398,  267,    1,    1,   43,  321,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1, 2759,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1965, 1728,    1,    9, 1204,    1, 2982,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,   98, 3107,  864,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  709,    1, 2431,  513,   32,  312,  400,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1550, 2339, 2673,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2801,    1,  289,   98,    1, 2013,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   28,  105,   60,  187,  510,  488,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,  168,    9,  449,   36,  698,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1068,  568,   93, 1270, 1271,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,   98,    1,  163,    1,   12,    1,  442,  910,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1712,  459, 2197,  132,   37, 1403,  388, 2910,   37,   72,  593,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1827, 1530,  548, 1260,   98, 1147,  947,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2140, 1877,  590,    1,   98,  734,  589,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2976,    9, 2580,  328,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  650,   12,  433,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1, 1577,   37, 2695, 2366,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  163,    1,   12,    1,    1,    1,  384,   86, 1898,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  972,   37,  319,  187,  716, 2704,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  583,  191, 2015,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  305, 1180,   28,   98,    1,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 1890, 2248,  763,  205,    1,    1,  619, 1333,  176, 2093,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1720, 1110,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  741,   32,    1,  890,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   61,  829, 2587, 2692,   37,    1, 2975, 2964,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  829, 1013, 1522, 1443,  224,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 2022, 3116, 3217,  220, 3023,  340, 2277,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  830,  121,   37,  138,  592,  734,  411,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1290,  396,  417,  763,   76,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  854,    1,  529,  636, 1124,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  422,  692,  469,   37,    1,    1,  176,  225,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,  267,  942,  315, 2089,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  870, 1643, 2264, 2506,   45,    1, 1876, 1484,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    8,  861, 2976,   37, 2324, 2558,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  603,    9,    1,   37,  100,  444,  864,\n",
      "            1,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,  228,  356,  231,   45, 1663, 3037,   37, 1281, 1054,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,   98,    1,  124,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110, 2139, 1724, 1114,   37, 1496,  421,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  664,   39, 1452,  548, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845, 1625,    9,  105,    1,    1,    1,  186,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3096, 2161,   12, 2630, 1908, 2357,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,  159,  439,   85,   98,  800,  104,    1,    1,    1,  568,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2292,    1,   32,  404,    1,    1,    1, 2816,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  148,   12,    1,    1,   98,  225,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  149,   33,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1021, 1025,    1,  333,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1479, 1260,  191, 2751,   98,    1, 1223,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  220, 1056,  356,  881,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1870, 2910,   37,   52,   53, 1632, 1362,  656,  918,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1166,   12,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 176, 656,  45,   1, 736, 428,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 388,   1, 386,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1861,   12,    1,   61,    1,   45, 2162,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2474,  777,   37,    1,   32, 1468,   45,  365, 1085, 2076,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  782,    1, 2983,  176,  440, 3009,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 2962,  405, 3291,    1,   32, 1394,  187, 2748,  140,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2582,  105,    1, 1526,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 2792,    1, 1247,  928,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3172, 1090, 1829, 2160, 2049,  951,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993,    1,  829,  166, 1868, 1172,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2311,    1,   37,  151,    1,    9,  152,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,   12,  858, 1108,   32,  463,   37,  439,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1051,   37,  130,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1300,  920,    1, 1066,   98,  531,  443,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  646,   71,    1,   32,  401,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,    1, 2646, 3346,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  195,    1,  167,  335,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  238,    1, 1464,  342, 2461,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1123,  892,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   45,  455,    1,    1,  674, 1107,    1,    1,    1,   37,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2070,    1,  220, 1583,    1, 1296,   28,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2292,    1,    1,  854,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1093,  574,   61,    1,  361, 2145,   37,  138,  962,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  297, 2212, 1204,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3093, 1625,    1,  548,  446, 2526,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2335, 1796, 1530,   32, 3043,  344,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  517,  541,  167,    1, 1821, 2057,    1, 1116,    1, 1821,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,   92,  384, 1828,   37, 1962,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3358,  105,  650, 2198,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340, 1194, 2907,  193, 2398,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,  220,  582,  297,  985,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   37,  877,  647,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  756,  757, 2034,  245,    1, 2216,  341,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3038,    1,   98,  105,  237,   32, 3383,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  531, 1485, 3365,  820,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746,    1,  179,  132, 1660, 1766, 1767,   17, 1568, 1569,  412,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  550,  433, 2591,   37,  877, 1089, 2530,   32,  668,    1,  105,\n",
      "          961, 2502,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3114,  379,  798, 3147, 2924,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,   66, 2410,  242,    1,   29,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  241, 1421,   45,  166, 1215,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  321,  166, 3083,    1,  166,  539,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700, 1604,   37, 1496,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  191,  600,  295,   28, 1515,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403, 1447,    1, 2529, 1585,  220,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3140,   51,   52, 1542,   37, 1195, 2024,   46,  220, 1094,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  581, 1148,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  121, 1821,  519,  402,   37,    1, 1604,   45,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1, 1849,  274,   45,  455,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  982,    1,  613,    1,  700,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,    1,  176,  177, 1941,   32, 2960,   27, 2835, 3101,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1647,   61, 1532,   32,    1, 1350,    8,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504, 2736, 1082,  439,   37, 2292,   32, 3348,  463,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  772,  325, 1054, 1411,   37,    1,    1, 1869,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  388,    1,   32,  531,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2616, 1454,  453,    1,   45, 3021,   12, 2725,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,  242,    1, 1946,  191,  496,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2489,   32,    1, 1090,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,    1, 2266,  498,   98, 1428,  652,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  999, 1900,    1, 2179,  378,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  550, 2980,    1, 2261,   37,    1,    1, 2819,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   51,  245,  176,   26,    1,   69,  246,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087,   37,  693,  449, 1140, 1876,    9,    1, 2706, 2232,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2184,  978, 3138,  550,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 950, 176, 105,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  12,   1, 166,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3359,  952, 3057,  168,  115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1925, 1583, 1149, 1551,   32,  166,  818,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  395, 1287,    9,  671,   32, 2161,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,    6,  116,  259, 1108,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2773,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2459, 1713,  166, 1638,   45, 2458,    1,  613,  116,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  148, 2767, 1416,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051, 2115,   37,   52,    1,   39, 2819,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  166,  726,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2059,   45, 1994,  104,    1,  952,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2685,   37, 1435,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325,   81,    1,   12,   48,   32,  132,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1597,    1, 1598, 1429,   32,   72,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  247, 3131,   61,  729,  105,    1, 1569,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  728,    1,    9,  982,    1, 1613, 2474,  618,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  825,    1,    1,  845,   32, 2502,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   22, 2150, 2900,  228,   59, 2705, 2021,  356,   32,  854, 1190,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2258,   76,  187,  730, 2614,  907,  931,   32, 1090,  547,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  376,  567,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,  251,  105, 2306,    9,    1, 2129,  384, 3339,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1168, 2534,    1,   37,   52,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2390, 2165,  254,    1,  191, 1592, 3399,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2919,    1,  579,    1, 3358,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1060,    1,  705,    1, 1417,    1, 1953,   98, 3251,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1070,  398,   37,  899,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   65,  288,    9,   72,   67,   71,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2170,   12,    1,  729,    1,  384,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   32, 1881,   45,  810,  199,  340,  951,   94,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 2767, 1778, 2232,  328,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1258,  832,  951,   94,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1028,  647, 2264,    1,   39,  600,  148,  214,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  824, 1778, 1494,  680,  114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3132,  665,   32,    1, 1569,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1061,   32,  463, 2170,   98, 2673,  134,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1564,    1,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1472,  460, 1604,  123,   37,  754,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   98, 2800,  590,    1, 3190,   30,  453, 2558,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3225, 1289, 1211, 2256,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3144,  288,    9,   46,   98, 1512,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2751, 2714,    1,   45,  134,  951,    1,    1, 2764,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  671,  640,  356,  845,  187,   60,    1,  444,   94,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  104,  684,   27,  734,    1, 2010,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  631,   32,  463, 2170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2628,   37, 2225, 3301,  453,  365, 2565,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  515, 1882,    1,   37,  943,  220, 2846,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2014,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  176,  177, 2572,   32, 1656, 2950,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1668,  103, 1367,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   46,  289,   98,    1,   45, 1867,   28,    1,   45,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3258, 1397, 1090,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3186, 1648,   98,   37,   94, 3098, 1844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1744,   78,    1,  261,   98,  286,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1568,    1,  572,  156,  866,  118,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3237,  267,  204,   12, 2861,   37, 2685,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3276,  688, 3244,   32, 2925, 3201,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  361, 1361,   12,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2685,  123,   32,   98,  802,  220,    1,    1,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,   12, 1384,  802,   51,   52,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  449, 1156,    1,  162,  537,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  588,   69,  176,  403, 1383,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2548, 1882, 1588,   37,   64,  686,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1688,   45, 2388,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  215,    1,   51, 1046,  104,  776,  297, 1405,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  108, 1448,   37,    1,  244,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    5,    1,   12, 1541,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 2701,   12,    1, 1102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,    1,   61,    1, 1023,    1,  357, 1023, 1698,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,    1, 1260,   98, 1147, 2038,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 1760, 1089, 1090,    9,    1,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,  190,    1,  713,    9,    1,  751,  384, 2592,  282,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1147,  947,  877,    1,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3251,  221, 2126,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   65,   76,   37,   92,  347,    9,   72,  423,  424,  356,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  290, 1159, 1099, 1453,   51,  423,  560, 1251,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  449,  593, 1990, 2107,   32, 1270,  537,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   85,  548,  227, 2799,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1720,  166, 1361,  901,  453, 1245,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3283,  469,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  754, 2264,  619,    7, 1778,  328,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  794,  784, 1100, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  314,  551, 1692,   37,  125,    1,    4,  187,  197, 1308,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  459,  402,   37,    1, 2022,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612, 2589, 1167,    1, 2191,  334,    1,  424,  480,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   14,   15, 1032,  763,   76,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,   15,    1,   34, 2054,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  104,  146,  147,   96,   85,    1,   12,    1,  132,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1100, 1996,    1,    9,  327,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359, 2489,    1,   37,  582,   79, 3057, 1512,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1547,  418,    1,  187,   69,  102,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3264,  193,    1,   37,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428,    1,  191, 1338,   45, 3118, 1647,   98, 1737,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671,  967,    1, 1551,   37,  460,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  683,  315,   37, 2535,    1,    1,  220, 3333, 2963,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  700,  884,  105, 1150,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1216,    1,    1, 2763,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1008,    1,  365,   82,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3108,  665,  104,   32, 1764, 1990, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  311,  105,  311,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3144,  147, 1118,  932,   32,  741, 2096,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   97,  897,   98, 1783,  297,  163,    1, 2196,    1,  957,  460,\n",
      "         1294,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1412, 2287, 1729,    1,  725,  168, 1273,  327,  593,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111,  225,  605,  162, 1507,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 3009,  361,    1,  104,   51,    1,    1,   37,   77, 1990,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3296,  877,  105,  221,    1,    9, 2469,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  713,    9,  550,   45,  487, 3102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,   66,    1,  365, 1766, 1767,  769,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   49,  332,  720,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,    1,  360, 3359, 1819,   98, 3339, 2271,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  669, 1720,  460, 1494,   37, 2819,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,  163,    1,   12,    1, 2872,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1798,  741,  972,   98,  864, 3146,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  186,  338, 1139,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  492, 2625,    1, 2172, 2791,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  125,    1,  125,    1,   61,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2004,    1, 2819,    1,  162,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  162,  449,    1, 1918,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192, 2018,  619,  449,    1,  176, 2882, 1463, 2447,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  460,   12, 1018, 1691,    1,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2882,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  140,    1, 1918,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,  537,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1,    1,  176,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 2185,    1, 1014,  996,   29,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3374,  650, 2572,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  650, 1484,    9,  388,    1,   32,  854, 2018,   46,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  548,  854,   12,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2372,   45,  440, 3369, 1681,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1647,   45,  804, 2407,    1,   37, 1171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2634,    1,    1,    1,  766,   32, 1395, 1597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328, 1465, 1466,   37,  130,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2696,    1, 3115, 1675,    1, 1176,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,   39,   37,    1, 1432,    1,    1,  384,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2060,  415,    1,    1,  810, 1215,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,  779, 3044, 2168,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1273,  681,  123,   37,  170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   50,   37,  138,    1,   32,  544,  193, 1140,  927,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1444, 1445,   32,  166, 1514,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2954,    1, 1809,    1,  176, 1757,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,  159,  670,   32, 1125,  411,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  166,    1, 1935,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1697, 2327,    1,   22, 1697,   12,    1,  805,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  373,    1, 1405,  494, 1439,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2804,   45,  403,  464, 1009,   12,    1,  898, 1530,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  709, 2925, 1863, 2572,   32,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1232,    1,  166, 1465,    1, 1658,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  574,   29,    1,  191,  422,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  638,    1,   51,    1,  356, 1691,    1, 2919,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1716,  988,  675,   93,   32,  572,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,    1,   32,  518,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  560, 1274, 1556,  915, 1034,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3157,  774, 1428, 3365,  729,   32, 3376,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2889,    9, 1204,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,    1,  912, 2852,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  899,   56,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  692,    1, 1126,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1530,  357, 2249,   32, 1157, 1177,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,    1,  284, 3118,  861, 1414,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3173,    1,  105, 2509,  220,  661,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  614,   37,  395,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1,    1, 2904,   28,    9,    1, 2168,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,  121,   37,  429,  622,    1,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1494,  754,   32, 2808, 1006,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,  729,    1,  590,   37,  365, 1788,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  667, 1557,    1,   39,    5, 1563,   37, 2199, 1002,  832,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1110,  104, 2951,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  386,   78, 3272,  602,   37,  221,   37, 3096, 3293,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,    1,   45, 2843,    1,    1,  361, 1239,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  542, 1779,    1,   37, 1937, 3108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3333,    1,  191, 1751, 2457,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1603,  361,  111,    1,  191, 1339, 2382,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1308,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3172, 1550,    1,   45, 3190, 1292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3211,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  947, 2263, 2026,    1, 3060,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1074,  861,  829, 1521, 2762, 1268, 2009,   37, 2964,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  197,   37,  245,  475, 1213,  796,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200,    1, 1101, 1102,    1,    1,    1, 1101,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1776,  170,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3332,  696, 1245,   37, 1509,  698,   32,    1, 2218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1242,  104, 2161,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  729,  967, 2200,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  726, 2726, 3117,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3376, 2960,   98,    1,   45,  806,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2994,    1,    1,  682,    1,    1, 2997, 2126,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  877, 1167,    1,  131,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1433,    1, 1710,    1, 1910,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1749,  220,  963, 2122,    1,  696, 3076,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1022,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,   37, 1539,  853, 1698,   45,  238,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  148, 1702,   98, 2515,  112, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1050,  446,    1, 2205,    1,   10,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  755, 1426,  630,   98,    1,  133,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294, 1456,  197,  418,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3332,  775,   32, 2748,  726,  297,  365,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1594,   28,  166,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  388, 1061,   32, 2018, 1969, 1887,   45, 2764, 3394,  650,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1126,    1, 1268,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3322,    1, 1957,  176,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2331,   17,  167,   92,  647,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  800, 2378,    1,   15,    1,    1,   12,  197,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777, 1718,    1,  191,  861, 2215,  126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3253,   32, 3293,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3076, 2582,  590, 2309,  202,   37,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  874,  275,    1,    1,  875,   43,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1375,    1,    1,    1,    1, 1413,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  388, 1499, 1064,  176, 1084,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   76,   37, 2243, 1904,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1249, 3253,   37,  726,    1,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2731,   37, 1075,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1088,  446,    1,    1,  297, 3102,    1,   32,  121,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1202, 2596, 2646,    1, 1625,   45, 2024,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1425,  166,  593,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  779, 1256,    1, 2639, 3004,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  829,  132,  155,   26,  756, 1574,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1803, 1258,   32, 3339,  787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  552,  551,  405,   37,  125,    1,    4,   37, 2103,  390,  176,\n",
      "            1,   50,  328,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  709, 1405, 1213,  190,  138,    1,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,   57,   49,   37,  138, 1370,   45,    5,  798,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2427,    1,    9,    1, 1990,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2919, 2072, 3358,   12, 2162,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1791,   32,   36, 1465,  210,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1277, 2437,  187,   65, 1990, 2565,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  18,  98, 857,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  166,  872,  361, 2226,  332,  105,    1, 1567,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  627,  734,  384,  818,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  531,  650,    1,  299,    1,    1,  890,   32, 2020,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1477, 1990,  872,    1,  288,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2308,  664,   32, 2171,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2333, 2087,    1,  782,  754,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  147,  802, 1641,   37, 1994, 2086, 1896,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1461, 1260, 2414,    1,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1523, 1618,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9, 2018,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  233, 2104,   37,    1,  790,  297,  749,  231,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  176,  169, 2552,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 1114,  686,  119, 1653,   32,  104,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,  794,    1,  861, 2581,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1203, 2859,    1,    1, 1316,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3228,  125, 2761, 1247,  548,  442, 1464,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1973,   32,   46,  220, 2925,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463,  294, 2153, 1207,   37, 1865, 1018,  342,    1, 2179,  474,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  121, 1874,    1, 2924, 2271,  384,  463,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  523,  267,  460,   61,  837,   45,    1,  290,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  433,    1,  233,  498,   98,  301,    5,  302,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,    9,    1,  929,   37, 1540,   32, 2160,   45,  183,\n",
      "         1272,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2885,    1,   32,    1,   45, 1194,  726,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,   82,  267, 1444,  565,  435, 1100,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1815, 2389,  729, 1533,   79,  528, 3380,   12,    1, 1721,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  742,    1,    1,  297,  386,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,   37, 2303, 2109,  548,  367,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1,  446,    1,  191, 3372,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  971, 2257,    1,  844,  117,    1,    1, 2886,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  603,  176,    1, 1816,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,    1, 1085,    1,    1,  260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  778,    9,    1,  117,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3251,  221,   61, 1018, 1516,   37,  860, 1123, 2462,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162, 1516,  176, 2218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  560,    1,  176, 1056,  356,  340,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  267,  782,    1,   79,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  774, 1064,    1,    1,  191, 2707,    9,  342,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,  675,   37,    1,  365, 2294,    9, 1412, 2945,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3317, 3009,   32,    1, 2457,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,    1,  455, 1604,   98,   27,    1,    1, 2201, 1558,    1,\n",
      "          250,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,   37,  151, 1645, 2244,  700,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   74, 1347, 2007,    9,    1, 1935,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2885,    1,  176,    1,  628,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  389,  682,    1,   32, 1312,  257,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  664,  104, 2251,  856,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1011,  777,  680, 1665,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 1401,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766, 1236,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1027, 2056,    1, 1594, 1827,  166, 1948, 1532,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3116,  922, 3096, 3181, 2540, 3314,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3253, 1564, 2936, 3329,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 3345,    1, 1623,   45, 1428, 3365,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  774, 2682,    1, 3163, 1705,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613,  200, 1766, 1767,    1,  841,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2695, 2223,   37,   52,    1, 1332,    1,   32, 1022,    1, 2296,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481,  300, 3397,    1, 2596, 1592,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1476,  977,  123,   39,  594,   72,  401,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2998,    1,  590,    1, 3119,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2578, 3186,  168,   98,  477,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715,  112, 1161, 1276,   32,  367,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,    1,  104, 1084,  841,   50,    9,  152,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3188,  967, 1880, 2424,  187, 3244,  688, 2321, 2925, 1034,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   57,  142, 2458,  193,   37,  856,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2106, 2409,    9, 3149,    1,  288,   37,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1354,    1,    1,   29,   98, 2135,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  111,  834, 2165, 2139,   37,   77,   28,  220, 1220,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  534,   12,  550,  369,    1,   37, 1413,   12,  552,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1242,    1,    1,   37,  853,  538,  132,  515,  183,   92,   37,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1100,  846,  769,    1,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  666,  884, 1003,  176,  584,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  845,    1,    1,  845,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,  520,  413, 2362,    9, 2448,  386,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  144,  145,  197,  686,  191,  526,  983,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  166, 3278,  416,  460,  917,  424,  199,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3380,   12, 2024, 1727,  162,  838,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   81,   37,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2343,  387,  924,    1, 1414,    1,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2247,   37,  166, 2918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  726,  221, 1159,  449,  913,   32,    1,  463,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  167,  664, 3238,    9, 1090,  228,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  905, 2166,  737,  156,  245,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  225,  338,  548, 1858, 2153,    1, 1251,  125,  469,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  190,  335,   81,  593,  119,  384,    1,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1631,    1,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3079,    1, 3266,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  475,    1,   39,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   72,  401,  197,  338,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,  167, 1330, 1517, 3135,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  550,    1,    1, 2264,    1,  297, 2693, 2716,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1534, 1112,  176,    1, 2990,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  167, 1046, 1328, 3172,  909,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,    1,  583,   32, 2835,    1, 3389,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  331,  105,  293,  246, 1469,  444, 2293,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1290,  396,   71,   98,   81,   45,  567,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,  517,    1,   32, 1916,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  261,    9,  148,   32,  647,  142,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2290, 3259,    1,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  245,  187,   69,    1,  105,  106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 2147,   32, 2573,   32,    1, 2716,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1918,   32,  455,    1, 2843,   12,  114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1037,  275,  539, 1037,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1417,    1,    1,  466,  275,  442,   32, 1658,    1,  259,\n",
      "            9,  105, 2474,  786, 1615, 1160,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2202,  297, 3290,    1, 3228,  726, 1194,   73,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 1966,   66,  187,  183,  132,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  775,    1, 2355,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  503,  251,    1,  105,    1,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1249,    1,    9, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  580, 1133, 1463,   32, 2091,  463,    1, 2107,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101,    1,  138, 1812,    1, 3359,  580, 2429,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  821,  700,    1,  865,   37,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  404,    1,  493,   46,   37,  439, 1371,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510, 1554, 1530,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1110, 1413,  517, 1414,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  952,    1,   37,  764, 1523,  166,  183, 1305,    1,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  424, 1034,   32,   80,  550,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,   26,  710,  267, 3274,   39,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  215,    1,  967,  105,  365,   19, 2690,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1190,    1,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  958,    1,    1,   32,  386,   78,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282, 3174,  801,   37,  395,   26,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,    1,  934,  328,    9,  963, 1223, 1821,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  379,   37,  907,  220, 2751,   37, 2000, 2179,  808,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1854,   98,  247,  915,  916,    9, 1463,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  953,   81, 1315,    1,  105,  106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1,  990, 1070,    9,  388,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,    1,   12,  215,   69,  112,    9,    1,  372,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 2946, 1976,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 1216, 2067, 1245,  297, 3102,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,   12,  432,   45, 3339, 2129, 1908,  410,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1226,  187,  163,    1,   12,    1, 1588,   66, 1239,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  446, 1118,   94, 2784,    9, 1530,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273,   12,    1,    1,   45, 1283,  943,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1087, 1042, 2336,    1,  260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2776, 1151,  279,  861,  384,  129,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,  69,  27,   1,  98, 889, 109, 509,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 902, 429,  79,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1029,   34,  962,   98,    1,  802,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,    1,  191,   69,   12,  245,  185,  186,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428,    1,  531, 1346,    1,  105,  356,  548, 2950,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786, 1178,   12,    1,    1,  231,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1363, 1564, 1361,  453,    1,  460, 1873, 2973, 1764,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2206, 3351,    1,    1,    1,    1,   45, 2197,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  585, 1403,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2628, 1345,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2415,    1,   37,  877, 1411,  698,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 1697,    1,    1,  317,    1,  619,    1, 1217,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1,  140,    1, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  741,   32,  391,  863,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1109, 1867,  111,    1, 1108,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,   98,    1, 1097,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1342,    1,   82,  548,    1,  939,   37, 1413,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,  475, 1112,  176,  388, 1184,   67,  418,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  755,  399,    1, 2091,    1, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,   46,  220, 2531,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1198,   79,    9, 3215,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  627,  996,  406,    1,  338,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2947,    1,    1, 2179,    1,   32, 1759,  309,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1214, 2761,   61,   74,   37,   74,  220,    1,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051,  387,  395,  187,  656,   45,  593,  275,  218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   14,   15,  297,    1, 1981,  227,    9,  284,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,    1,  359,  759, 1259,   98,    6,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  636,    1,   32,  819,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  179,   27,  132,   37,  151,  180,    9,  131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2634,  775,  365,  845,  439, 2759,  260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1435,  848,    1, 1443,   32, 1521, 1151, 2107,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3184, 1557,   37, 1860,  890, 2191, 1294, 1064,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  688,    1,   32, 2445,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,  986, 2069,    1,   37, 3395, 3102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1414,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,    1,  148, 2471,   28,  220,  326,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3157,    1, 1919, 1994, 3370, 3350, 1010, 2091,  861,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1675, 2332, 1343,  892,  565, 1176, 2970,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 968, 267, 190,  26,   1, 443,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 209,   1, 338,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2197, 1218,   37,    1, 1354, 1147,  734,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,    1, 1295,  631,  219,  159,  417,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,   45, 3016,  538,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,  446, 1481, 2864,  601, 1002,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 1877,   37, 1604,   98,  397,    1,    1, 2137,  296,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870,  571,   37,  327,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158,  200,  365,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1521, 2085,    1,   45,  105,    1,  988, 2483,  459,   45,\n",
      "         1185, 2983,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3298,    1,    1,  202, 2783, 2545,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3196,  884, 1383,    9, 2227,   12, 2002, 3222,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158,    1,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   28,    1,  118,   32, 1378,  442,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  359, 1054,    1,  528,    1, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  365, 1926, 1927, 1928,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1063,    1,  844, 1090, 1182,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1287,  608, 3001,   37,  798,  671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2779, 2540, 3173,   32,    1, 2069,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999,  215,   96, 1994, 2819,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 1013,    1,    1,   98,  449,   74,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,   12,    1,  200,  365, 1101, 1102,  280,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  433,  102,  245,  981,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1156,  650,   37, 1844,    9, 3358,   12,  389,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  686,   91,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,  631,   32, 1759,  309,  187,    1,  307,  125,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3384, 3382, 1231,   32, 1606, 2950,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1432, 3207, 2411,   37, 2192,   28,  671, 3126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3375, 2572,   32, 3101,  285,   32,  166,  539,  458,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   64,  799, 2162, 1950,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  571,   32,  726,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  515,  208,  183, 1198,  176,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1527, 1149,    1,    9,  388, 3118, 3396,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   37,  949,  327,  220,  844,    1,    1, 1797, 2177, 1027,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  437,   37,  151,   12,    1,  273,  434,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2963,  142,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2468, 2198,    1,  361,    1,    9, 2741, 1912,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117, 2208,    1,  815,  777,   37,    1,  863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  160, 1161,  640,  339,  340,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1802, 1118,  345,    1,  191, 1890, 2552,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   63,  166,  862, 1524,   72,    1,   79,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537, 2122,    1,  964,    9,  695,   39, 1428,  861, 1906,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  755, 1536,  449,    1,   43,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2905,    9,   80,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3271, 2712, 3231,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2528,    1,  829,    1, 1656, 1778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1879, 2815, 3229,    1,   79,  220,  583, 3265,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  166, 1994, 2650,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  864,  315,   37, 1195, 2673, 3366,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  560,    1,  640,  339,  340,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1,  361,    1, 1765, 1560,    9,  166,  295,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37, 2654, 2851,    9, 1778, 2232,  191,  356,   12,  439,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1976,   32,  395,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  549,  891,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2024,   32,    1, 2177,   37,    1,    1,  202,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,    1,  284,  104,    1,    1,    1, 2311,   37, 1124,  244,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  848,   12,    1, 2695,   55, 1191,   98, 2901,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179, 2261, 1765,  449,    1,   37,  693,  365, 1615,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  501,  827,  140,  220, 2213,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1606,    1,  835,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  566, 3289, 1684,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3005,    1,    1, 2072, 1104,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  156,  193,  320,  363,    9,  262,  263,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1009,   37, 1540,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2072, 3155, 1560,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1882,   12, 1931,  600,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 3012,  934,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1668,    1,    9, 2304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1369,  716,    1,  182,  354,    1,  202,  267,  460,   12,   81,\n",
      "           98, 1171,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386, 1070,  398,   37,  222,    1,   45, 1202,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2977,  288,   37, 1539,    1,    1,  880,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  528,    1,    1,   10,   12, 2237,   37,  942,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1855,  650, 1484,    9,  342,    1,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2266, 1008,  365,  475,   45, 1346,    1,  652,  973,   66,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3354,  446, 2055, 2579,   32, 2752,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  297, 3361, 2572,    1, 1941,   32, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1711,    1,  548, 2018,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  730, 2614, 2872,    9,  166,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 1789,   61, 1509, 2225,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3225, 1421,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  105,    1,  221,  384, 2929,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1333,  665, 2218,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3242,    8,  304,   37, 3215,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3209,    1,    9,    1, 1844,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,    1,   37,  166, 1746,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  531,  890, 1822,  335,  913,  187,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2677, 2885,  361, 3303,    1,    9,  427, 1343, 1798,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   29,    1, 1450, 2587,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,   85,   98,    1, 1820,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,  693, 2580, 1442, 2581,   37, 1797,    1,  437,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  449, 1173,    1,   12,    1,    9,    1,  327,  593,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1962,   37,  109,  517,  196, 1074,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  273, 1609,  325,   48,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,    1,  612,    1, 2834,    1,  202,    1,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  593,  770,  476,  104,   37,  771,  111,  772,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213,  108,  902,   37, 1807, 1545,   12, 1509,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1614,  535,  656, 2367,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1324, 2619,  297, 1837,    1,  382,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  921,  922,   45,  923,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  267,  121, 2567,   98,  365, 2673,  675,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 1723,   57,    1,   37,  138,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1337,  573,  469,    9,  365, 1635,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   64,  608, 1668,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1237, 1658, 1117, 1525,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2448,  386,  512,  476,   37,  619,   37,  166,    1,   45,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  468, 1362,  515, 2017, 1273,    1, 2706,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3064,  744,   28, 1388,  220,    1,  413,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  232,  267,    1, 1560, 1464,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2388, 1993, 2307,   32, 2069,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,  726,    1,  187, 3343, 1002, 2116,    1,   28,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  297,    1, 2668,  361, 2599,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790, 2996,    1, 2558,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1783,   37,  125,   28,   37,    1,    4,  297, 1056,  537,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1492, 1082, 1725,   37, 1598,  735,  442,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2528,    1,  105,  822, 1787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   47,    1,   32,    1,   54,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  437, 2677, 1327, 2062,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3132,    1, 3186,  606,  581,    1,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,    6,  377,    4,    1,    1,  311,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  996, 1986, 1500,  560,  347,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1668, 1194, 1567,   32,  726,  297,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1786, 2358, 1268, 1099,  927, 1039,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12,  182,    1, 2249,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1,  398,    6,  829,  822, 1469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  740,    1,  794,  777, 1085,  700,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,  218, 1115,    1,    1,  774,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  870,    1,  315,    1, 1766, 1767,  191,  857,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1292,    1,    1, 2500, 3020, 1821,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1107,  441,  190,  815,  111,  912, 2285, 1108,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 3164,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,   20,  872,   28,    9,  750, 1604,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273,    1,  162, 1018, 1901,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   47,    1,    1, 1499,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   28,  115,   45,  572,  156,  716,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2523,    1,    1,  427,   12,    1,  332,  631,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3127, 2322, 2052,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1158,   12,    1, 1516,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,   12,    1, 1082,    1,    1,   37,   81, 3057,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,  140,    1,  622, 1967,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,    1,   95,  473, 1415,   37,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,   42,  573,  767,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  108,   45, 1610, 1081, 1606, 1260,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,    1, 1979,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   37,  429,   49, 1611,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  912,  767,  444,  923,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  871,  568,   28,    1, 1844,  658,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2528,  829,    1, 1656, 1778,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766, 2914, 2071, 2294, 1935,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  973,   37,    1, 3383,   45, 3045,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1576,  774,  667, 2095, 3060,  972,   37,   52, 1683,  384, 3127,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  854, 1463,  546, 2673, 3085, 1461,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  947,    1,  388,  199,   37,    1,    1, 3382, 3402,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1766, 1767,  437, 1458,    1,  861, 2146,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280,  140, 2161,   12,  365, 1788, 2472,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  915,  356,   12,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2288,    1, 1083, 2817,  629,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1183,    1,    1,  614, 3204,   12,  454,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12, 1741, 1741,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1670,    1,   32,  342,  132,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1610,  458,  170,    1,    1, 1880,  458,  565,   32,   46,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  446,  515,    1,  304,   98,  651,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296,   37,  151,  388,  436,    1, 1155, 1967,   32,  395,    1,\n",
      "          232,  267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1527, 1149,  774,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,  418,    1,  159,  242,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,   22,  159,  866,    1,  359,  360,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  565, 1764, 1990, 2069,    1,    1,  267,\n",
      "         3230,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3359,  108,   45, 2368,  890, 2198,    1, 1322,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  220,    1,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3355,  577,  297,  531,  890,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1867, 1089, 1484, 1813,    1,  260,  361, 1273,  618,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1005, 2737,   32,  822, 2195,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   12, 1354, 2341, 2400,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1479,  668, 1701, 1207,   37, 1753,  116, 2633,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1702,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  580,    1,    1, 2298, 1428,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,   37, 2237,  854,   12, 2670,    1,  548,    1,  297, 1428,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3294,  729,    1,   32, 2316,  105,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  420,  737,  354,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2177,  686,    1,  729, 1139,   45,  238,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  231,    1, 1863,  193,  105,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1009,    1,    1,  331,  384, 2828, 2857, 2565,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   39,   45,    1,    1, 3174,  140,   26,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1427, 1401, 3271,  608, 3231,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1585,    1, 1656,   32,    1,    1, 2766,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  501, 2736, 1082,  522,   98,  651, 1031,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  393,  159,   71,   98,  753, 1167, 1858,  132,   27,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  275,  288,    9,  449,    1, 1090,  220, 2748,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2702,  298, 2414,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1855, 3365, 1683,   32,  531,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  785,  786,    1,    1,  580,  822, 1787,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1640,   12,    1,  476,  365, 1930,    9,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  864,    1, 2339,  622, 2390,  778,  384,  163,    1,  903,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   71,    1, 1572,  191,   69,    1,    1,  441,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  727,   37,  151,    1,   12,    1,    9,   54,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1425,  166, 1833,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  832, 1258,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,    1,  121,   37,  856, 2095,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2, 754,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 162,  24, 881,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  550,  179, 1205,  297, 1791,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 1021,  159, 1253,   98,  714,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035,   12,  365,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,   85,   37,  112,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  864, 1484,   98,  593,   37,    1,  453, 3032,  663,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  581,  617,  697,    9, 1081, 1260,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  215, 3102, 3025,   12, 1887, 2536,  191,  247, 1841,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,   45,  593,    1,  199,  776,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1363, 1042,   98,  420,  460, 1441,  142,    9,  179,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  102,    1,   32, 2088,  219,  442,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  547,    1, 2548, 2572,   32,    1, 2517, 3279,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   46,    9, 1850, 1423,  619,  680,  454,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  811,  267,  531,  443,    1,  388, 2342,  593,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999,  251,  210,   37, 1260,  923,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3363,  884,  411,  631,   32, 3343, 2116,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,    1, 1281,    1, 1987, 1408,    1,   79, 1327,   12,  872,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  786, 2847,  631,  297, 3203,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 2008,  129,    1,  297, 2655, 2096,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  649,    1, 3340,   32, 2531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220, 2615, 2175,    1,  730, 2614,  753,   37,   77,  166, 2789,\n",
      "          384,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,    1, 1976,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1037,  275,    1,   28,  282, 2334,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 3028, 2995, 1441,  116, 2542,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  129,  325,    1,  772,  624,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1794, 2800,    1, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141,  167,  815,  424,  360,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3199,  884,  631,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 1396,    1,    9, 1791, 2177,  988,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1821,    1, 1878,  567,  666,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  473, 1210,    1,  527, 1132,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2171, 2701,  709,    1, 1863,    1,    1, 2753, 1090,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,  476,   37, 1427,  883,   32,  537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  386, 2055,  394, 1013,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 1959,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1,    1,  297,   32, 1545, 2448,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1200,  267,   32,   46,   37,  151,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1712,    1, 1658,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,   37, 1075,    9,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  475,  267,  105,    1, 1924,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,    1, 2863,  149,  951,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 1426,  399,   32,  573,  149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089, 2530,  176,    1, 1710,   52, 2502,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  449,  776,  251,    1,   98,    1, 1405,  802,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   97,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  854,  240,   98, 2069,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2147, 1760,  815,   45, 1325, 2041,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3253,    1,  115,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,  681, 1542,  469,    9,  809,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,   12, 3359,    1, 2789, 2751,   63,  741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2765,    1, 2572,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2162, 1950,  384,   64,  431,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,   74,    9, 2995,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428, 2055, 2571,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 1013,   45,   26, 1039, 1592,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  982, 1564,    6,    1,    1,   98,  613,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 1447,  361,  455, 1248,    1,   37, 1195, 2673,   46,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2523, 1086, 3106,  220,  455, 2666,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147, 1523,  488,  844,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326, 2384,  460,  629, 1499, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3189, 1542,    9,  505,  856,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  341, 1108, 1301,  453,    1,  751,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12, 1185,    1,  387,  851,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3099,   12, 1994,    1,  475,  939,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  132,   61,    1,   45,  166,   99,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  601, 2132,  878,    1, 2906,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1936,    1,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,  845,  275, 2773,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3215, 1216,   37,  311, 1931,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 3165,  588,    1,  176,  455,   36,   32,  395,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228, 2449,   32, 2611,  548,    1, 2960,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   12,  535,  656,  729,  338, 1139,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401, 3059,  297, 3247,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3010,  967,    1,    9, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1380,  289,   98,   29, 1416,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   61,  460, 2595,  334,    1,  105,    1,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700,   45,  166, 1509,    9, 2857,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2550,    1,  191,    1, 2537, 1821,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3355,   32,  142,   37, 2460,  698, 3388, 2024,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2640,  571,   37, 3024,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,   12,    1,    1, 3053,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1087,   37, 2654,    1,    1, 1108,  191,  356,   12,  439,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  497, 1281,    1,  384, 1317,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1957, 2620,    1,    1, 2596, 1976,  115,   45, 3343,  741,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  430,  393, 2751,  498, 1302,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1751,  513,  514,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,   69,    1,  640,  102,   98,  236,  237,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  533,  729, 2854, 2279, 2861, 1159,  365,  356,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  305, 1269,  202,  840,    1, 1071,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1668, 3336,  852,  198,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  259, 2718,  872,   28,   37, 2654, 1273,  844,  918,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   81,  384,  166, 1530,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  162,  449,    1,  726,   32, 1700,  537, 3129,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1220,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1297,  618, 1937, 1632,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  823,  444,  166, 2402,    1, 2423,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  176,  845,   98, 2046, 2047,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1542,   37,  877,  388,  183,    1,    1,  267, 1644,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  474,  759,  630,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401, 2872, 2337,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  203, 1900, 2370,  600,    1,   45,  863,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  354,  703,   32,   72,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  190,  193,  690,  981,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2448,  386, 1086, 1545,   12, 1045,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  220,  154,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,  140, 3343,  863,    1,  232,  267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   32,  105,  129, 2578,    1,  166, 1140,   45,  166, 1264,   61,\n",
      "          460,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,  712,    1,   37, 1330, 1090,   45,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1700,  487, 2548, 1999, 1530,   32,    1,  298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2192,    1, 2674,   73,  922,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   32,  845,  846,    1,    1, 2289,    1,    1,  204,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,   37,  619,   39,  166,  741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1959, 2740,   32,  191,    1,    1, 1366, 1445,  415,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1035, 1070,   37, 1642, 1175, 1371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  649,  232,  610,   37, 2162,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999, 2215,  126,    1,    1, 2980,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  552,   37,  552, 2274,  134, 3003,  220,  768,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2049, 1174,  365, 1015,   32,    1, 2304,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  447, 1830,   37,    1,    1,  384,  557,  540,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  476,  917,   37,    1, 3107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2993,    1, 2373, 2994,    1, 2677,  949,    1, 3056,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1024,  551, 1024,   12,  197,  162,   92,  384,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1866,   37,  365, 1546,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  314,   37,    1, 1469, 1629,    1,    1,  744, 1511,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3282,    1, 2005,  608,    1,   32, 2936, 3329,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  744, 1274, 2750,  949,    9, 1332,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977,  880,  190, 2286,   37,  168,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1083,    1,   59,   32,  457,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2563,    1,  513,  193,  514,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425,   32,   54, 1883,  170,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1, 1486,    1,  716,  737,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  358,   32, 1259,  220,  587,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  702,  353,  197,  987,    1,  897,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1950,    1,  197, 1270, 1660,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   75,  991,  858,  297, 1021,  847,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  854,  342, 2396, 1924, 2312, 2133, 2406,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1899,    1,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 2612,    1, 1151,   32, 1463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3084, 1550, 2180, 2056, 1171,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2005,  163,    1,   12,    1,  297, 2468,    1,    1, 2228,\n",
      "           79,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,    1, 1536,    1, 2706, 2232,  361,    1, 2750,   98, 2264,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2597,  344, 3403, 2414,  176,  177,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2336,    1,    1,   37, 2481,  187, 1151,   12,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115,    1, 3200,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  679,   69,  420,    1,  102,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  765,   37, 3097,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1693, 2038,  922,  427,  716,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1127,   32,  331,  104, 1074,  151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1186,   37,    1, 1994, 2095, 1506,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    8,  228,    1,   98, 1778, 2558,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2741,    1, 2354,   37, 3184,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  991,  734,    1, 1268,  454,    9, 1527,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2212,    1,    1,  763, 2095,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  361, 2993, 2994, 2567, 2444,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  123,   32,   98, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1542,   37, 1947, 1390,   12, 1746,  469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  113,  176,  187,  531, 2361,  532,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  637, 1322,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2080,    1, 1308, 3326,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1183,   74,    9, 2779,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  202,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465,  298,  640,  869,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3252,    1, 1176,  445,    9, 3285,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  437, 2386, 1158,   45,    1, 2610, 1402,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3096,    1,    1, 2297,    1, 1354,    1, 1863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1985,    1, 2892, 2572,   32,  531,   12, 2646,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2211, 1968,  497,  907,   98,  442,    1,  861,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741, 2827,  191, 2637,    1, 1617,    1,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,  108, 3140,    1,  864,  444,    1,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1061,   32,  596,  777,  133,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  476,   37,    1,  168,   98, 1821,   95,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  171, 2682,  590,    1, 2570,  171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1517,    1,    1,  284,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1527,  437,  488, 3360, 2271,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1613, 1614,  166, 1615, 2474,  259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,    1,    1,  612, 2613,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  622,    1,  332,  888,  361,    1, 2325,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1232,  166,  730, 2614,  726,    1,    1,  166, 2769, 2378,    1,\n",
      "         1654,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1613,  566, 1273, 1117, 1525,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  246,  442, 2010,    9,  395,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2182,   79,    1,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1720,  166,  517,   46,    1,   61,    1,    1,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1723,  261,   32,    1,   45, 2254,   32, 2096,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  297, 2472,  595,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  326, 1635,  373,    1,   37, 1000,  607,    9,  327,   50,    1,\n",
      "            1,  267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3314, 2540, 1728,    1,   98,    1,   37,  726, 1326, 1990,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  191, 1255,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,   48,   32, 1700,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  600,  221,  384,    1,   37,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1089, 1090, 2692,  775,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2110, 2034,  903,    1, 1007,    1, 1264,  841, 1569,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1089,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  197,   98, 1032, 1220,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1676, 1994,  443, 3061, 1313, 2237,  191, 2868,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548, 3298,    1, 1492,   12,  590,    1,   32,  785,  786,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1094,  190, 1306, 3358,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3286,  603,   37,  583, 2018,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2699,    1,    9, 1539, 1821,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  922, 1090, 1829, 2916,  176, 1739,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 163,   1,  12,   1,  25, 123, 242, 187,  68, 338,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  46,  45, 442, 443, 444, 104,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1465, 1466,   37,  114,    1,  243, 1607,  260,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  204,  190,  690, 3343,  741, 1578,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   12,  342, 1523,  640, 1300,  147,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  438,   60,  682,    1, 1340,  245,  548, 1619,  458,  155,  347,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3235,  501, 3299, 1198, 2722, 3074,  608, 1834,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  920, 2171,    1,  321,  612, 1000,  105,  389,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  832,  187,  137,  533,    1,  326,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117, 2208,   37, 1046, 1479, 1463, 1970,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1744,  393,  359,  469,   37,  930, 1411,  339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1571,  123,   37,  132,  220, 1233,  785,  786,  872,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,   98,  429,  187, 1931, 1192,  297,   65,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,    1, 1178,   32, 1821,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3189,    1, 1779, 3130,  565,    1,   55, 1745,   63,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1581, 2376, 2024, 2223,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1444,  254, 1103,    1,    9,  104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  439, 1034,   98,  845, 1318,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2226,    1,    1,   45,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425,   37, 1539,  777,    1,    9,    1,    1, 3031,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   92, 1247,    1,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  125,  970,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 2693, 2694, 2501,  443,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,   85,  680,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  398, 1342, 1576,   37, 1599, 3378,    1,  297,  247,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1151,   15,   71,    1,  419,   32, 1352,  384,  385,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  547,  583,   32,  539,  458,  344, 1585,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  713,    1, 1411,  356,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  446,  536,  204,  190,  631, 1411, 1386,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1509,  310, 2057,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  769,   51,  973,  657,   79,  453,  336,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1403,  105,    1,    1, 2012,    1,   28, 2056,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3380,    1, 2143,  622, 1592,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2055, 1858,  912, 2285,  210,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2954,  176, 1542,  176,  691,   12,  803,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1512,   32,  365,  342, 1098,    1,  548,  957,  939,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1959,    1,  872,  420, 1657,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1079,  104,   12, 3207,   37, 2192,   28,  166,  671,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  642,  643,   57,   28, 1219,   15,   85,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  232,    1,  254,    1,    9,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2226,  331,  118,    1,    1,  267, 3021,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3292, 3021, 2317,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  183, 1090,    1,   79,  166, 2904,    9,    1,    1,  298,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 1405,  573,  469,    1,   37, 2222,    1, 1639,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  428,  597,    1,  650, 2301,   32, 1212,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3005, 2790, 1231,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  487, 1583,  839, 1920,   12, 2162,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  449,   37,  168,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  215, 3030,   37,    1, 2526,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  612, 1273,    1,    1, 1054, 1766, 1767, 1606,  802,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  386, 2047, 2408, 2205,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,    1,  856,   81,   32,    1,    1, 3192,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1247,  967,  460, 1427,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1398,  612, 2116,   39, 3330,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  572,   61,    1,    1,   37, 1548,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303,    1,    9,   60,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1181,  708,  882,    9,    1, 1017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1240,   23,  657,   79,  453,  336,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   94,  113,  453, 1737,  444,   60,   98,   65, 2001,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1162,    1,   37,    1,    1,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2059,  267,  976,    1, 3388,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,    1, 2982,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1707,    1, 1220,    9,    1,  131,   32,  365,  223,  987,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3221,  476,    1,   45,    1,  375,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1112,    1,  967,  227,  916,   45, 2410,  176, 3229,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  551, 3359, 1670, 1018,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2275,   12,  472,    1, 2034,   59,  297,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1795,    1,    1, 1046,  183,    6,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,   68,   69,  102,  245, 1315,  105,  106,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  140, 2376, 2024, 2223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,  566, 1407, 1228, 2109,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  325,  457,    1,  700,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3297,    1,  590,    1, 3089,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  267,  460,    1, 1443,   32,    7,    1, 1465, 1463,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2820,   12,  449,  123,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  455,   12, 3087, 1080,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1185,    1,    9, 2158,   45, 2121,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,  475,  108,   98,  673,    1,  442,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  968,    1, 2394, 1886, 2116,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  885,    1,  855,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2275, 2559,  938, 2911,  176,    1, 2151,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2236,    1,    9, 2142,  951,    1, 2551,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  183,  978, 2297,  103, 1465, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1170,  853, 1809,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,  124, 1316,  166, 1255,  361,   61,  166,  215,   12,\n",
      "         2084,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  805,   45,   69,  636,   98,   31,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2502,    1,  919, 2805,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428, 2736,    1,  146,   37, 3348,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  952,    1,  865,   37, 2642,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,    1, 2835, 1421,  104,    1,  442,  630,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,    1,   54,  132,   37,  349,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  920, 2005,    1,   45,  691,  361,  365, 2036,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  420, 2026,  133,  167,  759,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2751, 1250,    1, 3040,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   81,   37,   36,  920,    1,  623,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1294,    1,  657,  636,    6,  221, 2403,  363, 1569,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   39,  627,    9,    1, 1102,  436,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3251,  193,    1,   39,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,  997, 2400,  705,    1, 1256,    1,   12,  606,  105,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1498,  606, 1976, 1534,   45,  156,    1,  176, 1099,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1277,    1,    1,    1, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2962, 3238,  696,  730, 2614,   77, 1245,   98, 2615,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2957,  728,  212, 1395,  275,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128, 1702, 1718, 1159,  166,   29, 2363,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  632, 3372,  908,  863,  302,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56,    1, 1634,   37, 2638, 2931,  927,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1018, 2858, 2773,   32,  942,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  334, 1445,    1,    1, 1257,    1,  912,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  460,   25,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  156, 2393,  647,    1, 1396,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1126,  315,  384,  395,   12,    1,    1, 1109,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1005,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 657, 376, 572, 983, 308,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 793, 513, 220, 359,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  848,  744,  636,    1, 2306,    9, 2371,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1021,  256,    1,   37, 1871,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1183,  713,  297,    9, 3287,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  267, 1542,   37, 2394,  193,    1, 2390, 2375,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,  808,   51,  606, 1532,  104,  105, 2095,  837,  667, 1190,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  244,  554,  202,   69,  997, 1806,  732,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2994,    1,  166,  777,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  719,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1962,  256, 1101,    1,   37,  858,  613, 1841,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2127, 2432,  193,  320, 2127,    1,  187,  104,  996,   93,\n",
      "           61,    1,  242,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1625,  105,   12,    1, 2160,   28, 1140,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  733,   48,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428,    1,    9, 2024,  220,  365, 2389,   32, 3369,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1122, 2384, 2869,  853,  538, 1671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3182,    1,  313,   37, 1334,  202, 1240,  193,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,  353,  118,  242,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  258,   25,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2059, 1061,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1465,  572,  551,  105, 1804,   98,    1, 1778, 2580, 2851,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2374,  267,  460, 1924,    1,  297,   10,  622,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1619,  458,    6,    7, 1184,   67,  191, 1023,    1,  402,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  365, 1976,    1,    1, 1748,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1249,    1,    9, 1022,  667, 2800, 1684,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   51,    1,  365,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  857,  120,  919,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  844, 2151,    1,   37,  447,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  333,   34,    1,   12,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1215,  669,  376,  453,  570,    9,  156,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2669,  166,  917,    1, 1813, 1021,  361,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  324, 1229,   37,  151,    1,  327,  112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2087,  433, 1707,  442,  400,  951,    1,  395,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  372,  632,  141,   48,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  884,  356,   39,   37,  588,  365, 1355,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,   37, 1816,    1,  331,    1,    9,    1,  325,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2246, 3271, 1066,  220, 3117,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  592,  108,  600, 2066,   69,  636,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  381,   37,  151, 1739,  458,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178, 1905,   32,  147,  297,    1, 2772,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  397, 2055,   72, 1479,  231,   45,    1,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2497,  267,  375,  400,    1,   32, 3185,  856,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,   39, 2084,    1,  328,   32,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,  155,  104,  347,    9, 1524,  199,  424,  356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,    1, 1353,   32,   86,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2871,    1, 1844,  845,   32, 2184,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1497,    1,  190, 1306, 1056,   37,   56, 2119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  125,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1465,    1, 1894,  600,  112,  651,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1695,  876,  612, 1419, 2006,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  447,   37,  125,  734,  220, 1109,  333,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,   26,  417,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1537, 2404,  544,  193, 1807, 1479,    1,  176, 2018,   46,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  615,  335,  199,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1818,  147,  116, 2387,  484,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  430, 3357,  437, 1877,   37, 1260,   69, 1149, 1232,  681, 1334,\n",
      "           32,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  867,   76,   37,  837,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  650, 3123, 1249,    1,   32, 1050,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2178,  318, 1156,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1110, 1865,  365,  111, 1107, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1384, 1900, 2963,  297,  972,  425,  426,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,  608, 3024,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1,  162,    1,  166, 1868, 1172,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  258,  890, 1761, 1565,   45,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  193,    1,   81,   32, 1739,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1, 2317,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2506,   45,  981,    1,  522,  548, 2440,    1, 1510,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2787,    1,   37, 2788,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  550,    1,  150, 2025,  321,    1,   45, 2179, 2819,    1,    1,\n",
      "          166,  863,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2046, 2024,  142,    9, 1365, 1086, 2198, 2666,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2592,  105, 1039,   45, 1803,    1,    1,  267,   32, 2163,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2212,  861,  162,    1,  118,   92,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,   37,    1,  388,   98, 2673, 1021,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2369,  207, 1425, 3155,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3124,    1,  166, 2537,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311,  733,  331,    1,  176,  105,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  216,  135, 2597,    1,    1, 2414, 2611, 2664,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1687, 1022,    1, 3008,  105,    1, 1551,   45,  114,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 1972,    1,    1,   85,   32,  451,    1,   32, 2174,    9,\n",
      "          497,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   45,  507,   37,    1,    1, 2348,  618,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3186, 2827,  191,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1, 1790, 1776,  955,  956,    1, 1539, 1651,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  437,  108,   45, 1687, 1022,    1, 3008,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358, 1564,  915,    1,  693,   37,  587,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3260,  951,    1, 3232, 2677,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1251,   45, 2693, 1942,  418,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,  777,  778,    1,    1,    1, 1693,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284, 2911,    1,    1,   63,  863,   74,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  335,  460,   32, 2138,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  447,   98,  103,   32, 1764, 1990,\n",
      "         3295,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  838,    1,  478, 2593,  807,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  260,   28,    9, 2372,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1110,    1,    9, 3115,  361, 2777,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2757,    1,   37,    1,    1, 1259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3381,  859,    1,   37, 1926, 1927,  777,  778,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  408,    1,   32,  901,  174,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1985, 2569,  947, 2844,   32,    1, 2774,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2871,    1,    1,   37, 1752, 1211, 2256,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  411,  650,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175,    1, 3256,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3373,  254,    1,  548,  531, 2874,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   81, 1750,  119,  687,  951,    1,   94,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2920, 1564,    1,  176,  754,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2746,    1,  365, 1600,  138,  261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2327,    1,    1, 1975,  619, 1568,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  932, 2200, 2054,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  782,  363, 1569,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2414, 3006,   32, 3360,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  609,    1,  384,    1, 1604,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  485,    1,  197,  338,    1,  159,  720,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 1417,    1,    1, 2411,   37, 1334,   98, 1346,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  732,   95, 1803, 1627,  581,   74,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,    1,    1,  661,   98,  430,  109,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  410,    1,  297,    1, 2509,   98, 2924,    1,   32,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2194, 3050, 2622, 1056, 2165,   32,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   12, 1343,  176,  449,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147, 1009,  267,  806,  894,  168,  115,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1028,  167, 2704,    1,   45,  557,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  409,   25,  439,  417,   98,    1,  927,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1435, 1935, 2294,  855,   51,   52,  288,  424,    1,  766,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,   85, 1114,  163,    1,   12,    1,   68,   25,   66,   28,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  359,   37,    1,    1,    9, 2977,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3282,  719, 2858,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2016,  787, 1906,  246,    1, 1123,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,  659,   45, 1778,   34,  861,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796,   93,    1,   37,  105, 2199,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   71,  548,  642,  643,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1026,  353,  242,  572,  244,    1,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1652, 2386,  829,   45,    1, 2015,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  729,  162,  105, 2460,   39,   45, 2161,   12, 3096,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  565, 2213, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  191,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1710, 2714, 2087, 1159,    1, 1218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  822,  992,  698,    9, 1988,  163,    1,   12,    1, 3400,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2967,  782,  105,  754,  220,  166, 1497,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  770, 1976,   32, 3155,    1,   37,   52, 1919, 1527, 2664,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3375, 1248,  163,    1,  903,    1,  741,  444, 1094,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1276,  444, 1354, 1479,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094,   12, 3359, 1877,   37,  856,    1, 2072, 3389,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537,  446, 2885, 2024,   46,  220, 2018, 1809, 1647,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,    1, 1031,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  238,  813,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  224,  794, 2355, 1013,   37,    1,  829,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1360,  612,  138,  976,  297,    1,  400,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3382,  580, 2416,  134,   32, 1186,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1090, 1829,    1,  176, 2110,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  939,  187,    1,    1, 2565,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3240,    1,  440, 2317, 2308,  907,  220,    1, 3141, 1293,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  597, 1190,  583,   32,    1, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  964,  267, 2062,  493,    1,   61,  297,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1759,  309,    1,    9, 1273,  618,  167,  439,    1,  533,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1668, 2232,  745,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  754,    1,    1,    1,    9,  166, 2063,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,  440,  175,   45,   69,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481,    1,  691,   12,  233,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   88,  315,   37, 2316,    4,  176,  778,   32,  854,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  787, 3090, 2821,    1, 2874,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  709, 2178,  993,  475,  267,    1,   32, 3379,  565,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2920,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  134,    1,   32,    1,  220, 2811,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3335,   37,  619,  386, 1311,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  932,   45, 2823, 1708,  806,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1,   81,   28,  548,  109,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2994,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,  116,  126, 1439,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3157,  741,   32,  449,  890,  680, 2849,   45, 2292,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310, 2657,  458, 1009,   37, 1540,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1260,   98, 2597,  947, 2190, 2414,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220,  156,   28,    1,    1,  425,  426,  159,  720,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2802,    1,  331,  117,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  167,  125,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2481,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343,  863, 2040, 3090, 3040, 2564,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  225, 1279,   70,  276,  374,   25,  720,   32,   91,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,    1, 2355,  856,    1,  220, 1718,  187,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  187,    1,    1,   32,    1,    1, 1523,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,    1,  190, 1334,  115,   45,  195,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3104,  977,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 2386, 2275,   45, 2716, 2465,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   20,  566,   32,   95, 1824,  844,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504,  650,    1, 2224,  379,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  963,    1,  437,  315,  365, 2227,  872,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2780,    1,  220,    1,   32,    1,  163,    1,   12,    1, 1708,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  176,  613,   16,    1, 2992,  162,  105, 1217,  384,  657,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,   82,  267,  435, 1100,  769,    9, 2168,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1861,  113,    7,  187,  342, 1268, 2009,   37, 2707,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  477,    1, 3279, 2854,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 971,  37, 123,   1,   1,   1, 250,  32,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2372,    1, 1194, 1856,   45,  139,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  627,   45,  166,  116,    1,    1,  537, 1490,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2596,   32, 2468,  548, 3387,  304,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1341,   37,   47,  215,    1,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  754,  209,  133,  897,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  218,  387,  885,   65,  423,  424, 1034,    1,  202,  627, 1434,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1268, 2235,  525,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2748,  921,  590,    1, 1037,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1433, 1187, 3024,   12,    1, 2498,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  251,  119, 2627, 2177, 1027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3160, 2572,   32,  522, 2297,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,    1,    1, 2383,  706,  191,    1, 1327,   37,    1,  726,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  375,    1, 2086,  997,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  302,    9,    1, 1631,    9,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018, 1463,  546,    1, 2320,    1, 1461,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,   37, 1753,  297,   29, 1617,    1,   98,  954,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  193,   76,   37,   52,    1,   32,  287,  420,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,   74,    1, 1282,    1,  385,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  698,   28,    1,  845,  439,  777, 2515,   98,  166,  824,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  682,    1, 1340,  866,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,  10,   1, 459, 301,   5, 125, 302,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 623, 200,   1, 449,   1,   1,   1, 234, 182, 235,   1,   1,\n",
      "           1, 234, 182, 235,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  176, 1757,  830,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  195,    1, 2797,   32, 3343, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,    8, 1442, 2432,    9, 2997, 2454,  327,  593,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1260,   98,    1,  162,  105,    1,    1,   37, 1399,    1, 1366,\n",
      "          321,  764,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,  446,    1,  740,    1,  863,  190,   52, 2827,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  568,  418,   69,   70,  245,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3108, 2368, 3175, 2315, 1045,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  459,  220, 2206, 2435,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1407, 1563,  176,    1,   45,  736,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  333,    1,    9, 1850,  458,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,  590,    1,  511,   37, 2651,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 2396,   37, 1664,  593, 3136,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  410, 1810, 3118, 2751,  115,   45,   46,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  221,    1,   37,  764,   46,  220, 1629,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,    1,    1,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374, 1260,   66,  187, 2564,   37,    1, 1647,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,  32, 531, 105, 183, 112,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 316, 317, 318,   1,  85,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  698, 1658, 1957,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  650,    1,    1, 2543, 2396,   98, 3369,   12, 3118, 2299,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1220,    9,  183, 2247,  643, 1042,   32, 1275,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3216, 1090, 2340,  841, 1908,  119,  142,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2034,    1,    1,  997,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3284,    1,  105, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,   98, 2393,  187, 3043,  649, 2949,    1,   32,    1,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  864,  190,    1, 2673,  210,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,    1,  215,    1,  774,  190,  193, 2192,   32,   37, 3345,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1203,    1,    1, 1871, 2007,   37,  114,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2677, 3255, 2741,   12, 2583, 1015,  288,    9,  845,    1,  698,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614, 1284,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1427,   34, 3176,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  656, 1267,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 2783,  647,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1247, 1573, 2815,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,  810,  689,  321,  460,    1,  198, 1844,   28,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  103,   49, 1682,    1,    1, 2476,    1, 2816,  121,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2464, 1564,    1,    9,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2819,    1,  469,  321,  612,  151,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485,    1,  288, 1483,    1,   37, 1604,    9,  949,   45, 1056,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  978,    1, 2941,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1771,    1,  469,   37,    1, 1805,   22,  261,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3369, 1542,    9, 2330, 1428,    1,  297, 3118, 2404,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  356,    9, 1778, 2232,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1092,  992,   28, 2329,   37,    1,  777, 2086,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1558,   28, 3169, 1287,  608,    1,    9, 2410,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1684,   32,  759,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,   37, 1599,  522,   37,  299,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2962,    1,    1, 2907,   32, 1194,  187, 3108, 1285, 2838,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2261,  321,   52,    1,   32,    1, 1160,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  297,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1, 2494,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  985, 1450,  388,  972,   32,  984,  341,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  256, 2549,   37, 1013, 2177, 1825,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  183, 1838,   61,  415,  105,  698,    9, 2422,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3315,   39,    9, 2966,  444, 3191,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1066,  297,    1,   45,  531,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  446, 1481,  267,  691,  580, 1133,  996,  356,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  683, 1673,  241,    1,   45, 2041,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1957,    1, 2959,  187, 3141,    1,   37,  395,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   76,   37, 1306, 1694,   45,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  105,  487,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1240,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2604, 2923,   37,  439,   63,  460,  891,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2504,  446,    1, 1010, 1755,  297, 2705,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 2024,   23,   37,  335,  297, 3069,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   20,    1,  132, 1372,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,   37,    1,  978, 2953, 2334,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  513,  514,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,   32,    1,  187,    1,    1, 2512,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1039,    1,   39,  220,    1, 1987,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1808, 1273,  387,  156,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 2946, 1976,   32,  854,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,  614,   85,    1,    1,  850,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,    1,  395,    1,    1,   37, 1173,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  925, 1566,  613,  116,    9,  810,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  920,   61,  166,    1,    9, 3264,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  492,  446,  342, 1822,    1,    1, 1488,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1874,    1,   45, 2924,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2486,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,  176, 1233,  484,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,  25,  26,  28, 548, 594,   4, 420,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 166,   1, 384,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2098, 1211,  384,  626,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3238, 2781,  187,  730, 2614, 2651, 2087, 2614,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1211, 2391,   16,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1326, 1421, 3113,  132,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1476,  977,  737,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   25,   66,  526,  187,  863,  246,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1214,   64,  140,  717,    1,  903,    1,  182,    1,  105,    1,\n",
      "         1684,  297, 1361,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   37,  125,   28,   37,    1,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  878, 2109, 3055, 2728, 2150,   27,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2668,  220,  163,    1, 1774,   39, 1230, 2528,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094, 1112,    1, 3358, 1961,  191, 3339, 2271,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  954,  353, 2050,   93,    1,   32, 2073,  401,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2692,    1, 2943, 2610, 2812,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   81,   98,  166, 2125,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2835,   37, 1468,  622,    1,    9, 3358,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   37, 1155,    1,  365,  116,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  148, 2767, 1416,    1, 3004,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1625,   37,    1,   28,   98, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1106,    1, 2102,  361, 2309,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296, 1550, 1322,  829,   32,  342,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,   37,  130, 1204,  286,    1,    1,    1,  669,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  636,    6,    1,  215,   15,   45, 2975,    1, 1892,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  485,    1,  197,  338,  118,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,  313,   37, 1000,   83, 1351,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1739,  379, 1587,   45,  469,   37, 2884,  191,  116,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2286, 2177,   37,    1,  636,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1050, 2800,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  665,  104, 2444, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2347, 3321,    1,   45, 2925,  627,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176, 2643, 1675,    1,  166,  183, 1283, 2005, 1937, 2051,  671,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,  889,   45, 1677,    9, 1256,  551, 2196,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  225,   70,  526,  115,   45,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2958,    1,  341,   37,  186,  608,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1338,   45, 1867,  167,  222,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   55,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  742,  967, 1724,   37, 2704,  247,   38,    1, 1748,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  171,    1,    1,    1, 1090, 2052,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1576,  588, 1031,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,  418,  951,   94,  548,    1,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  564,    1,   98, 3383,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   40,   13,   12,  768,  149,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  868,   85,    1, 2931,  625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  647,  551,  326, 1421, 1422, 1259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,    1, 1333,   27,  501, 2060, 2596, 2414,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  513,  220,    1,  361,    1,   37,  865, 2487,  774,  590,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  846,   45,    1, 2014,  902, 1057,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3172, 1009, 1082,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  957,    1,  441, 1152,   45, 2786,  148, 2558,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1591,  744, 1126,  176,  331,  159,    1, 1146,  332,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3117,  442,    9,    1,  361,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  966, 1916,    1,   98, 3386,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2238,   37,  109, 2979,    1, 1151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2795,    1, 2777,    1,    1,    1,  323, 2212,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1439,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  213,   98,  331,  214,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1278, 1121,   98,  531,    1,    1,  420,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  535,  656, 2261,   51,  606, 1976, 1515,  199,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  140, 2376, 2223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  758,    1,  224,   48,    1,  733,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1191,  354, 2051,  763,   76,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  195,   30, 1677,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  220,  312,  149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  313,    1,  176,    1,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 1492,  665, 1515,    1,  361,  172,    1,   37, 1604,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1166,   12,  166,    1,   32,  777, 1085,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1627,  111, 1107,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  487,    1, 1256,  635, 1241,   28,  449, 2085,  354,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   12,  156,  415,  103,  689,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,    1, 2454,    1, 3034, 1525,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 2304, 1394,    1, 1851,  105,  726,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2226, 2969,  132,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233,   37,  741,   98,  301,    5, 1907,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  483,  384,  424,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  132,   37,  764,    1, 2830,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,  166, 1140,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2304,    1,  715, 3092,  379,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2620,    1, 2741,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3303,    1,   39,  294, 1456, 1918,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 1817,    1, 2229,  741,   32, 1820,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,  136,  475,  513,  193,  514,   37,  133,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 2408,    1,  154,   51,  335,   98, 1749,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260, 1782, 1415,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1564, 2968, 1748, 2747,  163,    1,   12,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61, 2613,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1449,   37,  151,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98, 2041,   37,  471,  220, 2050, 1918,  176,  166,   26,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3363,   66, 2315,    1,  449, 1385, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2612,  105,  872,  123,   37,  754,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2596,  176, 3348,   36, 1634,   37, 2772,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2776, 2692,   37, 2155, 2975, 2633,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1114,    1,  590, 1357,   98, 3251,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1355,  104,    1,  942,    1,    9,    1, 1281,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3369,    1, 1550, 1188,    9, 2117, 3406,   32, 3118,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  977,  123,   39,  220,  198,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2964,  815,  777, 2165,    1,  378,   37,    1, 2261,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1712,  292, 1228, 2463,  327,  593,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  150,  396,  829,    1, 1534,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  459,    9,  730, 1571,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,  162,  152,   22,   23, 1417,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   49, 1542,   37,   26,  365,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   42,  220, 1652,  361,  105,  442,  437,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   61, 1167, 2854,    1,   28,  166, 1514, 1841, 2209,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1441,    1, 1211, 1228,   32, 2065,  593,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3213, 2420,    1,   45,    1,  427,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,  108,   45, 3038,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  854,  992, 2017,  384,  166, 1691, 2441,  361,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  183,  315,    9, 2846,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  193,  972,   37,   52,   10,   12, 1223, 1332,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,    1, 1831,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1320, 1307,   37,    1, 2943,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485, 1009,    1,    1, 1786,  302,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1, 1219,    1,  191,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1419,  365, 2786, 2976,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3385, 3399, 1937,  630,   98,  864, 1411, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  535,  441,  664,  912, 2285,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2957,   56,  454, 2232, 1441,  845,    1, 2515,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   25,   26,  417,    1,  144,  145,  246,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1174,   37, 1910,    1,    1, 3346,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  288,   37,   26,  526,   37,  105,  784,  242,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,  877,  449, 2799,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786, 1645, 1924, 2572,  191,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,  331,  502,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746,   37,  693,   80, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2994,    1, 2997,  218,  332,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  329,   37,  693,  331,   32,  159,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  990, 1236, 1791, 2650,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1861,    1, 1103,  548,  985, 2456,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  455, 1090, 1091, 2116,   98, 1273, 2287,    9,   93,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  876,  612,  288,   37,  877,   69,    1,   37,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   14,   15,  554,   32,  463, 2170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3168, 2329,   81,   32,  602,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2885,   61,  105,    1,    9,  810,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,    1,    1,  105, 2149, 2022,   61,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2374,   37, 2225, 2104,   37,    1,   10, 2681,  724,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  204,   12,   32, 2027,   37,  764,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1725, 1702,  115,  442,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  232,  531,  193,  972,   37,  583,  954,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1284,   39,   45, 2244,   12,  581,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  696, 1594,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  241,    1,    1,    6,  197,  570,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   27,  526,    1, 1487,    1,  185,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 163,   1,  12,   1,  69, 113, 530,  98, 109, 997,  88,   1,   3,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 863, 190,   1, 760, 691,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  172,    1,  987,   32,   98,    1,  754,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   69,  102, 1198,    1,   12,  737,  197,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 1711,   45,    1,   45,   69,    1, 1159,  274, 2203,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,    1,  265, 1975,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   56, 2536, 1530,   32, 1640,  947, 3246,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1584,    1,   52, 2332,    1,  193,    1, 2616,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,   71,    1,  202, 1334, 1315,  105,  106,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2962,    1, 1735,   98,    1,  187, 3108,  688, 2615,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,   12,    1, 1277,    1,   85,   32,  947,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1065, 1190,  939,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  625,    1,    1,   45,    1,   61,    1,    1,  398,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,  325,  853, 1521,  700,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1645, 3146,   98, 2265,    1,   37,  168,   37,  741,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   51,  469, 2731,   32, 3360,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2371,   37, 1876, 1234,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  509,    1,  297,  163,    1,   12,    1,  620, 2208,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1297, 2264,    1, 2381,    1,  777, 2165, 2928,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1900,  856,  163,    1,   12,    1,  469,   37, 2856,    1,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 3027,   76,   37,    1,  284,    1,   29,  528,  298,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3013,    1,  402, 2681,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497,    1,    1,   45, 2631,  427,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  164, 1593,    1,    1, 1240,    1,  109,   45,  460,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  799, 1396,   64,    1,  584,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1300,  265,    7,   37, 2656,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  335,  460,  357, 1910,  460,    1,  833,  612, 2553, 1103,\n",
      "          220,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  547, 3157,  610,   37, 2162,    9, 1887,  649,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1726,   37, 2303,   98, 2128,  221,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1211,  861,    1,   37,  893,  755,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437,  396, 3026,   45, 1485, 3365,   32,  531, 2606,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 2108,  333,  854,   37, 1456, 1057,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1991,   32,    1,   37,   52,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1407, 1184, 1905,   37,    1,  187,   60,  338,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  615,    1,  702,    1,  169,  361, 1515,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  228, 1530,   32, 1640,  947, 3071, 3246,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 2962,    1, 1401, 1959,  608, 2307,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  147,    1,   37, 1174, 1332,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3203,  193,    1,  187, 3117,  877,    1, 1064,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2754, 3102,  820,   32,  531,   81,  754,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175,  477,  105,  132,  220, 3251,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  896,    1,   61, 2487,    1,  361,    1,    1,  837, 1178,  361,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  315, 2355, 1013, 2549,    9, 1158, 2261,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1072,  104, 1008,  365, 1009,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,   37,  125,    1,    1,    1, 1211,   45,   24,  420,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   35,    1,  365,  529,    1,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2623,    1,  103,    1, 2948, 1002,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1585,  176,  463, 2571,  493,  250, 2414,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1, 1827,  803,  615,   39,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1991,   37, 1152,    1,   98,   74,   45,    1, 2960,  665,\n",
      "           98, 1616,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1230,  954,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  178,  903,    1, 1447,   51,   52,    1, 1461, 1539,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  135, 1292,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   32,  166, 1108, 1783,  162,    1,  934,   81,   98, 1171,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,    1,  949,  103, 1016,  650,    1,  202,  529,  477,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  647,    1,   51,   52,    1,  148,   12, 1521,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  862, 1710,   52,  388,  763,  415,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1304,  400,   37, 1937, 1727,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1,  982,    1, 2957,    1, 1962,    1,  848, 1303, 1604,\n",
      "           98, 1273,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  331,   12,    1, 2405,  297,  166, 1006,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  159,  106,  608,   98, 1230,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  213,   37,   47, 1050,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   15,   71,   98, 2079, 1220,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  550,  163,    1,   12,    1,   22, 1225,  674, 1976,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,   91,    1,   98,  203,   37,    1,  864,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  560,  347, 1124,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  592,    6,  593,   93,  570, 1039,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  649,  700,  325,  326,  327,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  459,    9, 1056,  537,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2313, 2414,   56,   32,   36, 1939,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  321,  612, 2446,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2680, 1419,  365, 1117, 1525,    1, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 2161,  726, 2487, 3295,  176,  163,    1,   12,    1,   26,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   85, 1114,   32,  903,    1,  904,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3352, 2856, 1920,    1, 2924,   32, 1029,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1228,  515, 2698,  916,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2266, 1484,    9,  388,  342, 1896,   32, 1428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3267,    1,    1, 1758,   37,  136, 3217, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1,  552,  552,   37,  618,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,   37, 2225, 1708,  475,   37,  582, 2466,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   99, 1408,  347,  816,  528,    1,   69,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3149, 2751, 2572,   32, 3279,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2688,    1,  782,  365, 2946,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  384,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,   45,    1,  297,  947, 2455,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  146,  147,    1,  148,    1,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1771, 1603,    1,  317,  248,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,  102, 1126,  361,  155,    1,   54,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  369,    1,  615,  297,  104, 1119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3401,  566,    1,    1, 1281,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885, 1401,    1,  202,    1,   61, 1969,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2714,    9, 1683,    1, 1538,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,    1, 1594,   37,    1,   37,    1, 2492,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2615,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1216,   37, 2890, 1987,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707, 1579,    1, 2690,   32,   84, 2029,  342,   46,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  167, 2810,   98,    1,    9, 3231,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  305,    1,  417,    1,   29,   32, 1881,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,  640,  105,  365,  340,  528,  198,   93,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1114,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  861, 1906,  213,   98, 3369, 3146,  187,    1,  543, 1954,  132,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  295,    1,    9, 1512,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2807,  664,   37, 2295, 2321,   32, 1600,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  324,   51,   52,   32,  887,   46,  220,  326,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 1733, 2000,  649,    1,  315,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2427,    1, 2029, 1918,   32,    1, 1463,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  317,    1,    1, 1891,    1,  582,  404,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3084,    1,   37,   52, 2297,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2800,    1,   67,   61,   98,  166,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409, 1285,  388, 1273, 1107,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  826,  469, 1648, 2210,    1,    1,  920,    1,    1,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1361,  335,  105,  332,   45,  449,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1087,  292, 1228,   37, 1121, 1465,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3381,  437,  267,  460, 2572,  487, 2924,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2159,  936,  365, 2695,  361, 2695,  931,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3094, 1439,   45,    1,  327,  593,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  493,    1, 1036,  166,  454,   45,   69,  388, 1220,    1,\n",
      "         2051,  109,    1,  242, 1251,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1,  267, 1938, 1723,    1,  972,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   60, 1276,   98,  104,    1,    1,  122,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   12,  365, 2355, 1013, 1228,   51,   52, 1176,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  868,   37, 2192,  311, 2250,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  321,   92, 2293,   45, 1362,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1558,  176,  531,  129,    1, 2410,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035, 1070,    9,  611,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,    1,   32,    1,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37, 2243,  340,    1, 2580,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3177,    1,   37,  713,    9,  386, 3098,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3221,  183, 1136, 1924, 1607,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  403, 2926,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3238,  267,  204,  972, 1360,  612,   52, 1542,  191, 2410,   74,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  903,    1,  182,    1,  105,    1,    1,  460,   39,  187, 3226,\n",
      "         1335,  400,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1838,  417,   98,  677,   69,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   22,  942,  936,  132,   37,  151,  176,  177, 1266,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106,   61,  645,   37,  221, 1159,  593,   45,    1, 1085,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1957, 2856,   56,    1,    1,   32, 2597,   12,  501, 2060,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,   37, 1192,  816,    9, 1411,   56,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3323, 1073,   85,    1,  153,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035, 1070,   37,  619,  611,  297,  220,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  848,    1,  726,    1, 1624,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861, 1906,   37, 2000, 1239, 3114, 1512,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1044,  590,    1, 1851,  105,    1,   45,  199,    9, 2843,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,  361,  854, 2000, 3162,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  487, 2924,  582,  403,    9, 2699,   27, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186, 3109,   56,   32, 1994, 2095, 2262,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3215,   37, 2192,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999, 1380, 2819,  778,   98,  429,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1988,   45, 1996,    1,    9, 2591,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2721, 1594,    1,    9, 1185, 1537, 2617,   32, 1186,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  112,    1,    1,    1,  357, 2487,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  117, 1831, 1408,  247,  389,  361, 2034,  331,  797,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  422,   37,    1,    1,  269,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3209,    1,    1,   37, 1343,   32, 3220,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  391,  371,  936, 1736,  529,  336,  210,  220,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   69,  884,    1, 1159,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   81,  191, 3278,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,    1, 1768,    1,    1,  161,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 1952,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1079, 3063,    1, 1013, 1522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3141,    1, 2509,   98,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  882,   37, 1270, 1427,  395,  704,  551,  705, 1346,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  166, 1427,    1,    1, 1821,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1492, 1082,  388, 1116,   98,    1,    9,  164,    1,  440,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  190,  815,  594, 2332,  187, 3058,    1,   32,  365,  506,\n",
      "           98,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3165,   45,  410, 2107, 1664,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1006,  953,   98,    1, 2315, 1045,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  651,   46, 1403,   10,   12, 1563,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2978,   12,    1, 1539, 2306, 1961,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3254, 2594,  429,   79,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  297, 3039,    1, 1089, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1108, 1779,  460,   12,   32,  166, 1525,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  693, 2025,  331,   37,  856,    1,   32,  539, 2170,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3382, 1492,    1,   32, 2018,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  105, 1989, 1990,  628,  789,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3168, 1426, 3293,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   29,   98,  596, 1793,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2174,    9, 1054,   45,  166,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2695,    1,    1, 2581,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1432, 3207,    1,   39,    1,    1, 1608,  140, 2505,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  415,  885, 1090,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764,    1,    1, 1089,   45,    1, 3377,    1,    9, 1922, 1204,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3363,  884,  631,   32, 3343, 2823,  806,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12, 2692,  288,    9,    1,  949,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3267,    1,   32, 1742,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1406,  600,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  683,  251,   37, 2434,    1,   37,  125,  734,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885,    1,    1,    9, 3196,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1097,    1, 1165,   29,   16,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  365,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1047, 1236,   32,  104,    9,  182,   37,    1,  390,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1, 1147, 2924, 1539, 3383, 2731,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1035,   37,   77,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  535,  656, 2367, 2489, 1103,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2800, 3177,   12,  810,  288,   37,  631, 1178,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1805, 2872,  730, 2614,    1, 3175,  361,  713,    9, 1610,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3375, 2905,   37,  741,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2614, 1398,  612,    1, 1787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,  622, 1017,   32,  531,  443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   37,   26,    1,  115,   45,   15,   29,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  421,    1,  162,    1,  372,    1,  142, 1992,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2774,   32, 2646,  300,    1,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2470,  387,  903,    1, 1447,   46,    1,  455,  387, 2949,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1987,   61,  105, 1641,    9,  386,  361, 2741,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  176,   56,  339,  340,  548,  244,  304,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,  104,  476, 1428,  909,  951,    1,  864,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,  459,   64,  139,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3309,  476,    1, 3328,  698,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,  931,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  267, 1429, 2401, 2678,   61, 2567,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2872,    1,   32,    1,    1, 2080,  517,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  877,  460,   98, 1479, 3096, 1267,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1161, 1279, 1042,    1,  320,  544,  305,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2153,    1, 2708,  783,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  417,   98,  509,   69,  102,  190,  698,   37,  817,    1,\n",
      "           98,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2883,  140,  195,    1,   12,  433,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2, 328,  69, 102, 720, 528, 531,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 159,  32,   1, 245,  37, 810, 199, 340,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3256,    1,  104, 3163, 2954,   38,    1,  671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  454,   46,    1,   37, 2828,  464, 2396,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1043, 1268,   28,    1, 1572,  191,  185,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 3012, 1821,    1,    1,   37, 1206,    1, 2616,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2162, 2478, 2701,  593,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2576,  361,    1, 1654, 2545,  187, 1186,   12,  103,    1, 1885,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3006,  949, 1312, 3365,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1002, 1445, 1844, 1484, 1192,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2994,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,    1,  187,    1,  650,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1821,  927,   37,  119,  166, 3081,    1,   45,  938, 2538,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,   12, 2528,  810,   32,  786,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2508,  571, 3338,  550, 2168,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1170,  225,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1968,  159,    1, 1010,  400,  122,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,   52, 1542,   37,  319,    1, 2107,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1128,  108,   98,  114,  629,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  140,    1, 1624,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 104, 358, 108,  98, 869,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 166,   1, 698,   1, 176,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  326, 2760, 1564, 1762,    9,  166,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12,  460,  293,    1,    1,    1,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    5,  302,    1,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  542, 2270,   37, 1046,    1, 2276,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1675,  633,    1,   32,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  187, 3356,  787,    1,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283,  830,    9,  367,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2939,  583, 3265,  444,  166, 3248,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2500, 2107,   79,  361,  472,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1821,    1, 2968,    1,    1,   45, 2983,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 1428, 3365, 1683,   32, 3360,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  976,    1,    1,  600, 2390,    1, 1428,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1, 3256,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1821, 2190, 3033, 1373,   37,    1, 2051,  187, 1011, 2202,  340,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3043, 3101, 2878, 2856, 3384,   32, 3140,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   75,  475, 1702,  116,  259,    1,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 1380,    1, 2264,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  515, 1687, 1022,    1, 3008,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,    1,  163,    1,  903,    1, 1421,  132,    9,    1,  249,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307, 1289,   37,  786,    1, 1779,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  742,    1, 1452,  388,  386,  159,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  209,    1, 2446, 1473,    1,  202,  729,  103, 1347,  384,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  548, 1133, 2107,   32,  455,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,    1, 1253,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2508, 2985, 3101, 2968,  176, 1474, 1386,  178,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3270,    1, 2029,  593, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  223, 2420,   86,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2405, 2029, 3339,  741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283,   98,  844,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  108, 2287,  321,    1,    1,  841,   12, 1204,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,    1,    1,  498,   37, 1145,   98,  356,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1181,  387,  242, 1273,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1051,   37,   26,  704,  551,  705,    1,   32,  455,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 3030, 1484,   98, 3370,   37,  508,   85,\n",
      "         2108,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  321,   52,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977,   37,    1,   29,   37, 1527, 2152,    1,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1231,   32,  298,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051,  361,    1,  872,   98,  845,  439,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247, 1079,  361,  334,  190,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3034, 1478,   32,  157,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2410,  166, 2301, 2012, 1778, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  754,    1,   45,  915, 1675,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1827,   79,    1,  202,  204, 1293,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3170,  321,  815,  247,    1, 2447,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2551,   38, 3059,  449,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,  494, 1366, 1556,    1,   32, 2869, 1107,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1788,   12,    1, 2739, 1343,   96,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1178, 1231,  220,  840, 2339, 1778, 2690,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   37,  720,  647,  149, 1232,    1, 1464,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,   12, 2977,    1, 2599,  440,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2460,   79, 3179,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1013,    1,  388,    1, 1912,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  831,  202,  729,  680,   97,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3369,   57, 2199,   45, 1345,   32, 3118,  202, 2751,  774, 1450,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   28,  548,  537,   98, 1006, 1160,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  347,  415,  416,  417,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1625,    1,    9, 2249,  548, 2140,   64, 1950,  418,   37, 2144,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,   12,    1, 1707,  219, 1140,   37, 2446, 2673,  210,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1426, 1285,   45, 1821,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  167,   52,  105, 2389,   37, 1815, 1816,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2980, 1396, 2894,    1,  918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  147,    1,  957,   12,  400,  444,  148,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967, 1001,    9,  129,  195,  210,    1,    1,  518, 1726,\n",
      "          774,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1405,   45, 2570,  776,  891,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  443, 2938, 3060, 2347,   32, 3246,  220, 3069,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  439, 1298, 1382,   98,   69,    1,  657,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,  311,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3231, 2712, 3319,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  552,  552,    1,  700, 2733, 1044, 2264,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   61,  829,    1,   39,  453, 1013, 1522,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1315,   98, 1622,    1,  114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  187, 2695, 2223,  953, 2017,    1,  963,  729, 1877,   37, 1539,\n",
      "         1821,    1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3184, 1557,  650, 1976,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2822,    1,  167,   26,    1,   69,  361,  493, 2517,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043,   66,    1,  548,    1,  598,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  396,   98,  864,  792,    1,  792,  191,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2998,    1,  584,  171,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  884, 1383,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  831,  548,    1,  365,  340,  813,  444,   94,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2843,    1,    1,  176, 1477, 1990,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2256, 1977,   37,    1,   12,  865,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  378, 1003,  176, 1284,  171,   12,    1,   32,  388,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1007,    1,    1,    1,    1,  928,    1, 1116, 2896,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  485,  729,    1, 3296,  528, 1092, 1184,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2419,   15, 1348,   37,  720,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2909,    1, 3128,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1293, 1402, 1434,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2045,   88,   37,  877,    1, 2084,    1, 1153,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708, 2153, 2684,   32, 2197,   37, 2237, 3358,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  647, 1614,    1, 2750,  918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2890, 2826, 1251,  388,  763, 2112,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  275,  579,   12,  365,  361,  579,   12, 1411,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1452,   32, 1918,    1, 3310,   12,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,  379, 1013,   49, 1132, 1219,  963, 2122,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  726, 2297,  365, 1065, 1190,   45, 2862,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1818,  147, 1360,  612,  817,  207, 1107,   43, 2465,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  379, 1463, 1539, 2673, 3085, 1461,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2561, 2405,    9,  298, 2585,   32, 1204,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  259, 1110,  288, 2364,   98, 1273,  844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  103, 3407, 3382, 2167,  741,   52, 2827,   98,  199, 1452, 1232,\n",
      "          507,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2571,  474, 1082, 3369,    1, 2751,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1268,    1,    1,  525,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1,    1,   69,    1, 2017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1937, 1056,  365, 2983,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2144, 3111, 2572,   32, 2950,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  668,  293,  162, 1133,  220, 2633,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1141,   37, 1835,  382,  230, 1028, 1294,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3261, 1082,    1,    1,   37, 1814, 2298, 1371,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2885, 1564,  460,   37,  103,  361,   61, 2934,   37, 1334,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1214,  979,    1,   39,    9,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  219,    1,   45,  166,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178,    1,  297,    1, 2772,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   51,    1,  688,    1,    1,   32, 1674, 3295,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1500,    1,    1,    1,  347,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  861,  475,  864,  190,  764, 1403, 1147,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,    1,  132,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3176,   81,   98,  103,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  614, 1315,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2997,    1,  361,  720, 2762,  304,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   57,   58,   37,    1,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3238,    1,   84,    1, 1708, 2290,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537, 1228, 1479,    1,  581,  401,  207,  197,   28,  118,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1008,    1,    1,  187,  365,   82,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548, 1700,    1,    1,  854,    1, 2018,   37, 1816,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  649, 2401,  986,   79,    9, 1420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2282,  776,   45,    1, 1268,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3232, 3278,    1,    1,    1,  680,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1287,  444, 1479,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  288,    9, 1815, 2389, 3380,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  884,  631,   32, 1228,    9,    1, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1654,    1,  142,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2013,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1465, 1466,  794,    1,  279, 1402,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2693, 2393,    1, 2223,    1,  566,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  224, 2355, 1013,  122,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1268,   28, 2436,   45,  453, 3044, 2168,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  645,  287, 1380, 1381,   81,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1086,  119, 1045,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  548, 1118,    1,  657, 1394,   37, 1151, 1809, 1758,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1924,    1,   28,  191,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  310,   25,  504,  187,   10, 1401, 2116, 2117,    1,    1,    1,\n",
      "           71,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117,  442,  442,    1,  490,   32, 1352,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    6,  156, 1470, 2007,   37,  417, 1220,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1076,   12,    1,  214,  142, 2070,  147, 1787,   32,  463,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  794,  365,  778,    9,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1500,    1,  102,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2317,    1,    1, 1627, 1727,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,    1,   39, 2620,    1, 1249, 3169,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,    1,  166,    1,    1,  105,    1, 2665, 1671,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  442,  448,  640,  119,   32, 1352, 1169,  568,   28,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3308, 3116,  922,  716,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 3294,    1,    9,    1,   32,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  835, 1994, 2650,  650,  633,  669,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  754,   15,  120,    1,  118,   32,  385,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1874,  938,    1,  187,  955,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   79,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2729,    1,    1, 1690,  454,  187, 2990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3306,    1,  247,    1, 2878,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  854,   12,   93,  570,   37,    1,  118,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  284,    1,   98,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2795, 1118,  207, 2441, 2434,  302,   32,  233,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   36,  207, 1013, 2037,   28, 2931,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   89,   37, 1334,  187,  163,    1,   12,    1,  684, 2541,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  510,   12, 1992,    1,  626,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437, 2386,  212,   45,  330,   37,  970,    4,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2603,   61, 1354, 2947, 1013, 2113,   98,    1,  778,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2893,  894,  619, 2144,  356,  611, 2113,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1082, 2698,   37, 2866,   32,   37,    1, 1601,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,   12, 2162, 1950,  176, 1270,   59,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3006, 1539, 1260,   32, 1815,  115,   45, 1537,    1, 2237,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964, 2465, 1372,   37, 2103, 2834,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  593, 1033,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  267,   72,  401,  244,  190,   52, 1488,  763,   76,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2224,  908, 1197,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1658,  259,    1,    1,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  395, 2058,   79,  915,  547,    1, 3145,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,   22,    1,    1,  353,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1089, 1013,  682,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,    1,  782,   36,  518, 1294,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3363,  413, 2450,   37,    1,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1985, 1178,    1, 2935, 1909,   73,  726,  297,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2345,    1,  176, 2834,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3255,    1, 2297, 1509, 1863,  187,    1, 2872,    1, 2577,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  275, 2153,    1,   37, 1505,  934,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,   12, 1127,  437,  267,    1,   37,  158, 1563,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  901,    1, 1232, 1233,  250,  456, 1234,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  280, 2030,  176, 2759,    1,   16,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1409,  997,    1,   45,    1,  357,  135, 1240,    1,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,   12,   93, 1071,   32,   72,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3168, 1141,  608,    1,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  773, 1470,  410,  818,  739,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1106, 1013,   37, 1787,  224,  361,  758,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2912, 2753, 1797,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,   9,   1,   1, 105,   1,   1, 105, 713, 551, 105,   1,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  25,  66, 417, 548, 303,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2087,  433,    7,   37,  163,    1,   12,    1,  993,  652,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,    1,    1, 2017,  191,  198, 3334,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  582,   45,  166,  519, 2489,  581,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   98, 2393,  187, 3043,  649, 2949,    1,   32,    1,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,  991,  148,  142,    9,  647,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  191,  854, 1710, 1864,   32, 1314,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2880,  484,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1782, 1107,   79, 1658,  327,    1,  365, 1729,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  575, 2192,   28, 1054,  847,    9,  617,  618,  918,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  442,  475, 2331,   32,   20, 1559,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1082,    1,    1,   37,  764,   47,    1,   37,  104,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  514, 1727,   76,  384,  597, 1304, 1213,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  345, 1251,    1,  176,    1,  182,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  580,  606,    1,    1,    1,  506,  782,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2832, 1314, 1316,    1,  826,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2110,   12,  865,   61,  590,    1,    9, 3322,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  121,    1,  395,  429,  442,    1, 1994, 2834,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,    1,  284,    1,  550,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1106,   37, 1539, 1013, 1522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3062,  449, 1918,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   37, 1075,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1002, 2275, 1258,   37,  429, 1285,   32,    1,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1252,   37,  698,    1, 3284,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  765,  207,  602, 2250,  220,  968,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3032,    1,    1,   32,  104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1148,    1,   32, 1033,   37,  815, 1718,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1100,  515, 1243,   98, 2071, 1331,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,   12,  105, 1426,  760,  224,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   69, 1702,  104,  442,  448,   37,   27,  119,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  167,  271,  365, 3193, 1737,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  160, 1161,    1,   32,  367,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3299, 1215,   32, 2615, 2651,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1885,    1,   98,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1638,   45,    1,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  510, 2321,   85,   98, 2732,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,    1,  605,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2662,   12, 2918, 2820,  113,    1,  528,  123, 2984,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175,    1, 2087, 2614,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,    1,  326,    1,  766, 2192, 1243,   45,  617, 1151,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2026, 2454, 2952,   32, 2997,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2106,  221,  167,   26,   28,  493,  293,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1,   98, 3238,    1, 3269,  444, 3175,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  187,  885,  163,    1,   12,    1,    1,    1,  166,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3015, 2205,  786,   45,   56,    1, 2151, 2567, 1821,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1887,   45, 1583,    1,   30, 1239,  861, 2298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1136,  325,  885,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1, 1363, 1413, 1414,   37,    1, 1273,  259, 1228,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  812,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  321, 1980,   32,    1, 2421,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  744, 1881,  176,  104, 1393,   13,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  105, 2537,   32,  121,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,   37, 1136,   81,   32,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  160, 1278, 1032,  763,   76,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  716, 3152,    1, 2967,   37, 1668,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3296,    1,    1,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   32, 1102,   45, 2734, 1530,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1073,   85,    1, 1061,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1184, 1289,   37,  888,   45, 1084,  931,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2925,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3172, 1090, 1829, 2906,  951,    1, 2388,  171,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  121, 1830,   37,  686, 1730,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1436,    1, 3278,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1123,   61,   81,   32, 2016,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  160,  102,  276,    1,   32,  871,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1100,  769,   37,  504,  861,    1,    1, 2524,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1958, 1355, 1983,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 2976,  166, 2432,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,   70,  245, 1315,  104,  105,  106,  187,   69, 1588,\n",
      "         1192,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  179, 2261, 2384,  173, 1525, 2065,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   22,   37,  125,  284, 1499,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3216, 1360,  612, 2192,   32,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,    1,   10,  297, 1926, 1927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1204, 1281,    9,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  732,  840,   48,   32,   35,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,    1,  583,   32,  531, 1656, 3389,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2754, 3102,   32,  531,  513,    9, 1922, 1204,    1, 2764,    1,\n",
      "          716,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3285,    1, 2321,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821,  927, 1464,   37,    1,    1,    1, 2682, 1159, 3024, 1821,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3014, 1749,  220,  326,   37,   47, 2079, 1228,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  867, 2659, 1662,    1,  220,  767,  361, 1228,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2137,   81,    9,    1, 3098,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1,  884,   98, 1230,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  637,   79,    9, 3276,   32,    1,  220, 3244,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2476,    1, 3347, 3340,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  146,    1, 2104,    1,  484,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388, 1983,   41,  110,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  587, 1313, 1600, 1064,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2387, 1592,    1,  938,    1,   32, 1975,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    4,   81,  176, 1158,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283, 2939, 1754,    1,   37, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1309,    1,  453,  647,  159,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1695,  331,    1,  705,    1,    1,  176,    1, 2147,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   11, 1804, 1821,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1957, 2620,   98, 3360,  115,   45,  741,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1842,  116,  400,  614,   37, 1818,  147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3345, 2035, 1757,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  947,  619, 3382,    1,  881,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,    1,  437,  936, 1116,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2374, 1041,    1,    9,    1, 2737,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3331, 1421, 1056, 2308,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  683,    1,  332,   59,   60, 2213,  922,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  325, 2655,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  501,   37, 2553,   39, 3231, 1090,    9,    1,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2494,  872, 1654, 1114,    1,  202,  729,  801,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  867,   37, 1753,  297,  668,  912, 2285,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  439,   32, 1881,   37,  109,   45,  824,  844,   12,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035,    1,  856,   37, 1334,   39,   45, 1038,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,   98,   35,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  105, 2662, 2918,  220,    1,   45, 3024,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  546,    1,  176, 1050,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  424, 1034,   32, 1158,  550,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  648, 1216,    1,  148,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3358, 1581,    1, 1593,  548, 2162,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  112,    1,  388, 1021,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1011,  250,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1035, 1070,   37, 1174,  611, 2113,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  770,   45,    1,    1, 1976,   32, 3360,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,  894,   52,   53,    9,   54,    1,  232,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  691, 2531,  427,    1,    1,  854,   39,   45,    1, 2522,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1542,   37, 1343,  873,  361,   52, 2745,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3230, 1249, 3257,   32, 1739,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481, 1349,  361, 1170,  489,   79, 1479,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  958, 1396,  548, 1443, 1152,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  258,  535, 1761, 2523, 2220,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2198, 1460, 2560,    1,  579,  190,  365, 1778,  544,    1, 1160,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3402, 3408,    1, 1174,   32,  602,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1087, 2384,  754,  623,   32,  245, 1607, 2340,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2883,  850,   28,    1, 1054,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1151, 1091,  243,    1,   11,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  730, 2614,  288,  114,   37,    1,  176,  754,   45,\n",
      "          105,   12,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  700,   32,   46,   37,   47,   48,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1126,    9,  365, 1785, 1273,  669, 1268, 1352,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  842,   37,  335,  156,  686,   98,  195,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1471,   12, 1951, 1149,  690,  138, 1124,    1,    1,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3194, 3195,    1,  590,    1, 2388,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1298, 1544,   32, 3115,  454,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  952,  581,  878,  628,   32, 1559,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2502, 1397,  362, 1022,    1, 2296,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  716,   51,    1,  903,    1, 1447, 2673, 1463, 2163, 1215,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2498, 1567, 1045, 1426,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1, 2457,    9,  754,   45,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3378,  321, 1599, 3304,    1,  147,  261,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,   37,   47, 1270, 1023,  124,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1654,  176,  455,   26,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1398,  612,  125,    1,  505,  629,  506,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1141,  530,    1,  687,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  863,  297,    1,  566, 1594,   37,  347,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978,  769, 1150,    1,    1,  246,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1212, 2540, 1022,    1,    1,  361,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  800, 1220, 2072,  224,  636,  125,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2417, 2346, 1125,   98,  531, 1038,  966,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 2161,   12,  810, 1425,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3250,    1,   37, 1306,  547,   37,   56, 2119,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564,  693,   37,  151,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  567,  799,    1, 2977, 2978,  434,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2459, 2770,    1, 2551,   32, 1090,    1, 1056,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3326,    1,    1, 1061,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3002,   77,   98, 1239,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  561,  562,    1,  563,  564,    9,  295,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974,    1, 1137, 1159, 1821, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,   37,    1,    1,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2117,    1,  716,  417,  197,   32,  572,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2047,  361,    1,  384,  938, 1075,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3308,   37,  927, 3313,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  854,    9, 3116, 3217,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2892,  240,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  593,  358, 1137,   98,  969,  570,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,  613, 2373, 1273, 2492,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1870,  794, 2528, 1234, 1863,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  552,  552,    1, 1236, 3003,    9, 2730, 2607,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   60,   61,    1,  105,  596, 2814,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3251,  562,  802,  220,  182,    1,    1,    1,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2745,   37,   52,   81,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2802,   12,  132,  220, 3234,   61,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  975,   72,  401,  197,  338,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,    1, 1583, 1523,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2212,  861,  127,   37,   71,    1, 1411,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1658, 1117, 1525,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  147,   37, 1175,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2126, 2848,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  709,    1,  920,  753,   37,  877,  813,  176, 2661, 1510,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247, 1450,  342,   24,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3340,   32,  531,    1, 1130, 1683,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2396,   37,  289,   98,  557,  540,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3297,  511,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,   12,    1,    1,  547,  356, 1691,  632, 3065,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  308,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2617,    1,    5, 1631,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,  37, 288,  28, 581, 486,   1,  32, 395,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 105,   1,   9,   1, 517, 776,   1,  28,   1,   1,   3,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1312, 3053,  944, 1530,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  159,  756, 1039, 2690,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1668,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3015,  919,    1,   98,  411,    1, 1821,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1254, 1178,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  936, 1797,    1,   32,  942,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  386, 1285, 2423,   32, 1600,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  513,  514,   32,  116,  195,  333,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2994, 1378, 2677,  949, 2812,    9, 1958,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978, 3138, 1421,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   26, 1039,  650,  884, 1361,   12,    1,   37, 2082, 2973, 1764,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  682,   98,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2458, 1188,  388,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   21,    1,  182,   32,  365,  112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2226,  744,   28, 1228, 2657, 2456,   32, 2592,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   39,    9,  914,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  100,  187, 2210, 1510,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  353,  197,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3181, 1550, 2299,   45, 1184,   32, 3116,  922,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1, 1022,    1, 1408,  726, 1045,  707,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2713, 2017,  191, 1938, 2607,  382,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  876,  612, 1579,    1, 1527,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 1206,    1,  639,  891, 2103,  617,  934,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1976,   27,  903,    1, 1383,   32,  596, 1793, 1421,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1944, 1674,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  225,   70,    1,   32,  411,  707,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1284,    1,   32,    1,   26,    1,  934,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2708, 3384,  162,  741,    1, 1094,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  729,  590, 2324,    9,  104, 1821, 2978,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   13,    1,  599,  822,  260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 2257,    1,   98,    1, 1151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  314,  282,   12,  331, 2454,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2894, 2522,  162,   40, 1876,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  814,    6,  605, 1469,    1,  225, 1276,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,  387,  331,   32,  390,  187,  460,    1,    9,  242,  347,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  204,    1,  600, 1405,    1,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  459,    1,  344,    1,  625,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  108,  600, 1117, 1525, 2026,  126,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1227,    1, 1051,   37,    1,   98,  861, 2389,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  593,   12,  449,  705,  617, 1616,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  593,  442,  656,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2647, 2214, 1696,   37,    1, 1920,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  288,   37, 1048,  148,  647,  214,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  176,  845,   98, 2046, 2047,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2317,    9,  581, 1090, 1969, 2263,   32,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  140, 2024, 2223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424,    1,  190, 1747,  460,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3157,  429, 3370, 2985,    9, 3363, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1854,    1, 1401,    1, 1787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 2194,    1,  162,    1,   39,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1281,  256,   37,    1,  533,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1142,  267, 3104,    1,  966,  176, 3402, 3408,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 2962,    1, 2202,  297, 3227,  187, 1110,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3352, 1260, 2183, 2708,  655,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,    1,  469,   37,    1, 2826,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056,    1, 2684,  176, 1580,  656,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3079,    1, 1685, 2607,   44,   32,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  199,   37, 2709,    1,    1,    1,    1,  774, 1160,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  648,    1, 1533,  384,  297, 3000,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  657,  952,  808,   32, 2657,   45,  166, 1411,  116,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1,  267,    1,  792, 2349, 1176,    1,  792,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   98,    1, 3271,  176, 3319,    1, 2697,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1552,  297,    1, 2946,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  668, 1701,  664,   32,  400,  444,  912, 2285, 2515,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974, 2297,  199,   12,    1,   45,  166,  356,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  379, 1155,  105, 2529,  956,   32,  531,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2117, 2699, 1353,   32, 3369,   12, 3118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1976,   32, 3373,    1, 1436,  550,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  204,   12, 1488,  763,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2046, 2937,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2328,  140,  331, 2223,    9, 2784,   37, 1821,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  306,   12,  105, 1426,  760,  224,   12,    1, 2928,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647, 2120,   82, 1010,  148, 1523,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  193,   37,  142,    9, 1503,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2018,  861,  640, 3006,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  474,  765,    4,   37, 1533,  404,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1338,   45,    1,  384,  378,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  486, 1816,    1,   28,  176, 1151, 1929,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2259,  166, 1140,    9,  764,   32, 3369,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1956,    1,    1,    1,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766,  794,    1,    1, 1180,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3384, 2572,   32, 3339,  477,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967,    1, 2006,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  388, 2005,    9,  121,   12, 1009,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  302,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  653, 1159, 1423, 3273,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708, 2162, 1950,  418,   37, 2335,   32, 3101, 2625,   32, 3339,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1128,  884,  365,    1,  176, 3044, 2436,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,    6, 1213,    1, 1346,  138,  191,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  103,  104,  398,    1,    9,  505,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1300,    1, 1458,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  952,  449, 2579,  726,  176,    1, 3329,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,    1, 2308, 2317,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  316,    1, 2016, 1906,  765,   98, 1123, 1799,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  992,   85,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,  664,  449, 1463,  191, 2202,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  399, 2011,   98,    1,    1,  149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   12, 2877,    1, 3391,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   75, 1579,  858,  297, 1021,  260,  261,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,    1,  164,  165,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    4,   29, 1620, 1762,   37,  284,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  531,    9,    1,    1, 2669, 2830,  361,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  590, 1059,   32,   37,  531, 3345, 1186,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,    9,  105,   74,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  195,  937,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  352,   51,   47, 2245,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2875,   61,  383,   85,  632, 2699,  674,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    4,  420, 2050,  105,    1,    9,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,   12, 1884,  238,  250,   37,   52,    1, 1387,  339,  232,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1299, 2385,  612,    9, 2537,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3361, 2844,   32, 1656, 2909,    1, 3279,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  384,  104,   26,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  550, 1227,    1,  800, 2580,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1962,    1, 1273,  259, 1412, 2382,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  650,   37,  720,   39,   45, 2107,   37, 1504, 3358,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  437,    1,    1,   79,    1,  112,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2708, 2572,   32, 3339, 2831,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,  786,  475,    1,   37,   84,   85,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  483,  384,  424,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2420,    1, 2308,   45,  166, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2977,    1,  354,   45,    1,    1, 3053, 2477,  944,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1,  967,    1,    1,  220, 2820,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  303,  193, 1176,    1,  191,  166,   71,   32,  626,  102,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  267, 3118, 2756,  193,  998,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  640, 2579, 1918,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3257,   81,   98, 1171,  361,    1,  220,  270,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  297, 1023,  593,   12, 1219,  606,  472,  238,    1, 1492,  420,\n",
      "          782,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1938, 2410,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1251,    1,   61,  729,  166,    1,   45,  424, 3151,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885, 1385,    9,  166,  638,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1583, 2414, 1056, 3375,   32, 3046,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2086,  977, 2095,    1,  234, 3041,  235,    1,  234, 3041,  235,\n",
      "            1,   90, 2176,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275,  288,    9, 1460,  449,  736,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  244,    1,  202,  734,  850,   39,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  347,   98,  356,    1,   85,   37,  105,  339,  340,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1962,  140,    1,   24,  220,  104, 1273,  259,  633,  196,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2034, 1879,  979,  389,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2909,   32,  531, 2856,  176,  177,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  920,  460,   12, 1205,  896,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2252, 3310,    1, 2684,  176,  776,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2317,    1,    1, 1627, 1727,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3227, 3189,    1,  501, 1306, 2760,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1133,    9, 2559,   37,    1,   32, 2731,  116,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2391,    1,   32,    9,  105,    1,  341,    1,  906,   12,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1247, 1484,  460,  105, 2318,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1475,  636,   45,  159,   32,    1, 1300, 1996,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2104, 1082, 2978, 2699,   37,  764, 3015,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018, 1372, 2965,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,   25,  720,   32, 1034,   98,  996,  716,  503,  948,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  442,  448,  490, 1290,  396,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3198, 2963,  191, 1140,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  937,    1,  681,    1,   93,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  384, 1110,  365,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  437,    1, 1485, 3102,   32,  531, 2764,    1,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  198, 2164,    1,    1,   98,    1,    1,    1,  409,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  531, 1360,  612,  576,  365,    1,   37, 2646,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545,  688, 2049,   12,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2275,  108,   45,    1, 2212,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,    1,  479, 1352,   15,  245,    1, 1796,   28,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  800,  532,    1,    1,  335, 1950,   98,  463, 1447,   12,  954,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,    1,  191,  166, 1194, 2132,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  579, 2948,   61, 1167, 1710,  764, 3020,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885,    1,   32,  166,    1, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2486, 2286,   37, 1910, 1417, 2090,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  730, 2614, 3232, 2840,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  596,  954,    1,   28,   37,  356,  845,   93,  592,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   88, 1002,   10,  113, 1056,  402,  631,  297, 2275,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   89, 1550, 1194,  584, 2784,   61,    9,   10, 1708,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  282,    1, 1158,   12,    1,    1,  105,    1,  361,  388,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1009,  361, 1407, 1190, 1456,    1,   98, 2162,   45,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,    1,    1,  460,   12,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  257, 2248,    1,  729,    1,  224,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1040, 2203,    1,  166,    1, 2221,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  384,  166,  845,  237,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,    1, 3343, 1002,  211,    1,  528,  122,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  176,  629,    1,    1,    1,   45,  166,  593,   12, 1763,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1191,  361,  500,  872,    9,  668, 3049,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  379, 1096,    1,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3075,    1,    1,    1,    1,    1,  547, 1130,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  446,  447,  190,    1,   37,  448,  261,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  223,    1, 1466,    6,  572,  157,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,   34,    1, 2043,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1778, 2580, 2851,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158,   12, 2528, 1838, 2928,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2508,    1, 3043, 3101, 2968,  176, 1474,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1023, 1204,   12,  311, 1523,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 2152,  877,    1,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  657, 1949,  469,   37, 1237, 1412,  844, 1151,  218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1782, 1750, 2024,   32,  166, 1811,  404,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 1571, 2514,    1,  183,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 2018, 1009,   12,  413,  162, 1368,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2808, 1006,  166, 2012,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,  232, 3327,   61,    1,   37, 2565,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2171, 3134,    1,    1, 1037,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  891,  350, 1069,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1573,  166,    1,  994,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 1701, 2192, 1322,   37,  105, 2294,    9, 1935,   12,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1874,  710,  949,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 2132, 3190,  113,   81, 2906,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1123,   12, 1521, 1284,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1431,  769,   32, 1962,  517,  618,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1212, 2565,  162,  881,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  519,  606, 1621,    1,  424,  841,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1300,   37,  619, 2229,  412,   37,   59, 1772,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,  515, 1861,   12, 1811,  404, 2396, 1018,    1,   92,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   14,   15,    1,   32,  385,    1,  716,  774,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2048,    1,   32,    1,  333,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3225, 2935,    1, 2825,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2942,   12, 1948,   45,    1,  813,    1,  460,   12, 2218,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  367,  160, 1278,  526,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1435,    1,  967, 1846,    1,  191,  671,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1688,    1,    1,   37,  332, 2141,  195, 2034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,    1,  444, 2275,  115,   45,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1583,    1,    1, 2375,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3104,    1,    1, 2794,  791,   45,    1,  384,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  386,  295,   82,  387,  389,  390,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   37, 1075,   98, 1332,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  299,  300,   10,  301,    5,  302,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3111,    1,  191,    1,    1,   32,  531,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2975,   32, 2020,  176,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  972, 1744,   45,  424,    1,  167, 1371,   52, 2092,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3066,    1,    1, 2917,  191,  311, 2936,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1,  996,   93, 1406,  615,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  138,  152,   37,  875,  220,  422,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746, 2767,    1,    1, 2348,  259, 1294,  176,  479,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1537, 2778,   37,    1,  477, 1281,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  183,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1550, 2936, 2909,  254, 1634,   37,  531,  443,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  978,  769,  245,  187,   69,  102,   71,    1,  202, 1158,\n",
      "          919,  329,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1273,  259, 2264, 1427,  452,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2373, 2627, 1027,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  348,  475,    1,   98,  632, 1429,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1899,    1,    1, 1867,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1081, 1386,  958,    1,  140,    1,    1,  333,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978, 2953, 2334, 1713,  326,   12,    1, 1841,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1948,    1,  388,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3242,   12, 3215,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 1447,    1,  104,  439, 2128,  125,   46, 2198,  630,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1614, 1228,    1, 2706,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1545,  429, 3181,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1702, 3339, 2731,    1,  580,  741,   98, 2271,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 548, 713,   1, 224, 288,   9, 218, 714,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 197, 738, 739, 159,  71,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 2250,  514, 1727,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   37,  130, 2943, 1499,  700,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2843,  411,  698,    1,    9,  911,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  321,  538, 2856,  166, 1412, 1107, 1292,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3124,  992, 1159, 3084,   12,  808,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  125,    1,  589,    9, 1185,    1, 1492,  565,    1,\n",
      "           37, 1604,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2197,    1,  903,    1,  904,    1,    1, 1077,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358, 1268,  566,    1,    1, 3101,  420,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1817,    1,    1,   37, 1504,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  879, 1757,   98,  647,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,    1, 1218,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1479,  566,    1,    1,  131,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1123,   12,  331,  853,  538,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  160, 1278, 1137,  191,    1,   32,  385,    1, 1572,  191,\n",
      "          382,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1663, 1171,  770,  738,   37, 1543,  593,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340,  640, 2907,    1, 1110,  688,  705, 1458,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   45,    1, 1223,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  765, 1159,  166, 2886,   12, 1311,    9, 1965, 2982,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  665,    9,  920,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307, 1419,    1,  659,   45,    1,    1, 3031,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  328, 1537, 1109,  325,    1, 1074, 1541,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,   96,   37,    1,  359,   37,    1, 2604,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,  361, 1790,    1,   98, 1013,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974,  140,    1, 2223,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1, 548, 537, 428,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 2577, 1495,   37, 1901,    1,  847,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  603,   37,   52,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1310,   37,  271,  846,  119,  220,  915,  851, 1463,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,  176,  612,   32, 1832,   28,    9, 1067,    1,   29,\n",
      "            1,  613,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1, 1002,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  557,  540, 2024,  973,   51,   52,  915,  916, 1428, 3397,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3386, 1178, 1216,  312,  134,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1753,  923,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  780,  672,    1, 1639, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,    1, 1090,  220,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  10,   1, 420,   1, 443, 484,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2755, 1306,   37,  877,  484,   98, 3010, 1090,  191, 1970,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1,   37, 1753,    1,  297,    1,  396,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  162, 2623,  361, 3247,  619, 1452,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,  132, 1564,    1, 1912,    9,    1, 2264,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 1353,    1, 2115,    1,    1, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 3210,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1613, 1774,   39,  365, 1615, 1775,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,    1,  380,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1584,   12, 1403,    1, 1159, 2800,    1,    1,    1,  357,  193,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  741,  892,   51,   92,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  335,   98,    1, 3202,  714,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1016,    1,   23,  531,  741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3249,   77,    1,  176,  827,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2832,    1,   98,  365, 1788,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2583, 1777, 2739,   32, 2741,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,  447,    1, 1617,  361, 2741,  565,  603,    9,  449,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  136,  325,    1,    1, 2683,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9, 3358,  289,   98, 1896,    9, 2708,  171,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2870,   32,  403,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175,  123, 1387,  786, 1090,   45,  105,   12,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,    1,   34, 1420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2614, 2561,  566,  865,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1395,  361, 1768,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340, 2903,  247, 2312, 1509,    9,  166,  754,  542,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2634, 1825,  160, 2759,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  571,   37, 1691,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2249,  166,   97,  402,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175,  498,   37, 1145,  220,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,  794, 1895, 3004,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  965, 3031,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1585,    1,  220,  903,    1, 1447,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545,   12,  365,  754,   61,  611,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2924,    1,    1,   32,  567,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  119, 2674,  671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   47,    1,  124,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1353,  192, 1958,    1, 2043, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  159, 1198,   98,   91,  170,  221,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,   37,   38,   81,  388,  987,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1730,    1,  487, 3102,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2493, 2177,   37, 2111,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3086, 2924, 1237, 3114,    1, 2431,  267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1955,   12, 1352,   15,   71,    1,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  172, 1085,    1,  104,  875,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,  335,  332,   45, 1264,  841,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2777,   30, 3250,  579, 1444, 1445, 2249,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1, 1876,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  342,  213,   37,    1,   46,  220, 2707,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1564,  885, 1350,  132,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2509,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1293,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1879, 1523,   81,  548,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  682,   32,  197,  361,   15,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  980,  187, 1785,  251,  183,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   27,  119,  687,    1,  590,  517, 1876,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,  410,   63,  163,    1,   12,    1,  996,   29,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  403, 1447,  967, 1465, 2964,    1,  463, 1447,  396,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 2590, 3131, 1987,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  950,  951,    1,  702,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  138,  183,    9,  365, 2954,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  256, 1056,  388,  640,  187, 3236, 2784,   28, 3186,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,    1,    9,  166,    1,  117,  132,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1840,    1,   37,  151, 1840, 1300,   48,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  688, 3211,  191, 2202,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715, 1983,  669, 1581,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2466,    1, 2409,  115,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   37,   47,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  650,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1606,   46,   16,  410, 1647,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1017,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2875,   37,  619,  365, 2640,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1938, 2607,    1,   37,  103, 1675,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,  147, 1360,  612,    1, 1314,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1092, 2329, 1935, 1151, 1091,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380,  267,  204,   51,  193,   84,   85,  187,  622,  475,  420,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  388,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2628,  967,    1,    1,  469,   32,  913,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   93,   32, 2065, 2064,    1,   32,  547,    1,  593,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,  967,  166, 2252,    9,  786,    1,    1,  856,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  709, 2265, 1190, 2726, 2162,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,   45, 1128, 1129,    1,    9,  629,   45,  114,    1, 1242,\n",
      "          384,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,   91, 1343, 1096, 1090,  297,    1,   60,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1029, 1457,  932, 1876,  741, 2116,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2129,    9, 1676,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739,    1, 1898,    1,   37,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1147, 2778,    1,    9,  211,   32,  890,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2496,    1,  384,  778,   45,  851,  298,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3141, 3152,    1,    1, 2457,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  694,  669, 2414,  132,   37,  970,  164, 1593,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,    1,    1, 1523,    9,  674,   45,  647,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051, 1713,    1,  535, 2616,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 422, 794, 927,  45,   1,  50, 428,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 737, 156, 103, 308,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  493,  921,    1,    1,    1,    1,  384,  119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   14,   15,   71,   61, 2084,   32,  257,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,  774, 1444, 1445,  176,  629,   32, 3369,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275,    1, 1484, 1590,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 2753,  857,   37, 1832,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1429,  110,   37,   77,   69,    1,    1, 1721,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 2527, 2946,  167,    1, 1387,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1419, 2366,  279, 2355, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 1419, 2786,  861, 2432,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273,  730, 2614, 2247,  102,   28,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2476,  411,    1,    1,  202,  619,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1278,    1,  190, 1027,   28,  347,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 877, 104,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  61,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,    1,  119,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220, 1875,    1,    1,  166,    1, 2126,  166, 1690,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  759,    1,    1,   32, 2170,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1024,  729,    1, 2017,  548, 2291,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   46,  861,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2507,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  220,   15,   23,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  315, 2738,    1, 3339, 2456,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  236,  237,   25,   71,   98, 2040,   68,  361,  996,  716,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968,    1,  794,  449, 2328, 1159, 1821,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  818,  834,  914, 2126,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343,  650,  580, 1797, 2082,  548,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1364,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1022,    1,    1,   12, 3134, 2565,    1,  928,  176,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,  729,   32,   46,  220,  148,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1528, 1401,  176,    1, 3154,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3169,    1,    9,    1, 1787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   25,   28,    1,  479,  570,  515,  105, 1198,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1737,    1,   22, 1450, 2497, 3155,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1841,    1,    1,  372, 1448,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3184, 1760, 3192, 3073,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  166,  873,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  794, 1107, 1108,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2944,   12,    1, 1631, 1674,  119,   37,  726,    1,  671,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  121, 2767,   49, 1611,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,    1,  755, 1832,   28,    9,  861,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  247,  564,  444, 2062,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  166, 1551,    1,  617,    1, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3262, 2671,    1, 2912,  928,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868, 2770,    1, 1010,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   51,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,  193,   32,   46,  220,  727,  600,  179,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018,    1,  365, 1065, 1190,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  954, 1032,  763,  570,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,  45,  98,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,  37,  92,   1, 428,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1156,  597, 1405,  710,  373,  132,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758, 1564,  105,  132,  220,  166, 2594,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  864,  267,  460,  190, 2446, 3107, 3366,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   98,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3393, 2909, 1950,  418,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  113,  297,  187,  186,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  159,  686,  365,  845,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1811, 1280,    5,    6,  881, 1812,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   64, 2817, 2856,  388,  763,   32, 3349,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2126,   32,    1,   45, 3280,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3359,    1,   37,    1, 3057,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3238,    1,  273,    1,   37, 2218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  381,   37, 1073,  455, 2143,  458,    1, 1288,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,  467, 1905,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  365,    1,  261,   98,    1,  167, 1389,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3184,   12,    1,    1, 1312,    1,   32,  449,  297,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2733,  251,    1, 1211,  116, 1484,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1801,  600,    1, 2951,  183, 1090,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  477,  297, 2774, 1450,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1834,    1, 3341,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,  660,  102,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1191,   55, 2544,    9, 1122,  538,  680,  114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1, 2764,    1, 3350,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    8,    1,   45, 2996,   98,    1, 2432,   74,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 1090, 2690, 2607,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2386, 3140,  297,    1,  881,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1861, 1082,  439,   37,    1, 1895,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  325,  460, 1499,  698,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3079,  686,  166,  135,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  176, 1531,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2984,  884,  105,  123,   28, 1173,  176, 2662,   12,  633, 2918,\n",
      "         2820,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1926, 1927, 1928, 1082,   69, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2870,   32, 2178,    1, 1887,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,  176,    1,   12,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3322, 1673,  581,   73,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  794,  163, 1230,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  884, 1950,   98, 2308,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129, 2523, 2963,  176, 1477,  317,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1789, 1407, 1190,    1, 1053,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 2021,  440,   32, 3079,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2723, 2724,    1,  205,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3061,   16, 1791,  741, 2402, 2558,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  273,  580,    1,  674, 1463,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311,   12, 1107,  132, 1086,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1701, 1876,  766,   12, 1935, 2294,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1121,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  547, 1407, 1428, 3365,  820,   32, 3360,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1917, 3181, 1863,  748,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1065, 1190,   12,   76, 1596,    1, 2944,   12,  129,   74,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523,  321,  612,    1, 2220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  297, 2547,  361,    1,   32, 2752,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718, 1331,    1,   37, 1155,    1, 2690,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  318, 2526,    1, 1891,  844,    1,  475, 1061,  297, 3070,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  446,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  792,    1,  792,  267,    1,   32,    1, 3058,  611,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,  105,    1,  698,    1,  166, 1973, 2963, 2388,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  218, 1075,  626,  102, 1376,  220,  365, 1450,   98, 1147,   69,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  461,  384,  166, 2667,    1, 1159,  166,  114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2384,  593,   12,    1,    1,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3305, 2352,    1,  389,  176,  584,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  123, 1056, 2165,    1,  125,    4,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982, 1913, 1843,  207,    1,  218,  332, 1042,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  841,    1,  202,  193,    1,  191, 1194,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,  830,    1, 1352,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3178,   12,    1, 1684,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  592,  267,   46,  220,  208,   37, 2535,  734, 2434,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2226,    1,  416,  105,  550, 1101,    9, 2487, 2621,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1155, 1151,  250,   32,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  391, 1329,    1,  810,  707,  974,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1864, 2495,   37, 1230, 2528, 2455,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1110,   51,  664, 2967,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1851, 1761,    1,  600,  229,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1530,  938, 1075, 2548, 2297,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1,   32,    1,    1, 1533,  917,  682,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  147, 1707, 1100,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  157,    1,  951,    1, 1089, 1675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3118,    1,    1,   46, 1195,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1432, 2279, 1702,    9,  365,  593, 1320,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,  487,    1,  437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885,  566, 1194, 1684,  176, 1938, 2809,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  457,  851,  288,    9, 1821, 2699,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1572, 1414,  289,   98,  463,    1,  404,    9, 3343,  863,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,   28,   98,  109,  533,    1,  863,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3303, 2850,  105,   37,  221, 1056, 1048,  176, 1687,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,    1,  170,  469,  220,  158, 1960,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779,  744,   28, 1286, 2069,  220, 3174,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,  132,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  630, 2011,   98, 3369,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1128,    1,  220, 1158,   32, 2543,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  670,   98,  971,  156,    1,  242,   69,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2882, 3091, 3338,   32,  531,    1,    1,    9,  297, 2074,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,  102,   71,   27,  104,  187,  239,  240,  104,   29,\n",
      "            1,  107,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12,    1,  400,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,   37,  211, 2092,  932, 1724, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1739,    1,  353,  242,  572,  244,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2429,   37,  492,    1,  548, 1887,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2980,    1, 1689, 2999,   91, 3050,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,    1, 1054,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 1411,  756,  949,    9,  357,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1307,  572,  244,  190,  688,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2787, 1426, 1183, 2113,  132,  220, 1497,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,    1, 2334, 1638,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,  261, 1158,   12,    1,    1,  193, 1994, 2015,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  314,   46,   37, 1629,  600,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,    1,    1, 1159,   80,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  959,  105, 1442, 2183,   74,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2022, 1002,    1, 1401,   32, 3144,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  313,   37,    1,   28, 1718,  861,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  353,  242,  197,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2634,   12,    1, 2871,    1,    1,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 1260,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3152, 2565,  833,  612, 1937, 2967,  187, 1816,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3209,    1,    1, 3289, 3271,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  179,   37,  125,    4,  187,  460,  392,   81, 1108,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3231,  631, 3232,  548,  786,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1622,    1,    1,    1, 1559,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,    1, 1300,  225, 1996,  261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  420, 1574,    1,   98,  985,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1625,  861,  190,  619, 2264,   37, 1605,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3254,  361,    1,  688,  166,    1,   98,  754,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993,   12, 3056,    1,   30, 1677,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,  297, 2086,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1312,    1, 1041, 2300,    1,  331,  191,  422,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2967,   12, 2099,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  387, 1018,    1,  361,    1, 3098,   32,  730, 2614,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,  167, 1198, 2108, 3368,   98,  395,  191, 1411,  356,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1477, 1990,    1, 1779,  105, 1526,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  327,   13,   98,    1,   45,   15,  973, 1159,  163,    1,\n",
      "           12,    1,  361,  395,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  335,  166, 2205,   37,  222,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  949,   45, 1568,  365, 1089, 1675,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1838,   32, 1674, 2218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1228, 2351, 1083,    1,   32, 1186,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1089, 1090, 1539,   98,  454,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2357,  837,   10,  176, 2396,   32, 1966,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 2767,  365, 1013, 1522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116,  259, 1918,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018,  726,    1,  361,    1,   37, 2447,  444,  691,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1056,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  166, 1902,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,    1,    1,    1,    1,    1, 1454, 2309,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   56,    1,  384,  395, 2003, 2960,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  155,  157,    1,  159,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1028, 2681,    1,    1,  155, 1574,  600,  627,   45,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3256,  193, 1960,  166,  636,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,  476,    1, 1281,   32, 1524,   45,  403, 2288,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398, 1082,  104,   37,  846, 3402, 3408,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  198, 3087,  868, 1850,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2343,    1,  750,  924,  907,    9, 1022,  199,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1879,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1715,    1, 1162,  250,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   61, 1658, 3017,    1,   85,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2395, 1277,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  336, 2137,   32, 2755, 1094, 2856,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  274,    1, 1924,   32,  176,  166,  698,   45,  166, 1821, 2107,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275,  603,    9, 1285,   32,  736,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1723,  782,   86,    1, 1450,  565,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1176,    1,   45, 1537,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1088, 2153, 1207,  443,  444,    1, 3398,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1034,   32,  231,  105,    1,   45,  166,  365, 2693,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 2579,   45, 2468,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   37,   26,  417,   98,  677,   69,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 1708, 1586,   28,  187, 3363, 2405,   37, 2743,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  496, 1022,  493,  636, 1269,   32,  257,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  829,   12,    1,  768, 1710,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1251,  418,    1,    1,  159,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  633,  852,  176,    1, 1778,   39,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2971, 1958,   37,    1,    1,   45, 2189,  557,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2522,   45,    1,    1, 1687, 1022,    1, 3008,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 2026, 2538, 1976,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2700, 2884,    9,  183,    1, 3001,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2094,  105, 2213,    1,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2553,   32,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2924,    1,   64,  591,  285,   32,  166, 2140,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2578,  140,   63,  754,  542,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994, 2819, 1705, 2572, 1010,  768, 1559,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  669, 1278,   66,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3184,  147,  782,    1,  514,  297, 2282,  722, 2108,  132,    1,\n",
      "            1, 1130,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1717,    1,  191,    1, 2393,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868, 1082,  652,   32, 2710, 2064,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2596, 1585,    1, 2597,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  364,   37,  714,    1,   28,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3281, 2331,  297,  477, 2422,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  951,    1, 2615,    1,    1, 1388,  220, 2522,   98,\n",
      "          260, 1160,    1,  150,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  494, 1399,  299,   45,  388,  286,  533,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1076, 1077,   54,   37,  335,  297,  413,  671, 1078,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018,    1, 1281, 1816,   45,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   32,    1,  187,  531, 3102, 1757,  431,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1539,   45, 3101, 2968,  853, 1464,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993,   12, 2994,  600,   37,   52,  820,   98,  218,  320, 1533,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1279, 1394,   37,    1, 1115,  954,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  223,    1, 1672, 1215,  658,  763,  174,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3347, 1333, 1530,   32, 1785, 2095, 1260,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  437,    1,  301,    5,  832,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  588,  745, 1632, 1718,   32, 1133,  996, 1215,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   32, 3118, 1512,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2077,    1,  971,   32,    1, 1736,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2656,  267,  374, 1435, 1370,   45,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1, 1046,   79, 1411,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  381,   37,    1,  455,  285,   87,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,    1,  187, 2826, 2242, 1930,  166, 1930,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  542,    1, 2308, 2811,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3029, 2640,    1,    1,    1,  220, 1663, 1821, 2190,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  147,   37, 2303,    1,    1, 2162, 1780, 1655,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  446,    9, 3057, 2198, 1384, 2789,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 1458, 1247,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  352, 1489,  484,   98,  589,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2514, 3045,    9,    1,   32, 3155,  187, 1523,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  829, 1039, 2690,  333, 1924,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2292,  190,  631, 3349,   12, 2193, 3362, 2789,    1, 2038,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  758,   37,  151,    1,    1,  952,   37,   52, 1479, 1863,   32,\n",
      "          111, 1107,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  533, 1483,    1, 1051, 1284, 1542,    9,  365,   93, 1844,\n",
      "         1379,   12,  112,  499,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  853,  387, 1632,  567,  666,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3305,  908,  356,  132,  220, 3239,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  229, 1780, 1176, 2127,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1955,  765,   37,    1, 1522,  546,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1304,   42,  220,  422,    9,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503,  765,   37,    1,    7, 1346,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2625,   32, 1815, 1554, 1700, 1530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1918, 2070,  671, 1882,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1212,   12,    1,    1,  419,    1,  197,   71,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311,    1, 1114,    1,    1,  267,  590, 1512,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  533,   45, 1793, 2822,   37,    1,  481, 1704, 2715,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  132,  193,   32,  913, 1724,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  310,   25,  670,  187,   69,  765,  530,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,   32,  121,  186,  444, 2095,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2528,    1,    1,   12,    1,    1, 2232,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2907,  696,  730, 2614, 1832, 3175,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  420,    1,    1,   37, 1306,    1,  199,  220, 3265,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129,  317,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   37,    1,  667, 2042,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  245,   98,    4,  420,    1,  657,  304,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,  361,  219, 1149, 2905,    9, 1388,  297,  283,  315,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32,  531,   61,    1,  187,  105, 2773,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,   37, 1083,  347,  187,  954,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3390,   32,  187, 1009,   45, 3367,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,    1, 1550, 2368,  863,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1635, 1429,  458,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3311,  719,   37,   84,   28,    1,    1,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1617,   37,   52, 2506,   98,   94,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1879, 1664,    1,    1, 1380,    1, 1483,  361,    1,   98,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3260, 1348, 2315, 1844,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,  291,    1,  301,   29,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   12,  551,  552, 2185,    1, 1445,  437,  157,   37,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 1656,  117,  400,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  111,  818,  834,   15, 1124,  995,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1080,  455,   12, 2673, 2494,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  107, 1070,  104,   37, 1978,   69, 1356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  203,    1, 1187,  166, 1361,    1,  166,  651,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,    1,   32,   98, 1674, 3098,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  108,  310,    1,   45, 1718,  767,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2151,    1,    1,   45, 1889, 1084,  931,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1224,    9,  613, 2101, 2239,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1,  453, 2336,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835,    1,  365, 2789,    9, 1851,   72,  199,   32,  537,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  190, 1721,    1,  220, 1158,  424,  199,    1, 3011,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1, 3256,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3047,   32, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3389,    1, 2887, 1450,   32,  854, 2856,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  479,   37,  125, 1233, 1656, 1069,  191,    1, 1501,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785, 2044,    1,  395,  498,   37,    1, 2179,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  854,  147,   57,  365, 1077,    9,  844,  663,  333,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294, 1456,    1,  841,  441,  297, 1350,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 3111, 1000,    1, 2886, 3340,  220, 1645,    1,   32,  531,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3144,    1,  565,   55,  245,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3053,  884,  105, 1150,   32, 1821,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  491,  361,    1,  631,    1,   44,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2747,  847, 2890, 2094,   39,  166, 1675,    1,  175,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  102,   71,  220,   64,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,  952, 1527,    9, 1821,  210,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  860,  493,    1,    9,  680,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1447, 1585, 1372,   37,  606, 1846, 3032,   12,    1,\n",
      "         1447, 1190,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   14,  902,  236, 1022,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   28,    9, 1018,  411,  698,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2388,   12,    1, 1618,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1228,    1, 1401,   37, 3109,    1,    1,   45,    1,  643,  918,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1809,    1, 1013,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  185,  186,   98,  116,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3384,    1, 1073,  547,   69,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   25,  439,   28,    1,  479,  515,  105,\n",
      "         1198,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183, 2005, 1248,  864,   37,    1, 1428, 2390, 1806, 1220,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1149, 1683,   32, 3360, 1386,  379,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1839,  741,   32, 1352,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3132,    1,    1,  361,    1,  967, 1827,    9,  273,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  312,  361,  229,  168, 2444,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,  361,  104, 1421, 1461,  895,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2514, 1485,    1,   37, 2107,    9, 1326,   32,  455,  361,  968,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2700,    1,  191,    1,   45,    1, 2715,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2095, 1260,    1,   32, 2445,  861,  639,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3322, 1285,    1, 2475,   32, 2138,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1869,    1,  102,  453, 1126,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087, 1042, 2336,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3117, 1686,   32, 1194, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3121, 2414,   32, 1789,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,   39, 2084,    1,  328,   32,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1892,   37,  815, 2723, 2724,    1, 1892,  162,  365,    1, 1173,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2036,  919,  347, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1796,  102, 1348,   37,  245,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  683, 2145,   37,    1, 3103,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  167, 1021, 1488, 2604, 2727,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 1147,    1, 3045,  190,   37,  856,  193, 2961,  191,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   49,    1,  333, 1603, 1008, 2104, 1336,  166,  636,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1123, 2333, 1863,  477,    1,  455,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 1515, 2766,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   65,  573,  639,  448,   37,    1,  372,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  227, 3282,   61,  645,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  615,    1,   37, 1802,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  289,    1, 3358,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2759, 1085,  218, 2861,   37,  131, 3031,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   25,  504,  187,   69,  338,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1568,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  232,  920, 1550, 3374, 2763,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3372,    1,  134,  446,  220,    1,   37, 1094,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2591,   37,    1,  365,  650,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2062, 1631,  104,  429,   32,  331,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2855,    1,  548,    1,  736,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403,  878,    1,  474,  744,   46, 1757,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2254,    1, 1361,    1,  875, 2255,  149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2755,    1, 1993, 2110,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  893, 1860,    1,    1,    1, 2083, 1361, 1215,  434,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1602,   12,  963,  830,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,    1, 1428,    1,    1, 3051,    1, 1207,   37,  439,  443,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,   37,  130,    1, 1085,    1,    1,  260,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,  721, 1579,    1,  187,   82,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066,  162,    1, 2714,   32, 2448,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2551,    1,  220,    1,  176, 3229,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 1542,   37, 1982, 3380,   12,    1, 1232, 1532,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1255,  433,  218,    1,  471,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2037,    9,    1,  187,  590,    1,    1,    1,  463,  584,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 2170,    1, 2070, 2179,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  286,  475,  267, 2289,   12,    1,  590,    1,   32, 2160,   45,\n",
      "          287,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  554,   98,    1,   69,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3327, 2257,   39,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  147,  261,    1,    1,   45, 2220,    1,  963, 2122,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 1414, 1188, 2025,  104,  764,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1257,    1,  132,  220,    1,   61,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2741,   96,   81, 3244,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  288,  365,  845,    1, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  421,    1, 1273,  259, 1107,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   17,  193, 2331,   45,  148,  647, 1416,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3010, 2175,   28,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1633,  325, 1206,    1,   36,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3007,  365, 1102,    1,  361,    1,  931,  220,  593,   12,\n",
      "          553,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1, 2572,   32,    1, 2517,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3118, 2751, 1860,   46,    9, 2074,  297, 1450,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  162,  365, 2968,  475,  187,  233,  958,\n",
      "            1,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   28,  105, 1609, 2213,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,   61,    1, 2017,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  845,  147,  213,   37, 1709, 2096,  297, 1842,  116,  412,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1177,   37,  455,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 2975, 1824, 1225,    1, 1969, 2692, 1539,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1333,  176, 1514,  837,  408,    1,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,    1, 1713, 1107, 2610, 2107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1189,    1,   81, 1429,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  957,  939,  548, 2368,  741, 1140,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,    1, 2414, 3374, 3384,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  236,  237,  953,  187,  197,    1,  221,   32,  317,  863,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  438,  190,   77,    1,    9,  516,  297,    1, 2878,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2412,   12, 2533, 2609,  142,   37, 1413,  683,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  883,    1,   32,   86,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1117,    1,  669,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3238,   37, 1306,  105,    1, 1007,    1, 1417,    1,   12,    1,\n",
      "         1090,  698,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1630,    1,  866,    1,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 1903,  220, 3343, 3345,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3361,   37,    1, 3025,   12,  949,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  954,    1,  176,    1,  118,   67,   32, 2073,  401,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  565,  334,  105,  792,  972,    1,  792,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2226, 2968,  220, 2310, 1298,  661,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  952,   37,    1,  710,   12,  734,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3142,   32, 1054,   45,  166,  901,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1654,  131,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233, 1579, 2971, 1958,  302,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1668,  219,    1,   45,  356, 1624,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390,  587, 2253,  868,   98,   24, 1004,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  437,  460, 1745,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3021, 1558,  191, 3292,  872,    1,    1,   61,    1,  384,\n",
      "         2193,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  621,  624,   82,    1,   37,   84,   85,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,  550, 3113,   12, 1277,    1, 2545, 2658,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1028,  395,   12,  762,   32,    1,   32,  208,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1,  580, 3026,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  136,  253,   81, 1499,  297,    1, 1816,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1580, 1148,    1,  619,  111,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1, 3272,    1,   32, 2579,   45, 2468,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  542,    1,  191, 3079, 1623,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  396, 2073, 1267,   45, 2579,   45, 2468,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1774,   39, 1354,    1,  880,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  182,   32,    1, 1541,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 1386, 1988,   45,    1,  163,    1,   12,    1,  776,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361,  315,   37, 1140,   98,  324,  548,  326,  132,   82,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2832,    1,  487, 3372,   32,  365, 2716,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1537, 1538, 1539,  477,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1,    1, 1753,   37, 1198,  412,  636, 1806,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  886,   37,  151,    1,   45,  675,   98,  105, 1151,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3321,    1,    1,  202,    1, 2055,   32, 2807,  354,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1711, 1882,  754,  548, 2835, 3389,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1409,    1,    9,    1, 2103,  617, 1116,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3257,    1, 3169, 1758,   32, 2197, 3329,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2823,    1,    1,  890, 1174,   32, 3097,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2075,   81,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  308,  125,   98,    1,    1,  533,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1053,   12,    1,   69,  532,   71,  419,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  446, 1921,    9, 1319, 2396, 1010,    1, 2357,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  224, 2641,  738,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1419, 2851,  328,    9,  810, 1778, 2580, 2264,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1523,   45,  166,    1,  884, 1183, 2041,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 2593, 1090,   37, 1664, 3136,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1267,  288,    9,    1, 1841, 1953,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1648, 1010,    1,   32, 3118,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 3160, 1156,    9,    1, 1147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2723, 2724, 2636,    1,  794,  220,  388,  763,  441,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,  365,  863,    9,    1, 1905,  972,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  582,   45,  487,    1,    1,  384, 3369,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3140, 1258,    1,  453, 1414,  384, 1430,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  371, 2384,  166,  365, 2273,    1,  384,  370,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  105, 1884,  985,  321,  612,  817,   85, 3169,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1707, 1056,    1,  302,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,   34,  977,    9,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2145,   37,  489, 1994, 1718,  117,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  879,    1,  132,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3100,  171,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  602,    1,  208,  429,  590, 2047,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 1090, 1829,  501,  827,  176, 2926,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  804,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2752, 1070,    1,    9,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  636,   45,  596,    1,    1,  418,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106, 1013, 1522, 2776,    1, 1017,    9,    1, 2829,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1312, 1530,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  398,   57, 2199,   37,   49,   50, 1611,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1431,   51, 1031,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 3253,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3160,  513,  514,   32,  531,  966,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  195,    1,   39,   32,  505, 1523,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870,   37,    1,  225,  384,  507,  111,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1390,    1, 1746,   46,  220,  587,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1249, 1592,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1759,  309,    1,   12,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1303, 2257,    1, 1131,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  310,  437, 1874,  121,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   42,    1,  331,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  449, 2308,  477,   61,  297,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1877,   37,  973, 3369, 3146,  528, 1557,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  355,   37,  138,  365,   82, 1690,  187,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    6,  570, 1177,  686,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1300,  230, 1301,  180,    1,  727, 1302,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,  333, 1960,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596,   32, 2597, 2414,  176,  177,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  629, 1633,  720,  155, 1875,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  138,  187,  334,  168, 1228, 2019,  707, 1121,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2710,   36,  288,    1,   32, 2499,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2146,    1,  546,   32, 1759,  309,  187, 2015,  418,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3188, 2781,  187, 3244,    1,   28, 2551,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  449,   67,  176,  581,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,   25, 1150,  548, 1151, 1091, 1152,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2826, 3280,   37, 1844,    1,    1,  548, 1674, 2472,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  754, 2261,  193,  187,    1,  187,  154, 2898,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  446, 1554,    9,  854,  342, 2396,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 2050,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  777,  818,  834,   28,  419,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2956,    1, 1605,   98,  365,  791, 1563,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  567,  510, 1518,   32,   98, 1938,    1, 2028,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2316, 2772,   32,  273, 1010,  105,    1,    1,    1,   98,  166,\n",
      "           71,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,  852,   37,  619,   81,   98, 1171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  116,   61,   19,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1870,  708,   39, 2528,    1, 1234, 1863,  688,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2161,  726, 3077,   32,  238,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1106,   12,  645, 1013, 1626, 1781,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  190,  116,    1, 1878,  388,  537,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2582, 2527,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  657, 1660,  158,    1, 1353,  752,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1,  490,  115,   32, 1759,  309,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1532,  917,  484,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1178,  162, 1146, 1703,  138,  423,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2529, 3121,    1,  640, 2755,  455,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,   37, 1079,  147,   37,  125,  474, 1149,  138,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 2264, 1847,  388,  600,    1,  763, 3002,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  256, 2549,   37, 1013, 2177, 1825,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  632,   25, 1192,   98,  446,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  572, 1249,  236,  237,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  259,  633,   37,  125,    1,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  166,  442, 2521,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  550,    1,  905, 1310,   37,    1,   79, 1823,  535,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683, 1086,  142,   37,   47, 1021,  112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,  590,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   81,   37,  166,    1,  721,  176,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962, 3319, 1285, 1110,    1, 3260,  554,   37, 1264,  841,\n",
      "          631,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   49,  482, 1540,  297,   97,  384,  632,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  727,  744,   28,  754,   32, 1105,  787,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1236, 1228, 2633,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  166,   16,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1751, 2753,   37,  631,    1,  608, 2920,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  177, 3006, 2572,   32, 2018, 2262,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089, 1090,  542,    1,  240, 2692,   12,  949,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,  449,    9, 1481,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2090,    1,    1,  325,    1,    1, 2166,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,  794,  166, 2665,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2999,  614,   73,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3146,   32, 1559, 1813,    1,  551,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   72,  842,  195, 1976,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,   12,  244,  168,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,  986,   37, 1605,  220,  829,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  476, 2168,   37, 1027,  756,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2962,    1, 1401, 3175,   37, 2872,   45, 2615,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3340, 1527, 2664, 1564, 1727,   32, 1089,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2911, 1421,   28,   32,    1,   78,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 1172,   12, 1173,  115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004, 1087,   51, 1636,    1,    1, 1116,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  852,   37, 1636, 1778, 1589,  176,  754,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 2017,  832,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1771,    1,    1,  584,   32,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1462,    9,  550,  369,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,  247, 2966,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  614,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2494,  872,   39,   45,  671, 2107,  548,  354,   37,  208,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190, 1721,    1,  220, 1158,  424,  199,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,   26,  417,   60,  953,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  590, 2128, 2129,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,   88,    1,  854,  187, 1153,    9,  596,   29,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  705,    1, 1417,    1,  379,   37, 1604,   98, 1123,  132,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1842,  613,   37,  125,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   37,  665,   26, 1039, 3014,    1, 1228,   98, 2168,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 224,  12, 265, 921, 758,  88,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 156,  71,   1, 202, 159, 701,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  462,    1,   51, 1334,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1957,  686, 1606,   32, 2597, 3407, 2774,  251, 1302,  132,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3332,  894,  764, 1245,    1, 2308,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    1,  928,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   77,  661,   98, 1687, 1022,    1, 3008,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  219, 1619,  458, 1408,  347,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2733, 1996, 1211,  116,  279, 1484,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1569,   98, 2723, 2724,    1,    1,   32, 2294,  856,   37,  166,\n",
      "         1838,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1117, 2208,  681, 2704, 1228,   37,  561,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,  811,  361, 1130,    1,  105,  123,  661,   98,  104,  741,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  879,  693,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1958,    1,   74,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158,  967,  105, 2693,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  104,    1,    1,    1,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 1955,  292,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2839, 1707,  865,   45, 2162, 1780,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3343,    1,    1,  274,    1,  191,  118, 1428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1477, 1990,  872, 1044,  105,  856,    9,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  650,   37,    1, 1277,   37, 1334,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,   22,  548,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  459, 1273, 1107,    1,  220,    1,    1,  421,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  611, 2705,  134,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  231,  297, 3143, 1313,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2334, 1114,  396,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  213,   37,  138,   59,   37,  875,  149,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  600,  627, 1278,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    9, 2275,    1,  384,   10,  186,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2463,  186,  608, 2920,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2686, 2687,    1,    9, 1242,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  176, 3182,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1431,  325,  215,  517, 1228, 2683,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  336, 1585, 1229,    1, 2537,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,  627,   45,  457, 1821, 1697,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2406,  986,    1,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2868,    1,    1,   45,  163,    1,   12,    1, 1527,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  140,  593, 1990, 3275, 3295,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3196,  884, 1485, 1938, 3197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2780,   51,   52,  105,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,    1,   29,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3311,  750,    1,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,  829, 2564,   37,    1,  327,  361,  844,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597, 2924,    1, 3349,   12,  861,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  492,    1,  190,  151,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228, 3226,  686,  220, 2281,  134,    9, 2811,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   32,    1,    1,    1, 2139,   37,  877,  105, 2301,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  926, 2126,    1,    1,  267, 1002,   45, 2064,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   25,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  827,  826,    1, 2762,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2573,   12, 3398,  520, 2381, 2789,  662,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  750,   84,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2868, 1921,   32, 2592,    9,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  520,  521,  522,  444,  523,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  367,  465, 1895, 1097,  568, 1071,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1203,    1,  617,  259, 1871,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1847,  247, 1623,  892,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3311,  884,  297,  187, 2920,  650,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,  159,   71,   32,  714,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  617,  259, 1281,  972,   37, 2449,    9,  920,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  822,  122,  211,  963,  659,   45,  104, 2304, 2095, 1638,    9,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2955,   29, 1360,  612, 1496,  104,    1, 1592,  774,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  355,    1, 1443,    1,   98,    1,  238,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492,  361, 2427,  588, 2218,   32, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1447, 2808,  187,  455,  155, 1461, 1816,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  873, 2332,  619,    1,  176, 2936, 3282, 2630,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  463,    1,    1,    1, 2107,    1, 1354,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1539, 2177, 2636, 2869, 1107, 1863,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  606,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  855, 1361,    1,   37,    1,    9,  105,  838, 2305,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2408,  220, 1340,  873,    1, 1690, 1661,    1,   12,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  592,  387,    1,  163,    1,   12,    1,   93,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2805,   12,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700,   45,  103, 2144, 1107, 2308,   32,  455,  565,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  519, 2446, 3250,    9,  449, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1433,    1,  565, 1568,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  543,   37,   77,   37, 1183, 2113,    1, 1010,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460, 1132,  469, 1954,  221,   37, 2580, 2851,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  871,  160,  102,  720,    1,  626,  188,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1594,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   98, 3155,    1,    1, 3045, 1687,  105,    1,  856,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  166,  389,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   45,  166, 1892,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2265, 3365,  820,   32,  531,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  567,  510,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779, 2622, 3064,   37,  759,    1, 1286, 3179,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  328,    9,  116, 2542,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1771,  546,  582, 2565,    1,  548,   56,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2726, 3040, 2564,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2424, 3190,  608, 3194, 3195,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  548,  166,  862,    1, 1226,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 1293,   49, 3026,    9,  547,  257,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2010,   76,   37,   52, 2011,  187,  411,  187,  424, 1034,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3113,    1, 3283,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3178,  884,    1,  103, 2788,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  732, 1149, 1947,  818,  477,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1143, 2226, 1210, 2310,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1613,  353,  737,  197,   98, 2480,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3068,    1,   28, 1626, 1228,    9,  282, 2367, 2695,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2911,    1,  220,  104,  954,    1,  861,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  403, 1447,   12, 2673, 2375,  210,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1720, 2643,    1,  168, 2026,    1,  334, 1445,  166,  183,  786,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  207, 3017,  408,   98,  166,   71,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  332,  102, 1826,   98,  119,   69,  636,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2137,  989,  721,   98, 1277,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548, 1573,    1,    1,    1, 1408,  707,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3257,    1,   98,    1, 2699,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  750, 2358,    1, 1867,  207,  259, 1484,   98,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3216,  542,    1, 2308,    1,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1867,  166,  238,    9,  333,   45,  453, 1973,  217,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2516,    1,  275,  167,   92,  326,   12,    1, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089, 1377,    9,  949,   45, 1485, 3365,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  584,   36,    1,   46,   37,    1,   98,    1,    1, 3011,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1011,    1,  187,    1,  897,  220, 1121,   64,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  636,   85,   98,    1,  104,  341,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1759,  309,  458, 3205,  388,  763, 1889,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,  640,  365,  340,  671, 2405,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,  395,    1,  762,   37, 1446, 1294,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  978,  769,  439,  417,    1,  156,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1194,   73,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 2203, 3246,    1, 3161,  750,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3355,  267, 3369, 1809, 1647,   98, 3118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,   32,  147,  600,    1,    1,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2176,    1,    9,   93,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2870,   32, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 1463, 1281,   98,  854,   12,    1,    1,    1, 1946, 1282,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  358, 1070,   37,    1,  573, 1197,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  123,  124,    1,    4,  125,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3400, 1211,  548,  537,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403,  294,  987,    1, 1551,   28,   59,  104,   32,   15,   45,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2951, 1186,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 1484,    9, 1183, 2113, 1705,   37,    1,  596,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1247, 2270,   37, 1343,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  108, 1094,   98, 1378,    1,  868,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,    9,  166,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2771,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  449, 1023,  197,  418,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1187,    1, 1575,  166,  943,   98, 1384, 1563,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2297,  548,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   12,  978, 2953, 1007,  614,   98,  333,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3199,  744, 2364,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2902,  872,   28,   98,   80,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  335,  923,   37,  147,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2961,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  309,    1,    1,   51,   71,  220,  310,  311,    1,   25,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283,    1,  140,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2153,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  698,  636,   51,    1,   49,  734,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3068,  551, 1962, 1403,  613,   80,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 3345,  774,  957,  213,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  964,    1,  539,  297, 3144,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1883, 1228,   37,  151,    1, 1117, 1525,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  647,  615, 1066, 2591,   98,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  510,   12, 1438,    1,    1,    1, 2047,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3097, 2789,    1, 1389,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1,    1,  365, 1013, 1522, 2043,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1109,    1,   37,  151, 1694,   45, 1273,   50,    1,  249,  774,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,    1,   37, 1204,  176,  103,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3372,  670,   28,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810,   12, 1103,    9, 3238,  548,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1933,   51,   52,  123,   37, 2092,  467,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2126,   45,    1, 3046, 3143,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  176,  177, 2572,   32, 2137,  176, 2729,    1,    1,  191, 3095,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,   12,  142,    9,  438, 2763, 2385,  612,  264,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   47,  284,  285,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  346,  954,  686,  220, 2785,   45, 1628,  550,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  548, 2780,  416,  640,    1, 2374,  416,  105,  938,  661,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  833,  612,    1,   32,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1245,  606, 2760,   85,    1,  202, 1183,  454,   37,  168,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1542,  987,  167,    1,  236,  237, 1367,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  501,    1,    1,    1,   63, 3228, 1971, 2460,   79,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,   12,  865,   37,   95,   98, 1171,    1, 2978,  379,  774,\n",
      "         1821,    1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  928,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  229,    1,  344, 1634,    1,    1,  267,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,  365, 2741,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2329,    1,    1, 2498, 2337, 1769,   37, 1911, 2784,   37,\n",
      "          572,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,  361, 1181,   37, 1731, 2234, 2351,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  168,  187, 3243,   61,    1,  384,  166,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  373,    1,  852,   37, 1529, 1158,  754,  535, 2232,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  435,  523,    9,  521,  134,  297,    1,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2682, 3172,   32,  316,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1149,    1,  297, 1038,  966,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  459,  645,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  153,  449, 1385, 1586,  810,  634,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1, 1128,  631, 2232,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  765,   98, 2072,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  773,  225,   28,   98,  645, 1729,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596,   27,  163,    1,   12,    1, 3150,   32,    1, 2414,\n",
      "         3361,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  794,    1,   69,  605,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584, 1360,  612, 1584, 3301, 2565, 3239,   32,    1, 2771,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  251,  187,  445,  187,  356,   12,  138,   32, 2187,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  879,    1,    1,  260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  374, 1738,   70,  245, 2049,    1,  948,    1, 1026,  418,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1386, 1454, 2180,  127,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3277, 1216,   37, 2558,   32,  247,    1, 1563,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2677, 3066,  361, 3215,   37, 2370,  176,  754,  444, 2468,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2827,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2275,    1,   19,   10,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1970, 2305,  376,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2332, 1493,    1, 2223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328, 2018,  726,    1,  361, 2498,  444, 3099,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585,    1,    1, 2668, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3318,  688,  519, 2072,    1, 2925, 1034,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,  361, 3209, 2260,  548,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1143, 1454,  247,    1,  176,  654,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   37,  361, 3115,    1,  590, 3245,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   98, 2800,  105,  633, 2082, 1489,  365, 1788,   12, 3188,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796,   25,   51,  504,  548,   69,  948, 1326,   51, 1758,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  155,    1,  297, 2351,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  794,  103,  439, 3019, 1151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2264,  211, 2851,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  310,  497,  588, 1211,  442, 2060,  220,  677,  395,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  305,  186,   98,  720,   32,  367,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584, 1818,  147,   37,  804,   98, 2815,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  548,  862,    1,  338,    1,    1,  682,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,   28,   98, 1663,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,    1, 2218,  220,  104,    1,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2941, 2041,  190,   52, 1133,    1,  202,    1,   12, 3130,  190,\n",
      "          631,  872,   37,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1518,    1,  151,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106,  879,    1, 1467, 1013,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1245,  726, 1194,   73,    1,  688, 3206,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  566,  119,  726,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  515, 3019, 1151,  105, 1766, 1767,   92,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  276,    1,  245,   45,  104, 1940,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,   12,    1,  140,    1,  671,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1086,    1,  142,    9, 1183, 2921, 2218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700, 1864,  388, 1867,  176,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428,  903,    1, 1447,  300, 1894, 1263,   98, 3032,   46,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089, 1090, 1091,  168, 1092,    1,    1,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3194, 3195,  546,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  957, 1202, 2596, 2774,    1,   32,  557,  540,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  275,  218,    1, 2127,    1,  202, 1087,  533,  786,   45,  105,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,    1,  176, 2162,   45,    1,    1,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2511,   37,   47,  535,   50,   37,    1,    9,  152,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  386, 1936, 1003,  176,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3324,    1,  105,    1,   55,  356,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,  726,  515,  916,   37,    1, 3343,  957,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1689,  574,    1, 1595,  396,  929,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  597, 2774,  187,  446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700, 1013,    9,  443,    1,   32,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3132, 2446,  166,   46,   37,  130, 1024,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999,   91, 1905,   37,  606,    1,  453, 2819,  443,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3369, 2024,   46, 1195,    9,  463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,  421, 1201,    1, 1321,  142,    9,  849,    1,    1,  636,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1582,   51, 1251,  137,    1,  131,    1,  293,  267,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497, 1421,  572,    1, 2967,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3280,   12,    1, 1463,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  844, 1147, 3345,   45,  864, 3397, 1210,    1, 1683,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2417,    1, 1861, 1924, 2506,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  176,  163,    1,   12,    1,  806,  920,    1,    1,  388,\n",
      "            1,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  227,  550, 2026, 2574,  207,  234, 2226,  235, 1851,  234, 2226,\n",
      "          235,   59,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3281,    1,  220, 3314,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  561, 1025, 1173,  176,    1, 2471,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2576,  361,    1, 1654, 2545,  187, 1186,   12,  103,    1, 1885,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2663,   51,  345,    1,    1, 2715,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  593, 1990,   37,   52,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2556,    1,   37, 1413, 2588,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  361,    1,   32,   46,  600,    1, 1942,  361, 3018,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401, 2882,   44,   32, 2090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2932, 1192,    1,    1, 2727,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3175,  877,  917,  484,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708,    1, 2562,  420,   98, 3358, 2162,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  755, 1299,    1,   37,  837, 1003, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1203, 2871, 1021,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3282, 2779,  801,   37,  395,   26, 3293,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  181,    1,    1,   32,    1,   37, 2372,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  758, 1774,   39, 1463,   45,    1, 1013,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,    8,  282, 2367, 2695,  861,  328,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3271,  103, 3209,    1,   77, 1625, 2793,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,    1,  786,  915,  199,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  391,    1,    1,    1,  697,   37,  726,   32,  104,    5,  788,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2161,  335, 1204,   39,   45,    1,    1, 2242,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3129, 1434,    1,  967,  105,  599, 1477,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1759,  309, 2193, 2592,    1,    1,    1,   45,    1, 1300,  297,\n",
      "          312,  287,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,   95,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,  215, 3102,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,   12, 1043,    1,    1,  245,    1,    1,  191,    1,   98,\n",
      "          104,    4,  420,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1190,   37,    1,  104,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  266,  251,  105,    1,   37,  973,  268,  159,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523,   61, 1018,  269, 2280,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2919,    1, 2072, 2900,   45, 1427,  851,  139,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  891,   37,  335,  224, 1787,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1077,    1,   37, 3251,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1, 2108,    1,   37, 2884, 3051,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3046, 1917,    1,    1,  582,   37,  582,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1442,   37, 2929,    1,  150,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2945, 1230,  162,  166,  173,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  232,    1,    1,  176, 1785,    1,   45, 1178,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,  640, 2275,   98,  163,    1,   12,    1,    1,  596, 1463,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  889,    1,    1,   37, 1470,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  848, 1111,   98,  754,  623,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3054, 1631,  846,  119,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1683, 3398,    1,   37, 1445, 1237, 2325,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   45, 2819,  443,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1028, 3018,   12,  354,   51,   52,  284, 2264,  504,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3364,    1, 1048,    1,   37,    1, 3358,    1, 2726,  384, 3339,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  196,  613, 1564,  259,    9, 1135,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004, 2634,    1, 2627, 2871, 1825,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3062,    1, 2107, 1383,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1699,    1, 2522,   61,  729,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1419,  282, 2367, 2695, 1614,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363, 1774,   39,  517, 1273,  259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  590, 1534,   45,    1,  142, 1976,   63,  880,  216,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  183, 1124,   45,  365, 2911,   32, 2482,   78,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  326, 1070,  147,   37,  222,    1,   43,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999, 2257, 1994, 2819, 3050,  548, 2693, 2716,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2, 422,  42, 220,   1,   1, 494,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 430,  12,   1, 474,  51,   1, 477, 428,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  632, 1273,  259, 2264,  774,    1,   37, 2980,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  261,   39,  271,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   98,  786, 1816,    1,  166,  593, 2595,    1,   10,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,  933, 1412, 2528,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1327,   37, 2498, 1185, 3273,  444,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  104,    1,   91,  907,   98,    1, 1859,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  691,    1,  191, 2772,   45, 1527, 2664, 1492,  277,  531,   12,\n",
      "          594,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,   37,   47, 2710, 1340,  191, 2020,    1, 3371,  267,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2527, 2946,    1,  276,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3200, 2551,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1645,    1,    1,  297,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232,    1,  166,    1, 3103,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 2070, 3285,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1, 1194,  401,  197,   28,  419,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3270,  884,    1, 1918,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  459, 1167,   16,  460,   12,  199,   37,    1,  105,\n",
      "          225,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3245,    1,    9, 1517,   12, 1090,  951,    1,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178,  947, 1776, 2608,   45, 2147,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  212, 1395,  768,  149, 1396,  327,  293,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2431, 2275, 1710, 1119,  442,  289, 1750,  397,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  572,  354,   98,   44,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1867,  466, 1013, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  166, 1497,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  729,  387, 1332,    1,   15,   28,  419,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3402,    1,   32,  147,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  166,  593, 1849,  777,    1,  627, 2532,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2941,    1,  321,  612, 2116,   98,    1,  698,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3248,    1,   39, 2119,  220, 3265,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  931,   23, 1909, 1090,  220, 1194,    1, 2907,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  242,  187,   69,  980,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2909, 2856,  104, 2767, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2376, 2525,   37,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  506,    1,  471,    9,  460,  389,  218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,   37,   47, 2341,  161,    1,   37,  856, 2964,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  709, 2343,    1, 1025,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1231,  220,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  107,  246,  568, 1124,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116,   96,  892,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2170,    1, 1807,   92,   32, 1069,   45,    1, 1668,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  256, 1225,  414,   37, 2655, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  624,    1,   37,   47,  669,  159,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   32,    1,    1, 1085,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  147,  261,    1,   45, 2220,    1,  963, 2122,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302, 1712,  162,   59,    1,  105,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2633,  838,   85, 3260,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3251,  190,  193,  221,   37,  316,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  418,   98,  889,  341,  509,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,    1,  546, 1461,  176, 3006,   32, 3339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  418,   98,  365, 1087,  260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2597, 1656, 2596, 2414, 2144,    1, 2766, 3094,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 1414, 2040,   98,  949,   45, 1428, 3365,   32, 3360,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1023,   45,  116,    1,  167,   52, 1792,  506,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  596,  616,    1,  504,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 2868,   12, 1596,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,  105, 1136,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2939, 1343,  808,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  199,  421,  159,   71,   98,   46,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1442, 2695, 2796,    1,    1,   12, 1046,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1712, 1354,    1, 1178, 2793,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1016,    1,    1,  498,   98, 1945,  957,    1, 2144, 3375, 2572,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3089,   37,    1,  220, 3284, 1294,    9,  920,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  883,  406,  198,   32,  385,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1149,  562,  365,  356,   24,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1581,  619, 1103,    1,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   25,   25,   28,    1,    1,  191,  185,  361, 1507,   69,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1648,   37,    1, 3036,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   85,  187,    1,   82,    1,  190, 2449,  929,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  741,   98, 1459,  804,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  770, 1976,   32,  531,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1024, 1554, 1090,  220,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 3102, 1484,  754,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1353,  219, 1107, 2610,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1013, 1522, 1059, 2017,   59,   32, 2131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,   32,  424,  593, 2522,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1345,   32, 3360, 2414,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  190,  654,   77,    7,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3144,  851,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   91,   12, 1477,  872,   61,  288,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1611,    9,  159,   32,  224,   12, 1126,   51,  439,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3177, 1627, 1178,  163,    1,  220, 1777, 2739,   32,  714,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3292, 2579, 2689,  447, 1064,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,    1,   37,  899,  284, 2673,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  331,  551,   12,   15,  701, 1258,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3051, 2696, 2386, 2751,   45, 2930,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162, 1950,  384,  649, 2817,  431,  388, 1177,   76,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  219,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2789,    1,  686,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 1105,  787, 1052,  581,  401,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   28,   98,   14,   15,    1,  303,  943,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,    1,    1,   76,   37,  865, 2697,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  365, 1090, 1667,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,    1,  583,   32,    1,  336, 1450,   32, 3101,  787,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3082, 2434,   51, 1527, 3388, 2024,  226,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2890, 1171,  288,    9,    1, 1940,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,    1,    1,  260, 1380,   98,  227, 1030,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,   37,    1, 1772,  384,  183, 1410,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,    1, 2842,   37,  160, 1729,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  851, 2421,   32,  395,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123, 1340,  140, 1909, 3212, 1624,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3012,  298,  256,   37, 2977,  317,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092, 1701,   37, 1753, 1465, 2264,    9,  111,    1, 2086,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1028,  746,    1, 1130,    1,  183, 1787,   37, 1842,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3233, 1982,  678,    1,    9,  512,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1293,  220, 3117,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1573, 1675,   32, 1658,   12,    1, 1773,   61,    1,  334,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  632,   69,  633,  155, 1356,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3180,    1,    1,   37, 1140, 1302,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3359,   90, 2789, 2751,  204,   12,  193,    1,   45,  411,  890,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,    1, 1697,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1157,    1,    1,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2179,    1,   45,  365, 1788,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,   46, 1133,   98, 2439,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230,    1, 3001,  631,  104, 1764, 1990,  872,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2835, 2041,  298, 2414,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  446,    1,  548,  985,  351,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3276,  565,  415,    1,    1,    1, 1103,    1,    1,    1, 2267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,    1, 2177,   37,    1,  302,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1436, 2908,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403, 1447,  744, 2915,    9,    1, 1700, 2789, 2673,   46,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3003,  794,  552,  552,  912, 2285,  822,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2190, 2640, 1822,  125,   81,   98, 1011,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3337,    1,  411, 1477, 1990, 1798,  220, 2523,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   12, 1065, 1190, 1648,  193,   37, 1260, 3155,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1095,   37,  423,   48,   32,  258,  700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  770,    1,    1, 1821, 1697,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  261, 1812,    9,  858,  297, 1021,  847,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870,  353, 1455,  197,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  105, 1173,  176, 3194, 3195,    1, 1794,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 3384, 1900, 2253,   37, 2856, 3365,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2022,  806,    1,  602,   12, 2212, 2746,  664,  171,  863,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2832,    1,    1, 1140,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1, 1087,  289,   98, 2206, 1499,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2929, 1292, 1283,  884,    1,   37,  147,  297,  844,  663,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2425,   37,  130,  861,    1,   48,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1236,  297,    1,  768,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   28,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 2822,    1,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 2460, 1827,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  828, 2360, 1961,  751,   37, 2949,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2329,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196,  315,   37, 1901,  845,  846,   29, 1074,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  236,  237,  407,  187,   69,  102,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1531,  135,  787,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  550,  369,    1,   37, 1706,   32,    1, 2152,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247, 1880,  865,    1,  191, 1987,   37,    7,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  377,  249,    1,    9, 1107, 3049,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  565, 1764, 1990, 2069,    1,    1,  267, 3230,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  542,  698,  777,  778,   37, 2263, 3240,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  361, 2707, 2392, 2507,  132,   98, 2927,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  187, 3177, 2744,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2718, 2653,    1,    1,    1,  176,  613,    1, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  187, 1220,  418,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 1177,    1, 2454,   32,  197,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  398,   90, 2863,  163,  321,  612,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1551,  361, 1610,    1, 1976,  176, 2662,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1676,  446,  738,    1,  101,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  437,  213,   32,    1,   37,  151,  849,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  647,  470,  166,    1,    1,  111,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  632,  104, 2640, 1542,    9, 1539,   37, 1821, 2190,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1251,   45,  585,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2948,    1,  168,   98, 1616,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  927, 2156,   32, 3402, 3408,  400,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2764, 2765,  650, 1082, 1450,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2238, 1731, 2019,  132, 1894,    9,  657,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  485, 1948,    1,  103, 1499,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2974,  140,  152, 2695, 2223,  220,  892,   12,   95,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3245,    1, 1414,  885,  411, 2022,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 1285,   28,   98,  531,  532,  533,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,  267,  460,   12,  193,    1,   45, 1428, 3146,    1,  909,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  503,    1,  260,    1,  297,  749,  480,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2140,  134, 1700, 2764, 2765, 1634, 3006,    9,    1, 2950,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  691,   12, 2911,   37, 1543, 1813, 1481,    1,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,  958,   83,   37, 1910,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  344, 1656, 2596,   32,  531,   12,    1, 2414,  947,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  636,  176, 1816,  220, 2979, 2869,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  990,    1,    1,    1,    9,  923, 2405,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  411, 1844, 2392, 1918,    9, 2570,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3169,  140, 1183, 2921,    1,  300,  104,   26,  304,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3245,   61,   98,    1,   12, 2521,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3230,  951,    1, 3204,  167, 1291, 2809,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,  594,  197,  157,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3160,    1,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226,    1,  182,    1,  331,    1, 1830,    1,    9,  869,   45,\n",
      "          365, 1635,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  107,   37,    1,  805,   45,  104,  806,   98,   69,  102,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1, 1313,  220,  395,  297, 2949,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2065, 1832,   32, 1090,    9,    1,  891,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3349,   12,  650,  267, 3362,   61, 2072, 2292,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  356, 1691,  294,  513,  514,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  987, 2014,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  758,    1,  244,   32,  401,    1, 2645,   37,  224,  159,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2863, 2593,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1206,    1,    1, 1070, 1309,   37, 2122,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1293,    1,   45,    1,  187,    1,    1,   45,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  326, 1614,    1, 2544, 2232, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147, 1707, 2180,    1,    1,  146,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3231,  335,  631,  297, 3232,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  861, 1906,    1, 1994, 2834,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,  593,   32, 1658, 2473,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  213,   37,  875, 1370,   45,  961,  573,   43,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  565,    1,  166, 2615,    1,  612, 1188,  424, 1090,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766, 2061, 1343,   98, 2627,    1, 1863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1652, 1564,  197,   32,  572,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  901,    1, 1658,  259,    1,  105,  454,   39,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  294,    1, 2753,   32,    1,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  967, 1658,  327, 2626, 2026,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2578,   51,   52,   98,  166,  222,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  193, 1762,   98, 1256,    1,  705,    1, 2136,  132,    1,\n",
      "           82,  267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  982,   32,  356,   24,  881,  220,  180,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2662, 2699,   37,  362, 3024,  215, 1017,  190,  764,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,    1,    1, 1479,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  794,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1485,  379, 2096,  716,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  221,  640,  667,    1,   25,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1140,    9, 1118,   32,  568,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3345, 2253,   37,   38,  297,  487, 1527, 2664,   37, 3381,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  688, 3268,   32, 2138,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,   37, 2225,   82,  191, 1014,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051,  675,  156,   71,    1,  225,  338,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,    1, 2035,  631,  176,  103,   45,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1662,    1,    1, 1530,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3160,  267, 2047,    1,    1,    1, 1590,   32,  403, 1447,\n",
      "            9,   56,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,    1, 1485, 3365,  254,    1,  227,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092,    1,  297, 1411,    1, 1935, 2146,   32,  792,    1, 2304,\n",
      "          792,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2991,    1,    1,   12, 2524,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  340,    4,   93,    1,  104,   25,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1645, 3065,    1,  582,   32,    1, 1313,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  686,  220,  331,  574,  399,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2899, 2790,  292,  822,  912, 2285,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,    9,  793,    1,  469,  547,  537,  548,   86,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1349,  267, 1384,  509,    1,  187, 3141,  914,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  592,  155,  157,   98,  121,  954,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  992, 1159,    1,    1, 2166,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  500,  155,    1,  570,  548,  636,  125,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1594,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2567,   37,    1,    1,    1,  267,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1423,  556, 1484,   37,    1,   39,  116,  126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2315, 1262,   81,    9, 2551,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   28,  115,   45,  156,  716,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504,  446,    1, 1193, 2527,  164, 1953,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  684,  734,  102,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2070,  288,   37, 2354,   32, 2579,   45, 2468,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  856,    1,  220,    1,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  777, 2141, 1013,    9,  166,  917,  357, 1827,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1472, 2808,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2802,  140,  593, 1990,    1, 2107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  501,  827, 3227,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  475,   45,  352,   50, 2556,  103, 1569,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2004,    1,  325,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2227,    1, 1417,    1, 1417,    1,   12,  475,   96, 1159,    1,\n",
      "            9,    1, 1833,   37, 1412,  844,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788, 2685,  872,  420,  385,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2110,   98,    1,  187, 3322,  664,  857,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  195,    1,  580,  163,    1,   12,    1,  147,   32,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1433, 1778, 2385,  612,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3003, 1236,  388, 1107,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2631,  837, 2925,  119,  424, 1034,    1,  166, 1879,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1630,  533,   37, 2716,  615,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1205,    9,    1,  605,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,   12,  365, 2452,  460,   12,  810,   32,  166, 1616,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 2414, 3384, 2556,    9, 3380,  722,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3099,   37,    1, 2189, 1054,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386, 1654,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 1756,  167,  915,  537,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3352, 2564,   37,  335, 3383,  947,  353,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,   42,  573,  400,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  857, 2286,  515,    1,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  938,  796,  187,  941, 1201,    1,   82,  115,   45, 1379,  522,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  744,  365,  647, 2187, 1757,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3260, 1529,  182,   12,  472,   39,   45, 2467,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2751,  222, 1054,    1,   37,    1, 1633,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1088,  446, 1550,  132,  220, 3398,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1520,  361,  848, 1303, 1604, 2444,   98,  517,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  597,    1, 2778,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  169, 1084,  731,    1,  191,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1345,  556, 1527, 1149,   32, 3118,  384,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  108,    1,    1, 2239,  565,    1,   37,    1,   45, 1108,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  393,  672,  541,  384,    1,   37, 1959,    1, 1960,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3322,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1516, 2550,    1,    1,    1,    1,    1,    1,    1, 1000,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  729, 1625,   37,  875,  220,  342,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  256,  111,  834, 2560,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1347,   98, 2175,   81, 1411,  356,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   32, 1119,    1,  964,  267,  204,  190,   81,    1, 3144,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2881,  267,  829,  190, 3159, 1158,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1981,   32,  166, 2925,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  437,  396, 2772,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  503,   82, 1877,  700,  190, 1878,  749,  480,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  494, 1599,  210,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  820,    9,  617,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181,    1,  982,   32, 1339, 2788,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3117, 1066,    1,  220, 3271,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,  245,    9, 1524,   74,  472,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  202,  829,   14,  525, 1702, 1718,    1,   26, 1039, 3031,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   46,  220,   20,   98,  296, 1859,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051,   37,   47,  845,  439,    1,  220,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 3118, 2024,   46, 2317,  187, 2751,  489,   39,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3246, 1086,  632,   36, 3071,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3057, 2645,    1, 2977,    1,    1,  405,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  261,   39,  715, 2924,    9,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   12,  999, 1892,   37,  714,   32,  163,    1,   12,    1,\n",
      "            1,   91,   98, 1332,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2448,  386,  460,   51,    1,  214,  693,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 3210,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2236,  992, 1415,   37, 2792,  512,   12,  389,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,   37, 2243, 2869, 1107, 1863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  550,  369,    1,   51,    1,  301,    1,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  619, 2474,    1, 1123,  698,    1, 1958,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  119,  293, 1236,  542,    9,    1,    1, 1107,  384,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  168,  115,    9, 3342,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1163,   12, 2073,  401,  156, 1253,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  794, 1159,  111, 1107,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3375, 2572,   32, 3339, 2625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,   22,  298,   95,    1,   51,  193,  764,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  936,    1, 1085,    1,    1,  176,    1,  361,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1778,  659,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,    1,  647,    1,    9,    1,  693, 1757,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  391,    1,  733,   45, 1537,   81,  756,   50,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  261,    9,    1, 1715,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1953,  220, 3151, 1411, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  159,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  331,    1, 1250,  901,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2712, 2660, 1623,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2977,  396,  365, 2334,   61,  593,   12, 1254,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32,  395,  851,  298,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  566, 1691,    9,  777, 1704,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2053, 2055, 1376,  995,   32,  871,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    5,  125,    1, 1465, 1466,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,  580,    1,    5,  302,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1307,  315,  365,    1,    1,  659,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  386,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 2924,  297,  563,  564,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37,  631, 1764, 1990,  872,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,   37, 1539,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004, 1087,    1,  132,  220,  626,  700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2826, 1077,  167,    1,   98, 2325,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  294,   37,   44,    9,    1, 2247,  325,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  613,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2341,    1, 1805, 2872,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  307,  166, 2579, 3201,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2095, 2985,    1,   32,  487,  147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 696,   1, 856,  81,   1, 688,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 647,  26,  37, 148, 142, 940,  88,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1061,    9, 2638, 2931,   32,  691,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,   66, 1782, 1298,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  561, 1152,   98, 1763,  361,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2527,  164,    1,  640, 2573,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  573,  469,   11,  662,    1,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  293,   12,  449, 2474,    1, 1102,  841,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  502,  492,  491, 1041,   59,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,   32,  123, 1838,   32,    1, 2823,  741,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,    1,  419,    1,   48,    1,  159,  554,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226, 2112, 2226,    1,  105,    1,    1,  202, 2226,    1, 2226,\n",
      "         1188,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   76,   37, 1776, 1888,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  475,  167,    1,    9,  333,  297, 1126,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3214,  744,  640,  119,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2227, 2954,  469,  413, 2522,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,  407,  187,  166,  517,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,  166, 1690, 1691,  724,    9, 3326,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1497,    1, 1306,  105,  688,  220,  166,  260,  320,   32, 2866,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,  667,   26,  191,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3073,  872, 1554,    9,  854,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  884,  297,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32, 3123, 2857,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967, 2961,    1,    1,  202,  190, 1343,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3079, 2712, 2838,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2217,    1,   37, 2225,  365, 1277,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  449,  671,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3274,  140,   98, 2457,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  409,   25, 1285,   28,  242,   60,  338,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3003, 1536,  365,  912,  605, 2039,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  706,    1,  395,   12,    1, 2789,   12,  469,   37, 1155,   28,\n",
      "          453,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1664,  459, 1700,  356,  881,    1,  872, 1564,  440,  765,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1810,  365,    1, 1211, 2878,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1281,    1,   98,  776,   45,  182,    1, 1417,    1, 1920,\n",
      "         1988,   45,    1,  344,  963, 2122,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  571, 1642,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  624, 1359,   45,  224,   12,    1,  380,  669,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  915,    1,  211,    9, 2695, 2223,  413,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,   25,   71,  978,  769, 2139,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  764,  912,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 3381, 3006, 1260, 1147, 1583,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  566, 3140,   12, 1527,   32,  531,  861,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1477, 3009, 1685, 1981,  856,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1804,    1,  698,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 1117,    1, 1417,    1,  108,  460,   51,  100,   98,\n",
      "          597,  655,   45,  381,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  138,   59,   37,  875,  134,  297,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  700,   12,  505,  195, 1812,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  524,  525,   15,   71,   32,  166,  645, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 1613, 1508,  132,    9, 1273, 2215, 1085,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  350,    1,    1,  661, 2275,   12,  233, 1311,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  256,  647, 1499,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 113,   1,   1,   9,   1,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 166,   1,  45,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2551,  335,  411,  631,  548,  449,  401,   45,    1, 1990,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2634,    1,    1,    1,  766,   37,    1,  877, 2738, 1395,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1974,  506,   98, 2332,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  811,  387, 1516,   32,  395,   12,  996,  120,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1712,  829,  794, 1106, 1107,   32, 2144,  365,  497,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1270,   59, 3157,   37,    1, 3093,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,   38, 1176,  445,    9,   10,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  879,  693,    9,  647, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1652, 2369,    1,  956,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1348,  119, 2098, 1844,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  746,    1,   37,  125,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  267, 1094,  729, 1969, 2024, 2041, 2655,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  715, 1113,  418, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  295,  972,   37,  439,  573,  315,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  487, 2162, 1950,   32, 2734,  139,  418,   37,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3314,  140, 1326, 1990,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  741,   85,  469,    9,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,  703,  411,  631,   32, 3343, 1002,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2087, 2614,    1, 3079,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1,    1, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  197,  407,    1,  202,    1,  245,   98,  408,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1, 2743, 1141,    9,  103,  787, 1323,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  848,  794, 1107, 2308,  220, 1234, 1876,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973,    1,  770,   12,  756,    1,    1,    1, 2713,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  395, 1465,   13,  835,  326,  327,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  166,    1,    9, 2423,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  447,    1, 1670,   37,   62,    1,   32,  557,  540,    1, 2489,\n",
      "           85,    1,  808,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  327,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1043,  697,   37,  245,    9, 1194,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,  195,  293,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 2373, 2229, 2402,    9,  282, 3031,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1647,   61,    1,   32,  903,    1, 1423, 2024,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  766, 2061, 1343,   98, 2627,    1, 1863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,    1,  600, 2193, 1283,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   15,  619,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102, 1473,  530,  105,  106,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2888,  640,  878, 1688, 1465,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2925,   13, 2753,    1, 2800,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1584,   39,  105,    1,    9, 1509,    1,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2321,  680, 1665,  384, 1178, 1532,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  457, 2328, 2728, 2034,   59,   32,  365, 1821, 2107,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2335, 1231,  297, 2473, 2921,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,  859,   37,  221,    1,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676,   36,  336,  298, 2414, 1312,    1, 2803,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1804,  247,   38, 2552,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2604, 2923,    1, 1411, 1034,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  572,  105,    1, 1663,  475,   98,  596, 1509,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1757,   98, 3118,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,   66,  526,   29,    1, 2163, 2357,  343,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,    1,   32, 2589,  220, 1050, 2153,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  344, 1260, 2414,   32, 1094,  583,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,  368,    1,  114, 2414,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  796, 3103,    1,   37,    1,   32,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,    1, 1565,    1, 2645,   37,  510,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   12,  462, 1287,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428,  903,    1, 1447,  300, 1894, 1263,   98, 3032,   46,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2226,    1, 1745, 1846,  320,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  359,    1,    1,   37, 2051, 1001,   51, 1154,  393,   22,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 2227,    1, 1007,    1, 1974, 1751, 1056, 1675,    9,\n",
      "          195,  400,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2269,    1, 2348,  798,    1,   85,   98,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  487, 2548, 2844,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777,  779,  861,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1353, 3019,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  113,   79,    1,   37,  726,    1, 2802,  833,  612, 1838,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  122,  600, 2527,  164,  335,   95,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  202,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2334,  653,    1, 1631,  846,  119,    1,  326,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708,    1,   37,    1, 1964,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1833,  830,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 2073, 1023,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  258,    1, 1938, 2607,  382,    1,  166,   16,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  858,  640,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2094, 1228,   37, 1718,   98, 1021,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3389,   32,    1, 3038, 2137,    1, 2083,  105,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1186,   12, 3355,  267,  531,  890, 1822,  168,  115,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  197,    1,  108,   98,  308,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 593, 830,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 590,   1,  32,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  882,    1, 1307,  776,    1,  589,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91, 1554,  163,    1,   12,    1,    1, 1477, 1990, 2268,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  668, 1701,   37, 1753,  116,  912,  239,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  361,   10, 2228,   79,   98,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  579,    1,    1,    1,    1,    1,  506,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100, 2055,    1,    1,  769,   37,   17,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2807, 3321, 2347,   32,  354,   37,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403,  464, 2404,  267, 2960, 1924,    1, 1585,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1718, 1542,    9, 1065,  199,    1,  657,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593, 2153,    1, 1527, 2664,   12,    1, 1887,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  968,   12,    1,  315,   37,  439,  593, 3136,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 1656, 3403, 2414,  176,  177,   32, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3317, 1542,    9, 3262, 2457,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  612,  868,   80,  802,  220, 1842,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1545,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   90,  398,   45,    1,   32, 2319, 1778,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  550,   32,  870,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  338, 1315,  105,  106,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  702,  333,   30, 1056,    1, 1560,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2163, 2501,  861,  681,   37, 2123,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  586,  496, 1441, 1230, 2692, 1601,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  253,  606,    1, 1944,   98,  148,  142,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  852, 1750, 1972,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,   37,    1,  527,  142,   37,    1, 1384,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3115, 2125,  439,    1,   39,    9,  356,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  961,  147,   37, 1709,  829, 1377,   45,  116, 2542,  400,  327,\n",
      "          593,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  691,  762,  310,    1,  220, 1183, 2320, 3162,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1107, 1085, 2277, 1018,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3227,    1, 2563,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  573,  639,  353,    1,  182,  448,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2106, 2409,    1,  187,    1,  741, 1010,  997,   45,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  456,   85, 1640, 2003,  548, 2041, 2782,    1, 2357,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2942,  140,  449, 3126,    1,    1,  140,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  519,  631, 3250,   32,  601,  401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2178, 2921, 2164, 2414,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3344,  220,    1,    1,    1,   98, 1030,  260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788, 1215,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758, 1675,  361,    1, 2274,    9,  772, 2943,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  460, 2664, 1161,  884,  105, 1269,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,   12,    1, 3032, 1021,  250,  580,  388, 1118,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,   61, 2626,  187,   33,  614, 1159, 1601,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303,    1,  600, 1619,  458,    1,    1,  108,   98,  104,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 466, 275,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 563, 564,   1,   9, 815,  98, 541,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2275,   37, 1260,   10, 2128, 2129,  469,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1061,    9,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1710,  865,   37, 2875,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  742,  578,    1,  191, 2410,   46,  220,  365,  458,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   93,   61,    1,   37,  183,    1,    1,  448,  104,  232,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1679,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2, 303, 217, 565, 198,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1577,  155,  570,    1,  225,   28,  419,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550, 1691, 2261,  565,    1,    9,   29,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  183,  631,    9,  316,  187,    1,  556,  754,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  581,  401,  197,   28, 1146, 1703,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  914, 2740,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  744, 1251,  125,  469,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1808,    1,    1,    1, 1077,   98, 1095,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375, 1542,   37, 1604,  220, 2330,  104,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1861, 1484,    9, 1945,   37,  856, 2834,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3069, 1426,  630,   98,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3310, 2034, 1022, 1918,   98, 3258, 2579,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 1542,   37, 1046,    1,   12, 1107,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   11,    1,    1,    1,   12,   13,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1,  220,    1,  155,    1, 1810,  284,    1,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1298,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  705,    1, 1187,  460,  247,  454, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  365,  754,   15, 2107,   37,   72, 1637,   98,  119,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1005,    1,  284,  137,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  822,   92,    9,  829,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,   69,  393, 2024,   46,   37, 1195,  548, 1302,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  424, 2955,   61,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2882, 3192, 2671,    1, 2802,  928,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1470, 3048, 2923,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2551,    1,  706,    1,  187, 3227, 2222,  619,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  284,  442, 1515, 2387,    9, 1656,  286,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  459,    9,  166, 1034,   45, 1332,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2879, 3151,  914,   37,  686, 2378, 1704, 1089, 1675,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  442,    1,    1,   32,  273,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3367, 1830,   37,  429,  863,   37, 1504,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  366, 2855,   32, 3343,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2335, 3361, 2844,   32, 1656, 2950,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962,    1, 2781,   32, 3117, 1918,  297, 3296,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1211,  538,  952,  105,  365, 2294,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1644,    1,   37,  930,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  579,   12,   32,  105,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,  451,    1, 1887,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  125,    1,    4,  481,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1412,  754, 1993,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 2165,   63, 1104,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1717,    1,    1,  159, 1374,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  197,    1,  983,  418,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  954,   69, 1611,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   49, 1685,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2213, 1567,    9, 3141, 3009,  187, 1444, 1046,    1,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  297,  548, 3313,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1431,    1,  829,  872,   98,    1,  535,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1273,  618,   37,  619,  844,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2890,  947,  114,    1,    1,  176, 2868, 2832,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32, 2484, 2771, 2954,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1005, 2737,   12,    1,  967,    1, 1857,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3226, 3263,    1,  885,  938,  661,    9, 1531,   12, 1521,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3281, 1408,  340, 2395,   98,  865,   37, 3314,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  177,  228, 2708,    1, 2572,   32, 2426,  220,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   99,  475,  108,   98,   69,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,  856,   81,   37,  688,  602,   32, 3116, 3217,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2049, 2671,    1,    1,  928,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2232,    1,  105,    1,    9,  284,   29,  656, 1182,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2677,  547, 2954,  729,   32,  166, 2884,   32,  437,  182,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1925, 1583,  862,    1, 1000,  365,    1, 2165,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 1440,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1796, 1866,    1,  187,    1,    1, 1884, 1950,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  108,  310,    1,   45, 1718, 2039,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2005, 3260,   37, 1090,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1076,  671,  572,    1,  354,  307,  689,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3202,  395,  193, 1542,   37,    1,  384, 3141,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  125,    1,    4,   32,  283,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1325,  434,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,   12, 1230, 2528,  166, 1411,  183, 1265,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  622,   92,   51, 2200,  555,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68, 1784,  115,   45,    1,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2523,   61,  577,    9, 1411,  356,  548, 1141,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1662,  293,    1,  365, 1017,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3236, 2872, 3266,   32,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1222,  934, 1380,    1, 2261,   37,  227,  272,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1186,   12,    1, 1861, 2450,   37,    1,    9,  531, 2299,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2702,    1, 2456,  891,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1733,   12,  463,  294, 2579,  155, 1625,   45,  649,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779, 2853,   28,   37,  689,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  105,  628, 2775,   45,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,  539, 1037, 1036,   37,    1, 2771,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  515,  365, 2036, 2507,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  952, 1378,  158, 1119,   32,  225,  469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  571, 1717,    1, 2911,   81, 3153, 2220, 1281,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1433,  166, 3389,    1, 1079, 1853, 2832,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,  365, 3241,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2118,    1,  444, 1076,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,  292, 1718,  297, 1778,   32, 1033,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  338,   98,  365, 1220,  157,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,    1, 1747,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299,    1,   28,  220,  410,  932,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1640,  844,   30, 1748,   45, 1178,    1, 2793,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1038, 1149, 1575,   39,  297,  138,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  845,    1,  580,  133,  134,   32,  104,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790, 1187,    1,  861,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  275,  293, 1066,   32,  453, 2179,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1717,    1, 1008, 2161,   12, 3134, 2565,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1808,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2433, 2388, 1558,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  215,    1, 2421,   32,    1,    1,    1, 2640,  898, 1530,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   25,   71,  202,  800,   29,  817,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  546, 1084, 1682,  297, 1482,    1,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98, 2441,  187,  737,  244,  271,   54,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1861, 1550,  531,  317,  443, 1803,  304,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3021, 1558,  191,  872,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  389,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2061,    9, 1743,  548,    1, 1579, 3339,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2227,   37, 1031, 3275,  261,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,   51,   52,    1,   37,  546,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  449,    1, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2809,  696, 3231,   26,  547, 1090,  631,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,  259, 2101,    9, 1204,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 1213,    1,    1, 1996,    1,   12, 1173,  176, 1405,   12,\n",
      "          132, 1809,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,  159,    1,    1,   71, 1503,  129,    1,    1,  245,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  267,  996,   93, 1071, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3363,  859,   37,   33,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   25,  554,  548, 1986,   98,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2274, 1707,    1,   12,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,   28,  951, 1547,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2590,  390,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1607,  231,  105,  984,    1,  368,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   72,   73,  354, 1554,  104,  810,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  526, 2410,   66,  548,  642,  643,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  105, 1972, 1228, 1108,  313,   37,    1,    1,  161,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1386,  575, 1046,  845, 1245, 1879,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1405,  175,  132,  220,  373,    1, 1924,  105,    1,    1, 2173,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1489,  957,  221,   98,    1,  809,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,    1,  265,   45,    1,  361,  970, 1426,  104,    1,\n",
      "          372,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 3109,  297,  105,    1, 3043, 3006,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  275,    1, 2577,  693,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1,  183,  600,  803, 1244,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2706,  313,   37, 1864,  283,  191,  439, 2020,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,  777, 1085,  861,    1, 2123,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1671,    1,  191,   27, 1306,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   51,  720,  647,   43,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1124,  792,    1,  792,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  697,   37,  877,  247,  865,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2396, 1625,    9, 2003, 1211,  593,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 1537,    1, 1815,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 1358,   98,  557,  442, 2011,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  915, 1886,   98, 1108, 1779,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  580,    1, 1798,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994, 2650,  302,    1,  191,  433,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1237, 1658, 1117, 1525,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  235,  661,   98,   25,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3281,    1,    9, 3181,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2954,    1,   37,  125,  408,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,    1,    1,    1,    1, 1033,  597,  455,    1, 2677,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  945,   69,   50,    1,  880,  529,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  424, 1034,   32,   80,  550,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2726,    1,  220,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2549,  820,   37,    1, 2987, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,   12,  183,  996,  712,   61, 1411,   65,  475,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1425,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2528, 2896,    1,   37,   47, 1662,  361, 2616,\n",
      "          112,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  166,  914,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  361,    1,  912,    9, 1211,  639,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3359,  476,   37,  846,   28, 3339,  469,  178,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2406, 1625, 2024,  226,   37, 1348,  365,  446,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  964, 1579,  170, 1813,  462,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  846,   28, 2343,   12,  776,    1, 2877,   90,  147,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   65,  996,   93,   98, 1171,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1788, 2685, 1140,  550, 1929,    9, 2283,   76,   37, 1012,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   79,  396, 1167,  331, 1924, 2845,  297,   37, 1211,\n",
      "         2161,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2930,    1,    1,   32, 1029,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  393,  359,    1,   98, 1251,    1, 1907,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1845,   24,    9,  386,  359, 2011,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3186, 3176,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2327,    1, 1944,   45,    1,  361, 3138,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  202,  884, 1096,    9, 2667,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  485, 2243, 1651, 1597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,  750, 1167, 2810,  166,  302,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2613, 1589,  123,   37, 1273,  132,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 314,  37, 877, 589, 388,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1,  32, 531,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2, 398, 261,  32,   1,  45,   1,   1, 741,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 657,   6, 983, 157, 225, 338,  88,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  179,    1,  180,   37, 2123,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3086, 2924, 1237, 3114,    1, 3114,  379,  774,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  338,    1,  889,  529,    1,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2834,    1,  734,    1,  297,  691,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,  909, 2099,   98,  104,  532,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3267,    1,    1, 1758,   37,  136, 3217, 2069,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  639, 2576,  593, 1011,   74,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 1090, 3039,   12, 3040,   61,    1, 1159, 1465,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978,  769,  670,  187,  425,  426,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  411,    1,  515,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1, 3406,  583,   32, 3349,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  622,  134, 1056, 2548,  220, 2772,   45, 3361,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1116,  614,  845,  275,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2049, 1108,   37,  125,  460,    4,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3335, 2226,    1, 1846, 1284,  460,  810, 1514,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,   12, 1009,   61,    1,   37, 1417,    1, 1117,    1,  405,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1479,  647, 1379, 1360,  612,    1,  159,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,    1, 1790,  872,   28,   98,  365,  777, 1085,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1237, 1658, 1117, 1525,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,  361, 1790, 1749,    9, 1013,    1, 1274,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   59, 1778, 2580, 2851,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 1243,  365, 3017,    1,    1, 2043,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  225,  431, 2284,   98,  716,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056,    1,  494,    1,  393,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1457,  782, 2738, 2508,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1484,    9,    1, 1663,  947,   37, 3118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 1251,   45, 2440, 1943,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2997, 2988,   61,  103,   45,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  159,  245,   98,  572,  983,  304,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390, 1426,  132,  220,  587,   37, 1066,  700,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,  459,  131,  861,  673,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1018, 1601,   98, 2527,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3180,  176,  915,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2668, 1081,   12, 2197, 2147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 1030,   32, 2846,  202,    9,  203,  445, 1400,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 2572,   32,  539,  458, 1461,  477,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1092,    1,  848,   12,  365, 1935, 2294,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1035,  113,   39,  753,    9,  487, 3222,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 2586,  187, 2939, 2202,  166, 2107,   45, 1922, 1204,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  786,  356, 2248,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  506, 1656,    1, 1253,  548, 2095, 1450,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 2455,  443,   32, 3367,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,  613, 1258,  832,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,  496,   10,  227,    9,  486,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1485,  793,  669,  213, 1460, 1384,  132,  220,  442,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,  321, 1230,  220, 2455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094, 2386, 3140,   45,    1, 2834,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1, 1092, 1701,  875, 1350,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   75,   37,  771,    1,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3186,  335,    1,  631,   32, 2038,  922,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   84,   85,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   17,  726,   32, 2079, 2718, 2107,   37, 1718, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  766,   72, 2789, 1102,    1,  595,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  275,    1,    1, 2243,  809,    1,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  123,   28,   98,   14,  170,  202,   79, 1653,   98,   69,\n",
      "          636,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  600,  917,    1,    1, 1221,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  614,   37, 3225,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32, 2328, 1260,   98,    1, 1606,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  167, 2394,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,    1, 1941,   32,  547,    1, 1450,   32,  854,   12,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141,  892,  428,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2220, 1187,  193,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  340,    1,  972,   37, 2856,    1, 1743,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1110,  619,  332,   45, 1264,  841,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 3131,  509, 3132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   66,  526,    1,  195, 1091,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2729,    1,  254,    1, 1690,  454,  187, 2990,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1171,  361, 2498,  183, 2539,    9,    1,  683,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613, 1550,    1,  327,    1,    1,   45,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1215,  624,    1,   37,  151,   48,   32, 1211,  273, 1603,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1, 1031,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,    1, 1058,  700,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1013, 1522, 1441, 3153, 1659,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1464,   37,  665,   28,  460,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  526,    1,  642, 1278, 1308,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    9,    1, 1005,    1,    1,  460,   12,  810,   32,  166,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37,    1,  333,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1484,   98,  864,   37, 1806, 2390, 3366,  315,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2802,    1,  119,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3260, 3330, 1554, 1090,  444, 3233,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  262,  263,  422,  927,  703,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2507,    1,   95,    9, 2977, 3054, 1532,   32, 1252,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1093,  574, 1396,  355,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  640, 1844, 2907,    1, 3117,  688, 3260,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  331, 1067,    1,   29,  132,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1404,   45, 1405,   12,  508,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2939,  696,  519,   37,  449, 1918,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1339,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1, 1315,   37, 1034,  340,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  700,   61,    1,   32,  290, 1159,  137,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1194,    1,    1,    1,  967, 2632,   28, 2056,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  105, 1264,  786,  444,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1474, 1458,   79, 1665,   37,    1,  352, 1469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1100, 1784,   98, 1128,   12, 2232, 1151, 1184,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3381,  437,  396, 2877,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  952,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 1976, 1530,   32,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  647,    1,   81,   37,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1440, 3082,  162,  412,   37,    1,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3079, 2763, 1364,    1, 1009,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1966,   12, 1818,  147,  919, 1899,   12,    1,  384,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  993,  302,  967, 2179,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310,  225,  616,    1,  792, 2193,  112,  792,   10,  631,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  327,    1,   37, 1427,  191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 2263, 1532,   32, 1051, 1039, 2690, 2607,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 2334, 2545,    9,  166, 2814,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   61, 2491, 1140,  176,  166, 2826,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1211, 2460,  919,    1,  297, 3194, 3195,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,   45, 2849,    1, 2107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2618,    1,  608,  602,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   42,  134,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  217,    1, 1515, 2089,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3128,  104,   37,   77, 2647,    1,   98,  464,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  409,   25, 1376,   98,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1640,    1,    1, 1306,  593,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1023,   45,  104,  777, 2264,  920,   98,  858,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1082,   62,   98, 1430, 2735,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2151,    1,   69, 2014,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,  267,  282,  232,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  189,  207,   12,  389,    6,    1,    1,   32,  104,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  147,   37, 1709,  912, 2285, 2096,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,   12, 1448, 1512, 1414,    1,   37,  125, 1656, 1069,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3134,  163,    1,   12,    1,  140,    1, 2468, 1426, 3220,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2677,   45,    1, 2232,  820,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,  166, 2488,  774,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1178, 1179, 1831,  476, 3092,    1,    9, 1545,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403,  464,  535,  720, 3203,    1,    1,   12,    1, 1684,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  156, 2393, 1307,  387,  417,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  462,  159,    1,  118,  242,    1,    1, 1884,   11, 1258,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2977,   12, 2815,  469,    1, 1746,    1,    1, 1821, 2190,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1138,   37,  125,  600,    1,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  877,   28,    1,  885, 1265,  166,    1, 2768,    9,  104,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035,  894, 2810,  917,   32,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2008,  597,    1,  609,    9, 1204,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   25, 1758,   98,   69, 1253,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  373,  197,  338,    1,  596,  616,   85,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2227,  872,   37, 1237, 2227,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   65,   12,    1, 1082, 2324,    9,  673,  910,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  975, 1249,    1,  689,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  119,  515,    1,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2321,  167,   77, 2332,  384,   36,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 388, 585,  51,  52,  98, 454, 428,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 657, 302,   1, 113,  39,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   14,   15,   16,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403, 2778,   37,  907,    9,  241,   46,   98, 2024,  226,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1189, 3382,  577,   98,    1,   45, 2673,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  716,  136,   51,  836,  134,   32,    1,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3247,  361, 1497, 1000, 2941,    1, 2072, 2009,  590,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1, 2097, 1789,    1, 2405, 1159,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2430,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,  176,  103,   45, 1561,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1020,  191, 1020,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,    1,  191,  293,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1128, 1203, 1021,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,   12,  648,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  129,    1,    1,    1,    1,    9, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1, 2605, 1539, 2673,   46, 1670, 2143,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   12,  535,  656,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3092, 1717, 1717,    1, 1658,  327,  220, 1018,    1, 2693,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1107,  293, 1310,   37, 1073, 2733,   85,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1366, 1188,  388,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  365, 2764, 2765, 1928,   61,  820,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340,  167,  606,    1, 2644, 2901,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1572, 1414,    1,  674,   32, 2774, 1147,\n",
      "          787,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496,  388,  960,    1,  858,  412,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  215, 1352,  442,  448,   32,  643,  703,   37,    1,  372, 2097,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2726,  134,  187,    1,  619, 2478,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2984,    1, 1551,  361,  786,    1,    1, 1056,    1,    1,  176,\n",
      "         2662,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2321,    1,   39,  220,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1711,   32,  584, 2449,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,   12,    1,    1, 1633,  538,   37, 2123,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1773,  267,    1,   61,  227,   32,    1,   28, 2510,  378,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2055, 1107, 2610, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1498, 2360, 1099, 1453,   12, 2089,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492, 1140,    9,  439,   37, 2292, 1010,    1,    9, 1919,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2018,   12,  695, 2789,  396,  726,   32,  741,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1855,    1,  957,  796,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 3310,   12, 1435,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  493,  636,  720,  376,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1537, 2281, 2572,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  433,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2902,   32,  132,  220, 1051,   32,    1,  973,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2123,   37, 1865,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3175,    1,    1,    1,  193,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  313,    9, 1056,   32,  105, 1559,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2975,    1,    1,    1, 2119,  411,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  207, 1446,    1,   84,   28,  166, 2026,  126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98,  136,   12,    1,  151,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  181, 1886,   32, 3020,  776,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  111, 1107,  614,   81,   37,   36,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  398,  213,   37,    1,  941, 1201,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2193, 2579,  288,    9,  220,  357, 2198, 2579, 2689,  447,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,  590, 1048, 2108, 1534,   98,  864, 2673,\n",
      "          210,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226, 1924,    1,   32,  166,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3213,  695,   39,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,  551,  552,  376,  507,  539,  157,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   67,  418,  167, 1937,  433,  102,  701,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  338,  118,   63,  862,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1933,  225, 1137,   98,  170, 1801,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,    1, 2707,   37,  429,    1,   46, 1411, 1352,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  905, 1680,  156, 1470,    1,  752,  693,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3138, 1451, 3062,  449,  671,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  681,   32,   46,   37,  439, 1622,    4, 1313,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523, 2383, 1787,    1,  162,  247, 1090,   81,   98,  837,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2162, 1665,   37, 1855, 2886,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  376,  367,   15,  570,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3186, 1863, 1631,    1, 2408,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,    1,  183, 2759,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2754, 2375,   13,  459,  132,  220,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  195, 1812,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2962,    1,  919,  730, 2614,    1,   37, 2615,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  487,  754, 2541,  939,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2959, 1009, 1041,  191, 3151,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3012,   29,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3302,   37,    1,    9, 3185,  909,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  567,  799,  765, 3228, 3103, 1090, 1159, 1065,  199,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1646,  776,    1,  548,  985, 1450,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1710,  105,  399,   92,  425,  426,   12,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,  132,   98, 1438,   37, 2712,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359,  361, 3364,  774, 1444,  565,    1,   37,  907,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  236, 1022,    1,  983, 1470,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2597, 2292, 1554,  176,  177, 1530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885,    1, 1981,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,  488,  909,  444, 3369,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,  162,  332,    1,   92,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1988,   22,  854, 3403, 1373, 3133,   37,   77, 1515,    1, 1073,\n",
      "         2545,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1524, 2132, 3100, 1249, 2307,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3328,   37, 2243, 3309,  892,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2578,    1,  641,    1,    1, 1056,  356,  276,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1166,  321,  405,    1,  168,  384, 1120,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  585,  132, 1641,   37, 3287,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  515, 2458,   59,  384,  493,    5,  424,  356,    9,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  711,   37, 1066, 1074,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 163,   1,  12,   1,   1,  61,   1, 220,   1,   1,   1,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  20, 353, 242, 197,   1, 155,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3256,    1,    1,    9, 3280,  187, 2472, 2494,  928,   32,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  231, 1107, 1863, 1553,  472, 1224,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  344, 1656, 3403, 2414,  176,  177,   32, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,   37, 1463,    1, 1011,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1768,    1, 1636,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2798, 1222,  437,  256, 1128,    1, 1056, 1130,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1290,  396,   71,    1,   37,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37, 1496, 1011,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  219,    1,   99, 1408,   67,  176,    1,  387,  762,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425, 1310,   37,    1,  759,  760,  861, 2043,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  649, 3222,  365, 1292,   45, 2227, 1105,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  928,   32, 2197,  176,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2883, 3109,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  695,   98,    1,  424, 1034,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1808,    1,    1,    1,    1,   51,    1, 1914,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  603,  227,    1,    1, 1001,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 2292,    1,  591, 1896,   32, 2433, 3369,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3339,  469,   51, 1403, 2708,  171, 3359, 2431,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2736,   12, 2237,    1,    1,  715,  608,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2946,    1,  176, 1018,    1,   67,    1,  420,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1001,  277, 1557,   32, 3144,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  688,  978, 3138,   37,  698,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  563,  968,  208,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1157,  668, 1292,    1, 2823, 2409,    1,   32,    1,  548,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307,  244,  701,  528,  218,  332,  471,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  830,    1,  437,   37,   47,  215,  960,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  449, 1428,    1,  756, 2030,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2723, 2724,  357, 3016, 1935,    1, 2487,    1,  267, 2511,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  203,    1,    1, 1924,    1,   32, 3118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,    1, 1236,    1,    9,    1,   59,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1985, 2954,  260,   28,    9, 2227,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  251,  955,  956,   37,  854,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   22,   23,  288,    9, 1463,   95,   45,  365, 2328,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,   25,    9,  166,    1,   32,  334,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   17,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    4,  254, 1754,   32,  367,    1,  105,  784,   45,\n",
      "         1018,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,   70,  698, 2861,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3228,  186,    9, 1918,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   82,    1,    1,   37,  271,   28,  669,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3307,   23, 2149,    1,  176,  104,   26,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1985,    1, 1683,  191,  531, 3006,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   17,    1,  176,  647,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 2069,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  794,   22,  477,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1883,  879,  453,  759,    1, 1876,  361, 2389,  744,  220,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3321, 1554, 1090,  548,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1064,  167,    1, 1046,   45, 1051,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   12,  999, 1892,   37,  714,   32,  163,    1,   12,    1,\n",
      "            1,   91,   98, 1332,   88,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  193,  695,   39, 1844,    9, 1009,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3365,   32,  531, 1046, 2162,  187, 1757,  431,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3141, 1902,  571,   37,  631, 3287,  297,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   55,  105, 2994,  166, 1868, 1172,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2144, 2572,   32, 2597, 2137,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1829, 2321, 1110,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1643,  361, 1087,   37,  693,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  190,  429,  890,   98,  740,    1, 1009,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2670,  729, 2668,  166,  433,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433, 1140,  994,    1,  150,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2523,    1,  449,    1, 1684,   45,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,   45, 2771, 2954,    1, 2051,  763, 1023, 1515, 2308,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  176,  915,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537, 1583,  475,   37, 2237,  395,  384, 1657,   32,  449, 2784,\n",
      "            9,    1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   35,  571,   37,  605,  548,  732,  733,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1, 2620, 1178,   12, 2895,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  746,  190,  125,    1,    4,  191, 2092,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2222,    1,  105,   20,  296, 1798,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  535,   96,  552,  552,    1,   37, 1107,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  614, 2071, 2880,   98, 1766, 1767,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 108,  98,  71,  45,  69, 102, 428,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 671,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  967, 2582,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1531,    1,  132, 2903,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  460,    1,   37,  813, 1595,   93,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  131, 1021,  250,  190,    1,    1,    4,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3089,  188, 2337, 3297,  418,  548,  123,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  446,    1, 2224,    1, 1408,  284, 1726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  203,   37, 1569,  105,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3160, 2572,   32, 3343, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  331,    1,   24,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1323,   45,    1,   32, 1820,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  590, 2815, 3263,    1,    1,    1,    1,   32,  449, 2712,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2237,   37,  316,    1, 2275,    1, 1160,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  848,  891,    1, 2723, 2724,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  921, 2693, 1638, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 571,   1,  37, 632,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  622,    1, 1426,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2673,  250,   32,  365,    1, 1908,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,  176,    1,    1,  187, 3303,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  155,    1,   59,   32,  453, 1126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  388, 1857,    9, 3200,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2005,  608,  634,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1277,   45,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1902,    1, 2315,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2733,   37,    1,   28,  105,    1, 2301,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,    1,  220,  534,    1,    1,  952,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  506, 2587, 1763,  187, 1463,    1, 2052,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1631, 2481,  176, 1687, 1022,    1, 3008,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1417, 3143, 1917, 1178,  787,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  683, 1822,  138, 3103,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1720,    1,  361, 2990,  254,  786,  361,  166, 1690,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1823,  535,  197,  418,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  395, 1877,   37,   77,  954,   98, 1171,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,  884,   98,    1,   45,  116,  259, 1085,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3282, 3173,  683, 1426, 3179,   45,  395,   26,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  379,    1,  191,  691,    1,  438,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,  45,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 721, 490,  37,   1, 361,   1,   1, 726,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1363,  691,   37,  332,  613, 1074,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37,   97, 1094,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1176,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1268,   28, 2436,   45,  453, 3044, 2168,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  590, 1101,   32,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2695, 2223,  744, 2364,   98, 2948,    1, 1017,  361, 2212,\n",
      "            1, 1821,    1,  150,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  395, 1220,   34,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2236,  361,    1,   32, 2792,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1856,   45, 1428, 2950, 1380, 1381,   98,  861, 2537,    9,  166,\n",
      "          386,  497,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1074,    8,    1, 1370,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  325, 1474,  460,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,    1, 1461,  315,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  944,  733,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1932, 1353, 2916, 1325,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   32,  105,    1, 1918,    1, 3207, 1408, 3208,  671,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  716,   77,  615,   98, 1285,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  593, 1990, 3201,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   79,  699,  528,   69,  550,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3006, 1439,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1799, 2298, 1572,   37,    1,  595,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2708, 2572,   32,  365, 3101,   22,  477,   32, 3339,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087,  433,    1,  411, 2322,   98, 2922,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   32,   95,    1, 1411,   98,    1,   12,    1, 1638,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1172,    1,  161,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   79,  166,    1,  176,    1,   12,  365,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2839,  279,    1, 1551,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1230,    1, 2102, 1027,  198,   15,  176, 1158, 1465,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  548, 1839,  884,  656, 1267,  176,  651,   46,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1,   28,  453, 1230,  411,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1966,  147,  919, 1899,    1,   32,  663,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,    1, 1310,  450, 1992,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    8,    1,    1,    1,  861, 2393,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2179,  736,  176,    1,    1,   36,  162,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3341, 2825,  105,    1,    9,    1,   12,  865,   37, 1327,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  954,  366,    1,    1,  883, 1279, 1121,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,  421,   37,  138,  152,   37, 1814, 1786, 1535,  927,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,   37, 1174,    1, 2699,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2328,  851, 1478,    1,  548,  142,    9, 2695, 2223,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1704,   37,    1, 1777,   32,  784, 2695, 1151, 1551,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  558,  325, 1056,  366, 1008,   32, 1697,  293,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  947,  774,    1, 2596,    1,  434,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1537, 2673, 1409,    1,  928,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,    1,    1, 2625,    1,    1, 1158,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1525, 1108,  460,   12, 1121,    1,  202,  590,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   14,   15,  317,  198, 1376,   32,  385,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2685, 1340, 2137,  590,    1, 1110, 1838,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  245,  995,    1, 1099, 1453,  246,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,    1,  104, 1414,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3380, 2312, 2745,  600, 1887,   45,  103, 2764, 2765, 3384,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  219,   25,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  420,  388,  763, 1530,  548, 2924,   64,   36,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1212,   12,    1,  159, 1150,   98,    1,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  647,    1, 1557,   37,  148,  170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2859,  361,  166, 2955,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2787,    1,   37,  698,    9,  166, 1497,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1432,    1,    1, 2554, 1176,  445,    1,    9,  166,  616,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1592, 1248,  249,   37,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 1232,  403, 1447,   61,    1,    9, 2673, 1463,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  915,  916,  864,  342, 2673,   46,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228, 1061,   32, 3393, 2137,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1962,  256, 1101,    1,   37,  858,  613, 1841,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2737,  142,   37,    1, 2231,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  474, 1953, 1460,   37, 1390,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,   61,  227,    9,  166,  669,  361,  166, 2264,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2373, 2627, 2177,  988, 1027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,    1,  251, 2741, 1918,  187, 3334,  664,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  842, 1118,    1, 2092,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   81,    1,  686,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1450,    1,  531,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,    1,    1,  202,  193,  187,  334, 1847,  460,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1559,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3250, 2905,    9, 3228,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,   45,  275,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129,   91,  726, 1477, 1990,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  306,    1,  150,  891, 1935,    1, 1108,   98,  215,  778,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035, 1008,    1,  475,  187,    1,  939,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2884, 2892,   64,  487, 3372,    1,  202, 1281,  765, 1415,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884, 2461,  973,   37,  803,  681,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1433, 1924,  166,  356,   45,  166, 2603,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1479,    1,    1, 2867,  191, 2308,  474,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2645,    1, 1718,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1355,    1,  297, 1228, 2019,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  385,  389,   93,  143,  763,   76,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1740,   45, 1718,    1,    1, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1665,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  342, 1070,   56, 2064,   37,    1, 1140,    9,  657,  769,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,  10, 459, 131, 369,   5, 125, 302,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  12,   1,   1, 733,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   12, 1718,    1, 2940,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1021, 1499,  205,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  968,    1,  162,    1, 1876,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 1447,   12,  475, 2673,    1, 1554,    9,  455,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  964,  171,  681,  321,  142,    9,   49,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236, 1022,    1,   66,  526,  176,   26,  187,   69,  343,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1661,  551,  704,  222,    1,    1, 1405, 1340,    1,    1,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1474,    1, 1102,  934,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3279,   32,    1, 1633, 2856,  176,  177,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433, 2466,   37,  360,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  447,  839,    1, 1345,   32,  531,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  474, 2211,   12,  572,  197,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  819,  195,  426, 1913, 1843,  197,  418,   37, 1417,    1,   59,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485,    1, 1918,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   32,  367,   65,    1, 2635,    9,  388,   67, 1500,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 2318, 1086,  220,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1283,  830, 1169,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,    1,    1,   37, 1155, 1697, 1013,  778,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2984,    1,  300,    1, 1748,  384, 2820,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3161,  171,    1, 3130,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2236, 1631,  119,   32,    1,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   72, 2286,  193,  105,    1,    9, 1539,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2546, 1288, 1230, 1756, 2324, 3011,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613,    1,  829,   32,  132,   98, 1273, 1117, 1525,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1797, 2252,    9, 2953,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   98,  275,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  342,   61,    1,   37,  125,  296, 1859,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777, 1085, 2351,    1,    1,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  777,  279, 2549,  696, 2911, 1000,  806,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  537,   45, 2784,    1,    1,  439,  187,  104, 1554,  464,\n",
      "         2735,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1312,  249, 2572,   32, 2490,   12,    1,  463,   32,    1,   45,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3266,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32,  104, 2456,   37, 1445,  335,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112, 1480,   66,   28,  419,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2162,  191,  105,    1,    6,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  297,  864, 2673,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1167, 1031,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796,    1,   37,    1,  166, 1509,    1,   45, 1922, 2068,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  405,    1,  190, 2286,   37, 1253,  698,    1,  914,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  980,  187,  163,    1,   12,    1,  520,    1,   25,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1645,  650,  292, 2532, 1645,  650,    1,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1439,   45,    1,   98, 2921,    1,  191,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1081,   12,    1,    1,  162,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,    1, 2161,    1,    1,   61,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  381,   12,  597,  710,   51, 1046,  422,  522,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3064,  683, 1993,    1,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1147, 2924,    1, 3155,  187, 2292,    1,  440, 2458,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,  749,  480,    1,  166,  790,  361,  503, 2487,  798, 1167,\n",
      "          810,  440,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,   37, 2225, 3327,  365,  582, 2565, 1970,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  790,  476,  388,  230,   29,   98,  503,  195,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056, 2844,   32, 1157, 2702,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280,  571,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   66,  526,  548,  304,  191,  189,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  557,    1,   32,    1, 2515,   37,  777, 1085,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  619, 1241,   32,  457,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  998,   28, 2813,    9, 2024,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1477, 1990,   91,  697,    9, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2103,  617,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  459,   79,   32, 2304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503,  494,    1,   32,  400,   45,  214,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141, 1090, 1829,  718,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973,  361, 3249,  288,   37, 1523,  424,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  938, 1075, 1830,   37, 2354,  754,    9, 1104,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  125,  163,    1,   12,    1,    4,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1338,   45,  522,   32,    1,  399,  792, 1389,   45, 1057,  792,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  765,   37,    1, 2417,   32,  148,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  663, 2042, 2137,  964,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,  210, 2414,  617,  259, 1274,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  647,  148,  776, 1961,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123,  542,    1,  548,  477,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  766, 2721,   45, 1092,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  590,   37, 1300,  290, 1159,    1, 2208,  287,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 1816,   45, 1708,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1046,  119,    1,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   60, 1276,  444,   94,  187,  517,  251,  590,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190,  814,   47,  176,  105,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1433,    1,   61,    1,  810,  166,  454,   37,  166,  458,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  837, 1095,   17,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  631, 2615,  608,  730, 2614,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2515,  220,    1, 2524,    1, 1519,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1206,    1, 2458,    1,    1, 1753,  829,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2767,  228,  861,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3379, 2042, 1999,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  251,  331,  104,   37,  130,    1,    1,    1,    1,\n",
      "           45,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1230, 2438, 1426,    1, 1330,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2942,  140,  105,  628, 1608,  992, 1483,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  190,  306,   12,  105, 1013, 1522, 2192,  224, 1013,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  802,    1,  331,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094,  640, 3374, 2172, 2791,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,   96,  220,  581,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  319, 1675,    1,  119,  142, 1464,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32, 3354,   22, 2262,   98, 2764,    1,    1, 2172,\n",
      "         2791,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  758,   34, 1107,    1, 3000,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,    1,    1,  568,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2741,  245, 1139,  176,    1, 2577,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  771,  253,   37, 1418,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2689, 1717,    1, 2318,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3114, 1141,   37, 1865, 2210, 1583,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 422,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 264,   1,   9, 229,   1, 101,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2136, 1562, 2676,   98,    8,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  546,  547,  548,  549,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1028,    1,  476, 1488, 2471,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,  885,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3043, 2416, 1685,    1,  267,  204,    1,  966, 2072, 2008,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 1771,  171,    1,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2631,   37, 1463, 1971,  750, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  108,  453,    1,   32, 3360,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  403, 1447,  108,  455,  444,    1,  909,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3108,  665,   28, 2335, 1569,   32, 2674,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  121,  251,   37,  151,  963, 1448,  669,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2981,    1,    1,  384,    1, 1821,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   75,  261, 1167,  460,    1,    1, 1067,  297, 2348,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2855,  544,  275,  441, 1876,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1600,  261,  335, 1601, 1602,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504, 1065, 1190, 1082, 2862,    1,   37,  221, 1750,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  479,   15,  720,  118,   32, 1352,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870,   37,  693,    1, 2261, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3189, 2744,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  140,    1,   43,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1470,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1938, 2607,   45,    1, 2115,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1051, 1519, 1402,    9, 2264,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2500, 3145,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,  306,    1,  150,    1,  440,  111, 1117, 1943, 1110,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,  187,    1,    9, 1933,  528,  467, 2092,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2571, 2153, 2000, 3118,   32,  976,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1331,   31,    1,  763,   76,   32,  385,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1433,  565,   69,  102,  320,  845,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 314, 598,  45,   1,  98,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,  32, 455,  26,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  199,   37,   84,   37,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1306, 1640,  140,  593,    1, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2031,   37, 1539,  822,  777,  778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,  876,  612,  886, 1419,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1502,  207, 1137,   98,  160, 1446,    1,   48,  333,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1583,  475,    1,  247,    1,  176, 3065,   32, 3339,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1701,   37, 1753,  297,  111, 1662, 2086,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043,    1,   60,   85,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1095, 2520, 1563,   98,    1, 2829,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   59,    1,  444,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  199,   32, 1081,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1304,  213,   37,  138,   59,   37,  875,  133,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1419,  282, 2367, 2695, 1917,    1,    1, 3011,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  242, 1017,    9,    1, 2559,   37,    1,  105, 2620,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  593, 2005,  361,    1,   81, 1147,  890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,   12,  754,    1,  162,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,    1, 1824,    9,  755,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,  338,   98,    1,  107,  190,    1,   37,  568,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  831,  548,  531,  965, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2753, 1394,    1,  688, 3259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1094,  446, 1877,   37, 1403, 1016, 1159,  957,  528,  741,  191,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403, 1383, 1924, 1728,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1813,    1,  361,    1,    1,  203, 1048,  105,  260,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2812,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   63,  166,  862,  500,    1,  393,  720,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  173,   45, 3339,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,   12,  103, 1339,    1,   37,    1,  581, 2273,  191,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1,   37, 3190,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  102,  245,   98, 1986,  600,  679,   69, 1588,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  990,    1,  444, 2650,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  342, 2386,  829,   45,    1, 1470,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1375,  884, 1370,   32,    1, 2247, 1074,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3192,   97,    9, 1185,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  331, 2965,    1, 2136, 2889,  384, 1675,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  786,    1, 1312,  356, 1330,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043,    1,    1,    1,  186,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2258,  334, 1822, 1847,   37,   52, 2133,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,    1,    1, 1624,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1229,    1,   32,    1,    1,  287,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  308,    1,  417,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1181,  623, 2914,  593,   12, 1637, 1208,    1, 1151,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   69,    1,  242,   98,  531, 1345,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,  140, 1350,  149,   32,  142,    9,  413,  695,  919, 1479,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2024, 2924, 2434,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   39,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  613,  441,    1,   28,    1,    1, 1185,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  181,   32,   98,  395,  517, 1273,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2084, 1090,   45,  166,  356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 1731,  571,  548, 3155, 2731,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2716,    9, 1050,  542,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1853,  336, 2291, 2414,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  756,  757,   82,  939,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1090, 1377,    9,    1,   12, 2911,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3151,  914,   61,   32,    1,   12,  637,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  315,   37,   47,    1,   48,   32,  142,   37,  125,  734,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3296,    1, 3117,    1, 2799,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1370,   45,    1,  166, 1389,   45,   69,  636,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,    1,  698,    1,   37, 1839,  432,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  245,   98,  303,  448,  304,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2754,    1, 2034,  601, 1674,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3042,  161,   81,  384,  166, 1530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 1447,  267,  108,  403,  548,    1,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3141,  892,  428,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,    1,   98,  365, 1876,    1,   37,  860, 1108, 2568,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 2486,  176,  590,    1, 2748,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  916,  176, 1204,  220, 1056,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  851, 2596, 2393,  590,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3188,    1, 1484,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2283,   12, 1385,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  159,    1,  220,  813,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1458,   79,  590,  142,   24,  469,    9, 1325,  861,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1373,   37,  774, 2602, 1316,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,   40, 2524,  999,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  854,  794,  365, 1228,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  191, 2685,    1, 2614, 1360,  612,  168,  601,   98, 3237,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2994, 1618,   28,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 1396,  649,  218,  220, 1100,    1,  327,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1212, 1654, 1737,   37,  395,   32,  532,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  957, 1710,   81,  221,   37,    1,  375,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  303,  267,  954,   30,  284,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  753,  229,    1,  612, 1389,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1592,    1, 2596,   32, 2490,   12, 2292,  686,  463,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  249,   98, 1965, 1610,   32,   37,  537,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2334, 1631,  846,  119,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2159, 2914,    1, 1456,  279,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  487,  947, 2263, 3060,   32, 1051, 2690, 2607,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1628,  400,   45, 2478,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2500, 2485,    1, 1186,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1, 2753,   45, 1691, 1675,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   75, 1458,    1,   98,    1,  259,  260, 2285, 1650,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,    1,   69,    9,  987,    1,  225,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2279, 2437,  548, 1044,  176,  163,    1,   12,    1,   26,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3161,    1,  590,    1,   32, 2487,  806,    1, 1268,   72,   32,\n",
      "         3278, 2788,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1210,    1, 2541,   37, 2653, 2972,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,   12, 1340,   71,  548,    1,  267,   60,  504,   51,  125,\n",
      "           93,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2868,    1, 1133, 1058,   98,  903,    1,  464, 2375,  210,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2144, 2827,   32,  492,    1,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   81,   32,  166, 1090,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1,    9,  602,  361, 2944,   98, 2069,   74,   45,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1962,  744,   28,    1,   12,  613,  345,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739,  416,  105,  271,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1348,   32, 2646,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  975,  197,  845,   98,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1008, 1056,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  538,    1,  765,  115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1357,  384,   98,  845,    1,  617, 1484,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826, 3204,   12, 1674, 2494,    1,    1,  297,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   56,    1,  384, 2162,   12,    1,  191,  105,    1,   45, 3103,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,    1,  191, 2333, 1530,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1100,   12, 1273,    1,  769, 2017,  176, 3019,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1607,    1, 3004,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  667, 2404,   37, 2237,  403, 1447,    9,   46,   98, 2673, 1512,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1697,  691,   12,  638,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1069,    1,  423,    1,  191,  107, 1726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  619,    1,   32,  691,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,  251,  138,    9,  815, 1222, 2359,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1527,   37,  531,  894,   52, 1866,  658,    1,    1,  774,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2950, 2985, 1061,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1668,  726,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,  868, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3190,    1, 1440, 1022,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  281,  282,  267,   51, 1046,  422,  522,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  606, 3217,    1,  190, 1697,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  311, 1373,   37, 1272,    9,    1,  548,  105,  245,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  952,   26,  412, 1116, 1563,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  249, 1120,  753,    9, 2024,    1, 1945,   32, 1811,  404,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1726,    1,    1, 2362,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1117, 1525,    1,  190,  193, 2446,  923,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  290, 1268,   32, 3184,  220, 1298, 1647,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1823,  535,  197,  418,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  204,   12,    1,  123,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  803,  992,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 1386,  566, 1415, 2532,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2095,  650, 1229,    1, 2468, 1260,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  288,    9, 2127,   26,    1,  289,   98,  185,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2209,    1,  872,   28,    9,  166, 2924,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,    1,  716,  119,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  185,  631, 1043,   12,  186,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2634,    1,  766,    1,    1, 1539,  182, 1651, 1395, 1597,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   63,  166,  862,   58,   28,  548,  157,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2909,  135, 2458,   32, 2468,  548, 2095,  437,   12,  304,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  459, 1183, 2113,  132,  220,  902,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1831, 1566, 2006, 1064,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3282, 3064,  683,    1,    1,    1,    1, 3178, 1758,  176,  104,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2418,  176,    1,    1,  220, 1230, 2528,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  463,  507,    1,   32,  442,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  348,  738,  572,    1, 1680,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2,  22, 447,   1, 387,  93, 548, 198, 401,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 107,  12,   1, 905, 115,  45, 906, 907,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3251,  190,   77,    1,  983, 1906,    1, 1574,  365,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1597,    1,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2800,    1, 3314, 1046, 2022,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,    1, 2216, 1094,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  121, 1249,  447,   37,  726,  449,   65, 1990,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   27,  187,  531, 2292,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,    1,   48,   32, 1537, 1273,  700,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284,  542,  543,   37,  544,  545,   12,  199,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2176, 1421,   28,    9,  822, 2441, 3049,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  760,  197,   28,    1,  159,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1024,  190,  930,  187,    1,   12,  590,    1, 1213,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299, 2424,    5,  125,  302,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1168,   12,    1, 2775,    1,  166,    1,  176,  405,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388, 2924,   51,   52,  110,   32,  557,  540, 3405,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1128,  162,  331,  132,  384,  502,  882,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  997, 2319, 1778,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1148,  365, 1821,  293, 1198,   79,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1589, 1008,  335,  105, 2148,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    4,  125,   32, 1084,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3389,  176, 1056,    1,    1,  217, 2856,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1167,  173,  167,   52,  105, 2693,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  171,  681,  321,  142,    9,   49,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 2741, 3276,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3130,  176,    1,   32,    1, 1826,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2827,  680, 2834,  100,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  105,  365,  559,   98, 1018, 1691,    1, 1821,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3298,  190, 2107,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  570,    9, 1411,  356,  377,    1,  585,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1260,    1,   28,    1,    1,  207,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426, 1408, 1690,  525,   15,  157,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1557,    1, 3343,  863,  133,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,    1, 1707,    1,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   33,  166,    1,    1, 3285,  565, 2740,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   28,   37, 2844,   32, 3279,  297,    1, 3343, 2696,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  204,   12,    1,   28,  297,    1, 1160,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,   12,  631,  162,  999,   32, 1002, 1160,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2173, 1210,  776,   37, 2449,   32, 2110,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  218,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,   12,   26,    1, 2814,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1287,    1,  202,    1,    1,   76,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428,  108, 3369,  361, 2751,   98, 2756,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2177,   37,  619,  854,    1,  631,  444,  463,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2031,  353,  572,  354,  187,  822,  408, 1687,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,   26,  417,   98,  197, 2428,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 2452,  167, 2192, 1158,  105,  110,   92,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1842,  613,   37,  125,    4,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  119,    1, 1753, 2733,  700,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3033,    1,  245,    1,   32, 1821,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178,  159,   26,    1,  548,    1,  890,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  334,    1,  460,    1, 1492, 2996,  460,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3172, 1090, 1829, 3161,  171,  176, 1739,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  182,   45,  105,    1,  350,    1, 1797,  389,  125,    1,    1,\n",
      "         2050,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   26,  242,  236,  237, 1111,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,  230,    9, 1110,   61, 1133,   98, 3304,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3281,  590, 2518,  901, 1720, 1366, 1343, 1691,  872, 3314,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1181, 1660, 1102,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   67,  423,   66,  187,   65,  738,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,    1,    1,   26,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2355, 1718,    1,  803,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1940,    1,  191,    1,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  105,    1,  365, 1718,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3377,    1, 1530,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2691, 2368,   28,  365,  848, 2371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2424, 2017,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  766,  140, 1876,    9, 3016, 1935,  384, 1662, 1701,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,  692, 1133,    1, 1281,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  964, 2369,    1,   98, 1021,   32,  121,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  232, 1458,    1,   12,  659,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2964,    1, 2713, 2690,  525,  220, 1051, 1039,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1007,    1,  105,    1,    1,  316, 1606, 1149,  477,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  321, 1340,  759,   32,    1, 2498, 3135,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  479, 1149,   37,   52,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  215, 1557,    1,  952, 2128,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2184,    1, 2967,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3200,    1,   37,  606, 2091,  439,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1811,  404,    1,    1, 1976, 2793,   32,    1,  548,   64,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 1731,    1,    1,  191,    1,  625,    1,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777,  387, 1023,   45,   15, 2083,  163,    1,   12,    1,\n",
      "           32,  105,  356,   88,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1327, 3145,   37, 1154, 3365,   63, 1757,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  700,   98, 2924,  548,  531, 3102,  420,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  492,    1,    1,   32,    1,    1,  220,    1,   37,    1,   12,\n",
      "          770,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,  544, 2161, 1090,    1, 1210,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1122,  853,  538,  459, 1123,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  863,  483,  166,    1,   45,  926,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2606, 1089,    1,   37,   16,    1,   45,  547,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  290, 1268,  548,    1,    1,   32, 2597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2998,  147, 1707, 1603,    1,    9, 1117, 2208,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2436,    9, 2310,  758,  256, 2186,  311,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  647, 2471,    1,  220,  326,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1647,    1, 2728,    9, 2875, 1781,  384,  121,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  551, 1007,  952,    1,    9,   67,  641,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  941, 1663,   37,    1,    1,  400,  444,  597,   82,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  636,    1,    1,  187, 1588,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2073,  328,    1, 1109,  714,    1,  951,  395, 1021,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  581,  198, 2164,  640,  539,  455,    1, 2734,  304,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   22, 1426,    1,  132,  220,  359,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  691,    1,  531, 3353,  798,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,   93,    1,   32,   72,  401,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1628,   74,    9,  195,  441,  361,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3200,    1,   39,    9,  914, 3201,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 1917,  365, 2036,    1, 3116, 3217,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2056,  116, 1108,    9,  166,  249,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  837,  187, 1423,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2266, 2694,  104, 2874,   45,  531, 2189,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1434,  187,  365, 2789,  650,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1497, 2651, 3103,    1, 1832, 2631,   32,    1,  404,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,  159,  832, 1010,    1,  333,  997,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1326,  884,    1, 1736,   37,  395,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  180,   37,  693,  758, 1085,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2497, 1137,  444,   60,  548, 1242,   71,   32,   14,   15,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,   37,    1,  335,    1,   37,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  249, 1941,   32, 3149, 1656, 2950,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,    1,   12,    1,  105,    1,  389,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  160, 1161,  948,    9,   72,   73,  339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1277, 1679, 1439, 2042,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1786, 2358,    1, 1268, 1099, 2281,  927,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  968, 2274,   37,    1,   26, 1039, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,  410,   60,   85,  951,    1, 1547,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,   27,  132,   37,  151,  180,    9,  131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2050, 1918,    9,    1,   32, 3097,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043,   28,  176,    1,    1, 1572,  191,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   68,   69, 1867,  119,  845,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2476, 1414,  477, 3155,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  293,  437, 2023,   37, 1171,  361,    1, 2492, 2429,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2144,    1,    9, 3324,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2110, 1957,  872,  420, 1657,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,    1, 1811,  404,    1,    1, 1428, 1953,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  162,  227,    1,   98, 2851,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 1937,  365,  916,   37,  877,  132,    9, 1024,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2056, 2822,    1,  488,  249,    1,    1, 2321,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1423,   12,    1,    1,  267,    1,  191,  487,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2050,    1,   15,    5,    1,   81,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2748,    1, 2110,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1861, 1458,  854,   12, 2813,    9,    1, 1311,   98, 1428,  861,\n",
      "         1906,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967,  183,    1,   32,    1,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1000, 1117, 2208, 2298,   32, 2998,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  162,  317,  736, 2075,   32,  863,   70,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  640,   98,  889,  509,    1,  430,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1008,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  375,    1,    1,  619, 1593,  176,  671,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  389,    6,  288,  191,  176,  551,  612, 2300,   37,  686,\n",
      "           45, 1346,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2868,    1,  976, 1407, 1190,   37,  429,  449,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321,  166, 2024,   32, 2646,   52,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  200,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  164,  165, 2812,  384,  602,    1,  202,  132,  220,  942,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2148, 3161, 1710,   52,  562,  220,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  281,    1, 1099,  159, 2370,  241,   97,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2741,  197,  384, 1555, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380,  108,   45,  368,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2469, 2091, 1086,  619,    1,  670,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  511,    1,  967,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  632,    1,    1,  140, 2579,   45, 2468, 1194, 1267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649,  700,   37,  877,  723,  769,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2925, 1292, 1751,   76,   37, 1642, 1038, 2113,   32,  195,  400,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1107, 1863, 2759, 1671,  113, 2627,   45,   29, 3031,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1824, 2895, 1857,   37,   52,    1,   37,  215,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2158,   45, 2121,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  407,   98,   37, 1412,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3384,  437,  267,  460,    1,  632, 1497,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  384,    1,   12, 2918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  773,    1, 1448,  764,   25,  439, 1034,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1726,    1, 1040,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671, 1078,    1,   51,  631,   37,  147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1147, 1929,   98,  863,  469, 1308, 1159, 1803,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,   37,  588,  116,  279,  259,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2236, 2903, 1178,  386,  384, 2712,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1257, 1187, 1909,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  596,   12, 2939,    1,    1,   25,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,    1,  688,    1,    1,    1, 2250,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  588, 2986,  187,    1,   64, 1554, 1530,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 3372,  692,  365, 1994, 2095,  625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,  224,  258, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,  418,   98,    5, 1639,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,  418,    1,  444,   94,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2283,   12, 2677,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2292,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  233, 2322,    1,    1,  859,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  548,  105,    1,    1,    1, 1937,  105,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,    1, 1272,   39, 2496,    1,   32,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  608,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117, 2911, 2506,  297, 1017,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,    1,    1, 2347,  857,   32, 2321,  354,   37,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481, 1349,  190, 1403,  247,   16,   37,  853,  538,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1100,    1,  326, 1835, 2670,    1, 1017,   37,  860,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1691, 1443,  686,  105,  365,  340,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  996,  157,    1,   87,  496,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2708, 2107,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2984, 2981,    1,  388,    1, 1425, 2662,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1640,  597, 1009, 1707, 2251, 1140,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  140,    1, 2107,    1,    1,  220,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  220,  754,    1, 2626,    1, 2614,  389,  193, 2613,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614, 1237, 3220,  220,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1861,   37,  168, 2611,    9,  985,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   65,   12,    1,    1, 2409,   37,  582, 1739,  105,  551,  331,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1668,  335, 1264, 1747,   37,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  584, 1022,    1,  921,  590,    1, 1037,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,  794, 1718,   98,  166, 2355,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,  104,  207,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 2392, 2941, 1569,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3112,    1,  706,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1,   71, 2051,  763,  570,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2741,  288,   37, 2579,  187,    1, 1048, 3184,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  635,   12, 1152,   45,  449, 1023,  197,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1554, 1090,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584,    1,  242,  286,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2881,    1, 1718,  582,   98,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1, 3177,   12,  166,  311,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1043,   28,    1,  419,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 1740,  193,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2140, 1070, 1407,    1,   37,  764,    1, 3121,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  108,   45,    1,  805,   98, 2822,  384, 2500, 1532, 1793,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  831,   98, 1212, 1585,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1492,  839,    1, 2500,   37, 2500, 2527,  164, 1010,  997,   45,\n",
      "            1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  519,    1,   51,   52, 2626,    9,  356,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718, 2461, 1967,  659,    1,  967, 1417, 1876,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  542,    1,    9,  449, 1333,  176, 2692,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,    1, 1897,    1,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  487,  681,    1,  486,    4,    1,  496,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1345, 1886,    1,  531,  443,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1200,    1,  829,   37,    1,    1, 1501,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503,  891, 1013,    9,  365,   82,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   76,   37, 1445, 1413, 3227,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777, 1008,  365, 1644,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1352,  495,  176,  105, 1312,  339, 2284,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  388, 1111, 2802,  140,  885,  633,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  864,   12, 2673,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12,  365,    1, 3279,  220, 2789, 1831,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2246, 3181,   61,    1,   37, 1046, 3123,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3384,  650, 1924, 2827,   32, 2028,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  191, 1443, 1357,    1,    1,  506,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1462,   46, 1289,   37, 1645,    1,  220,  602,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  861,  122,  665, 1106,    1, 1626,   98,  429,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,   12, 1266,  546,   82,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  531,  890,  729,   98, 1171,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2981, 2436, 2896,    1,  928,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 1523,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3178,    1, 2540,    1,  176,   26,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1190,   12, 1002,    1, 1380, 1590,   32,  260,   37,   52, 2018,\n",
      "           12, 1411,  446,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  223, 2135,  408, 1348,   37,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,  103, 2334, 2545,    9,  163,    1,   12,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112, 1161, 1276,   32,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  773,  317, 1595,  682,   32,  385,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3188, 1187,  247, 1370,   37,  698,  105, 2795,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3322,    1,  153,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2069,    1, 1921,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   46,    1,  187, 3224, 1415,   37, 1211,  639,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  208, 2565,    1,  939,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2087,  433,  536,    1,   93,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3186,    1, 2435, 2317,    9,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2917,  548, 2705,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98, 1050,  865,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3311, 3310, 2930,  400,  167,   52, 1036,   37,  878,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  534,  251,   59,    9, 2163,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  861,  700,  782, 1479,    1,   32, 2851,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1586,    1,   82,    9, 1943,  317,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1250, 2794,    1,   45,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105, 2962,  140,    9,  166, 2857, 1110,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3235, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,    1,  861, 1429,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3237,   12,  537,   32,  273,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1049,    9, 2522,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   46,   98,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2972,  317,  719,  105,    1,    1,  681,  774,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3175,    1,  105,   12,    1,  565,  726,  384,  539, 1684,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2372,  193,    1, 1467,    1,  663,  437,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1079, 3063,  794,    1,  777, 1013, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1442,   37, 2929,    1,  150,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,  342,   93, 1396,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3403, 2414,   32, 2445,    1,  379,  774,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2004,  311,  292,  786, 1034,    1,   59,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496,   30,  579,    1,  365,  754,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  499,  550,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3012, 2699,  729,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1443,  774,  829,  111, 1107,  525,  338, 1139,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1474,  142,   37,  652,    1, 2208, 1908,  114,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1327,  933,  976,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,  550,    9, 1017, 2153,  398,    6,  822, 1469,   32,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  411,    1, 1813,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,  275,  681,  186,  444, 2730,  302,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  162,  790,  432,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171,   66, 2249,   39,   98, 2057, 1516,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,  37,  52,   1, 191,   1,   1,   1,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 619, 388,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1173,    1,    1,    1, 1046,  460, 1658,  327,   61,  193, 2341,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2137,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   60, 1287,    1,  202,    1,    1,   76,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1340,  640, 1194, 2318,  754, 1844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1676,  851,    1,   37, 1423,  548, 2596, 1665,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  565,    1, 2440,  384,    1,   32,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  951,    1,    1,    1,   85, 1443,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2070, 3268,  220,  556,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  572,  354,  703,   98,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1815,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1769,   37, 2192,    1,   45, 1001,   81,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018,  810,  365, 1021, 1575,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1897,    1,  457, 1821,   95,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2612,   98,  453, 1331,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1089,   30, 2936, 1260,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  738,    1, 3289,  447,    9,   65, 1990, 1684,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  129,   37,  130,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2857, 1249,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3130, 2126, 2731,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1956,    1,    9, 3362,  798,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,   51,  417,  453,  647,  142,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2789, 2937,    9,  650, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1594,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2076,  387, 1119,   37, 1526,    1,  112, 1228,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  228,    1,   37,  166, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1426, 1259,  220, 2774,  615,  328,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  189,  725, 1008,    1,    1,  475, 1299,  655,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,  884,  105,    1,   37, 1847,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2756,  891,  892,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2406, 1301,    1,   45, 1537,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   80, 1000,   39,  388,  600,  207,  259,   19,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  406, 1610,   98,    1,  760,    1, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2959, 2712, 1957,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181,   37, 1636,   32,  769,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  367,   14,   15,  583,  191,  389,  509,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1273,  861, 1665,   66,  340, 2680,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,  123, 1523,    9,  590,    1,    1,  166,  806,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2855,    9,  705, 1458,  389,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  120,    9,  581,   74,   98,  383,   69,  102,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321,  365,  132, 1154, 1257,   12,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2527,  164,    1, 1813, 2990,   32, 2490,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105,    1, 2640, 1098,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2414, 2548,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3023,    1,    1, 3274, 1987,  167, 2253, 2318,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,   45,  754,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,    1, 1188,  176,  177, 1056,  537,    9,  517, 1085,   37,\n",
      "          335,   79,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2779,    1,   32,    1, 1787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1173,  176, 2703, 2644, 3102,   32,  531,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  191,   20, 1749,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26,   12, 1264,  341,  590,    1,    9, 3253,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  590, 2050,    1,  166, 3175,  576,    1,   98,  247,  454,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196,    1,  132,   37,  619,    1,  562,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,  338,  548,  925,   65,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 3168,  361, 3178,   37,  907,   32,    1, 2069,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  411,  932,   16, 3363, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1478, 2658,   32, 2205,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  249,  565, 2500,    1, 1736,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1948,  105,  914, 1183, 1747,    9, 2279,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,  744,  453, 2364,   98,  803,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1468, 2080,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,  69,   1, 769,  37,   1,  25,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 487,   1,   1,   9, 510,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1447,   51,   52,    1, 1461, 1539, 1603,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3231,  914, 1494,   37,  439,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2450,   37,    1,   98,    1, 1167,    1,  333,  123,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1213,  796,    9,  702,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359,    1, 2224,  498,   37, 1479, 2731,   32, 3339,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,    1,   32, 1989, 1990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  885,  400,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3064,  140,    1, 3052,  184,  411,  522,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    8,  516,    9,    1, 2263,    1,  571,   37, 2340,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1189,  302, 1458, 2390,  626, 1027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1818,  147,   37,  231, 1936, 2115,    9, 2657,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1662,   85,  202, 2254,  197,  729,  418,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1410, 1237, 1412,  823,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2200,    1,   37,  885,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  433,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 3276,    1,  548, 2787,   12, 1183,   74,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3307,    1, 3247, 2125,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   74,   45, 2292, 1316,  531, 1554, 1530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  383,  604,  685,  193,   37, 1406,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219, 1164,  744,  864, 1757,   37,  907, 1428, 1994, 2390, 1004,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  796,  105,  163,    1,  903,    1, 2461,  437,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3111, 2262,    1,  973,   32, 1460,  274,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  864, 2450,   37, 2192,   28, 2673, 1116, 3399,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2153,  115,   32,  531, 1002,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1988,   45, 2319,    1,  804,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  276,  488,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  764, 2715,    1,    1,  506,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  284,  229,    1, 2370, 1488,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  393,  162,   28,   37,   59,   32,  365,  394,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  929,  267,  793,  167, 1046,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1360,  612,  877, 2149,  199,   37,  617,  618,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3381,    1, 2572,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3009,    9,   91,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1421,  220,  166, 3079,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  458,   45,  942,  387,  954,  123,   37, 1698, 1208,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089, 3407, 3348,    1, 3395,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3257, 2421,   39,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  800,  715,  646,  346,  997,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  148, 2593,    1,  210,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  507,   12,  638,  753,   32,    1,  967,  411, 2022,    1,    1,\n",
      "            1, 1159, 3295,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  328, 1157,  159,  686,  365,  339,  845,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  815,    1,   37, 3001,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2292,  418,   32, 1619,  507,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3281,  515, 3314,  166, 2453,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  773, 1003,   37,    1,  818,  819,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043,  879, 1044, 1045,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  683, 1360, 1675,    9,  166, 3232,   32,    1,    1, 3153,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  930,  187,  785,  786, 2886,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  845,  493,  102,   23,    1, 1064,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   12,  365,  327, 1013, 2549,    1,  762,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,   28,   98, 1290,   29,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994, 2995,    1,  820,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,   12,    1,  187, 1533,   81,  187, 2226,  321,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1343, 3304,   32,  668,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2644,   79,  163,    1,   12,    1, 3163,  548, 1894,    1,\n",
      "         1463,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676, 1740, 1253,   37, 1911,  973,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1055,    9, 1861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,    1,    1,   15,   28,  419,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3280,    1,   81,   37,  726,   32,  365, 1788,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  316, 1123,  176,  629,    1, 3167,   51,  588, 1077,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  792,    1,  863,  792,  420,    1,   85,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187, 3199,    1,    1,  416,   28,   37,  846,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  103,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1774,   39,  340,  439, 1456, 2168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2275,    1,    1,  361, 1542,   10,    1, 2074,  548,  736,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3386, 2757, 1216,  312,  134,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  715, 1161,  418,    1,  202,  157,   61,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715,  947,    1,    1,    1,   63,    1, 1314,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2751, 3060, 3369,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700, 1000,    1,    9, 1102,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   25, 1376,    1,  129, 1286,  225,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  110,   63,  185,  321, 1192,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  439,   45, 1018, 1015,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2, 704,   1,   1,  51, 698,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 683, 105,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3188, 2037,    9,    1,   32, 3244,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103, 1154,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  111,    1,  272,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437, 3079, 1824,   98, 1853, 2735,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   94,  654,  225, 1287,   98,    1, 1746, 1747,  220,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1963,  162,    1, 1708, 2714,   81,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  867, 1536,  449,  767,  444,  668,  912, 2852,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2573, 1523, 2073,  164,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 255,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 503,   1, 737, 158,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2077,    1,  971,   37,  872,   28,   98, 1736,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2295,   37,   47,  787, 1491,    1,   98, 1095,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2039,  429,  227,  550,    9,  615,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98, 1127,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,    1, 1839,    1, 2055,   98,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,  387,  183, 1064,   37,  166,  207,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1924,    1,  191,    1, 2617,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1159, 1505,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  220,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  364,  140,  479, 1383,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1113,  396, 1253,  191,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  256,   37,    1, 1499,   50,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3142,    1, 3218,   32, 2138,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  125,  308,    1,   25,  245,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  590, 2725,   98,  255,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  672, 1658,  626,    5,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  787,    1,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  224, 2355,    1, 1778,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   54,    1,  142, 1391,  887,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  550,   32,  870,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,    1, 1186,  973,    9,    1, 1389,   45, 2095,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  794,    1,   45,  761,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2643, 1225, 1397,  565,  311,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,   71,   98, 1622,  477,  122,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2573,  958, 3038, 2527,  164, 1976,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1095,  835,  777,  778,  384, 2499,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,   14,   15,  120,   32,  385,    1,    1,   67,  157,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,  104,   61,  593,  650,   32, 2948,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 2681, 3350, 1061,  191,  104,  622,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3046,   81,  220,  105,    1,   32, 3262,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1035,    1,  384,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   49, 1682, 2816,  121,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878,   37, 1753,    1,  297, 2208, 2402, 1491,  133,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,  361, 2254,  875,   39,   45,  147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  936,  469,    9, 2128,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2275,  396, 1918,  548, 2563,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  342,  956,   46, 1174,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,  166,    1,   82,   12, 1492, 1399, 2588,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,  267,    1,    7,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  224,  932,    1,  792,    1,  150,  792,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 2280,  133,  640,  119, 1722,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2476, 2587,  111,    1,  675,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1009, 1670,    1,   37, 1000, 1815, 2389,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  305,    1,   98,  997,   65,   37,  423,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1033, 2211, 2396, 1086,  220, 1994, 2095,  543,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  506,   66,   37,   81, 2221,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,    1,   32, 1029,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2737,  729,  113, 1191, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3259,    1,    1,  191,  947,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3204, 2810,    1,    1,  361, 1542,   37, 1599, 2545,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  104, 2108,   37,    1,  167,  805,  854, 2018, 2471, 1401,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3309, 2137, 3320,   12, 2304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  247,  857, 1567,   16,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2745,  705,    1, 1879,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388, 2584,  220, 3117,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1019,    1,    1,    1,    1,    1,    1,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2578,  729,  707,  198,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  408,  829,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1492,  164,    1,    1,    1,  315,  110,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  691, 2861,    9, 1918,  187, 3211, 1686,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1625,    9,  581,    1,  220,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  715,  458,   17, 2372,   45, 2026,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1433,  565,   69,  102,  320,  845,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3318,  664,    1,    1,    9,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3184,    1, 1988,    1,    9, 2375,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  593,   12,    1,    1,   81,   98,  166, 2655,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2956, 1809, 2812,  365, 3017, 1008,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3322,    1, 2583, 1464,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  140,  231,   45,  467,  398,  484,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1773, 2510, 2493, 2947,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,  979, 1217,    9, 3183,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1053,    1,   37,   33,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938, 1075, 3160, 2572,  361, 1056, 2347,  191,    1, 2596,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1267,   61,  288,    9, 3276, 1194,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,  159,    1,   79,  119,   94,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   46, 1173,    9,  365,  651, 1705,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  493, 2162, 1924,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  653,   28,  191, 2090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1260,  600,  531,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   26, 1039,    1,    1,    1,    1, 1554, 1652,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796, 1021,  669,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,  437,  884, 1645,    1, 3102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   59, 1714,  901,   32,  116, 2026, 2574,   32,  104,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3075,  571,    1,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  407,   37,  631,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  420, 1372,   37,    1,   65,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129, 2885,  546, 2069, 1385,   37,  726,   72,   73, 2630,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2488, 1599,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3021,    1,   28,    9,  856,  548, 2442,  872, 1042, 1590,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401, 2755,  878,  608, 3194, 3195,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2648, 2801,    1,  982,   37, 1835,  517, 1273, 1732,    9,  112,\n",
      "         2264,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2565,    1,    1,  614, 2040,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1496, 1658, 1465,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  550,    1, 1066,   98,  455,   12, 1906,  142,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  619,  985, 2474,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3369, 1800, 1428,  861, 1906,    1,   98, 3118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,    1, 1354,   17,  384,  822, 2429,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2103, 2727, 1532,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  365,    1,  388,    1, 2026, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  593,  547, 2844,  187,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,  932,   32, 2507, 3343,  741,  665, 3363,   32,  631,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  870, 1095, 2418,   28,    1,    1,  150,    9,  331,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938,    1,   12,    1, 2219,   26, 1039, 2690,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  858, 1702,   91,  777, 2264,   37,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1691,  700,    1, 1832,   32,    1, 1990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1299,  710, 2405,   37,  698,   28,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 726, 786,   9, 166,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 642, 643, 245,   1, 644,  57, 701,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   32,  702,   12,  132,    9,  169,    1,  105,    1, 1167,  311,\n",
      "            1,  321, 1257,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0],\n",
      "        [   2,  463, 1447,   37,    1, 3107,    1,  176, 3385,    1,  424,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2579,    1, 1665,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1668,   32, 1600,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  391,   93,   37,  151,    1,    9,    1,   54,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275, 1900,    1,  436,   45,  993,  302,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    9,    1, 2440,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1317,  704,  104,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  306, 1539, 1935,    1, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 3105,  979, 3102,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2646,   12, 2629, 2370, 3156,   32, 1523,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   45,    1,  361,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3356,    1,  498,   37,   38,  297, 2108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 2554,   39,  365,   22,  477,   98, 3339,  787,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2406,    1, 3380,    1,  365, 2240,   32, 2471,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884, 1383,    9, 1951, 3222,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1923,    1, 2388,    1, 2333, 2651,   32,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  587,  899,  477, 1665,    1,   69,   32,  593,   12,  590,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,    1,   27,  119,   98,  104,  996,   93,  420,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1154,   32, 2513, 1401,   37,  354,   98, 2907,   32, 1194,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,   71,    1,   60,  417,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3188,  361, 1110,   32,  260,   45,  114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101, 3339,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1, 1249, 3119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2076, 2086,    1, 1718,  327, 1828, 3004,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    7,  104, 1414,   37, 1334,   32,  602,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1309,  200,    1, 1469,   32,  399,   45,   26, 2078,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1924,  356,   45,    1, 3005,    1,  777,  700,    1,  267,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  856,  425,  426,  525,   27, 1019, 1212,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374,  546, 1957,    1, 3339, 1260,  614,   98,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3247,  168, 1183,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  850,   39,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307, 1713, 2341, 1412,  293,  437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,    1,  359,   37, 1195,   46,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1476,  574,  731,  700,  162, 1451,    1,  297,   29,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,  551,  552, 2185,  157,    9,  854,   12,    1,  731,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1309,    1,  453,  647,  159,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  706,    1,   98,    1, 1343,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   82,    1,   28,  861,  110,    9, 1117, 1943,   37,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843, 1542,    9, 2181, 1034,  548,  865,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1744, 2265,    1,  881,   45, 1009,   12, 2113,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  896,    1,    1, 1076,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  921, 2342, 2458, 1638,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  627, 1075, 2933, 1017,   37,   77,    1,   98,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  565,  334,    1,    1,    1, 1608, 1584,   12, 2968,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,    1,    9,    1,  548, 1056,   74, 2651,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1685,    1, 2041,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2278,  313,   37,  417,  269,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2056,    1,    1,   32,    1,    1, 2915,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1343, 1023, 1204,  190,  335,  297, 1658, 1204,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1054,   45,    1,  313,   37,   52,  845,  275,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622, 3357,  488, 3344, 2139,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3253,    1,    1, 1418,  384, 2197, 3329,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1627, 2708,  863,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   32,  511,    1,    1, 2385,  612, 2056, 2398,    9,  284,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1463,  167, 1569,    1,   12,  411,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2808,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  726,    1, 1107, 2223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    7, 1675,   98,  844,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2015,  927, 1710, 1937, 1502, 1594,  453,   81,   98, 1503,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2414, 1056,  176,    1,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579, 1128,  719,  105,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1167,   12,  166,    1, 3076, 2794,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 3300,   98,  428,  810,  507,  872,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2, 305,   1,   1,   1, 113,  28,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1, 741,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  872,  839,  453,  248,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3176,  688,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  384,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,   51, 1140,    9, 1479,  219,  808,   32,  317, 3358, 2024,\n",
      "         1705,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  968, 2262,    1,    1,   32, 2968,  927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422, 1536,  521,  134,  444,  938,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3407, 3382,   12, 3357,    1,   37,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718, 1552,    1,  763, 2112,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,  365,  103,  439,    1, 2168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2863, 1654,  822, 1523,  220, 2956,    1, 1114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  895, 2011,   98,    1,  163,    1,   12,    1,  993,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773, 2480,   37, 2560,  613,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2542, 1114,   32,  166,  550,    9, 1514,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2005,   37, 1918,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3276,    1, 1879,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,   26,  417,   98,  197, 1936,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1536,  134,  444, 1661,  704,  222,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1359,    1,    1, 1707,  152,  333,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  958,    1, 1184,  101,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  267,  864,    1,    1,    1,    1,    1,   98, 2673, 1816,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,   95,  473,  562, 1610,  477,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2733, 1988,   45,    1,  596, 1107, 2086, 1294,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,    1, 1100,  361, 1361,   37,    1,  310,  911,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 2210, 2953,   51,  764,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1211,  968, 3096, 1292,    1,   12, 2804,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  459,  625,   37,   92,  403,  464, 2500,  663,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  686,  119,  845,   32, 2741,  361, 2846,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  315, 1479,  333,   45,   69,    1,  663,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 657, 376,  72, 401, 689,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 179,  37, 119, 572,  44,   1, 125,   4,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  526,  548,  720,    1,  388,  390,   66,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1722,   37,  151,  179,   12,    1,   28,  112,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2304, 1529, 1976, 1530,   32, 1038,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967, 2315, 2589,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1285,    1, 1779,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386, 1625,  734,  469,  190, 2354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   95,  473,  186,  176, 2087,  433,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796,   50,  640,    1,   12,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1298, 1820,  600,  460,    9,    1,    1, 3326,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178, 2612, 2380,    1,    1,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2365,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465,   13,  200,  365, 2687,    1, 2530,    1, 2105,  361, 1107,\n",
      "         1863,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2708, 1260, 2414, 1920,   32, 3339,  399,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1458,  792,  198,   60,  792, 1563,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   75,  300, 1514,    1,   98, 1412,  844, 3000,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213, 1584,   85,  191, 3180, 2250,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3066,    1, 2080,  477,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1029, 2911, 2242,  806,   32, 1459, 1743,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2459,  852,   37, 1752,  786,  183, 1568, 1569,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  649,    1, 3047,   32, 2018,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,  245,  190,  686,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1034,  590,    1, 1090,   15,  103,    1,   59,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  202, 1875,    1,   37,  121,   12,    1,   22,\n",
      "          298,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,    1, 3260,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3140,    1,  166, 2517,  361,    1, 2823,  863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   79,    1,  239, 1111,   98,  303,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,  647,  615,  894,    1,  159,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61, 2213,    9,    1,  311,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  190,  138,    1,   59,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1,  176, 1273,  275,   16,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  542,   77,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800, 1090,  167,  631,   37, 2275,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3168, 1713,    1,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  750, 1604,  515,    1,   92,   32,  156,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2466,    1,   32, 2482,   78,  680, 2887,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  220,    1,    1, 2650,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  437,  396,   37, 2856, 3340,  531, 2924,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2280,  782,  365, 2946,   45,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 638, 427,   1, 220,   1, 410,  32,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  10, 459, 116,   5,   1, 327, 593,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2912,  928,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2802,  140,  593, 1990,  633,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,  920,    1,   12,  645,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25, 2075,   28,  176, 2410,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  193, 1018,    1,    1,  415, 1018,    1, 2886,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1252,    1,   28,  422, 1684, 1090, 2306,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  864,    1,  213,   37, 2446, 3366,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1, 1361,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 3144,  863,  852,  972,  454,   39,   45, 1512,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  493, 1253,   30, 1839,    1,  215,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  398,  515,  148,    1,   37,    1,  647,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3278,  105, 1604,    1,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3187,    1, 2034,  105,  402,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  582,  108,  444,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  196,  353,  331,  220,  176,  551,  612,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169,    1,  176, 1066,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3185,  400, 1924,    1,    1,  420,  782,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1151, 1593,  297,    9, 1151,  615,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3169,    1,    1, 2861,   37,   26,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  288,   37,  698,  605,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2310,  449, 2539,   32, 2206, 2989,  786,    1,    1,   12,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 1821,  639,   37,  109,    1,    9,    1, 1965, 2550,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  503,  159,    1,   98,  749,  997,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398, 1118, 2281,  776,    9,  709, 1405, 1682,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   39,    1,  505,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,   91,  176, 2413,   98, 1649,    1,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3231,    1, 3209,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  169,  794,  160,  623,  260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428, 3114, 1346,    1,  297,  966,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968,  952,  388, 3349, 1428, 2924,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,   51,    1,    1, 2119,  115,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  293,    1,  912,  332, 1046,   79,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2807,  429,   98,    9,  726,  297, 2551,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9, 2321,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2614, 2935, 2941,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2006, 2572,   32, 2597, 3392, 2625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1634,  220, 2147, 1260, 1061,   32, 1081,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  884,   98, 2102,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1062,    1,   37,  151,   39,  612,  111,    9,    1,  131,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3178,    1,  590,    1, 2788,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,  75, 991, 365, 259, 261,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  75,  37,   1, 388,  45, 166, 116,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1156, 3354, 1557,  650,    1,    9, 1065, 1190,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 3042,  161,   37,  504,  755, 1876,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1829,  303,  108,   45,  442,  448,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3364, 3396,  190,  865,   37, 1094,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,   12, 1509,  361, 2069,  693, 2443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  865,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1, 2196,    1,  420, 1261,    1,   45,   26, 1039,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  176, 2741, 2468,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2469,    1, 3252,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203,   91,  387,  460,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1707, 1313,  297,    1,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,  361,  463, 1447,   26,   46,    9, 2252, 1211,  442,  630,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3172, 1090, 1829,    1,  176, 2486,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  829, 1936, 1530, 1003,  176, 1718,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,  443, 2502, 1916,  167, 1174, 1411, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  882,  108,   98, 1151,   50,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  691,   12, 1481, 1396,  129,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129, 3134,    1, 1090, 3210,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   12, 2069,  590,    1,   32,    1,    1, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,  861,    1,  103, 1016,  650,  187,  129,   69,  477, 1552,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3055,   37,  624, 1468, 2376,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  841,   28,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  531,  446, 1070, 1428,   78,   37,  665,  166,  443, 2072, 2588,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,    1, 2965, 3139,   37,    1, 1796, 1920,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  886,    1,  220,  882,   98,  340, 1021, 2403,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2183, 3374,  650,  113,   39,    1,   45,    1,  114,  220,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  189,  376,  389,  125,  308,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2122,    8,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2596,   32, 1147,    1,    1,  787, 2414,    1, 2766,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,  176,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3323,    1,  191, 3318,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  544, 1366,  606,  105,  132,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2809, 1401, 3232,  608, 3296,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2751,   77,   28, 1450,   32, 1619,  361,  403,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  590, 3268,   32,  121,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 1428, 1149, 3338,  191, 3006,   32, 3376,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  424, 1981,   98,  844,    1,  538,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2463, 2712, 3322,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1023,  105,    1,  361,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3297,    1,   98,    1, 1569,   32,  422, 3154,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,  154,  360, 2308,  693,    1,  190,  877,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1577,  675, 2744,  572,  197,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  614,    9,  187, 2459, 1249,  166, 3271,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  776,   30,  203,  923,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    9,  698,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1465,  200, 2543,  124,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1047, 1536,  104,   43,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  902,    1,  191,    1,    1,  501,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147,  957,    1, 2764, 3356,  562, 2024,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1276,  548,    1,  119,  105,  106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  919, 1477, 1990, 1625,  220,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3385,    1,   32,   12,    1, 1447,    9, 2073,  549,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1353, 1106, 1107,  525, 2610, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  313,   37, 1421,   79,   32, 2304,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2605,  184, 1282,    1,  176, 1477, 1990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1940,    1,   32, 2872,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   21,  983,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141,   12, 1185,    1, 1289,    1,   32, 2236,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2751, 1260, 2696,   12,  756,   32, 1147,  787,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,   37, 1982,    1,  617,  618,   98, 1202,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   75, 1679,   80, 1108,  384,  171,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1343, 1305,  224, 1126,  105,  168,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2745,    1,    1,    1,   28,  105,  628,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537, 2700,    1,  365,    1, 2946,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2991,  614,  548, 1095,    1,  220,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  299,  765,   37,    1,  116,    5, 1281,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,  311,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  587,  176, 1390,    1,  315,   37,    1, 1711,   45,    4,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  449, 1173,    1,   12, 1568,  365,    1, 1234, 1863,  327,  593,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3400,    1,  176,  104, 1967,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  150,  267,  197,   37,   52,  176,  340,  439,   45,\n",
      "         2320,  328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  707,   79,  166,   22,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  433,  908,  302,   98,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,  659,   61, 2812,    9, 1718, 2264,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  593,   12,  553,    1,    1, 2616,   96,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,   12,  365, 1734,    1, 2995,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1484,    9,    1,   28,  522,   37, 1496, 3361,  384,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 1034,   32,  861,  550,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  136, 2520,    1, 1896,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  197,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3172,  103, 1090, 1829,    1,  176, 2307,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,    1,   10, 2591,  167,    1,  171, 3145,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2676,    1, 3128,  774, 2095, 2126, 1665,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843,  140,  248, 3023,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,    1,   28, 1273, 1013,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1674,  379,    1,  365, 1995,   98, 3207,   12,  671, 3126,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3199,  162,  726,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2724,    1,  314, 1727,  630,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  694,   12, 2771,  173,   39,   45,  289,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3170,  288,   37, 1343,   32,   72, 1463, 1917,  691,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1486,   37,   47,   48,   32,    1,   37,  125,  734,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2882, 1005, 1449,  140,  199,  776,  176, 2041, 3292,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  247,  569,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,    1, 2988,    1, 2997,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  744,  837,    9, 1411, 1778,  659,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1033, 2211, 1749,  856, 2095,    1, 2673,    1,    1,  442,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1298,    1, 1564,  183, 2489,    9, 2748,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2809,    1, 1110,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  784,    1, 2692,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 2124,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  902,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1458, 2884,    9,    1,   12,    1,  528, 1665,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1298, 1178, 2583, 2489,  183,    9, 3249,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,   44,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  366,    1,    1, 1360,  612,  222,    1,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3092,   37, 1539,    1, 1463,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,    1,  166,  559,  187, 1340,  162,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  678, 2275,  884,  631,  297,   10,   32,  428, 1002,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,   37,    1,  600,    1,    4,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  882,  108,   98,   15,    1,  387, 1424,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1147,    1, 1867,   16,    1,   61,  193, 2764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2826,    1,  255,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3363,   96,    1,   37,    1,  195,  442,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3180, 1844,   39,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  147,   37, 1709, 1842,  260, 2285,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 2468,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  548,    1,    1, 1983,    1, 1000,  365,  223,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   29,    1,  219,  157, 1083,   60,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2787,   12, 1513,  193, 1023, 1628,    9,  365, 1788,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  321,    1, 2527,  164,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  968, 1542,   37,    1,    1,   85,  625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,    1,  506,    1,    1, 1167,    1,  321,    1,    1,   32,\n",
      "          751,   37,  651, 1031,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  146, 1983, 2836,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,  279, 1228, 2639,    9,  517,  618,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1192,   32,  395,  220, 1056,  365,  436, 2152,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,    1,    1,   12, 3059,  619,    1, 1517,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,    1,   37,  120,    1,  191,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203, 2388,    1,    1,  176,  166, 2826,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1016, 2789,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1951,    1,   12, 2564,   37,  670, 1159,  104, 1086,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,    1,  600,  962,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  957,    1,  220, 1384, 2789,   32, 1844,   79,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  323, 2288,    1, 1380,    1,    1,   32,  759,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3214,    1, 1844,  186,  220,  119, 2098,  686,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  183,  978, 2483, 1254, 2334, 2793,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,   12,  365,  590,    1, 1665,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  163,    1,   12,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  116,    1,  577,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  726, 2094,  753,   45,  225,  218, 2401,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1897, 3175, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,  236,  237,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  487, 3102, 2572,   32,  531,  844,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1211, 2878, 2867,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  413, 1082,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  355,    1,  342,  477,  132,    1,  439, 1350,  927,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,    1,  191,    1,    1,  182,   32,    1, 1639,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,  361,   39,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2871,    1,   39,  187, 2748, 2565,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,  162,   57,  384,  395,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2804,   45, 3203,    1,    1,   12,    1,  898, 1530,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1176,  123,   37, 1140,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1865,  593,   12, 1524,  553,  442,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564, 2846, 1727,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2802,    1,   37,  885,  593, 1990,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,    1,  114,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  342,  475,  113, 2339, 3374,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2565, 3281,   37, 1046,  709, 3273,  220, 3181,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  191,   32,  963, 1663,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2505,    1,   45,  105,    1,  627,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1360,  612, 2192, 2851,  861, 2996,   37,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2862,   37,    1, 3351,    1,  885,  356, 2789,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  691,   37,   92,  861,  207, 1425,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878, 2164,  274,  105,    1, 1568, 1569,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2920, 2712, 2475,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 2662, 2918,  123, 1680, 2684,  548, 2981,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1051, 2369,  861,   98, 1067,  280,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1310,   37,    1, 2288,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1817,    1, 2911,   37, 1174,    1,  411,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  358,  359, 2035,   46,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1021,    1,    1,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,   98, 1996,  769,    9,    1, 2105,  920,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  190, 1745,    1,   98,    1,    1,    1, 1877,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,   61,  800,    1,    1,    1,  361,    1,   37,  631,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1277,    1,    1,    1,  357,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  163,    1,   12,    1,   22,  477, 2414, 1056,   32,  531,\n",
      "           12, 3391,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3227,  442,    1,   37, 3182,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12, 2401, 1494,   79,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1077,  152,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,  590,    1,   98,  898,  180,  170,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1181,   37,   47,  163,    1,   12,    1,  845,  846,  259,   32,\n",
      "          411,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3397,    1,    1,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  176,    1,    1,  460,  810,  357,  193,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1013, 1522,    1, 1381,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  845, 1625,    9, 1081,   12,  365,  650,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1155, 1151, 1069,  250,   32,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2529, 2164, 2668, 1850,  455,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  166,  787,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  103,   45, 2933,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1051,  494,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2105,    1, 2530,  103,  818,  315,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,   82,  267,  435, 1100,  769,    9, 2168,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1050,  458,    1,   37,  151,    1,  129,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3182,    1, 2908,    9,  340, 1641,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,  696,    1, 1778, 2580,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2534,    1,   37,  335,  822,  522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  179,   32,    1,    1, 1597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,  413,    1,  187, 3343,  344, 1950,  418,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  770,   45,    1,    1, 1976,   32, 3360,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2388,   30, 1161,   32,    1, 3229,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1625,   45,    1,  165,  191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  223, 2393, 1646,  794,  506,   37,   33,    9,  629,   45,  175,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1691,    1,   71,   28, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3045, 2856, 3361,  187, 2292,  490,    9,   72,   74,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 1753,  297, 1520,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  387,  983,  530, 1944,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,  162,  388,  259, 1397,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  474,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  321, 1937,  105,  627,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  501,  852,    9,  454,   37, 2200,  931, 3130,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,    9, 1011,  549, 2343,   12,    1, 1532,  388,  763,  182,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267, 1340,    1,    1,  195,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1936,  166,    1,   45, 3022, 3024,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  526,  187,   69,    1,   14,   15,  817,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  942,   12,  103, 1619,    1,  267,  954,  603, 1509,   32,  537,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  288,   37,  245, 1010,  845,   69,  636,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2154,  949,    1,    1,    1, 1089, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2245, 2685, 1594,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,   1, 191, 616,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 863, 190, 184, 236, 237,  12, 765,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,   37, 2237,  567,    1,   78,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537,  460, 1479,    1,  207,  197,  407,  118,  187,  486,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2425, 1614,  754,  361,  803,  756,  861,  280,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1010,    1,    1,    1,    1,  877,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 1141,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  193,  810, 3229, 1574,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  411, 1104,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1668,  619,    1,  220,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1953,   32,  829,  400,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2771,    1, 2094,    1, 1787,   37, 2742,    1, 2059,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,  32, 166,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 199,  98, 375,  12, 175,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,    1, 2238,    1,    1, 2403,    9,  365, 1090,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1829, 2321,    1, 2807,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  544, 2397,   12,  606, 1942,   32,  467,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 2221, 1562,   10,   98,  596, 1793, 1563,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1771, 1236, 1509,  151,    9, 1791,    1,  112,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  614,   37, 2028,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2630,   45,  166,   74, 1940,   12,  361, 2161,   12, 1333,  665,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  612,  335, 1183,  326,    1, 2933, 2545,  918,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,    1,   45,  613,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3116,  922,   37,  843, 3272,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2308,  619,  105,  916,   37,  688, 2843, 2523,  176,  247,  248,\n",
      "         1090,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,    1, 1484,  531,    1,    9,  104,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 1273, 1974,    1, 1273, 1085,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,    1, 1765,    1,    1, 2946,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  661,   98,   25,    9, 1970,    1, 1332,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  626, 2541,  162,  410, 2407,  176, 2722,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1691,  823,  105,    1,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1144,  267,  365, 1273,   29,  841,   37, 1539,   32, 1332,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1051,   37,  130,  460, 1499,  700,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1, 2587,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   10, 1988,   45,    1, 2822,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  753,   96,   37, 2557,   32, 1645, 3102, 1512,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    9, 3358, 1348,   37,    1,   32,  176, 1428,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160,  102,   32,  104, 1285,  242,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1497, 1421,    1, 2967,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  442,  910,    1,   37,    1,  131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  176,    1,    1,  453, 1610,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1625, 2877,  321,    1,  163,    1,   12,    1, 2911,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2275,   10,   61,  590,  227,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  920,    1,    9, 1658,  327,  282, 2367, 2695,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3331,    1,    1,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  288,   37,   26,  417,  303,  343,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   37,   26,  242,   98,   93,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  227,  802,    9,  217,    1, 2487, 2175,  361,  707,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1451,    1,    1,  163,    1,   12,    1,    1,  244,   71,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2309,   45,    1,   51,    1,  105, 2290,    9,  166,  845,  147,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2573,    1, 2490,   37, 2000, 2527,  164,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  186,  361,    1,    1,  223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  756,  757, 1360,  612,  907, 1721,  156,  308,    9, 1843,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1818,  147,   37,  335,  552,  552,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1128,  162,   81, 1159,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  669,  251, 1821,    1, 1085,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2246,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,    1, 2297,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[ 2,  1, 37,  1,  4,  3,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,\n",
      "          0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0],\n",
      "        [ 2,  1,  1,  3,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,\n",
      "          0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3096, 2671, 2207,    1, 1921,   32, 2028,   37, 1195,  195,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  582,   37,  593, 1990,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,    1, 1267,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  619, 1658,    1, 2337,  460,   12, 1568,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  593,  476,   10,   39,   45,  166, 2087,  433, 1002,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479, 2776,    1,    1,   37,   47,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1822,  130,  730, 1777,  357, 1652,  586,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2037,   32,  166,    1,  866,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,  466,    1,   32,    1,  626,    1,  396,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 2673,  639,  475, 1082,  864,   37,  899,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  529,  408,    1,   37,  393,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,   32, 3310,  400,    1,    1, 1250,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   37, 2286,   37, 2446,  333,    1,   49, 1536, 2240,   32,  104,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2685,    1, 3233,    1, 3260, 2225,  365, 1132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3242,   21, 3215,  471,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387,  156,   28,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1366,    1, 1366, 1360,  612,    1, 2162, 1780,  320, 1584,\n",
      "          104,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 2779,  140,    1, 1447,   26,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3369,  213,   37,    1, 2025, 2117, 2924, 2117, 1039,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938, 1075,    1,  548,  449, 3160,  928,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 1707, 2868, 1140,    9,    1,  220, 1789,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1631, 1567, 3106,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   92, 1153, 1606,  983,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,    6,  636,   98, 1090, 1667, 1758,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1053,  295,  733,   48,   32,   22,  365, 2036,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 2948,    1,   32,    1,   28, 3012, 3027, 1821,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  273,  951,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2578,   81,   98, 1171,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  677,    1,   93,  729, 1018, 1816,    1,  267,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2377,   45, 3340, 1796,  774,  903,    1, 1447,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1585,    1,    1, 3379,  237,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110, 1285, 3251,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  275,  681, 1776, 1089, 1994, 2086, 1017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2594, 2783,  219, 3329, 1684,  191,  228,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,    1,   98,  223, 2135,    9,  810,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447, 2577,   24,    9, 2341, 1718, 1294,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  531, 1527, 3150,    1,   98,  454,   37, 2646,    1, 1056, 1530,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 1447,   37,  843,  864,  220,    1,  858,  116,  847,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158,  775, 1254, 2085,    1,  517,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310,    1,  219, 2153,    1,   32,  451,    9, 1952, 2396,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094, 2414,  103, 3374, 3384,  115,   45, 3339,  741,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810, 2258, 1610,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  147, 2151, 3139,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 1574,   37,    1,    1,   32, 1742,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1533,  917, 1900,  504,   32, 1056,  715,  171,  890,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  315, 1003,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  691, 1285, 2741,   32,    1, 1990,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2206, 2435, 1606, 1149,  477,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1645, 2924,   98,    1,  548,  557,  540,  555,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,    1,    1,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2591,    9,  365, 1009,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,   98, 2393,  548, 2764, 3394, 3060,  928,   32, 2625,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  854, 2744, 1527,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3194, 3195,    1,   81,   37,  563, 2388,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  403, 1447,    1,  469, 2317, 2191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2040,   45, 2531,   16,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2, 198,  94,   1, 715,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  61, 729,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  121, 2137,  342, 1512, 2509,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  493,  636,  720, 1086,  590,    1,   76,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2047, 1408, 3118,  249,   32,    1,  357, 1223,    1,  267,  215,\n",
      "         1190,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116, 2429,  335,   98,  365,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  449, 1023,  197,  418,   98,  104,    1,  310, 1220,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103,    1,  410,   37, 1610,    1,  865,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1652, 1380,  453,    1, 2072, 2355, 1718,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 2571, 3192,    1,  680,  885,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1830,    9, 1610,  164,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1737, 1090, 2554,    1,  403,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2206, 2435, 1236,  829,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,    1,    1, 1173,  384, 2616,   37,  218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  305,  619,  105,   92,  384,   29,    1,  677,   69,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  297, 2572,   32,  163,    1,   12,    1, 1995,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3108,    1,  612,   52,    1,  191,   27, 1306,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1542,    9, 2457,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1110, 1340,  140,  119, 1909, 3235, 1354,    1, 1863, 1624,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 1178,    1,   85,   32, 1785, 2044,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614, 1421,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  978, 3138,  498,   37, 1056,  356,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 2794, 3361,   81,   37,    1,    1, 1219,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  338, 1139,  444,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2832,    1, 2752, 3392,  548,  531,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1607,  231, 1106,   12,    1,  897,   28,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2411,   37,  764, 1211, 1056, 2178, 2161, 3340,   32,\n",
      "          531,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2438,   92,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  256, 2819, 1017,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,  949, 1411, 1778,   32,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  810,  288,    9, 2107, 1167, 2151,  105, 1833,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1309,  315,   37, 1664,    1, 1213,  797,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3358,  967,    1,  595,    1,  379,  774,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2591,   32,  119, 1397,    1, 1707,    1,  279,    1, 1294,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1100,  330,  104, 2683, 1929,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  566,  182,   48,   32,  141,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   64,    1, 1684,    1, 1003,   37, 1334,   98,  103,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  912,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  571,   37,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707,   12, 1065, 1190, 1707,  219,  474,   12, 2081, 1010,    1,\n",
      "            1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2347,  187,  730, 2614,  688, 3079,    9, 1194,  726,   32,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 1707,    1,   45,  531,  443, 1530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1110, 3059,    1,  191,  449, 1173,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,    1,  166,    1,  166, 1868, 1172,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  691, 2471,  163,    1,   12,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12,    1,  614,   39,  166, 2009,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  837, 1042,    1,  384, 1925, 1583,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2377,    1, 1515, 1530,  187, 3071, 2081,  897,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1221,   61, 1125,  548,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3186, 1421, 1417,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1771,  171,    1,  590,    1, 2388,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2694,    1,  625,    1,  947, 2572,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2652,    1,    1,  887,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 3102, 1757, 2424,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  179,   37,  125,    4,    1,   21,   44,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,   12,  449, 2918, 2699, 2133,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  191, 2789,    1, 3359, 2061,   98,  220, 3339,  469,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  102,   71,   32, 1169,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2043, 2962, 3014,    1,    1, 1048,  661,   29,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3372,    1,    1,  202,  590,  943,   45,  863,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2158,   45, 2121,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2776, 2348,  207,   37,  674,  578,    1, 2239,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  636,  490,  608,   32, 1033,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  397,  782,    1,    1,   32,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  544, 1013, 1522,    1,  712,   28,    1,   32,  105,    1,    1,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2731, 1013, 1145,   37,   52, 2889,  191, 1095,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  698,   45,    1,  776, 1961,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,  335, 1515,   16,   98,  166, 2041,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1303,  571,   37,  737,  197,  187,  593,  616,   16,   93,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,    1,   37, 1844,    1, 3020,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3230, 2137,  454,  608, 3198, 1159, 3329, 3295,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  640,  734, 2010,  548,    1,  155, 1961,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  785,  786, 2514,  461,   12,  786, 1056,   61, 1698,   45,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1, 1500,   48,   32,  141,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  572, 1117, 1943,   15,   71,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1940,   12,  872,  162,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  864, 1564, 3107, 2666,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3199, 1041,    9,    1, 2829,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3354, 3073, 2684,   32,  854,    9,    1, 1815,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1042,   39,   45, 2708,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428, 3406, 2872, 2970, 3349,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2548,  335,  297, 3362,   12,  754,   27,    1, 2117, 2658,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3335,    1, 1675,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   28,  548,   65,    1,  409,  159,  832,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2154,    1,  605,  798,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2235,   19,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1168, 1236,   35,    1,  487,  358,  297,    1,    1, 2847,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2386,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1082,    1,   37,  686,   81,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,    1,    1,    1, 2863,  973,    1, 1085,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,   37,  837,    9, 1411, 1778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3224, 3269,  738,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  515, 2637,  631,   32, 1764, 1990, 2941,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1573, 2155,   28,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2689, 1717,    1,  967,  460,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  448,  703,  176,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  273,  730, 2614, 2247,  102,   28,  118,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358, 1564,  365, 2362,   37,    7,  587,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  302,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,   11,  492,  777,  778,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  920, 3335, 2386,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  845,  275,    1, 1083,    1,  122,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3061, 2139,   37,  838,    1,   12, 2169, 1245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3370,    1,  488,   37, 2856, 1428, 1149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  116,    1,  187,    1, 2416, 2549,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,  816,   27,  339,  845,   98, 1057,  600,  632,  109,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1472,  255,    1,   73,   32, 3360,    1,  191,    1,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3251,  221, 1415,   37, 2016,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3282, 2468,  361,  166,  104,  190, 2228,   28,   32,    1,    9,\n",
      "         1764, 1990,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,  334,  335,  166,  336,    1,  337,  335,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  375,  536, 1133,  698,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  729,  590,    1,   32,  903,    1, 1661,    1, 1007,    1, 1384,\n",
      "           46,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2615,    1, 3108, 1542,   37,  698,  582, 1675,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,  267,  998,    1, 2765,  650,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  310,  159,  439,    1,  417,   98,  509,  297,   69,  102,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1401, 1971, 1987,  533,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,   98,  166,    1,  341,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2279,    1,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  447,   12,    1,   32, 2170,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  945,    7,   32,  651, 1031, 1523,  215,  420,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,  132,  220, 1386,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37, 1012, 1060,  388,   32,  854,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  392, 1411, 1778, 2232,  949, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232,  726, 2941, 2522,    1, 3209,   23, 1090,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  550,  365,    1, 3005, 1042,   32,  361, 3049,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  551,    1,    1,    1,   32,  109, 1259,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1348,   32,   54, 2164,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035,  159,  686,  105,  547,  356,  845,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  630,  251,    1,  361,  987,   37,    1,  793,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585,   32,    1, 1606,   12,    1, 1554,  786, 2572,    1,  297,\n",
      "         2347,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  388,    1,  657,  833,  612, 1289, 1744, 1243,   98,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2646,    1,  946, 3346,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2716,  176,  311, 2936, 3283,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  153,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1366,  248,  166,  463,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1573,   39,  166,  183, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  684,  734,  102,  245,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  416,    1,    1,  469,  105,  818,   32, 1821,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2468,    1, 2992, 1074,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   11,    1,  524,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  325, 1023,   45,    1,  317,   37, 1636,  453,  403,  294,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,   71,   32,  572,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1186,    1,  384,  166,  698,  260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043, 1086,  242,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,   12, 1354, 2556,    1, 2572,   32, 3246,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2561, 1998,  191, 2490,   12,    1,  176, 1687,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3097,    1, 2164,    1, 2707,    1,    1,    1, 3144,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1496, 1658, 1841,  548, 1658, 2162,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   94,   12,    1,  387, 1787,  176,    1,    1,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 1090, 1829,    1,  176, 1252,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  384, 3358, 2834,   61,  183,  112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  794,  469,   37,  194, 1983,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1059,   81,   32,  105,  183,  454,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1414,  439, 1850, 3339, 2625, 1583,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3270, 2297,  365,    1, 2565,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  103, 1985,   45, 1354, 2342, 2458,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1035,  952,    1,  384,  248,  624,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1268,   28,   98, 1021,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 2177,  260,   98, 3036,   81,  176, 1428,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3182,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  727,   12,  495,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2719,   10,   61, 1018,  792,    1,  792,  267,  403, 1447,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  479,   12,    1,   37,  930,  187, 1009,   98,    1,    1,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  102,  470,  187,  104,   25,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  496, 2483,  383,  433,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2384,  454, 2229,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  105,  778,   37, 1937,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  268,   28,   98, 1092, 1089,  943,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2964,    1,  111,  525,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1773, 2510, 1137,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545, 1654, 1146, 1703,  119,  220,  857, 3320,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  845,   36, 2880,    1,    1, 1095,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2565,    1,    1,  928,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1106, 1107,  525,  794,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,   78,    1, 2379,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1451,    1,    1,  163,    1,   12,    1,    1,  244,   28,  419,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  901, 2721,   51,   16,    1, 2721,  565, 1532,   45,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1492,   12, 1827,  384,   10,   12,  449, 2113, 2224,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  443,  193, 1018, 1144,  444,  864,  602,   12, 3139,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  220, 3056,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1159,  342,    1, 1218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1853,   37,  335,    1,   12,  764,   37,    1,    1, 1260,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  442,  910,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  776,   98,  457, 1038,   32, 3360,   61,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2658,   45,    1,  166,    1, 1387,   61,  920, 2812,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2929, 2800, 2277,   32, 2267, 1262,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3348,  650,    1,    1,    1, 1484,    1,    1,  361,    1,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2415,    1, 1494,   28,  183,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1891,  535,  661,  104, 2107,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1721,    1, 1069,    6,    1,    1,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1759,  309,  998,    1,  890,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1645,    1,    1,    9, 2789,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1131, 1443,  907,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1900, 1787,  261,   98,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  814,   37,  125, 1354,  111,  442,    1,  191,  786,   72,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   71,    1,   68, 1042,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3095,    1,  147, 1250,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3228,   77, 2315,  528, 3307,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  332,  636,  338, 1139,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3060,  741, 1297, 2062,  650,   77, 1021,    1, 1557,    1,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,  256, 1021,    1,  176,  166,  845,  439,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  232,  108,    1,   37, 1910,  531,  548,    1,   45, 2638,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,   37, 2286,    9, 3054,  846,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  223,   45, 3358, 1229,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   37,  142,  182,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98,    1,    5,  446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32, 3101, 2625,   98, 3374, 3061, 2172,   32, 3339,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  215,   12, 3355, 1458,  121,   12, 1140,    9, 1428, 2834, 3146,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2960, 2668, 2597,    1,    1,   27,  501, 2060,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,  368, 2003,  114, 2162, 1950,  418,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   68,   27, 1653,   79,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 2375,    9, 2018,  190,  583, 2024,   46,  854,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1698, 3051, 2024,   46,  619,   79,   37,  105,    1,  698,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  146,  147,    1,  148,   32,    1,  149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 1009,  964, 1827,  854,    9, 2707,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,  267,  395, 2609,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  200, 1507,    1,  658,    1,  999,    1, 2687,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  229, 1976,   32, 2625,   98, 1676, 2565,   12,  525,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1256,    1,  552,    1,  485, 1949,  326,  486,   24,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1063, 2682, 2500,  663,    1,   32, 1759,  309,  115,   45,  806,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  313,   37,   77, 2664,    1,  845,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  316,    1, 2016,  315,   59, 1340,    9, 3283,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1778, 2580, 2851,    1,  328, 2007,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1229,   37,   52,  380,  166,  327,  112,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3213, 1458,    1,   12,  798,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   15,    1, 1361,  120,  115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2295,  361,    1,    1,  928,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1744, 1147, 1763, 1306,   36,  297, 2292, 1406,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1029,  155,  962,   98,    1,  802,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  341,  113,    7,   37, 2741,   12, 2467,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1028,   10, 1685, 1915, 1355,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2936, 3129,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428, 2673, 1063, 1554,   26, 2360,   45,  903,    1,  464,    1,\n",
      "          220,  976,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  103,  176,  754, 2885,  786,   81,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328, 2379,    1,  387,    1,  372,  720,   32,   69,    1,  493,\n",
      "            1,  265,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51, 1910, 2611,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,   98,  166, 1314,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 3036, 3037,   98,  429, 2191,  548,  163,    1,   12,    1,\n",
      "          863,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1902,  900,    1,  574,  488,    1,    1,   28,   32, 1799,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2073,  328,    1, 1077,  105,    1,  182,    9,    1,    1,\n",
      "         1443,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  268, 1086,  857, 1469,    1,  387,  526,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,  166, 2731,    1,  496,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  162, 2317,  611, 2113,    9,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810, 2948,  844, 1074, 2058,   79,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  384,    1,   37,  166, 2918, 1658,    1,   32, 1698,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 2423,  897,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3358,   12,    1,  267, 1389,   45, 2162,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,   66,  526,    1,  752,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  138,  618,  606, 1752, 1018, 1691,    1,    1,   28,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2789,   45,  968,   12, 1009, 2789, 1032,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,  168,    9,  370,    1,    1,    1,   45,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  220, 2685,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1786,    1,    1, 3304,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1086,  530,   98,  889,  109,  997,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   37,  405, 3291,    1, 3310,   12, 1851, 1167,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 2909, 2708,    1,    1, 1396, 3374,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  476,  943,   98,  403,    1, 2673, 2375,  210, 1195,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1142, 1143,   12, 2304,    1,  105,    1,  176,  654,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1060, 2572,   32, 2169, 3279,   32,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1127,  794, 1273,  259, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,  213,   37, 1604,   98,  269,   67,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 2597,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2476, 1573,  460,  838,   32,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,   37, 1285,   28,  187,   69,  636,  953,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  410,    1,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2950, 2372,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3188,    1,   32,  714,  202, 1110,  664,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  868,  176,  593, 1990,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2525,   45,    1, 1107, 2223, 2758,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 2559,    1,    1, 2482, 2911,   98,  954,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1053,  159,  439,  699,  242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   47,  159,  361,  108,    1,   51,   71,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  877, 2237,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,  478, 2391,    9,  166,    1, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1, 2547,  726,  129,  872, 2948, 2015,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  548,    1,   45,    1,    1,    1,  321,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1362,  656,   37,   47, 1870,  280,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 3160, 2572,   32,    1, 2596, 1585,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999,    1,    1, 2212,    1,  778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1474,  267,  460,  190,   26,    1,  132,   37, 2015,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2717,  680, 1665,   32,  492,    1,  361, 2169, 1512,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   13, 1203,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 2170, 1898, 3354, 3046, 1074,   37, 3109,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1287,   98, 2187,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  999,    1,    1, 2385,  612,    1, 1488,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 3078,   37, 1734,   98,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  613, 2348,  220,  179,    1,    1,    1,  361,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  463, 2170,  190, 1468,  105, 2107,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3266, 2434, 1021,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1785, 2044,   37,  423,   69, 1069, 1208,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2508,  696,  927,   45, 1585,  176,  104, 2103,  617, 2616,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2942,  162,    1,  220,  671,   32, 1211,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 2762,   32, 2580, 2324,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1775,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  437,  520,  271,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1317,  704,  104,  476,   37,    1,    1,  333,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  581,    1,   95,   45,  105,  457,    1, 2133,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  146,    9,  764,  187, 1060, 1530,    1, 1711,   45, 2377,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1463, 1669,  985, 2130,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1450,   32,  531,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  972,   37, 1306, 1497, 1090,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 1393,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2473, 2480, 2524,  388, 1102,    1,  590, 1766, 1767,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  166, 1438,    9, 3018,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1, 2550,    1,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  120,   45, 2597, 2292, 1554, 1530,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  259,  260,    1,    1, 1159,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2998,    1,  590,    1,  584,  171,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 2095, 2985, 1061,   32, 2235,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   20,   15,   37,  619,  365, 1513,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213,  166,    1,   12,  484, 1532,  166,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1863,  477,   61,  653,   79,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2297,    1,   12,  103, 3252,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2910,  764,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403, 1447,  680,  166, 1381,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1270,    1,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2924, 2681,  591,  285,   32, 2785,  686, 3349,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1848,   37, 1335,  514,   32, 1102, 1151,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  521,  443, 1610,  548,  531,  890,  104,  103, 3160,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,   69,    1,  232, 2572,   32, 2597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2028,  300, 1312,   37,  166,  671, 3126, 1385,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1013, 1522,    1, 1381,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2721,   45,  219,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1440,   81,   32, 1090,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1917,    1,   10, 1841,    1,  166,    1,    1,   32,\n",
      "          104,  806,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  626,  490,  548,  420,   45,   46,  220,  395,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3204, 1086,    1,  356,  220, 3329, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 1463,  546, 2673, 3085,    1, 1461,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1794, 2055, 2056,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3171, 3299,  187, 3271,  688, 3319,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  195,    1, 2763,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1577, 1419, 2785,   45,    1, 1274, 3004,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  141,   48,   98,  333,    9,    1,   54,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2255,    1,   26, 1039,    1,    1,    1,  361,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1012, 1228,    1,   32,  854,  191, 1411,  356,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   39,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2592,  162,  365,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 1370,   45,  119,    1,  872,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   39,    9,  257,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3029,    1,  220, 1821, 2190,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  572,  197,   28,  118,   37,    1,  331,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  225, 2850,    1, 2753,    1,   28,  384, 1126, 1160,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,    1,   32,    1,    1,  187, 1018,    1,  361,  105,\n",
      "          304,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2476,    1, 3347, 3340,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2335, 2572,   32,  104,   22, 2262,   98, 3155, 2611,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3326,    1,   28,    1,    1,  202,  729,  664,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   16,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3115,  554,  608, 1178,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   50,  600,   37, 1054,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  104,   37,    1,    1,  267,  104, 3160,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1830,  228,  356,  210,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   65,  919,  347,    9,  601,  199,  424,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  749,    1, 2267,    1, 2051, 1328,    1,  175,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  420, 1261,  163,    1,   12,    1,  244,   32,  333,   45, 1147,\n",
      "           69,  680,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,    1,  459,   45,    1,   12, 1461, 1463,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2067,  176,  754,   98,    1, 1434,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1962,  140, 1088,  517,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  613,  772,  681, 1776,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  719,   37,  322,    1,    1,  331,   33,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2596, 1147,    1,   37, 2597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1352,   14,   15,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2729,  379, 2684,   32,  539,  458,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  573,    1,  884,   98,  386,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  567, 1414, 2800,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2800, 2565,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1520,   71,   45,  166,   94,    1, 1406,   32,   91,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1189, 1806,   98, 3366,  190, 1348,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1629,   12,    1,  661,   45,  166,  625,    1,  137,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1057,  897,  297, 2314, 3358,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1203,    1,    1,    1, 1871,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  636,  176, 1816,  220, 2979, 2869,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  420, 1092,  992,   28, 2086,  856,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,   12, 1718,    1, 2608, 1085,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   16,  190,  759, 2284, 1602, 2539,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  997, 1192,    9,  487, 3102,   32,  531,  548, 3026,   45,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1880,    1,    1,   32,   46,   98, 1610,  132,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12, 1117,   91,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  917,  361, 1827,    1, 2325,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1126, 2204,    1,  719,  227,    1, 2177, 1173,  422,  475,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  683,    1, 2216,  299,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,  131, 2332, 1306,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3358,    1,    1, 1890,  110,    9,    1, 2431,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187, 1018, 3151, 1756, 1552,    1,  942,    1,    1,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  305,  245,  187,  642,  643,   57,  103,  739,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3299,  187, 3296,  688, 2633,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  864, 1229, 1769,   37, 2810, 3162,    9, 2439,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1,  852, 1628,    9,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1340,    1,  242,  187,   65, 1293,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 1713, 1619,  310, 2532,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  506,    1,    1, 2705, 2007,   37,  531, 2874,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1403, 2933,   37, 1021, 2264,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2246, 3219,    1, 1632, 3152,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  614,   26, 1039,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1123, 3238,  515,  730, 2614,  593, 2522,  631,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613,   37, 2243,  365, 2480,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  737,  244,   71,    9, 1840,  361, 1200,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   88,    1,  183,   98,    1,   50,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  314,  551, 1692,    1,  187,  218, 1844,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  356, 1691,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171,  237, 1116,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1724, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  510,   51,  415,   52,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  591,   32, 2295,  590,  388,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700, 1604,   98,  596, 2693, 1260, 1560,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  311, 1107,  884, 1526,   39,   45, 1158,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  625,  967,    1,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2960, 2576,  449,   74,   45,  531,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181,  590, 2047,    1,   32,   91,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  352,  353,  354,   98,    1,   44,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1170,  225, 1137,   98,    1, 1012,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2676, 2375,  420,    1,  531,  443,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614, 2872, 3175,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   22,   23,    1, 1794,   37, 1343,   32,  531,  443, 2849,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  198, 2164, 2478, 1850,  455,    1,    1,   32,  409,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1652,    1,    1, 1534,   51,   52,    1,   39,   32, 1227,    1,\n",
      "          400,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,  997,  651, 1031,  139,    1, 1355,  163,    1,   12,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361,  200, 1901,   45, 2088,    1, 2639,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2763,    1,    1, 1048,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  461,    1, 1938, 3197,    1,    1, 2760,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2321,  664,    1,    9, 2119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2153, 1388,   98,  907,  166, 2122,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  502,  492,  491,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  415,    1, 2248,    1, 1366,  865,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,  938,    1, 2966,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,   12,  365, 1015,  972,   37, 1174, 2198,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1412, 2287, 1729,    1,  725,  168, 1273,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  458,    1,  170,   98, 1171,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1349, 1553,   32, 3141,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299,    1,   28,    1,  741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   11,    1,    1,    1,   12,   13,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    9, 1837,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 2976,  166, 2432,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,    1, 2888,  610,   37, 1312,  537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   39,   45,  683,  220,  968, 1918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  894,  166,  104,    1,    1,  493,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  614,    1,   32, 1756,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700, 1804,    9,  105, 1805, 1084,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  777,    1,    1, 1674,  915,  913,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   28,   37, 2894,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2266,  163,    1,   12,    1,    1,  163,    1,  903,    1,    1,\n",
      "            1,  428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  443, 2891, 1988,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1412,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1583, 2414,    1,   32, 3339, 2831,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   91, 1268,  885,  290,    1,  829,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 3164, 1231,   32, 2162,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3324,   12,    1,  744,   28,  183,  138,   74,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   14,   15,   71,  191,    1, 1146, 1703,   32, 1169,    1,\n",
      "          242,  763,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  321, 1619, 2170,   12, 2620,    1, 1824,  220,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  650,  315, 1296,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 1383,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    9, 1032,  750, 2471,  220,  854, 3128,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  503,   12,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,    1,    9, 3388,  973,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  224, 1042,  837,  636,    1,  879, 1611,   37,  906,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,  670,   98,  217,    1,  137,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,  176,  177,  786,  339,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  795,  134,    9,   32,    1,    1,  259, 2247,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1427,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1191,    1,  500,  123,   37,  116,  668,  132,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    6,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  877,  255,    1, 2219,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  552,  552,  698,   28,  162,  119,    1,  802,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1931,    9, 3281,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,  884,  199,   37,  398,  166, 2848,  805,   45,  365, 1017,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  636, 1681,   32,    1, 1370,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2328,    1, 2968,  853, 1781,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1702, 3167,   37, 2653,    1, 1816,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  315, 1018, 2747,  389,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  750,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2523,  952, 1477, 1990, 1064,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087, 2614,  838,   79, 3256,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  572,  197,  995,  242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1937,  682,  384,  531,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  134,   37,    1,   98,  109, 2429,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  446,   12, 1876, 1226,   98,  531,  122, 1603,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,  37, 231, 386, 469, 587, 720,  43,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 395,  12, 160, 623, 218, 897,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  614, 1092,  220,  844, 1151,    9,  617,  618,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3125,  288, 1757,    9,  591, 2664,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2151, 3046,   12, 1844,   37,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3171,  476,   37, 1330,    9, 2615,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1412,    1,    9,    1,   32,  443,   98, 2633,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3306,    1,    1,   45,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  286,  396, 1782,    1,   32, 1817,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  461,   16, 1774,   98,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  346,   29,   37,   16,    1,  112, 1161,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   28,  951,   94, 1547, 1946,  442, 2088,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  864, 1118, 2673,  250, 2410,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613,   12, 1411,  765,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3209, 2192, 1840,  247,    1, 1194, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1200,    1,  829,   37,    1, 1089,    1,  288,  921,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  667,  446, 1481, 2864,  601, 1002,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  104,   60,   85,  699,  444,   94,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2449,   32, 3388,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1764,  921,  104, 3275,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  446,    1,    1,   12,    1, 2001,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2768,  224, 2596,  365,    1,  111,    1,  852, 1167,  454,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1739,    1,  921,  590,    1,  511,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343,  861,   98, 2393,  115,   45,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3186,    1, 2435, 2317,    9,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   12, 1230,   37,  631,  160,  973,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1087, 1898,  112,    1,  361,  460, 1499,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2048,   45,    1,  741,   32, 1422,  863,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2355, 1013,    1,  288,   37,  686,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  224,   96, 1410, 1159,  645,    1,  951,    1, 1013, 1443,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  375,  476,    1, 1359,   37,  335,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  528,    1,    1, 1537, 1662,    1,   98, 1239,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  105, 2557,   98, 2332,    1, 1017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2808, 1314,   32,  447,   98, 1194,   74,   45,    1,   45, 3073,\n",
      "         2827,   32,  531,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1757, 2424,  220,  590, 1357,   98,  667, 3365,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1167,    1, 1292,    1,   37,    1, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2814,    9,    1, 2266,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739, 1249,  105,  331,    1,    1,    9, 3278,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3272,    1,   37,  759,    1,   26, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826,  715, 2161,  688,    1,   37,  335, 3077,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,   37,  335,    1,   54,   44,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2104,    1,    1,   45, 2673, 1867,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1307,   12,  218,  332,   81,  530,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 3397, 2770, 3118,  187, 1428, 1757, 2202,\n",
      "           39, 1622, 2924,  168,   37, 3369,  963, 2122,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2018, 3372, 1458, 3380,   32,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,    1,  631,   32,  411, 3343,  741, 2116,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2883, 3062,    1,   45,    1, 2774,  437,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  359,    1, 1384,  630,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2101, 1700,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,  220, 1184,   67,  423,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  736, 1708, 2465,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  225, 1279,   70,  276,  374,   25,  720,   32,   91,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1055,  931,  565, 1568,    9, 1104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715,  650,  292,    9,  112,   32,    1,  976,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  508,   79, 1149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,   25,  631,  166,  454,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3012,    1,  927,    1,   98,    1, 2436,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1259,  447,  361,  602,   79,  166, 2904,    9,  920,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,  69, 113,  27,  98, 889, 529,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 601, 401,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  215, 1852,    1,    9,  388,    1, 1507,  858,  412,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2899,    1,    1,   37, 1778, 2474,  618,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  754, 1190,   37, 2237,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  459,  802,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  651, 3133,    1,  600, 1793,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545,  193, 1894, 2398, 3213,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1188,    9,  846,    1,  614,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  578,  698,   45,  627,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  898, 1530,   32,  187, 3343,  863, 1552,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3113, 1550, 2339,  104, 1038,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2135, 2664,    1,   37,   52, 1530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  572,  197,  418,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  689,    9, 3323,  565,  388,    1,  548, 1056, 1133,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2597, 1585, 2414,  176,  177,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1548,   12,    1, 1277,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  191, 2441,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2817, 2856,  176,  177,   32, 3349,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1013,    1,    1,  191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3208,    1,   61,  810, 1425,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  635,  884,  197,  686,   37,   92,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2855,    1,  361,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  176, 1515,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  315, 1606,  333,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  185,  631,  409,   25,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  715,  471, 1071,   32,   72,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1471, 1499,  361,  474,  759,    1,  630,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  183,  730,    1, 2141,  837, 2051,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  195,  700,   42,    1, 1116,  798,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,   12, 1751,   39,   45,    1,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962,    1, 1401, 3218,  186,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564,  449,  125,   32,  257,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2993, 2070,  365,  114,  220, 3056, 1117, 1525,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226, 2233, 2192, 2588,  424,  786,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  612,  613,  765,   37,   47,  942,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3255,    1,    1,  744,  247, 2364,   98,  593, 1990, 3098,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  107,  894, 1083,   68,   69,  636, 2880,    1,    1,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1223, 1976,   32, 2433,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2345,  166,    1, 2658,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2759,  280, 2030,  176,    1,   16, 3004,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1,    1,  829,    1,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   92,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3297,    1,    1,    1, 2260,    9,  590,    1,   32,  428, 1002,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2466, 1210,   10,   37, 1594,    1,  384,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,  459,  372,  301,    5,  125,    1,  735, 2187,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2863,    1,   28,    1, 1614,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2432,   32,    9,  829, 2232,    1, 2762,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  870,    1,   37,  125,    1,  191,   32,  283,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,   19,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2298,  470,  997,   45, 1395,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  398,   12,    1, 2250,    1,    1,    9, 1997,    1,  857,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3227, 1451,   37,  698,  444, 2551,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2101,   45,    1, 1270, 1660,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2202, 1159,  105, 1569,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2925, 3254,  105,  227, 2810,    9, 1971,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  170,   51, 1245,   28,  856,    9,  613,   17,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  183,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,   45,    1, 2660,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,  600, 1085,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808, 1107,  794, 1107,  525,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  121, 2216, 2834,    9,    1,  880,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  547, 1530,   32,    1, 3246,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,  267,   37,    1, 2673,  210,  220,  357, 2198, 3385,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  590,    1,   32,  463,  507,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1567, 2457, 2564,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2316, 2545,  844,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  197,  407,  176,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,    1,  708,    1,    9,   82,  389, 1118,  136,  593,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 1621,    1,    1,    1, 2340,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  169,  361,  702,   37, 2123,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,   12, 1823,    1,  181, 2608,  910,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  365,    1,    1, 2983, 2952,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3386, 1940,  610,   37,  611,    9,    1,  312,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1312,  729,  176, 2738,   32,  722,   37, 2596, 1050,  147,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  171,  256,    1,    4,   32, 1352,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1451,   37,  771,  111,    1,   37,  440,    1,    1, 3000,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  757,  624, 1359,  967,  365,  111, 1597,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 1586,    9,  105,    1, 1376,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  700,  187,    1,    1,  531,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1963,  267,    1,    9, 2275,  193,  105,  629,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2835, 1830,   37,    1, 3358,   12,  770,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,  155,  156,  361,  200,  365,  469,    9, 1233,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  410,  578,  384,    1,   98, 1184,  347,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1386,  933, 1827, 2778,    1, 1500,    1, 1291,   32,  945,   37,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1419, 2366,    9, 1211,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280,  140,    1,    1, 2472,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  596,    1,  408,  554,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  105,    7, 1370,   45,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  946,   32, 2890,  336, 2426,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2680,  794,    1, 1117, 1525, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  191, 1922,  793,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1824,   28,   37, 1515,  103, 2788,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  538, 1182,  562,  261,   98,  207,  297, 1021,  847,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2570,    1, 1252,  103, 3172, 3134,  806,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1043,  640,  786,  339,  181,  340,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1463,  546, 1400, 2320, 1461,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  408,   71,    1,   15,   37,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  325,  111, 2655,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  882,  891, 1809, 2261, 1114,  548, 1985,  356,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3029, 3027, 1478,   98,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   98, 1220,    1,  176,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   82,    1,   45, 1485, 2281,  927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2573,   12,    1,   32,    1,  220,  215, 1904,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597, 2656, 3091, 2137,  957,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  314, 2120,  103, 1682,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  217,    1, 2033,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2871,    1,  590,  484,   98, 3229,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2249,  402,    1, 3241,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,    1, 2162, 1950,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2355, 1013,  191,  439,   45,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2223, 2315, 1821, 1539,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,    1,    1, 1624,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3256, 2317,  398, 2853,   27, 3207,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3188,   30, 1677,  528, 1044,  449, 2925,  698,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3181,   12, 3306, 2770,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61, 1284,  298, 1434,   32, 3141,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1238,   22,  387,  152,  152,   32,    1,  408,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2368,   28,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32,    1, 1450,   98,    1, 3392,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  232,  487, 3102, 2399,   37,  836,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  908, 1281,   98,    1, 2208,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043, 1268,  242,    1, 1946,  191,  496,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1100, 1627,  166,    1, 2060,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1974, 2584,    1,    9,  914, 3201,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  829, 1039, 2690,  333, 1924,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  870, 1962,  108,   45,    1, 1080,  384,    1, 1273, 2866,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  395, 2785, 2705, 1687,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3089,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,  37, 151,   1,   1,   9,   1, 131,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  69, 636, 176, 365, 119,  45, 530,   1,   1,   1,   1,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1635,  103,  314,  710,    1,  225,  418,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3216,    1,  754,   37,  593, 2522, 3217,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2275,  822,  872, 1098,   61,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1063, 1450,  161,  841,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1242,   32,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  155,  157,   98,  596,  259,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  582,   45, 1309,  573,  574,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843,   39,   45,    1,  260,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3066,    1,  191,    1,   12, 2022,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275, 2476,  230,  176,   48,   32,  863,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  162, 1056,  365, 2108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12,    1,    1,  515,   28,  622,  317,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   35,  155,  529,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3247,  230,    1,   39,    9, 1694,   45,  356,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3010, 2871,    1,   28, 2125,  260, 1489,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,   71,   32,   91,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 1377,  163,    1,   12,    1, 2150,  695,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  469,   37,  288,  119,   73,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  387,  244, 1253,   37,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  750,   61,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  388, 2329,  972,   98,   10,  398, 1586,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2217,  765, 1415,   37,    1,  365,    1,  187,  233, 2424,    7,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  844,   30, 1928,   45,    1, 1147,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2206, 2207, 2313,  140, 1962,  103, 2223,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  491,  361,  971,   32,  201,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  884,  105, 2474, 1333,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1756, 1665, 1552,  297,  593, 1990, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12,    1,  288,   37,  674,    1, 2550, 1597,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  761,  108,   45,  762,  384,  453,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  267,  967, 1461,  220,    1,    1, 2320,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2844,   45,    1,  548, 2504,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 1480,  698,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  885, 1918,    1,  191, 1497,    1,  750,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1349, 1058,    9,   91,   12,  365, 1350,  475,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2680,    1,  136,    1, 1994, 2650, 3004,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181,    1,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  455,   12,    1, 2300,  119,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1024,   12,  298, 1484,    1,   37, 2762,   32,  166, 1948, 1294,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  506,  155, 1057,  297,  230,   45,  761,    1, 1646,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  352,  193,    1,   98,   24, 1281,   32,  430,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2565, 1581,  881,  548, 3172,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187,    1,   37,  116,   19,    1,  746,    1,   28, 1263,  809,\n",
      "         1379,   12,  112,  499,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 571,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  68,  70, 245, 388, 763,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12, 1184,   67,  423,    1,    1,  202,  193,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  187,    1, 1086,    1,  166,    1,   45,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3200,  972,  664,    1,    9,  356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  121,    1,   32,  726,  297,  104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1082,   10,   37,    1,    1,    1,  220,  942,    1,  593,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,  571,  903, 1447, 3396,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1237,    1,  187,    1, 1149, 1027,    1,  868, 1159,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3358,   12, 1404, 1450,  247, 3404,    1,    1,   79,  105, 1300,\n",
      "         2811,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2179, 1381,   61,   98,    4,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3096, 1292,    1,   45, 2693,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2206, 2435, 1606, 1149,   37,  168,   81,   37, 1604,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  294,   37,    1,   11, 1202,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353, 1913,  401,  354,  951,    1,    1, 1490,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  297, 3141,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  215,  891, 1479,  858, 1027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1772,   95,  220, 1808,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1412, 1107, 2610,    1,    1,   37,  693,  810,    1,    1,  810,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  776, 2306,  288,    9,   43, 1167,    1,   79,    1,    1,   45,\n",
      "            1,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,  354,  384,  166,    1,   45, 1918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 2586,   45, 2196,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1183,    1,  384, 2800,  289,   37,    1, 2800,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2770,  968,   12,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3110,   12,    1, 2781,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   30,  203,   37,  168,  754, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282,    1, 1294,  193, 2175,    1, 1371,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1035,    1, 3076,   12, 1780,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  116, 3017, 1008,  619,    1,  432,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2615,    1,  730, 2614,    1,  220, 1131, 1684,   98,  166,  260,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398, 1458,  647,  253,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3186, 1747, 2842,   45, 1986,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   46,  439,  220,  590,  163,    1,   12,    1,  651,  132,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1628, 2810,    1, 1628,    1,    1,  227,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  485, 1949,   54,  486,  132,  220,  326,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  387,  572,    1,   93, 1424,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  507,  891, 3155, 1995,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,  765,  786,   84, 1415,   32,  453,  142,   37,  335,  297,\n",
      "          105,  413,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3226,  998, 1133,  548,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  496,  460, 1278,    1,  699,   32,  385,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2823,  736,    1,  160,   29,  343,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2, 111, 575,   1, 388, 424, 818, 914,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 225, 218,   1, 995,   1, 548,  69, 640, 119, 104, 234, 182, 235,\n",
      "           1,   1,   1, 234, 182, 235,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  377,    1,  469,   37, 1012,   32,  411,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12, 2881,  108, 1033,   45, 1718, 2039,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  193, 2978,    1,   98,  166,  168,    1,    7,   95,\n",
      "         1816,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  123, 1680,   45, 2662, 2918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  455, 2450,   37, 2192,   28,  753,   98,  531, 3102,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1380, 2890, 2072, 1922,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1233, 2514,   53,   37,  730, 1571,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  262,  263,  197,    1,    1,  225,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3102, 2377,  865,   37,   36,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2136,   85,  754, 2304,    1,  105,  910,    9, 2275,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3292,  142,   37,    1,   32, 3292,  638,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3403, 2414,   32, 1094,  220, 3358,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2835,  476,    1, 1311,   98, 1428,  861, 1906,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,  288,   28,  854,    1, 1798,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  203, 2983, 1505,  460,   12,  105,    1,   39, 1221,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885,  640,   59,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  754, 2913, 2146,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,  737,  156, 1253,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2164,  640,  878,  537,  857,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596,  977,  693,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1941,  359, 1054, 2046,  851,  548,    1, 1260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   28, 1658,    1,   32,  166,  777, 1013,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,  949,  365, 1778,   32,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,    1,  829,  872,    9,  786,    1, 1499,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,  903,    1, 1661,    1, 1007,    1, 1822,    1,   39, 1232,\n",
      "          460,   12,    1,   98, 1251,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1564,  453, 1509,    1,  915,  693,    9,  647,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  830, 2523,  159, 1022, 1385,  631,  176, 1062,  458,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 1707,    1,  204,  792,    1,  792,  993,   98,  531,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   64,  799, 1658,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  701,   98,    1,  996,  739,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3308, 1990,    1,  919,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3075,  267,  593,    1,  191, 2292,    1, 2834,    1,  443,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  244,  187,  613,   15, 1253,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   22,  847,  353,  105,    1,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  384,  105,    1,  361,  365, 2376,  855,    1,  284, 1011,    9,\n",
      "         2112,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3297, 2540, 1037,  275,   32,    1, 2771,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  739,    1,  187,   69,  418,  361,  104,  448,  703,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2202,  297, 3290,    1, 3228,  726, 1194,   73,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2050,    1, 1340, 1464,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3096,    1, 1632, 3275,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2238, 1380,  105,    1,   98,  105,    1,  327,  593,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  147,  597,    1, 3289, 3139,  321,   52,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1445, 1421, 1836,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1797,  114, 2897,  176,    1,  757,   32,    1,  854, 1711,    1,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101,    1,  741, 2507, 2022,  384, 3339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 2414,  176,  177, 1312,   32, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 3298,    1,  440,  785,  786, 3009, 2684,   32,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  160,  102, 1124,    1,  118,   32, 1352,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   53,   59,   45,  225,   32,  105, 1034,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  208,  991, 2985,   32, 1994,    1, 2596,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  980, 1159, 1286, 3179,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545,  619,  331,    1,   92,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  709, 3141, 1292,    1,    1,  598,   45,    1,  134,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3209,  563, 1110,   32, 2513,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3238,   81,   32, 1090,    9,   10,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,    1, 1415,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,    1, 2018,   37, 2000,  493,  965, 1816,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1,    1,   98,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1100, 1835,  365,  815,   45,    1, 2670,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1512,   46,  297, 3282,  590,   30,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3282, 1292,    1,    1, 2437,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,    1,   37,  576, 1133, 1789, 1263,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2563, 2290,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967,  445,    1,   98, 1990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  959,  786,   32,   56, 1244,    1, 1228,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2578,   98, 1224,    9, 2674,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,  384, 2502,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  288,   37,   26,  699,  417,  176,   26,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1557, 2023,    1, 2500,  524,  444,  957,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178,    1,  386,    1,    1,  191,    1,    1, 2540, 3262,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1107,  293, 1236,  219,  207, 2441, 2852,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3303, 2069,  187,    1,  338,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1709,    1,  600,  116, 1393,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 1619,  458, 1554,  347,   32,  913,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1346,    1, 2433, 3343,  787,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3297,    1, 3010,  183,    1,   32, 3278,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  288,    9,  889, 1616, 1821,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  415, 2446, 1345,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 140,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 425, 426, 376, 367,  15, 570,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  634,  370,  371,  953,    1, 1159,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  696, 1879,  688, 3318,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   64, 1118, 2755, 1306, 3010, 1090,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2339,  593,   45,  314,  282,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2760, 1564,    1,   27, 1762,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479, 1203,  600,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,    1,   12,    1, 2495,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2288, 1606, 1585, 1554,  176,  177, 1312, 1941, 3101,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 1427,    1,  103, 1569,    9, 2828,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2676,    1, 2136,   37,  907,   32, 1851,  736,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,    1,   37,  151,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1384,    1, 1770,   10,   37,  726,  863,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1337,  342,    1, 1681,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1509,  151,    1,  105, 1523,   45,  166, 2166,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  758, 1782,   98, 2355, 1013,    1,  267,  204,  190, 1334,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 1234,  140, 2343,    1,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3173, 2005, 1159, 2033,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    7,    1,   46, 1348,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  750,  696, 1497,  860,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1641,   28,  531,   69,  965,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 104,  22, 359, 562, 118, 138, 125,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 141,  48,  37,  52,  53,   9, 176, 177,   1, 131, 328,   1,   3,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2945, 1230, 1478,   32, 2235,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 2572,    1, 2006, 2347,   32,   64,    1, 2433,    1, 1850,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  221,    1,  410,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1419,  340, 1251,    1, 2168,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  460, 1278,   61,  105, 1628, 1265,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1937,  334,   32,  166, 3295,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,   47, 1778, 2580,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,   47,  574, 1132, 2071,  808,  167,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2047,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1707, 1428, 3146,  115,   45,    1,  741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2234,    1,    1,    1, 1675,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  150,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 3203,    1,    1,    1,   32,  403, 1447, 2900, 1801,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  515,    1,  645,  938,  661,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  296,  105,    1,  365,  443,  220,   20,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2095, 2985,    1,   32, 3360,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  721,  859,   37, 1599,   49,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   52, 2745,    1,  665, 1888,  997,   37, 1694,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2142,  162, 2761,    1,  361, 2689,    1,  384, 2672,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1536,  449,    1,    1, 2039,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,    1, 1749,  693,    1,   45,  365,  792,  617,  792, 1151,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,    1,  829,   12, 3042,  161,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  411, 1567, 1086, 3186, 1844,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,  389,    1,    1,  273,  520,  450,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1,    1,  361,  903,    1,   12,    1,   37,  907,\n",
      "          220, 2279,   98,    1,    1,  963, 2122,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3385, 1243,   12,    1,  464, 2673,  210,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  867,   37,  335,  822,  522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1444, 1445,    1,    1,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2991,  936, 2172, 2549,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325,  183,  141,   48,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1452, 1412,    1,  321,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2295,   65,  387,  646,   85,  176,    1,  419,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  296, 1565,   34,    1,  244,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226,    1,  182,    1,  331,    1,   37,  332, 1017,  361,    1,\n",
      "            9,  365, 1465,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,  782,  183, 1272,  967,  183,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  916,  176, 3220,    1,   98, 2069, 1675,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    4,  420,  105, 1479,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,  789, 2321, 2595, 2582,   37,  335,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,   32,   26, 1039, 2079,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,    1,   85, 3339,  622, 2456,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   25, 1269,    1,  329,  418,   63,    4,   29,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2890, 2826,    1,   12, 2213, 1844,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3016,  327, 1507,  763,  845,    1,  844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193,   37, 1358,    1,    9,  466,  682, 3380,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  190,  875, 1370,   45,  573,   43,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,  108,  460,  190,  317,  105,  183,  354,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1095, 1518,   32,   98,  463,  464, 1611,  433,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1427, 2306,  220, 2427,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  463, 1447,   37,  712, 1255,   12,  449, 3033,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  657,   26,   28, 1515,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  358, 1310,   37,    1,    9,  105, 2073,  199,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12, 1520, 2914,  593,   12,  553, 1395,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1497,  753,   37, 2842,    1,   37,  284, 3307,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2966,   45,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1421,   28,   37,    1,  176, 1123, 2322,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12, 3202,  288,   37,    1, 1957,  220,    1,  191,  247,\n",
      "          175,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3111, 1919,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273,  259,    1,  469, 2030,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1755, 1451,   28,   32,    1,  297, 2930,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,  332,  636,  418,  187, 2510,    1,  616,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1008, 2073,   82,   32,  257,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  763,  105, 1001,   13,    1, 2692,  696,  288, 1267,    9,\n",
      "         2975,   12, 1411,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056,    1, 3340,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203,  445,  190, 3245, 1343,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1191,    1,    1,   37, 1910,    1,  700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,  418,   98,   15,   45,    7,  229,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2779, 1426,  455, 3293,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1229,   37,  759, 2646, 2024,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  557,  540,  622, 1450, 2774,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  925, 1566,  613,  116,    9,  810,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2868,    1,  632,  232,   32, 3144, 1388,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  169,  942,    1,  929,   82,  813,    1,  297,  955,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2911,    1,   39,  440, 2621, 2165,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3247,  726,    1,  103,    1,  539,  220, 1214,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2732,   12,    1, 1713,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  454,   37,  764, 1000, 2164, 2986,    1,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,  953,   98,  143, 1235,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 2104,   37, 1173, 1159, 3148,   32, 3369,   12, 3118,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1214, 1940, 1061,  590,    1, 2812,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3322,    1,  750,   32,  199,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3108,  726,   72,   73, 2764, 1619, 1684,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  493,  102,    1,    1,   32,  915, 1056, 2119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  336,    1, 1220,  331,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   45, 3070,    9,  121,  361,  166,  593,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1042,  190,  489,   85,  117,  983,    1,  586,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2723, 2724,    1,    9,    1, 2943,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2885,   30,  104,  105,  175, 1366,    1,  612, 1847,  204, 2582,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  201,  529, 1415,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3198,  980, 1159,  601, 2197, 3329, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,    1, 1130,  197,  384, 1479,  179, 1901,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2308,  562,   46,   98, 2901,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1926, 1927,    1,    1,  952,  868,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  756,  757, 2034,  245,    1, 2216,  341,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  592,  845,   69,  636,  105, 1665,    9,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  386,  275,   50,  162, 2977, 1259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,  193,   11,   14,   12, 1986,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  384,    1,   37,  872,    1,    1,  171,  884,    1, 1992,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  815,    1,    1,    1,  168,  613,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,    1,    1,  157,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  696, 1198, 1110,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1983, 2078,   51,  168,  111,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433, 1513,  556,  741,   98,  993,  302,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  430, 2008, 1495,  220,  352,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1016,  859,  365, 2664,  663,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1249,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643, 1419,  365,  659,   45,  112,  786,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2694,  443,   98, 1158,   12, 1230,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  800,  389,  218,    1,  767,  877, 2457,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  552,  552, 1107,    1,  459,   98,  166,  183, 1305,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1448, 1749, 1077,  152,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  844,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973,    1, 2755, 3010,    1,    1, 1246,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  547, 3375, 2844,   32, 3339, 2831,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  640, 1514,  837,    1, 1654,  671, 3126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   53,    1,   37,  166, 1178,  176,  166,   81,   32,  166,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204, 1774,   98,   32,  105, 1280,   45,  247,  248,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1017,  187,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3325, 2850,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1481,   32, 1140,   37, 2108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2182,   79,    1,    1, 1149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3297,   12,  363,  361,    1,  914,    1, 2771,    1,  590, 3278,\n",
      "         1684,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  515,  388,  199,   37, 3343, 1386,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  221,   37,  222,  223,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160, 1161,  640,  339,  340,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1545, 2699,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3117, 1334, 1568,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  267, 1169,   15, 1556, 1139,   45,  570, 1672,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2301, 3022,  420,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2806,    1,  618,    9,  207,  279, 1484,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  459, 1167,  166, 2491,   51,   52,  297,   32, 2170,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  517,  162,    1,  220,  365, 2080, 2056,  413,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1796, 1091,    1,  131, 1395,  662,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2679,   45, 3172, 2509,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  594,    1, 2788,    9, 1139, 2679,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  914,   12,    1,    9,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3203, 2850,    1, 1401,    1,    1,  229, 1787,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2161,  603,  297,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3396,   64, 2592,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1558,  187, 3233,  512,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2374,  267,  460,  321,  612,    1,    9,   10, 2417,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2800, 1218, 1831,  812, 1762,  872,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1194,    1,   45,    1,  985,  928,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1117, 1525,  681,  588, 2819, 2389,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  992, 2017,  384,    1,  625,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2640, 1830,    9, 2069,    1, 1821,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12,  880,  529,    1,  162,  881,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  811,    1,  247,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2197,    1,  852,  176, 2218,   45,    1,    1,  384,    1,   37,\n",
      "            1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  906,   12, 2677,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1057,  176, 2895,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2596, 2414,   32, 1815,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3167,    1,    1, 1834,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,  220,    1,    1, 1017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  451,    1, 1429, 1929,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  289,   98,    1, 2711,  176, 1194,    1,   16,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,   51, 1048,  166,  454,    9, 1507, 1508,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,    1,   37,  686,  247,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3303,  361,    1,  288,   28, 2069, 1798,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1079,  105, 2038,  460,  650,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 2087, 2317,  191, 3141,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  590, 1090,   32, 2445,    9,  166, 3013, 3268,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1841,    1,  297,  674,   45,  854,   12,  366,  112,  437,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1759,  309,  112,  388, 2331,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  437,   37, 1539, 1994, 2275,  378,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  393, 2185, 1952,  420,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 1130,  912,  388, 1994, 2819, 2039,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962,  140,    9, 3241,    1,  153,    1, 2920,  664,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2069, 2753,  384,  104,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   91, 1458, 1412,  844,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3333,    1,    1,    1,    1, 1917,    1,    1,    1,    1,  683,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1739,  105,  331,  921, 1739,  275,   32, 2138,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2321, 1849,    1,    1, 1061,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1212,   12,  709,  695, 2789,   98,  166,   71,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  597,    1, 1156,    9,  133,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3096,    1, 2889,    9,  547,    1,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2997,  580,  786, 1056, 1136,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98,    1, 1898, 1785, 2658,   37,    1,    1,  574,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   23,   61,  220,    1,  548, 1292, 1681,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2505,    1,    1,   98,  845,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26, 1039,    1,    1,  361,  629,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2077, 1203,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  105,  974,  365, 2067,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1721, 1569,  701,   32,    1, 1605,  218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089,  789,    9,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1787,   10,   32,  365, 1708,  117,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492,  774,    1,   53,    1,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,   25,   71,   98, 1986,  600,  863,  180,  801,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  453, 1625,  361,  159,   98,  365,  195,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1120,   12,   37,    1,    1,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  446,  794,  365,    1,  210,  187,    1,   45,  863, 1708,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3343,  437,  267, 1407, 3365, 2440,  251,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  565,  288,   37,   26,  699,  242,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2004,  224, 1867,    1,   32,  163,    1, 2196,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1419,    1, 2549,    9, 2261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  303,  754,  102,  193,    1,  954,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    9,  166, 2041,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1689, 1645,    1,    1,    1,  928,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2652,  331,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  575,    1,   28,    1,  320,  544,    1,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,  403, 1447,   61,  105, 2416,  171,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3354, 1414, 2263, 2006, 2764, 2765, 2985,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2197,  288,   37,  949, 3358,  912,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,  267,  645,    1, 2624, 1360,  612,    1,    1, 1958,  231,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1178, 1179, 2013,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1744,    1,    1,  599,    1,   22,  261,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,  580,  342,  856,  297,    5,  347,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1396,    1, 1074,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 1018,  294,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  510, 2682,    1, 2517,    1, 2414,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1086,  417,    1, 2046,   37,  439,  477,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2,  10,  37,   1,   1,   9, 751,  37,  86,   1,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  25,  66,  28, 187, 265,   1,  84,  32,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  232,    1,    1,    1,  195, 1463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  852, 1023,    1,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   25, 1758,  187,   69,  102,  670,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1487,   37, 1289,    1, 1166,   17,  321,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3361,  927,  716,   45, 2764,    1,   12, 2263,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947,    1,  176, 1022,    1, 1324, 1325,   37,  439,  548,  977,\n",
      "          125,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1118, 3072, 1539,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  850, 1159,  584,  220,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2972,  361,  166, 2360,   45, 1513,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2446,  176, 1977,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  633,    1,  176, 2413,  220,  422,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181,    1,  882,    1, 1087, 1505,  437,   37,    1,  160,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 1571,  697,   37,  151, 1233,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3355, 1186,    1,   37,  163,    1,   12,    1, 2128, 2099,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2028,  261,   39,  104, 1031,   45, 1563, 2029,  460,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  338,   37,  365,  340,  444,   94,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2603, 1354, 2947, 1357,   98,  777,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275,    1,  562,  547,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,  174, 1672,    1,  921,  689,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545,    1,    1, 1231,  220, 2930,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  811,   32, 1759,  309,  187,  310, 2579,    1,   28,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2822, 1793,   61,  227,  550,    9,   69,  441,    1,  202,  193,\n",
      "            9,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  359,   37,    1,    1,    9, 2977,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481,  140, 2507,  601, 2113,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1053, 1707,  163,    1,   12,    1,  312,    1,  134,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2409,  967, 2639,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2,  14,  15, 720,   1, 118,  32, 367, 428,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 395,   1, 620,   1, 428,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,  171,  921,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,  700,  297,    1, 1281,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2584, 2225,    1,  582, 2565,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2355, 1013,  884, 1003,  176,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1,    1,  361,  166,    1,  335,  225,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715, 1379, 1161,  490,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,  469,   37,  815,  399,  187, 2611,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2246,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3188,    1, 3244,   77,   28,  166, 1224,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283, 3161, 1739,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3115,    1,  284,  388, 2754,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2875, 2640, 1542,    9, 1539,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,  952,   37,  211,  573,  589,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,  885, 1989, 1990, 1918,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1431,   12,    1,  873,  162,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1020,    1,  453,    1, 2583,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  639, 1936, 2650,   37,  147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  729, 2040,   45, 3238,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  299, 2424,  853,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  515, 2069, 1217,   37,  224,   12, 1126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,  105,  787, 1387,  105,  787,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  522, 1090, 2692,   53,  411,   98, 1095,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  566,    1,  221,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  705,    1, 2802,    1, 1417,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  729,    1,  176,  393,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 2386,  511,   45,    1,    1,  114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  370, 2055,  117, 1708,   32,  104,   37,  860, 1521,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447, 1877,   37,   92,    1,    1,  163,    1,   12,\n",
      "            1, 1707, 1220,   88,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1013,    9, 2504, 2734, 1530, 1052,   37, 2177,  686,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3269,   98,  166,  454,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,  224,    1, 1013, 1108,    1,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1020,    1,  105, 1665,   37,    1, 2946,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  466,  467,  468,   96,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144, 1557,   37, 1539,  477,   32,  741, 2096,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1711,    1,    9, 2024,   32, 1537, 1815,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,    1, 3271,   32, 2799,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3261,  108,  444,    1, 1118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  660,  331,   51, 1876,    1,  279, 1085,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2522,   45,  216,  813, 3387,   12,  865,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  446,   32, 2611,  548, 1656, 2291,  639,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  978, 1151,   25, 1269,    1,  523,  418,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3141, 3009,  688,    1,   37,  726, 1674, 1940,   12, 3134,\n",
      "         3077,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   39,   32, 2637,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  256,    1,    1, 1204,    1,   37, 2340,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3208,  671,    1,  166,  104,  220,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,   37,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  203,   37, 1012,  105,  172,    1,  166, 1868, 1172,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  477, 1337,    1,    1, 1069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  854, 1463,  546, 2673, 3085, 1461,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,   37, 2346,    4,    1,    1,  219,  112,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3292,    1,  140, 1524, 1267,   32, 2468,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 1466,   37,  125,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2247,  278,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,    1,   32,  493,  191,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   10, 2576, 2410,   45, 1537,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,  395,  155,    1,   54,   32, 1126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,  311,    1,   45,  573,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2678,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,   32,    1,  351, 1259,  220,  503,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3280,  515,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   25, 1473,  242,  187,   69,  102,  670,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1405,   82,   12,  700,  952,  270,  278,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  848,  200,  365,  526, 2105,    1,  313,   37,   92,  332,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103, 2565,  796,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3394,    1, 2221, 2632,   32, 2018,    1,  384,  864,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,  284,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  751,    1, 3277,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3258,  361,  219, 3129,  645,    1, 2413,  550,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3166,   37, 1343,  590,    1, 3119,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3035, 2856, 3361,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3308, 1990, 2677, 3186,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2980,    1,  215,  777, 1446,   17,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  666,   76,   37, 1251,  137,  182,  182,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878, 2458,    1,    1, 1753,  829,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  806,  774, 2275,    1, 1360,  104,  863,  736,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 3356,   12, 3357,  213,   37,  698,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   12, 2819,  469, 2443,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  882,    1,   48,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,  590,    1,    9, 1148, 1149,  220,    1, 1160,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523,    1, 3325,   37,  698,   32, 1477, 1990,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3166,    1,   79,   37,  105, 2056,  698,    1,  140, 3023,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,  267,  104,    1,  105,  792,    1, 2739,  792,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   63,  166,  862,    1,  338,    1, 1176,  418,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  155,    1,  372,   32,  125,  636, 1126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3371,    1, 3354, 2038,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835,    1, 2909,  837, 3095,  176,  177, 1530,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2095,    1,    1, 2516,   27, 2087,  433,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3260,   98,  105, 2365,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1333,  665,  571,   37, 1019, 3283,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1427,  829, 1402,    9, 2071, 1331,  769,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,   98,  112,  226, 1499,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  822,  533,    1,  314,   12,  401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  391,  108,  297,  531, 1002,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2551,  103, 3232,    1,  271, 1044, 1045,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2598,   37,    1, 3058,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  754, 2261,  193,  187,    1,  187,  154, 2898, 1160,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   94,  744,  365,  119,  845,  176,    1, 1714,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1292,    1,    1,   37,  168,   98,  260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  637,   79,  638,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537,  954,   37, 1192,  176, 2404,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  590, 1820, 1444,  416, 1263,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,   50, 1541,   51,   52,   53,    9,   81,    5,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  398,   32,    1, 1863,   12, 2162, 1342,    1,  223, 2221,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  497,    1,   32,    1,   45,  593,   12, 1568,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2587, 2971,   98,   71,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  195,  937,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1186,    1,    1, 1764, 1990, 1832,    1,  191, 2620,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066,   81,   32, 2741,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   29, 2483,  677,    1,  408,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  365, 2565,  176, 2451,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1962, 1419, 2432,    9, 2522,  618,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2087,    1,    1, 1564, 2218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387,    1,   63, 3404,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  547, 2360,   37,    1,    1,  176, 1742,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  123,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1559,    1,    1,   32,    1, 3057,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 2170,  267, 3342, 1822, 2259,    1, 3058,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  958, 2339, 2763,  220, 3374,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2740,    1, 3141, 3009,    1,   37,    1, 1674, 2276,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  696, 3115,  688, 2551,    1,  759, 2925, 1034,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018,  954,    1, 1133,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1411,   37, 1412,    1,    1,    1, 1173,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3386, 1700,  514,   45,  312, 2938,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1408,  455,    1,   98, 2224,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   59,  792,    1,  792,   32,  412,    1,    1,    1,  284,\n",
      "          412,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  755,  515, 1067,   37,  575,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,  830,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1855,  650,  140,  342,  379, 1322,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3045, 2856,  129,    1,   32, 2597,    1,    1, 3377,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3077, 1610,    9, 1006,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3378, 1484, 2153,   37,  776,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1549,  443,    1,   61,    1,  267,  625,    1,  290,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2079,   37,    1, 2713,  618,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2162,  722, 3347, 1156,   32,  104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1022,    1,  678,   12,  113,   79,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  420, 3125, 2253,   37,   38,    1, 3377,  297,   37,  437,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1936, 1228,    9,  105, 1463, 1027, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  936,    1, 1637, 1208,  327, 2177, 1027,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2748,  390,  590,    1,    1,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1450, 2856,  176,  177,   32,    1,    1,  531,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463,    1, 3338,  176,   46,  220,    1,   32, 3184,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,   69,  102,   71,  548,  957,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1341,  975,  190,   47,    1,  361, 1204,    1,   37,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  200, 1251,  125,  315,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676,  229,    1,    1, 2942,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1711, 1267, 1313,  176,  968,   12, 1619,  458,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,  622,  108,   45,  395, 1461, 1665,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1810,    1,  458,    1,    1, 2297,  191, 2178,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  673,    1,  338,   98, 3048,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3328,    1,  608,  594,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1268,  822, 1260,   98,  647,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  335, 2144, 1021, 2152,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  544,  460,    1, 2026,    1,  631,   37,  388, 2574,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3343, 1708, 1586,   28,  187, 3363, 2405,   37, 2743,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 2095, 3080, 1683,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1468,    1,  737,  354, 1052,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3012,    1, 2684,  176, 1821,  656,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,   32,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1674, 3096,    1,  531, 1426, 3293,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   30,  166,  917,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962, 3117,  186,   37,  688, 3271,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  654,   12,   59, 1143,  776,    1,  111,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   63,  166,  862,    1,  418,   98,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  231,  365,    1, 1090, 1354,    1, 2085,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  163,    1,   12,    1,    1,  342,  297, 2883,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  497,  190, 1636,   37, 2335, 1463,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  267, 1114,  148,  142,    1,    1,  460, 1360,  612,   47,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 2736,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1971,    1, 2761, 1902, 2737,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2925, 1090, 1829, 2570,  787,  176,    1,  827,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2795, 1114,    1, 1674, 1675,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   37,   26,   28,  187,   69,  102,  489,   81,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,  811,  289,   98,  531,  443,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  105, 1173,  176,  103, 1675,  361,    1,  440, 2415,   32, 1034,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  166,  193,    9, 1183,  922,    1,  166,    1,    1,    1,\n",
      "          967,    1, 1018,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2053, 2055, 1124,   32,  367,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843, 2202,   39,   45,  128,  548,    1,  698,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,   65,  977,   67,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006, 1124, 1876,    9, 3364,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  155,    1,   54, 1632,  333,   45,  391, 1329,  159,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  539, 1037,    1,    1,    1,    1,  202,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1278,   28,   32,   86,    1,    1,   31,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773, 1680, 2510,    1,    1,  837,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  294,  295,  315,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2491,   69,    1,   32,  228,  537,   79,   12,    1,  395,  540,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1674, 2962, 1617,  812,  365,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3407,    1,  973,  741,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  584, 1022,    1,    1, 2160, 2049,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790,   37,    1,  273, 1609,    1,  250,   87,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  140, 2376, 2223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,    1,  889, 2826, 2030,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614, 2408, 2572,  191,  947,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1, 2465,   98, 1801,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1227, 2257,    1,  384, 3018,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3001,    1,  176, 1422,   32, 2150, 1313,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  163,    1,  903,    1, 1096, 2751,\n",
      "            9, 3369,    1,  428,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433, 2263,    1,    9,    1, 2193, 3093,  650, 3351,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 1610, 1066,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2102, 1402,    1,    1,  267,  487,  160,  437,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  558,   37,  559,   79,  560,  285,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,   12,    1,    1,    1,   32,    1, 1575,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1680,   37,  151,    1,  886,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  989,    1,  990,  991,    1,  225,  151,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  657, 1949,  844, 1151,  934,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  922, 3210,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2297,  624,    1,  940,   45,    1,  176, 2977,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  936, 2851, 1876,    9, 1053, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,  388,  164,  165,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481,   51, 2872,   37, 1918,   98, 2842,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1251,    6,  764,  702,  317,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  793,    1, 1046,    1,  861,  127,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141, 1090, 1829, 1717, 3219,  176,  365, 1788,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  531,    1,  105, 2813,   37,    1,  786,  388, 2961,    1,\n",
      "         2948,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3402, 3408, 3160, 1216,   37,  284,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228,   28,    9, 1675,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  636,  423,  288,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1, 1976, 1530,   32,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  579,  190,  334,  544,  220, 1658, 1084,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1774,   39,    1, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 2075,   81,  297,  813,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 1756,   51,  193,   52, 2093, 2330,  199, 1371,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  647,   12,    1, 2813,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12,  535, 1863,    1,  105,  365, 2866,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  803,    1, 1171,  321, 1389,  183, 2298,    9, 2711,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  868,  885,  365,  845,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1189,    1, 1683,   32,  531,    1, 1625,  969,    9, 1130,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1891,  922,    1, 1734,   98, 1428,   32, 1430,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  550,   10, 1830,    9, 1610,    1,   45,    1, 1074,   32,  129,\n",
      "         1512,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2087,  313,    9,  105,    1,    1, 1838,   37,  166,  914,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1778, 2580, 2851,  328, 1961,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1744,    1,   98,  166,    1,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3198, 3205,    1,   32, 2936, 2069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1048, 1049,    1,   32, 2114,  550,  187,    1,  550,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056, 1530,   32,    1,    1,  187, 2406, 2885, 1921,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,   30,   79, 2071, 1331, 2403,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 1428, 3339, 3146,  193,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766, 1236,    1,    9,  768,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2883,   12,  299,   37, 1584,    1, 1844, 1114,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1941, 1951,  947,    1,   74,  548,  249, 1976, 1333,   27,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  873, 2415,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,    1,  537,  857,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3076, 2886,  612,    1,    1,   37, 1027,  905, 2462,   32,  180,\n",
      "         1990,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1786, 1535, 2659, 2501, 2502,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2480,  327, 1464,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   37,  151,   29, 1499, 1873,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2870,   32, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3120,    1,   45,   38, 1380,   64,   12, 2737,   79, 1922, 1090,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3121, 2414,   32,  455,    1,  176,  177, 2249,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  532,   71,    1,  104,  442,  910,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,  141,    1,  140,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2608,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1792,    1, 3066, 2455, 1539, 2980,    1, 2693,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  631,  220,  857,  186,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2672,    1,  162,   24,  881,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545,    1,    1, 1542,    9, 1832,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2615, 1173,   37,  335,  674,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  681, 1173,  115,   37, 1649,    6, 2311,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2615, 3294,    1,    9,    1,   32,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  894,  606,    1,  652,   63,    1, 3104, 1831,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  796,  548,    1, 2263,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1226,   37,  105,    1, 2260,    9, 1548,  631,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1570,   37,  151,  395,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  176,    1,    1,    1,  202,    1, 3281,  967, 1194,  915,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3075, 3067,    1, 2948,    1, 3036,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   85,  951, 1547,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1778, 2580,  861,  328, 1961,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3228,    1,  862, 2126,   39,  220, 1987,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  130, 1117, 1525,  669,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1320,   32, 1081,  313,   37,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  947,    1,  186,   27,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  268,  251,   37,  151, 1092, 2913,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  616,  838,   37,  395,   12,   67, 1124,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 3350,  536,  531,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  288,   37,   26,  417,  187,   69,  418,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  721, 1098,   45,  647,   26,   37,  170,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1545, 2800, 1218,  361, 2448,  386, 2800, 1218,  429,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,    1, 2859, 2971,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  310,  681,    1,  166,  275,    1,   32, 2468,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1120,   12,  166, 2904,    1,    9,  111,  302,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1796,  957,    1, 1193,    1,  548,  770,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2628,  884,  103, 2788,   32,  428, 1002,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,   37,    1,    1,    1, 1108,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  474, 1082,  562,   45,  895,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  854, 1463,  546, 2673, 3085, 1461,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018,    1, 2024,   32, 2646,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3117,  619,  538,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  854,   12,    1,    1, 2734, 1530,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977,   61, 1769,   37,  194,  166, 2293,   45,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  777,  834,   61,  579,   12,   32,  525,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1773,  313,   37,  184, 2869,  772,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,    1,  885, 2300, 1213,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1228,    1, 2474,  618,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  593,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1619,  458, 2126, 2808,  187,  166,   94,  418,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  213,   37,  290, 1159,  632,   36, 3071,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  756,  191,  166,  172, 1397,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885, 1034,    1,  885,  631,    9, 2885,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  262,  263,  225,  188, 1010,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1891,  593,    1,  220, 3358,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  716, 2137,  135, 2936,  493,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1021,    1,  297,  413,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  301, 1251,    1, 1306,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428, 1142,   30,    1,   32,    1,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2790,    1,    9, 3036, 2234,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,    1,    1,    1,   61,  786, 1385,  384,  449, 1918,   32,\n",
      "          537,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  711,    9,  333,  176,  105,  332,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  430,    1,  107,   69,    1, 1124,    1,  476,  242,  636, 2880,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  695, 2789,  140,    1,  890,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1149, 1046,  365, 1600,  261,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  547, 1785,  861,    1, 2572,  187, 2884,    9, 3006,  614,   98,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497, 2279,  590,    1,   98, 2925,    1, 1638,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  714,  176,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2947, 1230,  256,  173,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,   39,   37,  877, 2218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  819, 1882,   37,    1,  425,  426,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  114, 3145, 1632,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,   98,    1,    1,    1,  750,  565,    1,   12,    1,\n",
      "            9,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1247,   37,  698, 1517,  444,  730, 2614,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  304,    1, 2054,  680,   97,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  224, 2384,  224,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  331,    1,  375,  801,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   34,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1216,    1,   32,    1, 1512,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1110, 3188,  162,  284,    1,    1, 1398,  612, 2784,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380,    1, 3390,   32,  187, 2018, 1065, 1190,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2737,    1, 3310,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  733,   79,    1, 1149,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,  794,  290, 1159,   36, 3071,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1732,  183,  228, 1604, 2444,   37, 1027, 1273,    1, 1085,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2971,  187,  105,  312, 2502,    1,  227, 2549,    1,  193,  974,\n",
      "         2389,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  775, 2355, 1013, 2549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   69, 1226,   37,    1,  105,  106,    1,  105,    1,    1,  340,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,   32,  602,   37,  439,  701,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2924, 1000,    1, 2165,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181,    1,  882, 2274,    9,  617,  259,  589,  918,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  639, 1206,    1,  238, 1119, 1360,  612,  583, 3001,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1992,  384,  311, 3242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3151,  719,   37, 2898,  803,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1869, 1494,   37,    1,  220,  331, 1904,  469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  803, 1244, 1000, 1444,  321, 1824,  220,  183, 1510,  124,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 2229,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   82,    1,   37,    1,    9, 1841,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2221,   21,  388,  585, 1114, 1411,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  156, 1285,  242,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885, 3034,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  430,  477,   76,   37,  439, 2283,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2658,    1, 2202,   85,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 1718,  528,  342,  736, 3004,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  709,    1, 1213,    1,  187, 2500, 2955,  475,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 1564,  207,  861,  221,  191,    1,  633,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,    1,  626,    1,  125,  987,    1,   37,  615,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  395, 2201, 2003, 1585, 2162, 1950,  418,   37,    1,  753,    1,\n",
      "            9, 2249,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1497, 2025,    1,   37,    1,   61,    1,   79,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   80,   37,  759,   45,  104, 1219,   32,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2658,   37, 1599, 3304,   32, 1819,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  458,  625, 2007,  424, 1034,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3274,  361, 3169, 1140,   79,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2482,  361,  105, 1306,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115,    1, 3250, 2777, 1631,  284,  933,  361,    1,  388,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3251,  221,   37, 2016,   98,    1,   45, 1686,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  429,  700,   27,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 2524, 2175,   37,    1, 2232,   32, 1626,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2583,    1,    1,  619,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  938,  361,  978, 2614,  726, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3178, 1177, 1159, 1286, 3179,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  547,  454,  132,   32, 1809, 1167, 2222,  300,   50,   37, 3132,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,  933, 1412, 2528,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  446,  267,  531,    1,   32,  856,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962, 3252, 3224, 1401, 2633,  297, 3260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   12, 2571,  610,    9, 3058, 2282, 2286,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2820, 2481,  729,  105, 2919,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3369,    1,  582,   45, 1186, 1527,  639,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    1, 2056,  858,   61, 1120,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   16, 1822,  168,   98, 2198,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3339, 2611,   61,    1,  220, 1941,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   65,  155,    1,  105, 1194,  199,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   91,   61,  645,   37,  619,    1,  191,  460,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,  300,    1,  947,   37, 1413, 1428, 3406,   32, 3349,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 1405,    1,    1,  868, 1727,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  437,   45, 2458,    1,    1, 1236,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  381,   12,   54,  604,  442,  680,  549,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1307, 2373,  786,   59,  903,    1, 1090,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  167,    1,    1,   12,  517, 2234,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2962,    1, 2951,  187, 2615,    1,  730, 2614,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  134,    1, 1902,  220,  133,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 2818,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2345,  439,   45, 3071,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,    1,    9,    1,  131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  180,   12,  197,  418,    1, 1680,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2235,   12,    1,    1,  140,  103,    1, 2223,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1547,    1,  548,    1,   98,  455,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2820, 2619,   98,   37,  453,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1310,   37,  764,  163,    1,   12,    1,  681, 1706,   32,\n",
      "          976,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  851, 2421,    1,    1,   37, 3076, 2107,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  359,  474,   37, 1195,   46,  220,  793,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2800,  891,  365, 1015,  220, 2748,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  475, 1082,  522,  297, 3118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 199, 421,  12, 197, 948, 129, 441,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1361,  729,  198,   98,  148, 3004,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1306,    1,    1,  187,  582, 2565,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,    1, 1659,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1349,    1,    1, 2567,   98,    1,   16,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1390,    1,  331,   94,  209,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,   37,    1,    1,  659,   45, 2366,  892,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1039, 2690, 1013, 1522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,  778, 1370,   45, 3301,   12,    1, 2840,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   15,  720, 2070, 1278,  997,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181, 1518,   32,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  651, 1031, 1534,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3095, 2263, 2596,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2978,   98, 1171,    9, 1539,    1, 2104,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  198, 2164, 2668,  409,  361,    1,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  231,  829,    1,    1, 2744,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043,  332, 1738,   85,  118,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1662, 1701,  726,   59,  444,  777,  778,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  522,  176,  105,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1654, 2068,   37, 2895,  505,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739,    1,  315,  752,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  750, 2541,  267,  622, 2471,  220,  854,  190,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1,    1, 1464,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2275, 1708,  582, 1216,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 3006, 1910, 3346,   32, 2024,  132,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  987,    1, 2861,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  324,  958,  887,   46,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  600,    1,    1,  361, 3103,  606,    1,   98,  667,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  370,  253, 1947,  221,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2614, 2408,    1, 2245,  191, 2522,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  193, 1670,    9, 2024,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  861,    1, 1997,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   12,  299,  288,   37, 1505, 1386,   32,    7,  171,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  458,   45, 1423,  353,   71,   32,  156,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  729,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  523,   37,  138,  152,   37,  875,  422,  134,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  859, 1876,    9,    1,    1,  176,  105,  636,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  311,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2602,    1,    1,  166,    1,   61,  193,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1060, 2827,   32,  365, 1788, 1994,   10,    1, 1313,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3271, 1421,  375,   37,  786,  356,   24,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  207,  418,   98,    1,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2698,   45, 3395, 1178,   32, 1242,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  148, 2682,  647,  721,   98,  214,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942, 1226,  608, 2618,  176,   56,  497, 1990,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  103, 2855,   32, 3144, 2823,  741, 1046,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  705,    1, 1417,    1, 2171, 2547,    1,   32, 2086,  149,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  111,    1,    1,   61, 2213,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  706, 1398,  612,    1, 3281,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777,    1,    1, 1776,  956,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2073,    1,  548,    1,  484,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  487, 2924, 2572,   32,  531,  344, 2950,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,  542,  335,  856,   37,  166, 2488,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1100,    1,   39,  365,  845,  439,    1,  340,  439,  769,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1143, 1454,  247,  808,   32, 1436,  495,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3300,    1,    1,    1,   81,   98,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2436,  418,   98,    1,    1,  195,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2691,  753, 1089,    1,  220, 1185,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3244, 3284,  744,    1,  119,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  177, 3006, 2572,   32, 2018, 2262,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,  159,    1,   85,   32, 2088,  442,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1724,  885,    1,    1,    9,  667,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3194, 3195,    1,  590,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3151,  590, 1647,   32,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2741, 2753,  411,  361,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  321, 2277,   79,  166, 2498,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1557, 1900, 1860, 1065, 1190, 1161,  741,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1327, 1337, 2649,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1051,   37, 1835,    1,    1, 2239,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   85,   37,  166,    1,   32,  539,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  991,    1,  548, 1914,   12, 1263,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,  454,  530, 1717,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3243,  132,  972,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2956,  765,   37, 1947,    1, 1697,  361,    1,  317,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3186, 2449,   32,   84,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 2137,  296,  469,   37,  588,  365,  342,  209,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1423,  556, 1484,   37, 2446,  126,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  971,   91,  313,   37, 1911, 2270,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  359,   37, 2286,   37,    1, 3012, 3027,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  667,    1, 3340,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128, 2257, 2017,  384, 1087,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  487, 1107,  542,    1, 2102, 1402,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  313,   37,  335,  105, 1526,   39,   45, 1158,   12, 2102,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428,  146,    9,  949,   45, 3343, 3365,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2747,    1,    1, 2561,    1,  837,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1940,   12,  103,    1, 1993,  608,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2694, 3148,   32, 3369,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 1562,    1,    9,    1,   98, 1789,   12, 2225,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  960,    1, 1612,   39,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  315,    1,   22,   23,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179, 1249,  739,   98, 1565,   45,  613, 1160,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3365, 1683,  384,    1,    1,   32, 1640,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,  325,  492,    1,  778,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  865,    1,  384, 1821, 2699,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  313,   37,  439, 1158,   12,  179,   98, 1107,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158, 3007,    1, 2193,    1,    1, 1456,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437,   45, 2458,    1,    1, 1236,  829,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  780,    1,  587,  606, 1845,  630,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2895,  345,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  921,  105,  106,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  193, 1542,   37, 1198,  909,  444,  104,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  223,  113,   81,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141,    1,  474,  736, 2811,   63,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,    1,  325,    1,    9,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 3375, 2572,   32, 3339,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   11,    1,  297,  166,  116,  167, 2192,  334,  105,  985, 1260,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777,  325, 3028, 1017,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  487, 2924, 2684,  176, 1967,   32, 1619,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,    1, 2162,   45,    1, 3358,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094, 2414, 3374,  650,   32, 3140,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   71,   98,  720,   32,  160,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1325,   61,    1,    1,    1, 1354, 2181,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1985, 1530,   32, 3360, 2596, 1585,  104,  622,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   45,  311, 2936,    1, 3262, 1184,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2166,   92,    1,   12,    1,  260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  439,  242,    1, 1946,  191,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2104,  957, 1322,    9,    1,  321,  362,  112,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3192, 2741, 2579, 2619,   32,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,    1,  773, 1169,   15, 1121,  187,  493,  102,   71,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2421,   39,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   12,  978, 2953,   37,  686,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1547,  640,    1,  845,  951,   60,    1,    1,   29,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 1159, 1056,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  215, 1408, 2095, 2985,   32,  611,    1,  528,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1, 1249,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   25, 1285,  242,   69,  176,  339,  340,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  439,  242,   98,  577,  996,  550,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  596,  269,   37,  151,  326, 1085, 1501,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1718,   51, 1719,  636,    6,    1,  377,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   60, 1993,   28,  548,   94,    1,   85,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  231, 1100,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3181, 1917, 3314,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1707,  104,  214,  693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3216,  631, 2615,  548, 1056, 2799,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 1707,  104, 2081,   45,    1, 2106, 1021,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1765,  645,  590,  168, 2060,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179, 1586, 1158,    9, 2943,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  388,    1,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,   12,  160, 2355,  868,  105,  365,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2673,  639,  246,  864,  992,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37, 1195, 2851,  382,    1,  906,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  224, 2996, 3034,    1, 2762,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2185, 2461,    9,    5,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  691, 1464,   37,    1,    1,  420,   98, 1791,    1,  176, 3127,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1279, 1276,    9,  163,    1,   12,    1,    1,  455,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3114, 1345, 3147, 2924,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755, 1867, 2355, 1013,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,    1,    1, 2275,    1, 2746,   98,  844,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,   12, 2107,    9,  166,  433, 1167,  167,  631,   37,\n",
      "          166, 2227,    1, 1417,    1, 1417,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1710,  690,  957,  764,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550, 2606,  251,    1, 2226,    1,  705,    1,    1, 1108,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  447,   37, 1048,  453, 1054,    1,  384,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2942,    1,    1, 1758,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2, 531, 890, 729,  98, 837, 528, 861, 122,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 365,   1,   1,  64, 166, 116,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2551,  420,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   81,  220, 3083,    9, 2791,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   22, 2262,  686, 2140, 2751,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  941, 1201,    1,  475, 1213,    1,  938,  939,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  306, 1353,  777, 1085, 1896,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  169,    1,  702,   37, 2123,   32,  131,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  487, 2924, 1119,  176,  104, 2099,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1253,   32,    1,  338, 1979,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1201,    1,  267,  460,   12,  435,  333,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1766,    1, 1517,    1,  385,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  557,  540,    1, 2856, 1645, 2548,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  664,  440, 2125,  439,    9,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1023, 1204, 1169,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1159,  105,  979,  808, 2198, 2330,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2614,  190,  856,   37,  166, 1838,    9, 1131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  202,  220,  105, 1264,  841,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3121,    1,    1,  455,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37, 1237, 2815,  218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1712,    1,  191, 1718,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,    1, 1938,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1117, 1525,  509, 2264,   45,  617,  618, 2928,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1204,   98, 1965,  105,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1331, 1805, 1030,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1,  854,  202,    1,  640,   81,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3013,  953,   32, 3278, 1002,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 2373,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2903,    1,   12,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1966,   12, 1899,    1,  191,    1,  398,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1802,    1,   37,  151,    1, 1021, 2043,    1,    9,  331,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1853,  298,   37, 1329, 1224,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  526,   37,  242,   98,   69,    1,  410,   29,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,  187,  218,    1,    9,  365,  448, 1347,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   97,   98, 3363,  187, 3343,  195, 2537,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,    1,  449,  671,   37,    1, 2372,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  492, 2292,  444, 3105, 1258,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708, 2153,  907, 2198, 3358,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  853,  538,   12,  105, 1133,   47, 1221,   12,    1,   37,  151,\n",
      "            1, 1469,   37,  138,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1435,    1,  582, 2188, 1140,    9,  107, 1208,   92,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2827,   32,  215,    9, 1769,   37,  151,  903,    1,  548,\n",
      "         2488,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1465, 1466,  546,  645, 1385,   32, 2650, 1523,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2967,  166,  985,   45,  166,  365,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1047, 1236,  458,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1621,  472,   98,  255,  550,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  885,    1,    1,   45,   89,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  311, 2936,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1090,  469,  688, 2477,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1074,    1,   61,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 1762,  112,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2727,    1,   37,    1,  661, 1080,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2427,  335, 1735,  631,   32,   72, 1463,  187, 3170, 1141,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  198, 1220,  187, 1327,  733,    1,  159,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2292,  190,    1,  115,   45,  531,  806,    1, 3128,  108,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2177, 1027,  220,    1, 2212,  861, 1397,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2127,    1,  109, 2476,  220,  388,    1,  763,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403, 1447, 2673,  250, 2317, 1114,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  755,  365, 2995,    1, 2994,  220, 2542,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1173,  176,  163,    1,   12,    1,  622, 2705,   32,  531,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1206,    1,    1,  261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2950, 1167, 2803,  667, 2548,  193,  344,    1, 1583,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  153, 1421,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,    1,  878,   67, 1500,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  794,  365,  192,  361,    1, 1228,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2774,  650,  396,    1,    9, 1450,   32,  854,   12,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,    9, 1411,  537,   45, 1151, 1809,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,   37,  912,    1,  932,  740,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2416, 2849,  297,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  741,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3113, 1874, 3243,  132,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171,  237, 1116,   37,  125, 1346,  548, 2187,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2265,    1,  583,   32,    1,  344, 2564, 2886,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  917,   32,  220, 1880,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2503,    1,    1,  176, 1858,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 1398,  612, 1399,    1,  202,  424,   61,\n",
      "            1,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2275,  361,   10,  335, 1003,  176,    7, 2482,   78,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1512,  167,  619,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  437,    1,  104,  441, 1167,  576,    4,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  391, 1458,   79,   98, 1161,   45, 1926, 1927, 2555,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3207,    1,    1,   37,    1,    1, 2505,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1709, 1214,    1, 2096,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  870,    1,    1,  150, 1702,   98, 2657,    1, 1416,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  619,  105,  873,  176,  166,   26,    1,    1,  460,   81,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,    1,   48,   32,  667,    1,    1,  879,  693,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187, 1759,  309, 1830,    9,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3276,  176,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2316, 1450,   32, 3393,    1, 2835,    1, 1554, 1530,  361, 2347,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2877,   32, 3113,    9,    1,  220,    1, 3361,  202,  261,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2569, 2751,  205,   37, 2856, 1009,   10,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,    1,  123,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3340, 1072, 1235,  820,   32, 3339,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,  245,   39,  384,  749,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  732,  387,  244,  388,  763, 1427,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  980,   37,   56, 1333,  726,  176, 2957,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2384, 1106,    1, 2750, 1626,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  511,   12,    1,   16, 1515, 1280,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  389,    6,  176,  339,  845,   32,   86,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  447,   37, 1468, 2673,    1,  934,  342, 1039,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1535,  124,  353,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1411, 2273, 1158, 1230,   37, 2560,    1, 1675,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2066,   94,    1,  996, 1625,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  228,  388, 2317,  191,    1,  770,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503,  159, 1376,  699,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1396,    1,  218,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 1682,  176,  314,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3364, 2024,  142,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2373, 2627,  327, 2177,  988, 1027,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2426,    1, 3356,   12, 1876,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 3096,  872, 2659,  608,  455,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2017,   98,  112,    1, 1658,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2658,   32,    1, 1136,   28,    1,  614,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   75, 2167,  858,    1,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1484,   98,  593,   37,    1,  453, 3032,  663,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  952,   37,    1,   28,    1,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2578,  967, 2847,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1530,   32,  632,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1449,   32, 2149,  698,    9,    1, 3130,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   32, 3356,  787,    1,    1,  166,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2972,  475,  884,  105,  423,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1074,    1, 1261, 1021,   45,    1,  675,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 3382, 3356,    1,  674,   45, 3346,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1147,    1, 1065, 1190,  513,    9, 1527,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,   12,  405,    1,   37, 1540,  597, 1461,  750,  475,  921,\n",
      "         1638,   45,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,  531, 2699,    9,  938, 1075,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2393, 2134, 1676,  851,   37, 1054,   32, 2235,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1575,   32, 2578,    9, 2615,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  819,  702,   37,  151,  169,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  597, 2977, 2664, 1231,    9,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   58,   34,  197,  570,    1,  225,  407,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1090,    1,  731, 1090,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   60, 1258,  832,  951,    1, 1443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1809,  166, 3220,  105, 1882,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1,  657,  872,   98, 2894,  618,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  331,  612,  458,  197, 1784,   98,  377, 1628,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,    1,  180, 1814,  822,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  683,    1,    1,    1, 3230,    1,   98,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,  396,  449, 1684,   32,  257,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  935, 1288,    1,  365,  636,  443,   98, 2235,   37,    1,   22,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1381,   12,   98, 2692,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3306,   39,   32,  984,  548,    1,  195,  815,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  474,   37,  221, 1711,   45,    4,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1628,  698,    1, 3307,  321,  612, 2446, 1823,   12, 1027,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  484,   98, 1503,   76, 1411, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  580,  365,  342, 2015,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  225,  218,  298, 1434,  579,  614,   85,  833,  612,    1,   18,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  721,  893,    1, 1682,  361, 1841,  893,  321,  729,  362,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  927,  967,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1585, 1554, 1530,    1, 3156,   32, 1619,  395,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3045, 2891, 1583,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1133, 2082, 2483,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  403, 1447,    1,   85,   98, 1273,  618,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  632,    1,    1, 1632,   89,   37, 1937,    1,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2323, 1414,    1,    1,   37, 1821, 2190,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3181,    1,   32, 3116,  922,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1974, 2335, 2308,    1, 3240,    9, 1694,   45,  914,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1848,  494, 1335,  514,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  267,  455,  321,  335,   81,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    7,    1,   45,  166,  993, 1879,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785, 2924,    1, 3352, 1388,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1176, 1568,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275, 2216,  677,  223,  408,    9,  389,  390,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  565, 2901,  187, 1628,  187, 1366, 2898, 1444,  565,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,  905, 2581,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2645,   37,    1,    1,    1,  105, 1048,  855,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   69,  566,    1,  567,  456,  568,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1362,  353,    1,  737,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2028,    1, 1050,    1,  492,    1,   32,  342,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3103,  912,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,  698,    9, 3248,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1338,   45, 3102,  550,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,    1, 2503,  104,   32,  179, 3163,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  572,  105,    1,   82,   98,    1,  460,    1,    1,  112,  569,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 3160,  488,   37, 1641,   28,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  818,   15,    1,   32,  365, 1262,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2507, 2410,   74,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1800, 2387, 2118,  444,  795,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790, 1988,   45,    1,  749,  937,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  761,    1, 1646,  230,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1421,  220,  166, 3079,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2159,  794,    1,    9, 1100,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  861,  231,   37,  289,   98, 2429,   37,    1,    1, 1930,    1,\n",
      "         1346,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190,  201, 1371, 2856, 1811,  404,   68,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1017,   25,    1, 1043,  242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  773,    1,   32,  166,  818,  914,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   98, 3347, 2162,   44,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1326,  572,  156,  670,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2154,  170,   45,    1,   61,  166, 1354, 2529,   98,  119,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2924,  856, 3006,   32, 2597,    1,  440, 2458,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1022,    1, 2296, 1380,  439,   37, 1717,   12, 2963, 1625,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  167,    1,   54,   45,  734,  411,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  189,  190,  125,    1,  191,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1, 1225,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  342, 1579,  148,   12,    1,   45,  647,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965, 2550,  782,    1, 2668,  361,  388,  459,   45,  238,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3359,  267, 1533,    1, 1769,   37,    1,  443,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,    1, 1361,    1,  875, 2255,  149,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3187,  435,    1, 3177,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1290,  396,   85,   37,    1, 1722,   32,  600, 1056,  257,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1533,  377,    4,  254, 1754,   32, 1169,  763,  570,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2656,  288,    9, 1479, 1296,   28,    1,  396,  676,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  487, 3030,  513,    9,  414,   98, 3025,   12,  770,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   51,  720,  149,  444,  647,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  590,  315,    9,    1,  531,  863,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,   37, 2199,  284, 2673,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2062, 1743, 1578, 2794,    1,   37, 1642,   72, 2113,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3206,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1023, 1204,   12,  311, 1523,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1530,   32,  395, 2620,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1181,   12, 1234,    1,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1090, 1829, 2206,    1,  176, 1959,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  393,   22,  672,  284,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321,  617,  259,  815,  631,   37, 2895,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,    1,  187,  730, 2614, 1136,   39,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2656,  724,   98,  374,    1,    1,  105,    1,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  187, 2620,    1,  395,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2821,    1,    9,    1, 2791,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1128, 1380,   26, 1039,    1, 2043,   98,  365, 2232,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  212, 1421,  356,    1,  331,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1439,   45,    1, 1404,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196,   37, 1901,   29, 1074,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3025, 2845,   37,  885,  437,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087,    1,  896,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  567,  640, 2977,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,    1,   12, 2095,  509,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  848, 2371,  190, 2728,  191,  356,   12,  439,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302, 1712, 2126,    1, 1638,   45,    1,  994,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2783,    1,  671,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  698, 1090,    9, 3260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3257,  546, 1010,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128, 1392,  160,  623, 1140,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  385,   15,   28,    1,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1877,   37,   52, 1133,   98,  183,  112,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2453,   51, 1694,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2383,    1,  220,    1, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3053, 2477,  944,  928,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2673,    1,    1, 1428,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  155,  156,  570,    9,  356,  548,   72,  401,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3128, 1145,    1,    1,   32, 1345, 2834,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  854, 2257, 2924,  384, 1815,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504, 1708, 1396,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,   52,  366,   32,    1,    1, 2107,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  469,  105,  705,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2707, 1822,    1,    1, 3148,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  374,    1,   72,  401,  197,  490,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1186,    1,  600,    9,    1,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  421,    1, 2466, 1248, 1799,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3226, 1360,  612,    1,  220,  947, 2099,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  638,    1,    9, 3250,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2614, 1697,   37, 1022,    1, 2296,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160, 1161,  176, 1312,  339,  340,   32,  104,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  420,  327,   15, 1239,  187,  954,  831,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,    1,   72,   32, 1267,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,  637,   39,  792,  501,  841,    1,  792, 2315,    1,   45,\n",
      "         2703,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   96,   37, 3190,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  829, 1655,   63,  342,  147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1, 1084, 1085,  721, 1086,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  590,  427,    9, 2328,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,  359,  741,   98,  786,   72,  138,  125,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  148, 1360,  612,  319,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727, 1458,   79,  384, 1610,  179,  142,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   49, 2590,  981,    5, 2195,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  364,   37,  714,    1,   28,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2376,    1, 1454, 1922,    1, 1167, 2141,    1,  384,  722,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968, 1290,  338,   37,  339,  340,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1591, 1908,  105, 2242,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2372,   45,    1, 3389,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  795, 1236,    1,  297,   24,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  650,  267, 2292, 1360,  612, 2446,  741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  511,  275,    1,    1,  754, 1844,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3130,   37, 1174,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  171,  879,    1,   24,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 1118,    1,   45,  487, 1527,  639, 2405,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3215,  155, 2741, 1625,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2790,    1,    9, 2500, 3036,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   16,  203,  460,   12, 2740,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1051, 2094,  460,    1,   37,  215, 3080,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,    1, 2751,    1,  854,   12,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   45,  169,  702,  132,    1,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2308,    1,  872,  154, 1685, 1183,   24,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1795,   12,    1,  140,  372,   24,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3069,  213,   37, 1636,  531,  808,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1053,   12,    1,   37, 1124,    1,   37, 1033,    1,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1503,  103,  389,    9, 1502, 1178,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 967, 846,  37,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 716,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2646, 2024,  895,  898,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 1249,  163,    1,   12,    1, 1940,    9,    1, 3077,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1988, 1740,   37, 1399, 1515,  175,   45,  724,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  765,   37,  335, 2798,    1,   37,   26, 1039,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   75,  929, 1877,   37, 2446,  171,    1,   45,   80,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 2709,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  862,    1,   98, 2347, 1482,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363, 2645,  854,    9, 1527,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1304,   37,  138,   59,   32,  133,  927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2362,  105,  803,   84,   32,  917,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  779,    1,    1, 2750,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 2924,  477,  778,   32, 3155, 1229, 1530,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2180,  361,    1, 1205,  191,  294, 1456,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  521,    1, 1046,  477, 2661,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2957, 2914,    1,  617,  259, 2403,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  909,    1,    1, 1512,   32, 3369,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  762,  105,    1,   60,  139,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1870,  327, 1408,  460,  838,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  347,    9,  679,   69,  105,  789,    9,  258,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2009,   26,    9,  900, 1831,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1294,    1,   10,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2800, 3277, 2864,  726,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2511,   37, 1876, 2487, 3016, 1935,  361, 2723, 2724,  918,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  299, 2424, 1811, 1280,    5,    6,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1480,  698,    9,    1,    1, 2561,  166, 1254,   32, 2760,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   75, 1679,   80, 1108,  384,  171,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,    1,  686,  242,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2837,    1, 1515,  248,  957,   32,    1,  139, 2372,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,  244,   98,    1,  285,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,   37, 1418, 1815, 2924,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2924,    1, 3383,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1687, 1022, 3008, 2037,   28,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1899, 1061,   98, 2500,  663,  134,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777,  387, 1023,   45,   15, 2083,  104,   32,  105,  356,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,  565,  334,    1,  600,    1,  994,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2232,   15,    1, 1718,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3364, 2632,   32, 3339,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2677,    1, 1178,  386,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1167, 2572,  667, 2313,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1554,  105,    1,    1,    9, 3320,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437,  315,    1,   45,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1128,  292, 1222, 2359,  297,    1,  675,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,  197,   28,  118,   32,  401,    1,  577,   98,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   56, 2827,  680, 2095, 1506,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1550,    1,  856,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  854,  559, 1260,    1,  565,  176,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  726,   98, 2041,  515, 3200, 1161,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1323,    9, 3201, 2353,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1284,   81,   32,  166, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  592,   12,    1,  387,  593,  646,    1,  118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  973,   37,  943,  738, 1766, 1767,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1773, 2510,    1,  227, 2071,    1,    1,  772,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1,   45,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401, 1668,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1003,   37,  168, 1012,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 197, 738, 739, 159,  71,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 746,   1,   1, 187,   1,   1,   9, 934,   1,  32, 234, 182, 235,\n",
      "           1,   1,   1, 234, 182, 235,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1234,  251,   37,    1, 2397,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  163,    1,   12,    1, 1467,  636,    9, 1338,   45, 2924,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1867,    1, 3021,   37,   77, 1674,  671,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,   37, 2243,  445,    1,  659,   45, 2366,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,    1,   32, 3276, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1663, 1603,  353,  572,  448,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  601, 2505,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1281,    1,   32,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1186,  828,  588,  861,  231,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,    1,    1,  163,    1,   12,    1,  112,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1497,  774, 2787,    1,  191, 3131,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  573,  574,  232, 1713, 1854,  700,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  256,  988, 2815, 1876,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1775,  293,    1,    9, 2894,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  114, 2414, 2638,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755, 1419,  659,    1,  220,  861, 1228,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  691,    1,  163,    1,   12,    1,  288,  119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1509,  151,   37,   47,  176,  551,  612,   12,  116,  259, 1108,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1643, 1353,    1,   37,    1,   37,   93,  616,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1591,  744,  105,  332, 1126,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 1623,   45,    1, 3025,  361,  166, 2139,  444,  166,    1,\n",
      "           45,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  151, 1702,  326,   12,   98, 1220, 2521,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1573,    1,  190,  877,    9,  105, 2267, 1090,   32,  539, 2069,\n",
      "            1,  267,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 2925, 2962, 3276,  726,  119, 1194,   73,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2227,    1,  705,    1,  105,    1, 1454,  453,    1,   45,  749,\n",
      "          230,    8,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,   45, 1913,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3177,  415,  786,   45, 3277,   12,    1,   37,   52,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  776,   37,    1, 2733,  154,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 2147,   32, 3349,    1,   37,  813,   74,   45,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779,  801,   37, 1447,   26, 2069,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1833,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1962,  108,   45,    1, 1080,  384, 1273,  259,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  581,    1, 3382,    1,   85,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,    1,  159,   51,  504,  548,    1,    1,  155,  142,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3013, 1920,   12,  770, 1976,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  794,   22, 2625,   98, 3339,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2268, 1149,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1,   37,   52,    1,   32, 1428,  861, 1906,    1,  517,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1625, 1694,   98, 1816,   45, 1513,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  476, 1428,  909,   98,  864,  297, 2673,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1127,  330,  131,  887,   45,    1, 1085,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162, 1950,   32, 2140,   64,  921,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  428,  437,    1,  678,  166,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1353, 2731,   32, 3339, 2831,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  424,   61, 1433,  166, 3249, 1188,   37,  168,  548,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597, 3160,    1,    1, 1765,    1,  650,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 1585,  640,  104, 3150,   32, 3383,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1156, 2708,  650,   37, 1844,    9, 1009,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1178, 1179,   32,  365,  142, 1523,  187,  742, 1310, 1114,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3215,   61, 1415,   37, 2741,  168,  115,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  726, 1938, 2069,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  794, 1778,  535, 2441, 3049,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  766,    1, 1230,  220, 2627,  413,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994,    1, 1553,  176,  632, 2673,    1,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3129, 2523,   81,   37, 1509,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  894,  619, 1488, 2172,   37,  132,  220, 1915,  966,    1,\n",
      "          267,    1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1017, 1128,  952,   37,   26,  581,  327,  250,   32,   91,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1057, 1744,  190,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  547, 1763, 2249,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  907,  166,    1,    1,   45,  166,  273,  730, 2614,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1700,  514,   45,  312, 1450,   98, 3386,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,  450,   95,  384,  104,   37,  451,  452,  967,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   81,    1,  423, 1232,  636,  845,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  132,    1,  467, 2022,  191, 1014,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2707,  908,  342,    1, 2281, 2690, 1064,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,   25,    1,  604,  685, 1285,  242,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1426, 2820,   12, 2481, 1632, 2599,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3231,  726,  539,  187, 1110, 1686,   32, 1194,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,  176,    1,    9, 3343,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1548,    1,  453,  104,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  603,   37,  221,   28,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  673,    1,    1, 3359,   12, 3339, 2271,  469,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  596, 1273, 2264,   37, 1992, 1056,  131,  191, 1303,  475,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1461,  477, 2414, 3374,  650,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  794, 2355, 1013,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,    1,  895,  220,  342,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   25, 1150,    1,  303,    1,  615,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2414, 2548,   32, 1815,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  195,    1,  125,  985, 2130, 2162,   67,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380, 1484,    9,  736,   98, 1815,  809,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1764, 1890,  167,   52,    1,  220, 1971,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1326,  315,  388,    1,   15,   32,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2753,  449, 2579,  726,  176, 1869,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1975,    1,   98,    1,  805,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3359,   37, 1584, 3375,  384,  404,    1,  741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2383,  134,   32, 2707,    1,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   10, 1373,   37,  619,   32,   84,  220, 2972,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  375, 1236,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2164, 2414,   32, 1081,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2546, 1086, 2610, 1703,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2745,  176, 3328,  386, 2800, 1218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 1707, 3139, 1377,    1,    8,    1, 1250,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 1665,  176,  754,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  348,  387,    1,   93,   45,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1372,    1, 2072, 2107,   37, 1821,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2711, 1493, 2872,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  952,   48,   32,  121,   12,  141,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885,   61,  449,   59, 1178,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1968,  459, 1127,   37,   47,   40,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203,   37,    1,  105,  754, 1465,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1390,  587,    1,  176,    1,  389,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  526,  523,    1,   69,   25,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  669,  519, 1492,    1,    4, 1493,  388,    1,  506,  782,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 1921,    1,    1,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  954,   12, 2127, 2432,   37,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,  580,  365,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2737, 1401,   64,   12, 1758,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718, 2791,  884,  365,    1,   98,    1, 2973, 1764,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  647,   12,  597,   82, 2352,   37,  606,    1,  615,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1090,  891,  176,  446,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  653,   28,   37,  764,  730, 2614,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325,   56,  960,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  381,   12,    1,   61, 1018,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  763,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,  439,   37,  632, 1512,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   14,   15, 2449,  198,   32, 1332,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2984, 2405, 1750,  633, 2918,   98, 2662,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1791,  163,    1,   12,    1, 3400,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1100,    1,  657,  220,    1, 2282,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092,    1,   81,  766, 1935,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  547, 3375, 2572,   32, 3339,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  884,  822,  522,  444,  451,  706,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  624,    1,  197,  338,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2565,    1, 2526,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  374,    1,  417,  191,  503,   12,  195,  480,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1938, 2607,  382,   81,  220,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962, 1340,    1,  176,  827,  202, 1110,  186,    9,  726,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3114, 2924, 1345,   27, 3147, 2735,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  838,  341, 2572,    1,    1,   32,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1258,  868,   32, 3339,    1, 3374, 3384, 2572,   32,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2862,  729,    1,  187, 1033,    1,   91, 2405,  907,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    7,    1,   32, 1850, 1423, 2299,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2634,    1,  365, 2759,  260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1107,    1,   37,   52,   53,   98, 1102,  841,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  484,  199,    9, 1668,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   82,   45,  680,  114,  314,  939,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1483,   32, 2138,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2433,  691,    1, 2018,    9,   32, 2579, 1090,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,   28,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1046,  443, 2938,    8,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3343,    1,    1,  183,  861,  231,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37,  119,  156,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  315,   91,   12, 1254,  517,  613, 1074,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3216,  489, 1387,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2658,   45,    1,    1, 1387, 2373,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1570,    1,   28, 2367,    9, 1273,  618,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1216, 1095, 3017,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2971, 1768,    1,  967,  122,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  602,   12,    1,  914,    1, 1159, 1204,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1,  921,    1, 2227,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3039, 1939, 1090,    1, 1755,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 2266, 1484,    9,    1, 1663,    1,   37, 2446,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  663,   37,    1,  754, 2741, 1867,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  794,  306, 2304,  825, 1013,  112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  732,   37,    1,    1,    1,  541,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  459, 1440, 2203, 1942, 1259,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,  325, 1117, 1525, 1013,  669,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  844,  768,  149,  444,  829,  190,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  463, 2926, 2308, 2317,    9,  856,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1292,    1,    1,    1, 1581, 1292,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,  37, 846,  33,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 575, 529, 658, 996,  93,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  266,  353,  354,   98,  268,   44,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3300, 1421,    1,  683,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2333,  649,    1, 2713,  384,  487,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1282,   12, 3129, 3210,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  103, 1718,  710,    1,  384, 1652,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 3103,  273,  580, 2836,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  707,   81,   37,  166, 2807,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790, 1579,  815,   45, 1151,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  972,   37,  865,   37,  522,   32, 1700, 2119,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  267,  864,   12, 1461,   61, 1665,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   61,    1, 2015,    1,   37,    1,  829,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  613,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2889,    9,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,  613,    1,    1,  441,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1051,   37,   47,    1,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567, 1666, 3228, 3103, 1090,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  567,  510,    1,  436,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129, 1222,    1,   37,   47,  487,  493,  725,    9,    1,  131,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1790,  197,   28,    1,  159,  245,   98,  157,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  220, 2745,  932,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 1834,    1, 3341,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3002,    1,  176,  829,   71,  995, 2425,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1237,  166,  593,   45,    1,    1, 1371,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  787,    1,  142,    9, 2826,    1,  202,  539,  175,  778,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  111,  818,  834, 2055,  220,  105,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  220,  227, 1084,    1, 1298,  987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  594,    1, 1948, 1147, 2494,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1194, 1843,  197,  418,   37, 1637,   32,   56,  537,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  294,  922, 1090, 1829, 2570,  787,  176,  718,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  614,   37,  147,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  903,    1,  904,    1, 1874, 2832,  220,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  144,  145,  353, 1520,  276,   32,  572,  244,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  796,    1,    1,  317,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3358,   12,    1,    1,    1,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3369, 2751,   38,  297, 3080,   45,  443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1528,  213,   37,  138,    1,  331,   37,  875, 1405,  149,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1313,    1,    1,   63, 2868, 2237,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   89,  536,   69,  102,  288,   37,  168,   85,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 1447, 1458, 1428, 1953,   98, 2103,  617, 1116,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2476,  664,  581,    1,    1,  427,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,  267, 2275,    1,  443,   98, 2834,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186, 1874,    1, 2531,   46,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  387,  197,  225,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1974,  829,    1,  231,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2317,    9,    1,  220,   38,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1177,    1, 2721,   45,  584,  754,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 621, 624, 475, 710,   1,  37,  84,  85,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  765,   37,    1, 2176,   45, 2375,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885, 2263,   32,  896,    1, 2772,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1763,   12,  913,   37,  151,  654,  124,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2771,  297, 1169, 2769,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2980,    1,   37,   52,  227, 3031,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1407, 2153,    1, 3266, 2684,    9,    1, 2545, 2658,   12,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  655,   12, 1583, 1910,  105,  133,    1,  947,  774,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190,    1,  206,    1,   32, 3220,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  487,  114,  361,  230,  700,    1, 2352,  214,  191,  386,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   69,  102,   71,  187,  430,  477, 2055,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1085,  190,  877,  987, 2014,    1,  267, 1363,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2685,    1,    1,    1,   98,    1,   12, 1638,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1200,    1,  199,  421,  661,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3278,  288,   37,    1,  595,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  633, 1564,  221,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  741,    9, 1009,    1,    1, 2055,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1341,   37,   47, 1204,    1,    1,    1,   50,   37,    1,    1,\n",
      "            1,    9,    1,  182,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  726,  357,  664,    1,  730, 2614,  565,    1,  105, 2250,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2325,  220,    1,   45,  105, 2519,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2629, 1439,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1105,  787,   12,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1050,  650, 1564,  142,   37,    1,  166,  443,   98, 2095,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1829,    1,  297, 1147, 3373,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 2161,    1,   32, 2226,  540, 2292,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1622,  147,  804,   98,    1,  477,    1,  191,  442,  474,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1006,  782, 2463, 2589,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2942, 1268,  183,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545,    1,    1,  877,  915,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1283, 1188,   37,    1,  674,   45,  542,    1, 2308,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089,    1, 1220,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  968,  695, 2789,  952, 1032,   38,  384, 1002,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  736, 1167,    1,    1,  166,    1, 1574,   98,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1476,  574, 2591,   16, 1650,   37, 1031,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,    1,    1, 2437,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  602,    1, 2839, 1343,   85,    1, 1559,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 2815,  469,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  632,    1,  147, 1707,   49, 1727,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,    1,   12, 2828, 2318,  297,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,  167,  877,  453,  218,  714,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843, 1450, 2313,    1, 1914,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  648,  357,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1283,  932,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,    1,    1, 2264,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2862,    1, 2849,  297, 1033,   91, 2396,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  630, 1391, 1833,   12, 1407,   93,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993,  520, 2355, 1013, 1416,    9, 2994,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1968,  768, 2096,    1,   81,   37,  417,  147,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2767,    9,  443,  361,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1137,   32, 1300,  605,  714,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1,  854, 1421,  955,  956,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1123, 1183,    1, 1183, 2539,   12,    1,    9, 3132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2765, 1634, 3006, 2572,   32, 2018, 3246,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1567,    9, 3115,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  200,  645, 2543, 2873,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  125,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    4,  218, 1631,   39,   45,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  596, 2232,   15,   28,   32,  581,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228,    1,    1, 2611,    1,   32, 2597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 2220,   45, 1796,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  775, 2371, 1090,    1,   32,  455,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2497, 2313,   37,  619, 1211,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  154,  741,   37,  221,  872,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 1172,   12, 1173,  115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,    1, 3271,   77,   97,   98, 3117,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1220,    9,  642,  643, 1042,   32,  367,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3114,   12,    1,  580, 2124,  187,    1,  865,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2615,  688, 3108,   37,  726, 2941, 2522,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321,  455,  804,  166,  160,  623,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3128, 1564, 2050,  531, 2237,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1,   79,    1, 1288,    1, 1874, 1883,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1112,  176,    1,   98, 2397,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1574,   98,  258,  805,   45,  702,  169,  170, 2449,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2889,  191, 3302,    9,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1411,   84,    9, 1230, 2627,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  597, 2379,    1,  239, 1335,  514,   37,    1,  716,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  208, 2652, 2494,  872,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  342, 2015,  475,    1,    1,    1,   37, 1712,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1,  174,  490,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  845,  147,  261,  444,    1,   32, 2227,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   89,   90,   91,   37,   92,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3358,   12,    1,    1, 1983, 2078,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2728,    1, 2206, 2989,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2031,  315,  777,  778,    9,  822,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1,    1,   37, 2611,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1473,   37, 1909,  220,  726,  297,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649,   14,   15,  429,  700,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   10,  361,    5,  652,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3364, 1484,   98, 3375,   37,  720, 3344, 2139,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2518,  680,  105,    1, 2209,  744,  219,    1,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1230, 2453,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2854,  820,  191,    1, 2497,   37,  365,  154,   81,  220,    1,\n",
      "         1841,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75, 1550,   78,  674,   45,   80,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3374,  551, 2710,    1,  166, 1450, 1822, 1348,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1574,  600,  741,   32, 3360,    1,  105,   74, 2248,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1465, 1466,  353,    1,  354,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  381,   12,  597,  710,   51, 1046,  422,  522,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2977,    1, 1000,    1, 1241, 1425,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1001,  977,   71,   32,  645, 1034,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3167,  176, 2413,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3353, 1988,  267,  204,    1,    9,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  727,  613, 1353,  858,   37, 2458,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  342,  753,   37,  907,  442, 1757,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  266, 1627,  104,    1,  538,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,   12,   31,   67,  338,   32,  367,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2605, 1210, 2869, 1107,    1,  193, 1089,  496,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,  778,  696,    1, 2911, 1543,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094, 1419, 2183, 3374,  650,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,  742,   84,    1,    1, 2448,  386,   12, 2084,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   89,  267,  395,  442,  910, 1176,  183,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  670,  548, 1138,  108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  136,  835,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2166, 1031, 1434,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018, 1190,    1, 1926, 1927,   61, 1530,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,    1, 3118, 2162, 1347,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  984,    1, 1529, 1216,  903,    1, 1973,  924, 2772,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  697,   37,  142, 1056,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3343, 2924,   64, 3071, 1038,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,    1, 2278,    1,  657,  361,  148,  260,   28,   98,  166,\n",
      "         1222,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2899,  361,    1, 1421,  132,    9, 1273,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  550,    1,    1,   61,    1,  220,  166,  365,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1520,  200, 2723, 2724, 2636,    1,  220, 2177, 1027,    1, 1935,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2, 104,  37, 741,  98, 993, 652,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 326, 733, 327,   1,  37, 324,   9,   1, 182,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1035,  162,  365,  228,  356,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1479,  922, 1123,  550,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2425,   37,  130,  861,  700,   48,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   94, 1258,  120,  444,  104,   60,    1,    1,  365,  845,   45,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2, 550,  32, 870,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 433,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  550,  870, 1465,  595,    1,    1,  541,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585, 2083, 1853, 1557,    1, 2414,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 1484,    1,   37,  447, 3273,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2069, 1385,   32, 1842,    1,  856,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1203,    1,  517, 2400, 1871,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453,   37,    1, 2048,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3388, 2198, 3358,    1,  753,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158,  476,   37, 1636, 1107, 2610, 1108, 1316,   91,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  200,  547,  365, 2382,  618,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  183,  354,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3206, 1285, 2475,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1427,    1,    9,  116, 2542, 2762,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  527,  213,   37,    1, 2878,   37,    1,  573,  977,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 1447,  927, 1770,  590,    1,  384,  403,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1484,    9,  215,   37,   52, 2024,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  709, 3151,    1, 1432,    1,  928,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3157, 2905,   37, 2116, 2591,  528, 1860,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3358,   12, 1983, 2078,   51,   52,  820,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12, 1778,  328, 1085, 1552,   98,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  990,  614,  548, 2650,  285,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3130,  190, 2192,    1,  105,  227, 1787,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  171, 2565,    1,  459,  881,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2962,    1, 2781,  187, 3175,    1,   97,   98,  105,   12,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1548, 1831,  744, 2364,   98,   91,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  744,  636,   45,   32,    1,  372, 1126,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3323,    1,    1,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 1707, 2099,    9, 2548,   37, 1496, 1428,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 2589,    1,  220,  559,   98,  460,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  176, 2362, 1167, 3207,  865,  247,  671,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3151,   12, 2158,    1,    1,  582,   37,   91,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  636,  338,    9, 1194, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  729,    1,  384,    1,    1, 3199,   61, 1542,    9, 3076,   12,\n",
      "          365,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  458,  200,  131,   60,  469,   37,  125, 1964,   32,  854,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  506,  958,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885, 2133, 2984,   12, 2820,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 2924,  973,    1, 1159, 3155,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   37,    1,    1,  218,  220, 2734,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  364,    1,   97,   37,  726, 1990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  620,    1,  459,    1, 2925, 2234,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1035,  702,  710,    1,   51,  362,  700,  545,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2477, 1247, 2058,    1, 1574,  297,    1, 1411,   51,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  129, 1209,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422, 1536,  133,  134,  444,  709,  702, 1682,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  449, 1173, 1089,    1, 2515, 2228,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228, 1148,  441,  688,    1,    1, 1757,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2050,  902,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  590, 1400, 2249,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  163,    1,   12,    1, 2855,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,    1,  958,  455,   12,  816,  996,  471,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1018, 1691, 2049,    1,  176,  166, 1086,   45,  166, 3024,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2693,  640, 1117, 1525,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3192,  854, 2753,  105, 1844,    1, 1918,  444, 2741,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3194, 3195,  190,  193,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  542, 1096, 2021,  440,    9,  365,    1, 2292,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299,  288,   37, 2035, 1841,    5,    6,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1364, 1365,    1, 1484,  460,  105,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2663, 1000,  191,    1, 2280,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   56,   94, 1477, 1990, 2308,  565,   81,   32,  522,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942, 1566, 1623,   45, 3043,    1, 3396,   32,  395,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  409,   25, 1285,  417,    1,   60,  242,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3086, 1009, 1114, 1112,  176,  622,  522,  444, 2751,   32, 3114,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  581, 1385,  667, 3258,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,    1,  365, 2287,  187,    1,  897,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   56,  104, 2548,   32, 3402, 3408, 3082,  287, 1046,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2013, 3181,  539,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   89,   69, 2599,  596,   93,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1591,  936, 1126,  469,   37, 1083,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 1571, 1380,    1,   32, 2227,  786,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1564,    1,  714,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  337,    1,    1,    1,    1, 1210,  365,  961,    1, 2616,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3018,  211,   61, 1718,  504, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2737,  581,   37,    1,    9, 3212,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1, 3054, 1830,    9,    1, 2564,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,   46,   37,  151,  463, 2170,   12, 2084,   14,  458,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,  615,  220,  449,  932,  452, 1126, 1160,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2628,    1,   39,   28,   37, 2119,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971, 1149,   98,  477,  444,    1,  389,  125,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  454,  115,   45, 3363,   37,    1,    1, 2521,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,    1,    1, 1866,   37,    1, 2611,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1962,  396,  613,  846,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  123,  417,  187,  626,    1, 1256,  551, 1256,  817,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3096, 1691,    1,    1,   81,   37,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  750,  321,    1,  384,  594, 1022, 1023,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3260,  688, 3296,    9, 1194,   73,  726,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790, 1458,  365,    1,    1,  195,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1028,    1,   85,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  511,  190,   52, 2017,  384,    1,    9, 1675,  548,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  458,   98,  460, 2579,  190,  865,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1812,    9, 1972,  541,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1147,  446,  267, 1916,   45, 2343,   12,  103,    1,   37, 1174,\n",
      "         1411,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739,  105,  551,  331, 3284,  782,    1, 1728, 1114,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2551,  865,   37, 1691, 1505,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1904,  633,   32,   54, 1869,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   26, 2908,   37, 3173,  548,    1, 2485,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2608, 2607, 2985, 1061,   32,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147,  446, 2506,   37,  240,    1,   45, 2162,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,    1, 1383,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1511, 2562, 1084,    9, 1488,  996, 2788,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861, 2716, 1518,  487, 1325,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   91, 2272,   85,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3117,  619, 2568,  384,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  220,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1312,    1,  928,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  169,   20,  597, 1644,  513,  514,   32,   22,   23, 1012,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3071,    1,  337,    9,  964, 1746,  105,    1,    9,  650,  361,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3379, 2950, 1908, 1663,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2967,  792,    1,  792,    1,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962,    1, 1401,    1,   37, 1909,   73,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  218,  328,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1260,  155,  997,   45, 1994,    1,    1,   32,  447,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965, 2982, 2567, 1600,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  654,  267,   82,   83,   37,  930,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,   78,    1, 2487, 2695,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 387, 197, 225,  28,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  13,  12, 731,  61, 969,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,  622, 1841, 1074,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1988,  297, 3140, 1585,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2925,    1,  190,   52,   98,  211,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   83, 1258,  750,   45,  495,    1, 2667,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1101,    1, 1100,   12,  983,  157,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1121,  707,    9,    1, 2054,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2328,   12,  270,    1, 2467,   45, 1821, 2057,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2343,   37, 1046,  776, 1387, 2119,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158, 2102,  640,   59,   15,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3149, 1231,  297, 3071,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1013,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  191,    1,    1,    1, 1293,  103,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3236,    1, 3216,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3233,  103, 3234,   37, 2446, 1826,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  361,    1, 2256,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  765,   37,  335, 2798,    1,   37,   26, 1039,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  479,    1,  624,    1,  936, 2319,   45,  166, 2681,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   12,    1, 2664, 2572,   32,  166, 1255, 2289,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  410,   98,   69,  102,    1,  197,  157,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2695,   12,  894,    1,  223,  304,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  305,  102,  677,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  437,   37,    1, 2275,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2177, 1384,  986,   79,    9,  593, 2101,  786, 2885,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1061,    9, 1769,   37,    1, 3141, 1863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  729,    1, 2438,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  221,  388,    4,   37,  854,    1, 1364, 1365,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2089,    1, 1401,   37,    1,  131,  354,  176, 1369,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 1194,  187, 3260,  688, 3232,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1783,  459,  220,    1,    1, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2922, 1454, 2001,   98,  531, 2390, 1665,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2835,    1, 2985,  297, 3038, 3393, 3389,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   28,  166, 2041, 2655,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 1454,  104, 1563,   98,  531,    1,    1, 3093,   32, 1428,\n",
      "         1819,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  191,    1,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,  116, 2327,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   40,   32,    1,  220, 1158,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  734,  591,  132,    9,  594,  497,    1,   37,   52,   27,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1654,  131,   43,   37, 2254,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  199,    9,  166, 1428,   37,  100,   98,    1, 2673,  210,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1978,  365,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1183,    1,  777,    1, 1494, 1415,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1111,   65,  919,  347,  202, 1112,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1834, 1171,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1173, 1425,  166,  183,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1592,    1,   61, 1109, 1530,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1126,   12,  270,  833,  612,    1,  224,   12,  636,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1900,    1,  301,    5, 1631,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1173,    1, 1234,   12,    1,  365, 1234, 1863,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1693,    1,  877,    1,    9, 3066,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26, 3178,  879, 1045,   37,  759,   72, 1385,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1366,   51,  193,   52,  166, 1851, 2990,   98, 3024,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,   37, 2243, 1442, 2581,  163, 1230,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2754, 3102, 1683,   32,  531, 1621,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115, 2394,    1,  220,    1,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,   37,    1,    1,   98,  284,    1,  532,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1987,    1, 3318,    1,    9,  356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  295,    1, 1048,   45,  672,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  513,  514,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  326, 2023,    1, 2760,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  853,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,  36,  12,  39,   9,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  25, 439, 526, 548, 347, 168,  28,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   98,  247,  454,   37,    1, 1340, 1408,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640, 1684,    1,   32,    1, 1869,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2991,  794,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1002, 1360,  191,  121, 1696,    1,   12, 2789,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  590,    1,   32,    1,    1, 1002,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  166,  575,  220,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  249,    1,  191,  166,    1,    1,   45,  166, 1551,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1529,   12,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2508,    1, 2767, 2341, 1718,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  352,   51,    1,    1,   50,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    7,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3158, 3204,    1, 1159, 3329, 1286, 3179,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2590,  885, 2195,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  117,  151,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,  288,   37, 1198, 2108, 3368,   98,  976,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  870,  368,    1, 2418,   28, 2815, 1228, 1873,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,  952, 2010,   98,    1, 1723, 2577,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   61,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2209, 2830,  565,    1,   37,  365,  261,   98,    1, 1064,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  525,  388, 2634, 1419,    1, 2871, 2177,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3256,  726,   37,    1,   98,   37, 2764,  539,  631,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2685,    1,  729,  366, 1178,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2379,    1,  590, 1421,   45, 2439,  176, 3060, 1189,  778,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  741,    1,  891,   32, 3343,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    9, 1497,    1, 1056,    1,  361, 1056,  183, 3307,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2597,    1, 2696,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3228,    1,    1,  202,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282, 3204,  361, 3169,  288,    9,  104,   26, 2069, 1388,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1577,  155,  570,    1,  225,   28,  419,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3215,    1, 1505,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2104,  267,    1,  938,    1,  105,  301,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103, 2761, 2477, 2803, 3131,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1087,   12, 1222, 2759,    1, 1401,  166,  454,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,   82,    1,  733,    1,  159,    9,    1,  152,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1657,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2487, 2621,    1,  220,  914,   98, 2378,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  232,  443,   98,  229,  176,    1,  402,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1670,  103,   45,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1821, 2978,    1,    1, 1976,   32, 1739,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2643,    1,  565,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1766, 1767,  593,  680, 1665,  384,  874,  768,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175,  688, 3132,    1, 3216, 1415,   32, 2764,  404,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  215,  134, 3348, 3382, 2764,    1,  220,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3287, 1242,  590,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1797,  104,  448,    1,    1,  593, 1470,   45,  166,  294,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  379,  321,  612,  774, 2439, 2440,  384, 2095,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1414,   39, 1009,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2104,    1,  211,    1,   32,  105, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1479, 3288,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,    1,    1,  967, 1183,  759,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2677, 1252,  176,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1668,    1,  696,    1, 3065,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  328, 1149,  176,  715,  250,   77,   28, 1313,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  348,  733,  854,   81,  756,   50,    9,  152,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  581, 2132, 3297, 2622,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1407,  615,  661,    1,  497,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,   12, 1343,  176,  166,    1,   61,  707,   37,   52,\n",
      "         2312,  123,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1157, 3397,   32, 3376,   37,  588,  949,   45, 3102,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  798,  103, 1569,  220,  726,  297,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  571,    9, 2448,  386,  548, 1281,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,  580, 1857,    9,  985,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3113,    1, 2764, 3381,   98,  722,  134,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1693, 2038,  922,  427,  716,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  121,  108,  539,   98, 3149, 1816,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1050, 2153,    1,    1,    1,  191, 3096,  542,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  947, 1360,  612,  250, 3373,    9, 2172,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   32, 1328, 3137,    1, 1407,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   71,   32, 3349,   64, 2705,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  166, 1510,  967,  419,  423,   32,  197,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2843,  794, 2179, 2789,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3076,  919,    1,  117, 1281,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1123,    1,   28, 3238, 1564,  593, 2522, 2218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   28,  951, 1547,    1,  640, 1034,  340,  951,   94,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  691, 2095, 3060, 2867,    1, 2488,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  391,    1,  365,    1,  446,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  119,    1,    1, 2137, 3260, 1159, 1832,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,   37, 1083,  104,  347,   37,    1,  816,   93,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2942,  140,  581,  671, 3126,    1,   32, 2354,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2614,    1,  460,   98,   32, 1194,   37, 2253, 2163,    1,    1,\n",
      "            1,    9,  183,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   20,   82,   46, 1425,    1, 2298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3046,  744, 2364,   98,  671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2744,   26, 1039,    1, 1522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1919,  947,    1,    1,   32, 3349,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035, 1866,   37,  717,    1, 1037, 1038,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1542,    9,  765,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  182,    1, 1417,    1,    1, 1140,    9,    1,  290, 1159, 2211,\n",
      "            1,    1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  216,   32, 2597,   12,  501, 2060, 2856,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2578,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   35,    1,    1,    1,   71,  220,   69,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1256,    1,  552,    1,  485, 1949,  326,  486,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2153,  680,   97,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3260,  105,    1, 1979,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,  908,  331,  829,  399,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 3101,   22, 1821,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  732,   37,   47,    1,   48,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   91, 2390,  132,  251,  864,    1, 1527,  379,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537,  446,  936, 2128,    1,   32, 1815,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2144, 1530,    1, 2347,   32, 1645,    1,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1251, 3326,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3359,   12,  809,  905,  528, 1207,   37,    1, 3339,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2795,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,  936,  636,   98, 2869, 1089, 1090, 2402,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2280, 2297,   32,    1,   43,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  940,    1,    1, 1143, 2667,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   42,    1,  344,    1,  149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1489,    1,   98, 1029, 2208,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159, 1374,   98,  506, 2199,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275, 1542,    9, 2069, 1046,   79,  906,   32, 2142,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1668,  331,    1,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 3103,  565, 1284,  688,  361,    1,  424,  914,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,    1,    1,    1, 2317,    9, 3185,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3265, 1987, 1380,    1,   12,    1,   98, 2378,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   45, 2725,  729, 1844,  323,   32, 2170,   12,  638,\n",
      "            1, 2517,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  148, 1353,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2865, 3169,   39,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2802,    1,    1, 1492,    1,    1,    1,  928,   32,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 1082,  810,   37,    1, 2580, 2851,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2573,   12, 1506,   98, 3153,  312, 1188,   37,   52,    1, 3398,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3140,  958, 1887,   45, 3374, 3384,   32, 1656, 2960,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  502,  437,    1, 1258,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  381,   12,    1,    1,  375,    1,    1,   37, 1910,  166,  700,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  777,    5,  801,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,    1,  600,  166,  638,  224,  789,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  818, 1554,   69, 1555,    9,  105,  631,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2206, 2989, 2850,   28,  388,  763,  772,   15,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3306,  288,   37,   52, 1231,  191, 3092,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1465, 2537, 1949,    1,  541,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885, 2297, 3258, 2579, 1863,   45,  166,  356,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  197,   28,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3190,  321,  612,    1,   37,    1,   32,    1, 2800,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   10, 1454,  531,  443,   32,  581,  736,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,   51, 1198,  414,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2517,    1,    1,  335,   28,  864, 2673, 1816,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2641,    1,    1, 1008,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2785,  176,  649, 2003,    1, 1149,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171,  223, 2135,    1, 1710,  362, 1744, 1149,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  303,    1,  509,  297,  845,  104,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597, 1405,    1,    1,  868, 1727,  132,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1766, 1767,    1,  182,   32,  737,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  116,   45, 2258,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  881,  220, 2584,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,    1,  854,    9,  460,  956,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 206,  12, 581, 401, 197, 418,  88,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 214,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  531, 1527, 2664,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  651, 1031,    1,  108,   45, 2342, 1793,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1236,    1,    1,  297,  808, 1573, 1090,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  245, 1315,  105,  106,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  829,  877, 1515,  400, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,    1,  372,  354,   98,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1009,  455,  894,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116, 2542,  218,  332, 1042, 1315,  118,   32,   91,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   98,  103,   45,  166,  593,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545, 1310,   37, 2035, 3158, 1045,   37,    1,  665, 2017, 1443,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  506,  267, 3103,  565, 1176, 2088,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  245,  187,   64,  509,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  810, 3009,    9, 3132,  245,   39,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,    1,  297, 1964,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  176,  177, 1700, 2119,  220,    1, 1987,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   51, 2358,    1,  353,  417,  197,    1,   15,  245,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  141,  142,    1,  105,    1,   98,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   12,    1,    1, 1140,    9,  863, 1860,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  314,  225,  407,   98,  943,   45,   82, 1031,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,  190,  125,    1,    4,    1,  377,  763,   76,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1163,  244, 1844,  115,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2668,  218,   32, 2292,    1, 2755, 2490,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3190,  921,    1,    9, 2484, 2771, 2784,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1,  705,    1,    1,  356,  506,   98,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2246,    1,   61,  972,   37, 1413, 2365,   45, 2249, 3250,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2902,   46,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,  443, 2938, 1916,   37, 1174, 1411, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115,    1, 1247,  459, 1700,  356,  881,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  215,  441, 1044,   39,   98,  342, 1495,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  160,  636, 1279, 1893,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  632,   36, 3071, 1223,    1,  449,   45,  453, 1530,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2490,  267, 3105,    1,   32, 1583,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,    1,  612, 2175,    1, 1724,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1409,  696,    1, 1821,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1,   81,   32, 2707,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  494, 1599,  142,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1194,   98,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  295,  498,   98,  365,  238, 1958,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1900,    1,    1,  712,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  315, 2866,   28,   45,  535,  656,  327,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   79, 1194,   32,    1,   37,  123,   32, 2020,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1137,    1,    1,    1,   37,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1570, 2384,    1,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  705, 2796,    1,   32,  105,   12,  726,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2295,   65,  387,  646,   85,  176,    1,  419,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2832, 1260, 2548,   32, 3360,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32, 3131, 3044, 1991,   37, 1192,  365,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  199,    9,   91,   12, 1273, 1182,  187,  517,  640,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2638, 2931,  856,  162,  331,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485,    1,    1,  475, 1550,  971, 2271,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  864, 2673, 3366, 1806,  693,  105,    1,  163,    1,   12,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,   37,   26,    1, 1636,   28,   37,  124,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  453, 1522,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  768,  400,  444,  848,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2870,   27,  622, 3150,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  636,    1,    1,    1,   15,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  358, 1536,    9,  467, 1942,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  132,  227,    9,  575,    1,  586,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  260,    9,  247,  270,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1380,   28,   56,    9,  837,   12,  721,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1, 1460,  317,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193,    1,    9, 1106, 2264,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2890, 2094,   39, 1509,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  353,  183,  682,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 1982, 1537,  693,   45, 2024,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,   69,  934,   37,   52,    1,    9,    1, 1665,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2746,  345, 2275,   12,  736,    1,  220, 1515,  248,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  941, 1001,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,   98,  567,    1, 1608, 2885,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1211, 2878, 2825,  220, 2954,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3269,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2452, 1380, 1719, 1159,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  325, 2882,    1,    9,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1476,  574, 2591,   16, 1650,   37, 1031,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  200,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  105,    1, 1417,    1, 1417,    1, 2202,  323,  361,  198,\n",
      "          424,  914,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  447,  267, 3365,  729, 2793,  105, 1875, 1890, 1490,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12, 2015,  384, 2993,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,  515,   28,  453, 1188,    9,  846,   37,  289,   98, 1021,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3262, 1831,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  104,   37, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1723,  847,   28,    9, 3311, 3310, 2930,  776,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  503,  225,    1,   98,  550,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1468, 1361,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1117,    1, 3188,   12, 1580,  891,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,  681, 1776, 1089, 1994, 2086, 1017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 2026,  126, 1452,  388,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,  877,    1,  195,  279,   98,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,  213,   37, 1982,    1, 1650,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  777, 2232,    1,  653, 1819, 1665, 3031,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  757,  624, 1359,  794,  365,  111, 1597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1069, 2361,  176,  971,  250,   32,  602,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  840,  105, 2666, 2385,  612,    1, 2613,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878,  669,   37,  877,  365,    1,  165,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,   71, 1724, 1114,   32,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3207, 1216,  204,  190,   52,    1, 1232,  204, 1654,  671,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2647,  570,    9,  117, 1278,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1470,   45, 2662,   12, 1241,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    5,  125,  302, 1908, 2087,  433, 1931,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1396,    1,  218,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,   45, 2213,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3051, 2024,   46,    1,  548,  786,   74, 2774, 1860,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  879,  338,    1,  109,  997,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  304,  297, 3343,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1247,   98,    1,  361,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,   60, 2272,    1,  104,    9,  166,  449,  199,   32,  105,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2328, 2870,  176,    1,    1, 1887,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,  730, 2614,    9,  166, 2539,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  370,  371,    1, 2077,    1,  956,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,   24,    1,  155,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,  418,   15,    1,  526,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2137, 1922,  454,   37,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,   28,  118,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 2924,   37, 1334,    1, 1190,  267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1783,  716,  207,  354,   45,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1546, 2771,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   56,  803,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  650,  140,  581, 2113,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056, 2548,  583,   32,  531, 1450,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380,  267,    1, 1822,  856, 2834,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  111, 1107, 2613,    1,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1191,    1, 1842,  357,  853,    1, 1543, 1167, 2474,  844,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3303,  852,  115,  220, 1677,  548, 1479,  533,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885, 1408,  247,  631,   32,  273,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2700, 1140,    9,    1,    1, 1281,    1,  293,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2533, 1877,   37, 1734,  191,  484,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  952,  592,  808,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1834,    6,  356, 2469,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  353,  197,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2350,  515,  854,    1,   32,  581, 1463,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453,    1,   61,  786,    9,  166, 1772,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550, 2031,    1,   32,    1, 2348, 1313,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1537, 1109,  256,    1, 1074,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3067,  446,   12,  347, 2716, 1708,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  647,  488,  148,  220,  149,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2877, 2343,    1,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2276,   45, 3228, 1380,  105, 2149,  439,   37,  166, 1879, 2494,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1964,    1, 1665,    1,  518, 2153, 1373,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3363, 1260,    1, 3343, 1002,  997,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3143, 2428,  449,  726,   45,  914,  444, 1178,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  422, 2008,  284, 1476,  574, 1469,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111,  133, 1366,  416,  625,    1,  202,  590,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1372,    1,  856,    9,  166,  917,   37, 2789,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 1386,    1,   32,  674,   45, 2487,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3092, 1990, 1913, 1385, 2250,    1, 2471,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1051,   37,  877,  858, 1507,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32, 1939,  176, 3358, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190, 1140,  460,  796,  892,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2984,   30,    1,   45, 1056, 2662,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  928,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  408,   23,   49,   37,  899,  284,   69,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  375, 2909,   39,   45, 2890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1076,  200, 1251,    1,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2520, 1135,    9,  166,  649,  954,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1808,    1,   28,    9, 1611,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  935, 1426,    9,  166, 3009,   32,  645, 1597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2524, 1159,  618,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,  773,  720,   32,   69,  102, 2192,  616,   92,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,   12, 2851,  105, 2324, 1167,    1,  284, 2910,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 3397, 1454,  163,    1,  903,    1,  444,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  190,  829,  664,  166, 2995, 1681,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1766, 1767,    1, 2992, 1530,  361, 2626,    1,    1,    1,  774,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  138, 1146, 1049,  844, 1710, 1251,    1,  388,   75,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1463,  427,   32,  438,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  447, 2767, 3146,   98,  557,  540, 2108, 1281,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1583, 1967,  580, 2353, 1623,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1128, 2744,  764,   37,  803, 1244,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   96,    1, 1159, 2821,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3018,    1,   37,    1, 1691,   36, 3002,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2391,  845,    9, 3175,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2275,   10,    1, 1698,   45, 1628,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1013,  193, 1724, 1542,    9, 1065,  199,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1870,  794, 2261,    9,  773,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1284,    1,   12,    1,  105,    1,    1,   45, 1018, 1674, 3126,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2597, 2696,    1, 3403, 2414,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1173, 2393,    1,   61,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2077,    1,  759, 2381,  250, 1384,  630,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  755,   12, 1876,    9, 1994, 2819, 1017, 2928,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1700, 2572,  187, 2702,    1, 1159, 1656,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741, 1642,    1,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  766,  936,  596, 2871,  480,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 1147, 1726,    1,   32,    1, 1450,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2227, 2954, 1953,   32, 2235,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  458,   37,   47,    1,   48,   37,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1138,   37,  125,  600,    1,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3226,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  321, 2244,    1,   52,  227,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  628, 2522, 1489,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 705,   1,   1,   1, 182,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 425, 426, 376,  15, 570,   9, 367,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1206,    1,   37, 1753,  297,    1,    1,    1, 1437,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,   69, 1491,   25,  720,  667,    1,  418,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  171,  947, 1173,    9, 2383, 2072,  709, 2925, 1863,   12, 2162,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   38,  297, 2108,    9,  987,   32, 2597,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  619,    1,   12, 1698, 1876,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1112,  163,    1,   12,    1, 1822,  865, 3127,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  848,    1,  326,    1,  361,  766, 2704,    1, 1243,   98,  617,\n",
      "         1151,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2185, 1994, 2819, 2146,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   10, 2776,  538, 2653,   37,    1, 2275,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118, 3396, 2047,    1,  754, 1428,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  393,   82,  948,  248,    1,    9,    1,   45,  356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1324,   45, 1820,    1,  297,    1,   12, 2370,  227,  726,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,  459,   45, 1204, 1976,  176,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2186,    1,    6,  207,  176,    1,    1,  882,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2089,  721,  782,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2529, 3343, 2696, 2526,    1,  948,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   29, 1506,  288, 2759, 2521,    9,  326,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  642,  643,   57, 1285,   28,   32,  385,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,   12, 2534,  361, 2519, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 3006,    1,    1, 2572,   32, 1815, 1260,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2999, 1994, 2819, 3050, 2493, 1176,    1,    9,  837,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37, 1539,  365, 1013, 1522,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1016, 1550,  469,    9,    1, 1002,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2127,    1,  125, 1266,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,  365,    1,   74,    9,    1,    1, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2729,  998,  669,  267,  460,  967,    1,   56, 2729, 3365,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1782, 1739, 1097,   37,  395,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1008,  365,  318,   32,  475,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  614,  220,  421,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  459, 1700,  356,  881,  220, 3268,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1700,    1, 2572,   32,  531, 3389,    1, 2421,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1925, 1583,    1,  548,  837,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3364,    1,    1,  472, 1452,   32, 2708, 1002,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   83,    1,   98, 1143,    1,    1,  105, 2717, 1388,  176,  654,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  546,   81,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1530,   32,    1,  632,  851, 2421,    1, 2095,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3214,  686,  191, 1330,    1, 1554, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2617,  927, 1924,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  549, 1118,    1,  737,  422, 2092,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193,  227,    9,    1,  810,  505,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  845,  147,   37,  817,  912, 2285,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2483, 2339, 2518, 2638,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3229,    1,  729,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  397, 1118,  484,   98, 1117,    1,  163,    1,   12, 2244, 1281,\n",
      "         2928,    1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,  458,   45, 2163,  952,   37,    1,  134,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1187,  166, 2692, 1601, 2253,  858,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  190,    1, 3343,  741,    1,  437,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181,    1, 3116, 3314,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  121, 1411,   32,  260,    9,  824, 1778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1426,  163,    1,   12,    1,    1, 3293,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1384, 2789, 1401,    1,  741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3095, 2122,  115,  220, 3339, 2731,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 1822,  713,   37,    1, 3348, 3382,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3310,    1,    1,    1,    1,   32,  521,   43,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  742,   51,    1, 1178, 1179,  929,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  279, 2019,    1,  301,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   32,  915,    1,  132,  220,  474,    1,  393,   51, 1911,  467,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1380, 1204,    1,    1,  361,    1,  460, 1625,    1,   15,\n",
      "           32,  105, 1393,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1140,    9,    1,  649, 1021,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1211,  442,    1,  861,    9,  942,  361,  163,    1,   12,\n",
      "            1,    1, 3030,  267,    1,  963, 2122,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2529, 3121,    1,  640, 2755,  455,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2102,  680,  114,  297,  215, 1402,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3121,   30, 2227, 1167,  547,  321,  168, 1159, 1056,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1897, 3175, 1090,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1290,  396,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  650, 3090,  640,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3230,    1,    1,  176, 2490,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1,    1,    1,  769,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,    1, 1128,   37,   92, 1222, 2461,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   35,   32,   46,  220, 1053,   22,   98,  105, 1251,    6,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,   12, 1354, 2556, 2572,   32, 2887, 1523,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1986,   32, 2235,    1,    1,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  162,  105, 1292,   32, 1092,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  418,   32, 1961, 1126,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2741, 2494,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2056,   32, 2421,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  219,  104,  457,    1,    1,  325,    1,   32,  132,    1,  176,\n",
      "           54,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 3096,  872, 1573,  220, 1161,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,  191, 2909,  176, 1853,  186,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1940,   12, 3134,  208, 1249, 1327,    1,  884,  671,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3227,  576,    1,    1,   37, 2672,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1583,    1, 2775, 1425,  337,    1, 2699,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  267,  204,   12,  590,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  422,  134,  597,    1,  494,  220,  133,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1067,    1,   32, 1997,    1,  187, 2161,   12,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1815,   61,    7,   37, 2024,    1,  267, 3354,  446,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3297, 1036,   37,    1, 2771,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1861, 1877, 2521,    9,  627,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  341, 1118, 1186,   12, 1764, 1990,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  286,  927,  703,  314, 1974,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1432, 3207,  764,    1, 2643, 1675,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1070,  104,  147,   37,    1,   43,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,  551,  552,   37,  429,    1, 1929,  892,   98,  523,    1,\n",
      "         2561,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  291,    1,  600,    1, 3004,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649, 1619,  458,  641,  347,    9,  449,  199,   32,  537,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2559,   37, 2303, 1623,   45, 2179, 3080,  446,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,   15,    1,  773,  288, 1515,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  550, 1075,   39,    1, 1221,   12,  105,    1,  600,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2171, 2800, 2246,    1,  670,  608, 3115,   98,  915,  581,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  709, 2018, 2038,    1,    1,   12,    1,  820,   98, 1368,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 2277,    9, 2144,   98,  581,   74,   45,    1, 1463,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 1707,  723,    1,   12,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  176,  224,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3292,    1, 2360, 2619,  297, 2579,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 2023,  365, 3044,  437,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  166, 1158,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1853,   37, 1664,  926,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  359,  759,  630,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  523,  580,  961, 1938, 1723,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203, 2700,  361, 2372,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1029,  782,  590,  133,   32,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3127, 2104,  893, 1046, 1355,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   47, 1535,  124,    1,    1,    1,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3079,    1,   59, 1144,   98, 1415,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3161,  171,    1, 2484,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232,    1, 3310,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1796, 2224,  939,   63,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1194,   32, 1225,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3310, 2554, 2920,  608, 3219,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3395, 1796, 3102, 1976,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3051,  957,    1, 2751, 1980,   37,  498,   98,  861,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1229,   37, 1012,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3161,  765,  608, 2748,   37,  590,    1,   32, 3278,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597, 3086,  655,  513,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158,    1,   39, 2546,  220, 1230,  328,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  253, 1584,    1, 1734,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 1447, 1625, 3385,  190,  439,  453,  400,   32, 1169,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  657,  572,  983,  699,  242,  763,  365,  689,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 1082, 1437,   45, 2734,  304, 1294,   37,\n",
      "         1537,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  564,    1,    1,  464,   22, 1497,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,    1,    1,   37,   52, 2562,  388, 1821,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3324,   12,  631,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  395, 2369,    1,   98,  116,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1520, 1124,   32,  411, 2208,    1, 1708,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  160,  102, 1556,    1,   32,  871,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3061,   64, 3372,   32, 2774,  511, 2517,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,   12,  197,   93,   30,  275,  471,    1,   98,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,  768, 1523,  288,   37,    1,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   26,   27,  526,  548,  642,  643,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22, 1681, 2226,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3151,   12,    1,    1, 2056,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1674, 1675,  254,  227, 1429,    1,  267, 1676,  954, 1190,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,  267,   46, 1851,  454,   37, 1814, 2390, 2426,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3186,    1, 3256,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  224, 2355, 1013, 2549,    9,  282,  920,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3253,    1,    1,    1,    1, 1521,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  893,   45, 2877,   12, 1841, 3340,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1929,   98,  531,   37,   81,  166,  957,   12,  443,   98, 3045,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  681,  528,    1,   12,  682,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2658,   45,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2885,  921,   59,  220,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1140,    1, 1747,   39,  139,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2786, 2580, 2851,  328, 2996, 1778,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  927, 1648,   45,    1,  444,  790,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  410,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1486,    1,    1, 2021, 1041,  342,   59,  191, 1852,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1547,  418,  202,    1,  905,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   28,  187,  104,  679,   25,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  590, 2025,  728,  110,    9,    1,  769,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1307, 1421,  976,  259,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3129, 3254, 1177, 1159,  631,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1586,   28, 3193,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  547, 3375, 2572,   32, 1850, 3339, 2292,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,   28, 3019, 1151,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  393,  359,  335,  138,  125,  187,  467, 1552,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  656,    1, 1445,  459,  220,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  647,  475,  488,   37, 1753,  297,  148,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  737,  983,  640,    1,  131,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,    1,   60,  670,    1,   69,   79,    1,  671,   28,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422, 1070,  146,  147,   37,    1,  755,   43,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  706,    1,  190,  631,   37,  389,  390,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  837,   37,   47, 1191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  606,  334,  653, 1658, 1656,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  316,  389, 1025,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,    1,  384, 1090,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2737,  782,    1, 1746,   98,  147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  622,    1, 3381,    1, 1976,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203,  340,  321,  500,  168,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453, 1991,    1, 2089,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,  218, 1063,    1, 1486,    1,  709,   82,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3381, 2431,  928,   32,   22,  477,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1790, 1249,  572,  308,  159, 1253,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  113,  215,  347,  176,    1,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,  726,    1,  361, 2447,  444,  539,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1028,  531, 2951, 1563,  736,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230,    1, 3169, 1632,   37,  104,   26,   72, 1385,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1498, 1677, 1125, 2589,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437,    1,    1,    1,   37, 1171, 2492,    1,  552,  552, 2429,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2685,    1,  159, 1381,   32,  105, 1264, 1918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,  218, 1063,    1, 1486,    1,  709,   82,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2755, 2774,  475,    1, 1707, 1898,   37, 3118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,  220,    1,    1,  275,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962, 1340, 3299, 1114,  187, 1110, 2651, 3251,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3200,    1,   37, 1306, 1090,  951,    1, 2551,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1, 2101,  220,    1, 2936,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2272,    1,   37,  631, 1364, 1365,   37,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   51, 1306, 2522,    1,   45, 3288, 1987,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  700, 1337,  531, 1604,   37, 1154, 3365,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  647, 1607,  710,    1,   82,   39,  166, 2009,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3139, 2744,  198, 1263,   32, 3140,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2994,  640,   59,  813,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1815, 2237,    1,  105,   84,   32,  166,  917,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,  267,  460, 1360,  612, 2199, 2673, 1017, 1027,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  247, 1343,   61,  193,   39,   45, 1827, 2498,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2275,   10, 2776, 2716, 2465,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  952, 1849,  805,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2171, 3134,  403, 2926,  921,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1867,    1, 2320, 2673, 3085, 1461,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1353,  192, 1958,    1, 2043,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  957,    1, 1003,    9, 1228,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  526,  983,    1,  355,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  361,  163,   37, 2243,  938, 1230,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 1037, 2951,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   51,  186, 1232,   69,  980,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,  686,  191, 1429,  997,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3206,  619,  608,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  547, 3095, 1810,  228, 2572,   32, 2708, 2625,   98, 3339,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1361, 1362,    1,   98, 1211, 1455, 1294,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  604,  288,    9, 1178, 1988,   32,  425,  426, 1939,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1038,    1,  220,  545,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  907,  166,  249, 1492, 1532,  507,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283,  971,    1, 2256,    1,  774,    1,  190,   52, 2812, 1970,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2848,  211,   45, 1090,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  233, 2104,    1,   98, 1983,    1,  652,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  633, 2344,   37,  974,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 2171,    9,  116, 1090,  293,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  388,  763,    1,    1,   45,  499, 1069,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   22,  719,    6,   37,    1,  615,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1077,    9,    1,  596,   87,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  853, 2945,   51,   16,  365,  864, 2673,  778,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  546, 2565,  548,    1,   45,  594,  932,   32, 1050,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006, 1025, 1677,   37, 1211, 3340, 2433, 3091,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  477, 1380, 1132,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2959, 1285,  608, 3120,  220,  726,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2826, 3202,  919,  395, 1159, 1674,  401, 3179,  220, 2268,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  374, 1068,   25,  245,   32,   91,    1,  953,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,  692,  163,    1,  903,    1, 2095, 3060, 1638,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1323,    9, 2003,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2658, 1040,  640,   81,  176,   39,   45, 2589,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1718, 2351,   32,  342,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1414,    1,   32,   78,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 328,   1, 253,  81,   1, 221,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 235, 661,  98,  25,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  677,  223,  408,  631, 1744,  575,   37,  125, 1888,  745,    1,\n",
      "          496,  782,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   37, 1031,  531, 1799,  289,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1525,  593,  872,   98, 1117, 1525, 1108,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051, 1039, 2690, 2607,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  777, 2165,    1,   28, 2081,   45,    1,    1, 1452,  166, 3158,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  316,    1,  460, 2233,   52, 1584,   12,  168,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1161, 1276,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2982,  619, 1700,  388,  257,   37,    1, 1965,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3230, 1426, 1913, 1385,   32, 2197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  162,  562,   37,    1,  138,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,  12,   1, 420,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  49,   6, 570, 191,   1, 118,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2885, 1293,   32, 1030,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219, 2579,    1, 1260,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1766, 1767, 1351,  653,  845,  846,    1,    1,    9,  920,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,  952,   37,   26,  250,   32,   91,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  730, 2614,  542, 1398,  612,    1, 2615,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  625,  204,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  709, 3181, 2800, 1218, 1292,  190,  865,   37, 2800,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  201, 2174,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,  297, 2468,   12, 3153, 2220,  469,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  197,   28,   82,    1, 1961,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1962,   37, 1835, 1378,    1,  613,  858,  280,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  503,    1,    1, 2139,   98,  480,    1,  594,   15,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2300, 2923,  167, 2192, 2918,  105,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  251,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2571,  474,   37,    1,  861,    1,   98, 3118, 1512,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1278, 1376,   32,  871,  227,  550,    9,   93,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1633,  361,    1,  498,   98, 1145,   45,  331,  170,  132,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2567,   98,    1, 1151,    9,  618,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  550,  146,  147, 2682,    1, 2009,    1,  798,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2107,  357,    1, 1167,  167,   52,  166, 2360,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1921,   32,  455,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2729,  437, 3043,  297,    1, 3389,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1228, 2054, 2222, 1627,  105,  170,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2201,  572,  197,  338,  699,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035,    1,  159,  554,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   28,   74,   61,  748,  855,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1290,  396,  720,  388,  763,   76,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  617,  618,    1,    1,   37, 2964,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  167, 1251,   10, 2591, 2722, 3074, 1215,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2896,   45,    1,    5,    1,    1,   85,    9,  105, 1378,  611,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  543,    1,   37,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1450,   98, 2703,   32, 1785, 2044,  452,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1521,  707,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2479,  602,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   51, 2704,  411, 2500,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  267, 1930,    1, 2349,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,   37,  508,   79,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,  588,    1,  384, 2311,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2038,  580,    1, 2757,   32, 3097,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  647, 1702,   39,  648,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 2425,  213,   37,  151, 1883, 1228,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 3328,    1,    1,  187,  512,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  333, 1564,  331,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1652, 1226,   98,  710,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294, 1940, 1844, 2017,  384, 2498,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1643,    1, 1087,  693,    1,    1,    9,    1,  441, 2973, 1764,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 2659, 2084,    1,    1,   32,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   22,   23, 1330,    9,   20,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1663,    1, 1152, 1364,    1,  957,  600,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977,  475,   61,    1,  548,  537,    1,  379,  774,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2769,   45,  166,    1,    1,  273,  833,  612, 1847,  384,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   67, 1556,   37,    1, 1722,   32,  388,  763,  537,  915,\n",
      "          356,    1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  437,  744,   79,  216,   32, 2468,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  405,    1,    1, 1427, 1641,    1,    1, 1748,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1, 3016, 1607,  315,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  405,    1,  898, 1542,   37,  319, 2977,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3188,   32,  260,    9,    1,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  240, 1687, 1022,    1, 3008,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1867,  885,    1, 2498,    9,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1312, 1407, 1538, 1683,   32,  531,  447,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3255, 3164,    1,    1,   39, 2741,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2977,   37, 1463,    1, 2699,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1189,  996,  652,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 852,  37, 166, 627,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 561,   1, 231, 210, 167,  23, 389,   1,  45, 234, 182, 235,   1,\n",
      "           1,   1, 234, 182, 235,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  631, 3206,   32, 2522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,  103, 1132, 1910,  121,    1, 2263,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  457, 1597, 2598, 1159, 2218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,    1,  102,   92,    1,  975,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2, 303,   1,  25,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 191, 389,   6,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2627, 1831, 1454,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,  159,  504,    1,  202, 1340,  670,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,   12, 2102,  920,    1, 2464,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  180,  197,  418,   98, 1889,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1092,  546,  449, 2039,  176, 2633,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1332, 1539,    9, 2071, 2186, 1090, 1667,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428,  488, 3369,  220,  909,   98, 3118,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1040,  814,    6,  111,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1341,  975,   57,   28,    1,    1,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,    1,  475, 1213,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1457,  782, 2738, 2508,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1750,   80,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2450,   37,  335,    1,   32, 2457,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437,  650, 1086, 1973,  876,  612,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1423,  556, 2064,  548,  207, 2574,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314,    1,  488, 2152,   32,   12,    1, 2227,    1,  827,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,  97,   1, 422,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 434, 435, 142,   9, 436,  45,   1, 437,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  957,  872,   98,  161,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1233,   37,  489,   39,   45,  785,  786,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,  159,   71,   98, 1625,    9,  359, 1259,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   32,    1, 2027,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3236,   37, 2225, 2805,    1,  512,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504, 2736, 1082, 1833,   37,    1,   37,  439, 2755, 2292,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  518, 2192,    1, 1167, 2192,   81,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3354,  446, 1554,    9, 2752,   98,  547, 1833,  463,  310, 2579,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  833,  612,   81,    1,  446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169,  852, 1750,  885,  163,    1,   12,    1,   26, 1684,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  388,    1, 1530,  361,    1,   79,  691,   12,  463,  540,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   69, 1086,  530,   98,  430,  997,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  455, 1408,    1, 1563,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  188,  548,    1,  985,  776,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  931,  581,    1,    1,    1, 2347,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1892,  921,   59,   32, 1447,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2235,   69,  102,    1,  104,   60, 1722,    9,  449,  199,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1, 2755,  455, 1530,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2611,  267, 2572,   32,  344, 1585,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  729,    1, 2591,   32,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2929,  566, 1273,  259,  218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1, 2516,  750,   23,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  638, 2144,    9,    1,    1,  105,   12,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  135,  538,    1,    1, 1713,  572, 1914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  183,    1,    1,   37,  123, 1675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2429,    1, 2849,   98,  207,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,   37,  130,    1,    9,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2214,    1,  321,   52,    1,   37, 2844,    1,  398,  261,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  353,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   63,    1, 2743,  186,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3343,  863, 2094, 2179, 1299,   37,    1, 1255,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  460, 1924,  105, 1628,  221,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   10, 1554,    9,    1, 2784,   37,  942,   32, 1705,   37,   23,\n",
      "         1415, 2471,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878, 1713,  149,  444, 1117, 2208, 1873,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,   37,    1,  798,  297, 3374,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  439,  856,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2964,  686, 1084,  841,  669,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,  719,  764,   37,  439, 3118, 1512, 2835,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1363, 1660,  158,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3160, 1231,  220, 2772,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  215, 2489,   85, 2658, 2269, 3353, 1665,  716,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   59,    1,   17,  664,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  548,  247,    1,  449,   74,    1, 3325,  884,  105, 1311,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  297,  741, 2116,   32, 1422, 3343,  863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2157,    9,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,    1,    9,  111,  126,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1264,    1,  897,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176, 2643, 1675,    1,  166,  183, 1283, 2005, 1937, 2051,  671,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3068, 2767,  112,    1, 1996,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1090, 2677,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,  928,  176,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095, 1680,    1,   98,  198,  401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3247,    1, 3248, 2260,  548,  449,  401,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  782, 2586,   32, 2540,    1,  191, 2476,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  199,   12,  472,   39,    9, 3271,   32, 1948,    9, 3235, 1264,\n",
      "          841,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3386, 2742, 1556,   32, 2518,  220,  356, 1691,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  709,    1, 2777,    1,    1,  872,   12,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2768,  334,    1,   37, 1140,  166, 1935,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  980, 3117,  191, 3233,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  375,  852,   37,  439,    1,  356,   98, 2213, 1318,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2424, 3290,   37,  726,  297, 2563,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,  893, 1066,   98,    1,  568,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2676,    1, 1260,   98, 2275,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1902,   12,  631,  718,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  205, 1412,  844,  302,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  743,   12,   82,    1,  548,  365, 1857,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   68,  102,  877,  105, 2338,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   12,    1,  891,    1,   37, 2646, 3133,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3226,  361,  542,  565, 1231,   32,  856,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,  251, 1754,  861,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3209,  688, 3260,   37,  288,   28, 1834, 3135,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  795,  295, 1203,  473,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   25, 1285,   85,    1,  583,  191,  800,   60,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159,  554,   32,  218,  714,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1547,   27, 1034,  340,  951,   60,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233,  736,  578, 1066,   98, 1879,   37, 1865, 2968,  317,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  302, 1712,   37, 2392,    1,  956,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1492,  267, 1366,  321,  612, 1343,    1,  774,    1,  487,\n",
      "         2488,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3141, 1090, 1829, 1959,  176, 2748,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   12,  484,   98, 2128,    1,    1, 3380,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,   51,    1,  220,  163,    1,   12,    1,  297, 2439,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885,  879,  631,  297, 2523,    1,  181,   98,  103, 1569,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1423,   37, 2579,  455,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3205,  602,   32,  593, 1990, 2701,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1841,  958,  770, 1976,   61, 3102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597, 2774,    1,   37,  631,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 1464,   37,  759, 1384,  132,  191,  971, 1757,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  565, 1724, 1114,    1,   28, 1514, 2209,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 405,   1,   1,  45,  91,  12, 103,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 954, 897, 176,   1, 118,  67,  32, 572, 428,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   64,  765, 3228, 3103,   37,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,    1,  590,  786,   12, 2494,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  288,   37,   26,  410,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2508,    1,  388, 2501, 2502, 1655,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1741, 1228,    1,    1, 1876,   37,    1, 2549,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1,    1,    9, 1488, 1234, 1863,  218, 2027,    1,  256,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  395, 2003, 2162, 1950,  641,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  528, 2579, 3154,  354,    1, 2523,   81,   37,  590,    1,   32,\n",
      "          166,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1820,  297, 2703,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  811,    1,  518, 1190,   98, 2315,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  506, 1087,   61,  593,   12,  103, 1151,  607,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2464, 2329,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1, 2026, 2739,   32,  166,  593,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  104, 2823, 1708,    1,  191,    1,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1773,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2244,    1,    1, 2286,   37, 1154, 1029, 2821,  272,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  647,  546,   82,  648,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2524,  365,  613,   41,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1972, 1220,    1,   91, 1027,  327,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  430,   12,    1, 1260,  947,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,    1,   37,  572,  207,  354,    1,  387,  390,   32,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 2489,   85,  863,    1,    1,  444,   10,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12, 1656,    1,    1,    1,   37,    1, 1975,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2241,   45,    1, 1937, 2921,  187,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,    1,   28, 2941, 1569,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1527, 2664, 2572,  191, 1054, 2003,   32, 3369,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   69, 1069,  580,    1,  548,    1,   39, 1665,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  340,    7,    1, 2489,  183,  808,    9,  931,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  506,  575,  335,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12, 1384,  738,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2477,  944,    1, 2977,    1, 2896,    1,  928,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043, 1086,  526,    1,   69,  122,  817,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,  415,  105, 2426,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,  193,  415,  105, 1339,    1,  460,   12, 1018,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2593, 1429, 1446,  700,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2137,   32,    1,  854, 2856,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  792,    1,  792,  548,  730,  841,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2345,  622,   46,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 2094, 2580,    1, 1228,   37,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  135, 3024,  323,    1, 2206, 2989,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  867, 1236,  668, 2852,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   26, 1039,   98,  166,  260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2985, 1061,   32, 2328, 1260,   98, 3343, 1009,   12,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  187, 1230,    1,    1, 1443,    1,   37,   77, 1224,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785,    1,  107,    1, 1124,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2, 978, 769, 565, 526,   1,   1, 682,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  67, 423,  12,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,   12,    1, 2331,   32,  647,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 2160,   28, 1140,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3358, 1554,    9,  351,   32, 2197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739,    1,  155,  568,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  761,   51, 1289,   37,    1,  304,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  445,  967, 1382,  452, 3248,  361, 2672,  915,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1329,  787, 3273, 2072,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1753,    9, 1107,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  942,  958,  581, 2623, 2624,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,   37,  693,    1,  861,   12,    1, 1942, 3031,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    9, 1567,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671, 3126,    9, 1695,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   91, 1707,  864,   12, 1220,   37,  815, 3107,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3014,    1,  326,    1,  297, 1718,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2053, 2055,    1,    1,   32, 1332,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2980,    1,    1,   98,  777, 1446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  691,   12,    1,    1,    1,   32, 1523,  297,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  434, 1821,    1,   98, 3024,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  208, 1536,  372,  283,  220,  104,  422,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 1386,   37,   47,   28,   37,   32,  447,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  361, 3231,  498,   37, 1056,  356,   24,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 2541,  391, 2266, 1484,  104, 1572,  443,   32,  531, 2189,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2615,  276,  809,   98,    1,    1, 1854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  166, 2276, 2072,  166, 1521,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2579, 3252,    1, 1086,  220,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,  162, 1363,  562,    9,  179,  142,   87,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3276, 2365,   98,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,    1, 3169,    1, 2779,    1, 1632,   32,  455,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3095,  361, 3375,  588,  949,   45, 3340, 3091,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1157,  379, 1343,    1,    1, 1512,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1100, 1654, 2238,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  183,  197, 1253,    1,    1,  996,  570,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1257, 2040,  548,  283, 2195,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,   22,   39,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2904,  104,  575,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  382, 1885,    1,    6,  197,  157,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  938, 1075,   37,  335,   98,  531, 2751,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  639,   37,    1,    1,    9,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  147, 2037,   39,    1, 1655,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3238,   61,    1,    1,    9, 1090,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147, 3006, 2856,    1, 3365,  777,  778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2882,    1, 2827,    1, 3102,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,   28,   98, 1869, 1606,  112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  252,   78, 1004, 2253,    1, 3037,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3303,  884, 1003,  176,  247,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  488,    1, 2095,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  613, 2665,  361,   29,  412, 1228,  256, 1766, 1767,  361,  388,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  908,  399,   32,  176,  551,  612,  613,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  286,  379,    1,  365,    1,    1,  261,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1831,  992,   85,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1185,  564, 1403,   81,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492, 2263, 1791, 2343, 2431,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3302,  936,  365,    1,    9, 3099,   12, 3275,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  267, 2978,   61,   98, 1171,    9,   51,   95,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1283,  912,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   13, 1591,    1,  236,  237,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  800,  104,  285,    1,    1,   12,  932,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98, 1089, 1675,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  964,   12,  751,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1926, 1927,    1, 1081,   12,    1,    1,  147, 1373,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  215, 1063,    1, 2102, 1402,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523,  590,    1,   61, 2440,    9,  920,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1334, 2087, 1568,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275, 1993,  115,  176,  455,   16,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,  829, 1013, 1522, 1268,  443,    9,  116,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   45,    1, 3143,    1,  191,  247,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  455, 1877, 2924,  190, 1334,   32,  531,  548,  356, 1691, 3102,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089,  259,  764,    9,    1,  249,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  872, 2341, 3126,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  552,  551,  405,    6,   37,  686, 1346,  361,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  220, 2250,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2466, 2153,    1,   12,    1, 1417,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  326, 2400, 2524, 1768,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275, 1112,  176, 1610, 2087,  433, 1844,  716,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  303,  996,  570,  577,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1966,    6, 1649,    1,  696,  455,    1,  942,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977,  267, 2239,   51,  606,    1, 3012,  298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1028, 1327,    1,  680,  114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2751,  865,   37,  598,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2888, 2043, 1719, 2987, 3005, 2175, 1371,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2842,    1,  176,  208,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3175,    1,    1,  759,  172,  895,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1030,    1,    1, 3081,   45,  105, 2275, 1708,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1123, 1340,   12,    1,   45, 1194, 2907,   37, 1348,  176,  754,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1441,  198,  104,   60,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2171, 2800,   98,  844, 2697,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,  580,  856,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1956, 2565,    1,  167,  319,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3034,    1, 2355, 1525,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  776, 1268,   32,    1,   45, 1023,    1,   45, 3282, 3009, 3064,\n",
      "          361,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,  396,  449, 1684,   32,  257,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,   81,  284, 1737,  444, 1547,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1099, 1453,  307,  422,  572, 2092, 1757,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2822,  497,  498,   37,  856,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,  267,  460, 2385,  612,    1,  142,    9,  179,  220,  727,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  561, 2625,  552,  552, 2264,    1, 3003, 1702, 2039,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1445, 1061,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1018, 1691,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3168, 2257,   39,   45,   65, 1990, 3179,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  786, 2446,  854,  550,    1,   98,  166,  777,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  387, 1639,   32,  301,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,  267,  299, 1822, 2324,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,  660, 1151,    9,  365, 2436,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2922, 1454,  531, 2375,    1, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  504,   32,  166,    1,    1,  404,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  388,    1,  115,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,  267,  190, 1745,    1,  453, 3032, 2108,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1662, 1292,    1,  928,   32, 2140,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1380,    1, 2101,   45,    1,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2779,    1,  191,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  935,   12, 1808,  437,  315,   37,  693, 1821,  541,   32,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  661,    1,  934,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1966,   12, 1899,  680,  433, 2263,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2249, 1325,    1,    1,  590, 1665,    1,  942,  267,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2722, 3074, 2920,  872,  420, 1657,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3204,    1, 3230,    1, 3169,  489,   39,   45, 2936, 3329,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  208,  140,  449, 1674,  671,   32,  537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   40,    1,  259,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  391, 2094,  622,    1,   37,  700,   12,   24,   50,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  590, 2613,  865,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  386,   37,  125,  104,  541,    1,  289,   98, 1663,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   69, 1518,  530,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1323,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3285,  442,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1444,  321,  612, 1594,   85,  916,   37, 1594,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  355,   12,    1,   37,  168,    1,   51, 1413,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192, 1364, 1365,  270,   37,    1,  691,   32,  854, 1463,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2953,    1,   96,    1,    1,    1, 1159,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,   98,  103,  187, 2523,    1, 3325, 2139,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  671, 1078,  214,  142,  852,  187, 1232,  460, 1924,\n",
      "         1696,   45,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 2018,    1, 2884,    9, 2765, 1634, 3006,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1206,    1,   22,  721, 1830,   37,  741,   98, 1656, 1649,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564,  123, 2709,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596,    1, 2083,   45, 1147,  947,    1, 2190,   32,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1707,  372,   94,  142,    9,  844,   16,   50,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  715,  589,   37,  166,  342,  894,   52,    1,   32,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  619, 1253,   98, 1823,   32, 1090,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1938, 2607,  382,   66, 2098, 1675,   15,  119,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 1243,  622,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   91,  852,   37, 2651,  163,    1,   12,    1, 2198, 3337,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1757, 2424,    9, 1818,  147,    1,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2264,    1,  191,    1, 2432, 1419,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  817,   98, 1053,   12,  367, 1097,  568,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1229,  104, 2309,   37,    1,    1,  187, 1094, 3397,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2688,   12, 2518,   45,    1,  361,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  599,    1,  334, 1445,  917,    1, 2226,  331,    1,\n",
      "            1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2275,  108, 1811, 1280,  444,   10,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 2954, 1174,   37,    1, 1675,   37, 1211,   28,    1,    1,\n",
      "            9,  440,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2859, 2955,  894,   92, 2971, 1116,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3128, 2040,   45, 2128, 2022,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,  213,   37,  698,    1,   46,  220, 2707,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2620,    1,    1,    1, 1033,   12, 2734,  591,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  396,  885,  726,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1214, 1215,    1, 1216,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   10, 1450, 2275,   98,  129,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1258, 2457, 1844,  176,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  608, 2551,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,  463, 2170,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  506,  782,    1,    1,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2789,  650, 2040,   98,    1,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3324,  571,  384,    1,   37,  726, 1913,    1, 2579, 1684,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1162,   37,    1, 1771,    1,    1,  250,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3115, 3130,  894,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3391, 1523, 2897,    1, 3279,   32, 2597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  631,  166, 2708,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1880,  835,    1,   48,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1712,    1, 2819,  190,   52,    1, 1387, 1056,  537,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,    1,    1,    1,  111, 2638, 2931,  625,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1658,  224,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1412,    1,    1, 1465,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  215,  552,  552,  912,    1, 1046,  822,  522,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  777,  778, 2008, 2311,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3118, 2696,  267, 2751,    1, 2282,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2528,   45,  596, 2691, 1388,    9,  987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  585,   92,  104, 1290,  396,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3276, 1376,  191, 1997,    1, 1133,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2511,    1,  173,   98,  845,    1, 1935,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   13,    1,  213,   37,  151, 1479,    1, 2166,  384, 1341,\n",
      "            9,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1725, 1421, 1211,  442,  630,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 1938, 3197,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  749, 2129,  155, 1057,  600,  790,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   37,   26, 1116,  656,   32,  463, 1447,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018,  300, 2427,   32,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 1366,  705, 1488,  619, 1542,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  103, 2635,    1,    1,  191,    1,   32, 2592,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390,  387,  354,   45,  342,   59,    1,   32,  260,  220,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  684,  102, 1285,  417,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203, 1018,  460, 3065,  901, 1922,    1,    1, 1608, 1976, 1922,\n",
      "         1090,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  176, 1255,    1,    1, 3153,  893, 1210,  810,    1,    9, 1749,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   69,  102,    1, 1621,    1, 2571,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   61,  590, 1665,   37,  224, 1724,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  820,   32,  104, 1411,  339,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  112, 2840,  408,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  439,   45,  166, 2318, 3084,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,   37,  187, 1588, 1155,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 2962, 3021,    1, 3263,   37,  726,  297, 3300,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  885,  758,   37,    1,  220, 3034,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169,  361, 3257, 1758,   32, 2197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  334,  321,  458,   98, 2843,    1,  267,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  729,    1,   37, 2041, 2655,    1,  267, 3359,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   51,    1,   37,  827,  274, 3087,  629,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035, 1070,   37, 1174, 1038, 1175,  187, 1371,  187, 1610,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,  416, 2596, 2985,   98, 1202,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  365,    1,   61,  125,    9,  596,    1,  442,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  884, 1096,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283, 3100,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3192,    1,  335,  674,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3294,   12, 2256, 1631,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  796,    1,  193,   37, 1505,  105,  365,  957,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  361, 1749,  498,   37,  130,  849,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1622, 1009,  794, 2154,    1,    1, 1708,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2313, 1988,   45, 1809, 2429,  600,   36,    1,    1, 2375,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  864,  431,  132,   98,    1, 2673, 1806,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965, 2982, 1284, 1691,    1,  202, 1444,   77,   98,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1017,  669, 1236,  228,  597, 1612,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,  230,   37,  606, 3265, 1857,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1956,   12, 1117, 1450, 1253,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2628,  437,  108, 2698,   45,    1, 2342, 1317,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,  848,   37,    1,  617, 1892,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  144,  145,  108,   98,  244,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,  117,  700,    1,  140,  142,    9,  163,    1,   12,    1,\n",
      "          413,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2282,    9, 1795,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3256, 2868, 1401,  166,  454, 1159, 1849,   26, 2069,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,    1,  885,  183,   80,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  688,  614,   98,    9,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1542,   37,  843, 2390,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2275, 1004, 2383,  600, 2249, 3373,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  387,   15,   28,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  174,   28,  152,    9,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2563,  949,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  365,  754,   15,  245,   32,  871,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3336,  361, 1755,  176,   36, 2632,   28,   32, 2834,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2095, 3060, 2572, 1897,    1,   32, 2018,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1884, 1345, 2897,   32, 2646,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2087, 2614,  103, 1214,    1, 1913,  726,   32, 1559,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  442,  910, 1052,  202,  729, 2073, 1637,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1087, 2767, 1228,   37,    1, 1465,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,  326,    1,   28, 1056,  223, 2135,  140,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  709,  104,    1,    1, 3289, 1061,   98, 2887,   44,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  952,    1,  182,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,  551,    1,   51,    1,    1,    1,    1, 1279, 1380,  854,\n",
      "          176, 1194,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3342,   12, 2059, 1061,  297, 2282,  722,  396,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,    1,  361,    1,  187, 1841, 1564, 1377,   37, 3345,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708,  379, 1882,   37,    1,   45, 2314, 3358,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  876,  612,  692,    1, 1281,   98,    1,   32, 1300,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  169,    1,  702,  427,  167,    1, 1443,    1, 1592,  774,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3296,  872,  420,  385,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  321,  877, 1605,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  160,  437, 1484,    9,  927,   45,    1,   79, 2102,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  800,  659,   45, 1354, 2529,  216, 1976, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  593,   12,  103, 1090, 2308, 1523,    9,  987,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2500,    1,    1,  959, 1745, 1306,    1,  506,  782,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1079, 3063, 2384, 1724,  885, 2355, 1013, 2549,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2658,   45,    1,    1, 1387,   32,  124,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1360,  612, 1377,  148,   12,  214,  315,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1757,    9,  864,  549, 3385,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  632,    1,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1404,   45,  597, 1405,  475,  225,  333,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  827,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1151,   12,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  631,   32,    1, 1787,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  674,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2768,    4,    1,  848, 1831,  297, 2102, 1994, 1712, 2518,   32,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  619, 1509,   39,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1107,  176,  105,    1,   12,    1,    1,  202,  544, 1366, 2595,\n",
      "         1709,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1338,   45,    1, 2058, 1086, 2423,   12, 1844,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 1021, 2072, 2979,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283, 1656,    1,    1,   28,    1,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1188,  105,  389,    1,  619,  105,  841,    1,  161, 1330,   37,\n",
      "          112,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1292,  418,   32,  463,    1, 1396,    1,  616,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1081, 1082,  107,   37, 1083,    1,  636,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110, 1940, 1810, 1305,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  845,   69,  102,  932,   32,  417,  225,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3083,  442,    1,   37,    1,    9,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2071, 1331,  769, 1403, 2071,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1202,   37,   52, 2889,  384, 1480,  340,  297, 2235,   12,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  338,    9, 1524,    1,  187,  531, 1302,  980,  109, 1057,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1464,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  665,   98, 1569,  297,  487, 3222,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1397,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612, 1584, 1658, 2603,  619,  901,   32,  166,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  996,    1, 1394,   37,    1,  468,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   56, 2755,    1, 1231,   32,    1, 1228,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    9, 1948,    1,    1,   39,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3132,  688, 3108,   37,  335, 2941,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3391, 2625,   98, 3381,  433,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1486, 1680,    1,  259,   48,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  573,  469,   11,  662,    1,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1053, 1710,  193,    1,    1, 1789,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2255,   12,    1,   39,   45,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3244, 2516,    1,   32, 1090,  220, 3276,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 2414, 2729,  947,  191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3012,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 2952,  612,    1,    1,    1, 2582,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3310,    1,  187, 2920,  664,   37, 3206,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  770,    1, 1796, 3102, 1976,   32,  531,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  103, 1428, 3397, 1243, 1338,   45, 1647,   32, 3118, 1512,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  886,  261,   39,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1951,  700,  325,    1,    9,    1,   54,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  770, 2116,  418,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056, 3095, 2844,    1, 3403,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,  868, 2856, 3094,   27, 3343, 2735,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  464, 2924,    1,   32,  531,    1,  907,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  954,  256,    1,    4,   56,  356,  389,   93,  729,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1092, 1236, 1465, 2232, 1182,   32, 1479, 1994, 2086,  221,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  657,    1,    1,  844, 1151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2, 192,   1, 198,  32,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  12, 156,  28,  32, 705, 401,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3260, 1824, 1264, 1204,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3140,   37,    1,  861,   98,  531, 2735,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  334, 1445,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1530, 2598,    9,  529,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3382, 1492,    1,   32, 2018,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  750,  379, 3358,    1, 1372,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2153, 1421,  342,   12,  449, 3341,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2881,    1,   98, 1718,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  668, 2039,   98,  166,  454,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    6,  570,    1,  225,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   66,  242,  187,   69,  953, 1315,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1221,   96,   79, 2041,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  640, 1714,   32,  620,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2224, 1726, 2317,  548, 3114,   12, 3372,    1,  926,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3018,  190,  211,  829,  112,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3186,    1, 3256,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,   12, 2842,   45, 1450,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,    1,    1,    1,    1,  564,   85,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  912, 2285,  725, 1976,  193,  514,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  381,  267,  422,   51,  335,  522,  444,  375,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 919, 102,  45, 437, 441, 191,   1,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 328, 691,  12,   1, 325, 104,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1249,  739,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1820,  897,    1,  190,  123,    1,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2212,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2433, 1606,   32,  985,   45, 2597,  686,  191, 1957,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2314, 2523,    1,   32, 1423,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3141,  395,  357,  649, 3141,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  859,   37,  439, 3107,    1,  384, 1332,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2592, 1949,  349,   45,  829, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  912,    1, 1046,  166, 1107,   32, 2678,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2571, 2153,    1, 1970,   37,    1,    1, 2657,  210,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310, 1109,  681,   18, 2444,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1536, 1183,    1,  331, 1126,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 1107,  542,    1, 2102, 1402,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2507, 2707,  342,  132,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  370,  513,  193,  514,   37,    1,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1554,    1, 2789,  315,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1486,    1, 1917,    9, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  395, 1896,   37,  838,  954, 2567,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 1466,   37,  125,    1,   87,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,  458,    1,   32,    1,    1,  155,  347,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,    1,    1,   39,    9,   28,   37,  105,  339,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1094,  315,    9, 3358,    1,   32, 3339,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  794, 1273, 2665, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1017,  308, 2056, 1011, 1220,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2909, 2856,   32, 2597,    1, 3383,    1,   69,  965,    1,\n",
      "           28,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2800,    1, 1187, 2739,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  565,    1, 2321,    1,  384,  293,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  547, 2572,   32,  632, 3102, 1512,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2924, 1866,   37, 1496,  395,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2227, 1831, 1236,   32,    1, 1559,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3276, 3232, 2420,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  793,   12,    1,  729,  105, 1882,  389,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  957,  958,    1,  140,  458,    1,  333,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  224, 1749,  220,    1,    1,  950, 1130,   37,    1, 1410,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  420,   96,  289,   37,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1718,  162, 2146,    1, 1564,  221,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  867, 1396,  668,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2315,  166,    1,  443,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,    1, 3358,   12,  172, 1021,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3192, 2741,  688, 1364, 1365,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1279,    1,  402,  166,  454,    9,    1, 2700,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2993,    1,  581,  100,  220, 1117, 1525,    1, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1120,   37,  856, 2819,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3289,  603,   37, 2592,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2041,    1,    1, 1042,  484,   37, 2388,  171,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  307, 1913,  401,  570,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273,  259,   15, 1192,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3096,    1,  361,    1,    1, 1154,    1,   12,  389,   32, 2839,\n",
      "          487,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,  464, 1585,    1,  612, 2673, 3399,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  155,    1,   54,  384,  332,  333,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947,  114,    1,  493,   98, 2930,  798, 2832,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,    1,  163,    1,   12,    1,  907,   37, 2000,  442,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  367, 1097,   57, 1269,    1,  644,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  970,    1,  567,  533, 1198,   69,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  475,    1,    9,  389,  187,    1,   45,    1,  171,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  854, 1867,    1, 2320, 1461,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  102,   45,   69,  670,   98,   64,  509,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,  242,  737,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2726, 2564,   98, 1204,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1000,  361,  865,  901, 2615, 2941,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2409, 2694, 1918,   32,    1,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  361,  166, 2218,   45,  345,  434,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  863,  133,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   81,   37,    1,   37, 1154,  458,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1110,  913,    1,  683,   98,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1005, 3298,  140,  166, 1796, 1938, 3197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2178,  147,   57,  776,   45,    1, 3382,  732,    1,   37,  168,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3068, 1542,    9, 2487,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  314,  475,   51,   84,   85,  187, 1370,   45,  399,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  764,   61,   98,  166,  454,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  648,   12,    1, 1572,   37, 2667,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3296,  712,   28,    1,   12, 1144,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2597,  186,    9, 3340,    1, 3377,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151,  232,  267, 2308,  565,  193,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1094, 1648,   37, 2010,  622,  751,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  384, 2616,    1,  191,  584,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977,  232,  387,  808,   32, 1821,    9,  457,  441,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  207, 2325,    1,  460,   12,    1,  951, 2854,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1001,   46,  829,  875,  220, 1652,  361,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,    1, 1360,  612,    1,   24,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,   32, 2088,  605,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  613,  441,    1,   28,    1,    1, 1185,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2569,  195,    1,   32, 2748, 1038,  617,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3147,    1,  297, 3114,   23,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  676,  267,  503, 2399,   37, 1496,  749,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2377,    1, 1008,   45, 2372,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,    1, 3024,    1,  187,  593,   12, 1354, 2529,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1366, 1445,  193,  320,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3305,  415,  267,  590,   37, 3194, 3195,    1,  190, 2565,  176,\n",
      "          584,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087, 2614,    1, 3186,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,  288,   37, 1048,  148,   12,   54,  142,    9,  647,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1411,    9,  224,    1,    1, 2995,    1, 2355, 1013,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,  647, 2187,   51,  973,    1, 2718, 1159,  105,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  977,    1, 2889,  384,  293,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 1379,  994,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   18,    1,  829,  190, 1403, 1778, 2580,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  315,    1, 1964,  856,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  355, 1654,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  501,   37, 2553,   39, 3231, 1090,    9,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   22,    1,   15,    1,  393, 1702,  359,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  166, 1110,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861,  997, 2200,  221,   37, 1718,   32,  864,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    8,   39,   45,    1, 2542, 2432,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2017,   98,  112,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141,    1, 2317,  297, 2408,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,    1, 2649, 1219,    1, 2414,  786,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  136, 1025,  288,   37, 2225,  365,  475,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2547,    1,   32,   98,  587,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2764,    1,    1,    1,  132,    9, 3088,  787,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2190,    1,  272,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1117,    1,  163,    1,  879,  231,   45, 1994, 2086, 1228,  132,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,  633,  829, 1241,   28,    1,   60,  197,  504,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,   45, 1022,    1, 2296,   32,    1, 1821,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178,    1,  318, 1976,  514,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1427,  166,  671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  887,   45,    1, 1380,  289,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2578,  546,  181,    9, 2613, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 2209,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1013,  441,    1,    9,  166, 2355,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,    1, 2924,    1, 1221,   61,  590,  707,  754,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  137,  631,    1,  417,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1451,    1,  132, 2337,  730, 2614,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3378,  776, 2052,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1184,  347,   98,  684, 1879,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1083,   69, 1069,   32,  142,   37, 1403,   85,  119,\n",
      "          102,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,    1,    1, 1458, 3042,  161,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 793,  37,  44,   9,  11,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   6, 156, 570,   1, 159, 245,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  354,  703,   98,  134,    1,  704,  705,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  261,  444,    1,  625, 1167, 2109, 2638,    1, 2165,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2911,    1,   37,    1,    1, 2778,   32,  715,  890,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  249, 1980,   37,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1017, 3014, 1749,  220,  326,   37,   47, 2079, 1228,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3251,  149,    1,   39,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1110, 1594,   37, 3188,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1234,    1, 1112,   45,  211,    9, 2979, 2869,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2708,    1,  187, 3393, 3389,  582,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,   51,   71,   98,  109, 2429,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  727,  613, 1360,  612,    1,  180, 2434,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1902,  900,   12,  667,    1,  574, 1536,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2685,  907,    1,    9,    1,  176,  754,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1177,    1,    1, 1080,    1,    1,  845,   36,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  596,    1, 1420,    1,  353,  119,  207,  197,  187, 1220, 1137,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1,  108, 2629,   45, 1610,  161, 2607,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2815,    1,  168, 1836,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  150,  933,  486,   98, 1220,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2410,   28, 1879,    1, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,  515, 2266,  741,   45, 1161,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  667, 1384,   37, 1083,  869,    1,  574,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1562, 1338,   45, 2924,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 1603, 2715,  884,    1,   32, 2490,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004, 2898,  258,    1,  100,  224,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1231,   32, 1228,    1,  400,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  911,    1,   37, 3018,  211,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1958, 1215,    9, 3215,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 2003, 1585, 2414,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1821,  927, 1518,   32,   37,    1,  166,    1,  985,   45, 2820,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  775,  365, 2474,  259,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  622,    1,  513,  514,   37,  966,  361,   61, 1156,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1741,    1,  728,  167,  168,  845,  275,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  854, 2018,   46,    1,  220,  798,   45, 1647,   98, 1815,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1482,   37,  151,    1,    1,   50,    9,    1,  372,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  848, 1303, 2384,  365,    1, 2880, 1285, 1766, 1767,  327,  841,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  747,    1,  408,   37,  125,  572, 2034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,    1,   37,  166, 2010,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 3149,  650, 1877, 2024,    1, 1002,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  125,    4, 1010, 1115,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   99,    1,  487,  631,  220,  429,   98,  347,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,   37,  764,    1,  911,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 2924,   98,  454,   37, 2597,  455, 1707, 3006, 1665,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  113,  166,    1,  548,    1, 3182,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3397, 1550, 2587,    1,   32, 3343,  890,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  549, 1159,  104,  286,  293,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  102,  972,   37,   52,  969,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2800,  742,  566, 1178,  163,  142,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,    1,    1,    1,   32, 2205,  548,  354,   37, 2468,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,  142,  162,  501, 1125,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3247, 2737,    1,   39,  444, 3248,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3319, 2446, 1022,    1, 2296,    1, 1334,   32, 1264,  841, 2884,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2313,    1,   37,    1,    1,   32, 2073,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2663,   51,    1,  910,   32, 3020,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,  395,  802,    1, 2605,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2292,    1,  531,  863, 1708,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,  464,    1, 2352,  695,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1671,    1, 2227,    1,  705,    1,  105,    1,  680,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343,   46,  271,   85,  202,    1,   51,   52,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  200,    1,    1, 2474, 1605,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447, 1484, 1512,   46,  297,  531, 3365,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2076,    1, 1716,  606, 2267,  884,   98,  572,  327,  218,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1,  365,  792, 2031,    1,  792,   26, 1039, 2234,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  487, 3102, 1999, 1530,   32,  531,  187, 2751,    1,   32, 3383,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1923, 3272, 3100,   37, 2428,  332,   45,  183, 1985, 1684,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  794,    1,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,    1, 1314,   98,  163,    1,   12,    1,  220,  976, 2237,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  159,   45,    1,    1,  120,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1242,    1, 1823,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3167,    1, 2916,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 1034,   32,  861,  550,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  597, 3104,  475, 1712,  108,   98,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,  218,   37,    1,   54,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2004,    1, 1635,  597,  755,  117,  710,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1569,   98,    1, 2813,    1,    1,  640,  455,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147, 2924, 2625, 2597, 3392,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1,   98,    1,  773,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3142,  429,   79, 3152,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187, 3339,  741, 1552,    1, 1094,  108,   45,  521,  443,  629,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1375, 2385,  612, 1799,  453,  573,  469,  424,  356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2084,    1,  387, 2505,    1,   32,  584,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2437,  411,  384, 2551,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2469,  487,    1,  678,    1,  928,   32, 1640,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  197, 1249,  308,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   37, 1539, 2693,    1, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   98, 2041,    1,    1, 2551,  590,  388,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 3369, 1822,  439, 2292,   32, 3118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,  32,   1, 127, 168,   1,  32,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 255,   1, 760,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  326, 2767,    1, 2043,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  705, 1102,  769,  837, 1090,   41,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  253,  166,    1,    1,  420,  134,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  957,    1,  441, 1152,   45, 2786,  148, 2558,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   56,    1, 2844, 1769,   37,  759, 1050,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2343,   12, 3404, 1046,  776,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  215,  681,   37, 1173,    1,    1,    1,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,    1,    1, 2821,    1,  105,  227,    1,    1,    1,    1,\n",
      "          166, 2789,  260,   32,  104,  101,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1987,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3045,   32,  786,  913,    1,  361, 1444, 1561,   28,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3321,    1,    1, 2055,  444, 3244,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   81,   98, 1567, 2290,   37, 2192,  386,  726,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  166,    1,   61,    1,  297,    6,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  288,   37, 1198,  909,    9,  920,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2275, 1484,  117,  437,  105, 1030,    9,  166,   10, 1708,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1423,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  228, 2458,   37,  877, 1674,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1065, 1190,  939,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1613,  728,  829,  269,    9, 1273, 1117, 1525,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1630,  513,  514,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1017, 1573,  808,   32,    1, 1209, 2357,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 1009, 2726, 1260,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 2770, 2147,    1,  251,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  851,   32, 3360,    1,    1,  178,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  358, 1536,    9,    1,    1,  467,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,    1,  863, 1822, 1734,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1783,  353, 1961,  572,  932,    1,  387,  331,  354,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  478,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3232,   23, 1090,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 2591,  891,   32, 3360,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2523,  361, 3325,  619, 1217,    9, 3201,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  147,   37,  231,    1, 1393,    1, 1506,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  964,  765,   37,    1, 2106,   12, 1021,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2076, 2185,  327,  218,  570,    1,  108,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2034,  449,  726,  395,   26,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1520,  884, 1003,  176,    1,  218,  220, 2084, 1395,  844,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,   92,   37,  247, 1967,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1447,   12, 2467,    9,    1,  671,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  335,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  287,  408, 2302,  624,  388,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1751,    1,    9,  247,  413,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1,  187,    1, 2479, 2507, 2505,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2387, 1574,    1,  187,  192,  640,  124,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  315,    1, 1219,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3369,  488,   37,    1, 1056,  215, 1527,  639, 2405,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1384,  408,    1,  567,  686, 1162,  197,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1000,  166, 2320,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2912,    1,  191,    1, 2457,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2254,  140, 2255,   43,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 1090,    1,  460,   12,    1,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  586,  700,  536, 1117, 1943,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  144,  145,  108,   98,  244,    1,  159,  720,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,   12,  395,    1, 1908,  114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,  361,  829,  872,   28,   37,  856,  923,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  506, 1023,   45,  163,    1,   12,    1, 1606,    1,  606,  858,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1, 2012,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1396,  709,  971,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2160, 1154, 1046,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1013, 1522,    1, 1381,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1236,  923,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  733,   39,   45, 1050,  112,    9,  331,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  191, 1278,  544,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612, 1550,  221, 2017,  384, 1778,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  105,  271,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,   37,    1, 1489,  163,    1,   12,    1,  225,   29,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2963,  968,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  861, 1228,    1,   29,    1, 1273,  618,  361,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  686,  531, 2006,  220,  947,  475, 2572,   32, 2137,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2977,   64, 1527,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1512, 2393,   32, 2786,  171,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  789,   12,   98, 1220,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1290,  396,   71,   98,   81,   45,  567,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3260,  631, 3209,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1509,  151,  115,   32,    1,   45, 1595,   93,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  755, 2065,  912, 2815, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3124, 2652,  119, 1918,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  657, 1949,  469,   37, 1237, 1412,  844, 1151,  218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  393,    1, 1961,    9,  176,  177, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545, 2308, 1991,    1,    1,  267, 3213,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2090,  884,  631,   32, 1764, 1990, 3293,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  396,    1, 1766, 1767, 2320,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  729,   21,   37,  123, 1503,  214,  191,  356,  439,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  133,    1,    1, 1457,  437,  267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3375,    1, 3095,  907,   37,  469,    9, 3358,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,  167,  860, 2177, 1027, 1998,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3096, 3009, 2632,   32, 2596,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1435, 2018,  267,  199,    1,    9, 1815, 2666,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2498,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2871,    1,    1,    1,  297,    1, 2286,   63, 1023,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361, 1684, 1489,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 1989, 1990,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  396, 1994, 2693,  449,  220,  365, 2403,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  390,  361,    1,    9,   10,  361, 2275, 2722, 3074, 1215,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2038,    1,  104,  967,    1,  453,    1,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1853,    1,    9,  388, 2357,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2206, 2435, 1110,  872,  420,  385,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  758,   11,    1,    9,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  315,    1, 2237,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2548, 1523,    1,   32, 2646,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1133,   37,  688,  176, 1477, 1990,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1938, 2607,  382,   66, 2098, 1675,   15,  119,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2789,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3328, 2192, 3309, 2315,  922,  698,  176, 3182,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  584,    1,    1,  754,  390,    1, 1542,    9, 2966,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  521,  443,    1, 3369,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,  361,   91,    1,   37, 2286,   37, 1154, 2673,  630,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885,  288,   37,    1, 2523, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  195, 1916,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2176,    1, 1410,  116, 1527, 1961,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  597,    1,  741,    1,   32,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32,  218, 2596, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1897,  166,  818,  834,  914,    1,    1,   45, 2608, 2607,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2514, 1212,  315, 2227, 2107,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  839,  111,    1, 1879,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1700, 1833,   46,   98,    1, 2673, 1027, 1411,  339,  420,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2327, 2885,  697,    9,    1, 2308,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311,    1,    1,    1,    9,    1,   32,  449, 1863,  221,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  305, 1826,    1,  685,  686,  241, 1653,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1249,  602,   32, 1990, 1343,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307, 1713,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  954,  897,  176,    1,   67,   32,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  218,  650,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2925,   61,   32,  105,  922,   45,  453,  248,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3384,  650,  583,   32, 1260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  267, 1147,  947, 1188,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2070,  854, 1686,  187, 1463, 2405,    9, 2250,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3005,   96,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1051,   12,    1,   21,    1, 2073, 1843,   15,   93,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  585,   51,  606, 2963, 2977,   12, 2462,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1725,  854,    1,  288,   37, 2460,   79,   32, 2020,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2628,  884,  103, 2788,   32,  428, 1002,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,  688,    1,    1, 2615,   37,  489, 1387,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1016,    1,  897,  176,    1, 1146, 1703, 1224,   32,   72,\n",
      "          401,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1013, 1522,    1, 1159, 2994,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2676, 2136,  736, 1908,    1,   59,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  683,   98, 2056, 1171,  548,    1,   37, 2505,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  251,  547,  454, 1766, 1767, 1876,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  360, 1809,  142,    9, 1503,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  859,   37,    1, 1926, 1927,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1938, 3197,    1, 2402,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2672,    1,  750,  729,  719,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  964, 1288,   54, 1714,   37,    1,    1,  680,  632,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115,    1,   98,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2473,   12,    1,  682,  388, 1102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   94,   27,  365,  845,  310,   25,  504,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  119,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2907, 2745, 3236,  439, 1826,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,  765, 1415, 2029,  105,  218,  954,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  566,  365, 2240,   32,  864, 2471,    1,  202,    1, 2449,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  256,    1,   37,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968,  952,  793,  734, 1197,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1557,   37, 1860,  863,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107, 1372,   37, 1031,    1,  430,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1243,    1,   32,  212,   12,  149,  444, 1158,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   42, 1652, 1350,  149,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  547, 2476,  726, 2376,    9,    1,    1, 1604,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3288,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1354,  295, 1083,    1, 2007,   37,  529,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2980, 2776, 3066,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3096, 3316,   12, 2072,  104,    1, 1403,   98,    1,    1,  267,\n",
      "          311,   12,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2043,   45,  166,  442,  166,  829, 1778,  803,  112,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1676, 2773,    1,  166, 1178,    9,  166,  183,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  376,  737,  570,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1796, 1920,  140, 2472,    1,   72,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1140,   98,  163,    1,   12,    1,   37,  764, 2734, 2986,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1212,   12, 2114,   98,    1,  444,  299,    1,  787,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1647,   66,    1, 1682,   37, 1910,  479,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2066,  529,  408,   37,    1,  793,    1,   35,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  853,  595,  640,  858, 2264,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  864, 2673,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,  439,  526,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2573,   12, 3398,  146,    1,    1,  952, 2179, 1445, 2927,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,    1, 1256,    1,   37,    1,    9,    1,  176, 2484, 2771,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3375, 1140,    9, 2024,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1902,  138,    1,   37,  709, 2565,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2652, 1108,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3014, 1749,  220,  326,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1834, 1494,   81,   37,  688,  590,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  256,  845,  846, 1605,   37,  453, 3044, 2168,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1570,  288,   37,  130,  395,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  719, 2688, 1482, 1074,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  311, 1090,    1,  548, 2596, 1665,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2810,    9, 3262,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 3361, 3340,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1474,  597,    1,  865,   37, 2095,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  140,  593, 1990,  633,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2983,   32,    1,    1,    1,    1, 1411, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  843,    1, 1876,   37,  829,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3123,  688,  311,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2302,   37,  335,   59,   44,   32,    1,  287,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1608,  361,  920,  166, 1690,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596,   27,  163,    1,   12,    1, 3150,   32,    1, 2414,\n",
      "         3361,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510, 1774, 2029, 2028,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  588,    1,  764,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1855, 3384,    1, 1231,  548, 2251,  384,  602,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,  920,    1,   12,  645,    1, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1899, 1654,    1,   32, 1966,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2868,   75,  475,  162,  695,   32,    1,   45,   80,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,  102,   51,  245,  187,  568,  831,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1017,    1,   82,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,  140,    1,  829,  399,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1457,  770,  183,  681,    1, 2298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3231,  619,  183, 1198,  384,  501,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2646, 1523,    1,    1,    1,  140,  183,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,    1, 2693,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1021, 1499,  205,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2035,  726, 1045,   37, 1675,  220, 1600,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   45,  617,  259, 1662,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1891,  922,  475,  531, 1284,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3189,  193,    1,  204,  321,    1,  377, 1586,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,    1,   32, 3339, 2414, 2708,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1398,  612, 2047,  166,  116,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  733, 1204, 1085,  886,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  667,  446,  267,  590, 2609,  297,    1, 2509,  548, 3379,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3237,   51,   52,  415,  698,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3370, 2985, 1061,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1574,    1,  297,  121,   36,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  162, 1084,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  361,    1, 1928, 2579,    1,  992, 1159, 1369, 2697,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1497, 2035,  971,    1,    1,   12,   24,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2971, 2502,  302,    1,   32,  433,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  915,  916, 2191, 2300, 3048, 2923, 2697,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043,  490,   37, 1637,  123,   32, 2119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  183, 1220,    9, 1412, 1107, 2308,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    4,   81,   37, 1604,  187, 1158,  475, 1213, 3000,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 3343, 2548, 2263, 2985,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   45,  166,    1, 2596,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2415,    1,   12,  914,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1691,    1, 1090,    1,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  449,    1,   45, 2994,    1, 2677,  949,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  828, 2245,  191,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1154,  166,    1,    1, 1608,  579,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  502,  432,    9, 1920,   32, 2087,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  200,  453,  365, 1013, 1522,  176,  915,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,  409,   25,  800,    1,   60,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2909,    1,  176,  186,   32, 1853,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,   61,   74,   37,   74,  548, 3288, 1987,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  590, 2602,  384,  166, 2736,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305, 1285,  115,   98,   31,  591,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  420,   51,    1,   10,   12,  531,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189, 1008,  475, 1299,  655,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  326, 1419, 1819, 1017,   37,   26, 1039,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3250,  726, 1494, 1176,  857,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  761, 1484,  420,   98, 1646,  230,  122,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1190, 1070, 3079,  193,   37,  168,   81,   37,  443,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    9,  449,  199,    1,  104, 1386, 2272,   85,   98, 2650,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192, 1364, 1365, 1878, 2716,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2897,   32, 2930,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  296,  991,  885,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,   22,  197,   28,   98, 2311, 1220,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3385,  765,   37,    1,  864,   12, 2673, 2836,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2685,    1, 3209,    1,  162,  686,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  458,   45,    1,  361,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1564,    1,  176,  754,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  202,  579,  600,  166,  954,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  225,  809,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2298,    1,  176, 2464,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1632,  245,    1,  959,  187, 2181,  187,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  765,   37,    1, 2106,   12,    1,   98, 1021, 1969, 2416,\n",
      "         1450,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1495,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1046,    1,  187,    1,  556, 1011,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  221,   34, 1972, 1222, 2359,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3277, 1542,    9, 1545,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  795,  359,    1,  152,    1,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,  565,  166, 1509, 2458,    9,  112,   32, 1033,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  490, 1159,  601,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,   12,    1,  786, 1090,  631,  220, 2513,    1,  726,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   94,    1,   81,  384,  885,  810,  199,   60,  845,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  868,   28,  453, 1230,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3227, 3284, 3189,    1,  220, 1841,    1, 1728, 1114,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1293,    1,   45,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   45, 1273,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,   37, 2286,    1,   98,  134,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056, 2572,   32, 2564,   37, 2596, 1708,  756,   45, 3343, 1009,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 1082,  531, 3102,   12,  949,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  433, 1827,   37,    1,  220,  302,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1035, 2145,   37, 1038, 1387, 2119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  215, 1498,    1,  491,   32,    1,  328,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  113,  861, 1953,  187,  108,   45,  581,  344, 2596,  872,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  183, 1272,    4,  565,    1,  439,   45, 2041,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3114,    1,    1,  129, 1945,  957,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1965, 2982,    1,  238, 2218,  176, 1056, 2165,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2345, 3385,    1, 2099,  412,   37,    1,    1, 3046,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1106,    1, 2286,   37,    1,   28,    1, 2549,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,    1,  202,  193,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  460,   12,   32,   46,  220, 1327,   12,    1,    1,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  914, 1494,   37, 1018,  439,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  764,    1,  171, 2277,   56,    1,   32,   72,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  443, 2938, 3060,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  716, 1022,  156,  452,  170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1957,  686,    1, 2597,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    5,  271,   61,   32,  166,  272,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,    1,  191,  119,    1, 2347,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  811, 1566,  411,  741,   98,  342,  548,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,    1,    1,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,  323, 1387, 1658, 1465,  220,  365, 2355, 2549,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2967,  536,  584, 1002,  190, 1114,   52,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  790,  761,   12,    1,  321,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  131, 1651,  142,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  239,    1,    1, 1343,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2193, 2474,  259,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2024,    7,   37,  417,   69,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2488, 1982,  105,  627, 2198,  166, 2708,  650,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3234,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  744,  105,  593,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3230, 1426, 2490,   26, 2033,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  244,   71,  187,    1,    1,  438,  333,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,  167,  606, 2270, 1578,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  342, 2192, 2069,    1,   98,    1, 2836,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1890,   37,  168,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  680,   97,   32, 2088,  605,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,   27, 1034,  340,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2412,  726,   24,    1,   45,  443,  297, 2533,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,   25,   26,  417,    1,  275,  159,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1024,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051,   37,  130,  552,    1,   32,  331,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3330, 1566, 1888,    1,  202,  590,  484, 1724,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  190,  424, 2222,   52,  166,  356,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585,  640, 2504,    1, 1097,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1062,   37,  462,  151,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,   72,  401,  354,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  323,    1,    1, 2100, 2206, 2989,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,    9,  460, 1278,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  316,  317,  197,   28,   98, 1580,    1,  844,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835, 2404,   37, 2237, 1094,    1,  973,    9, 1698, 3339, 2271,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1528,    1,   39,   59,   37, 1405,  253,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1211,  442,  856,  297, 1393,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3166,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,   69,    1,  765, 1159,  448,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  198, 1220, 1702,  212,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  861,  475,    1,  939,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 179,   1, 176, 612,  37, 138, 600,   1,  59,   9,   1,   1,   3,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 648, 357, 166,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  903,  464,  650,   12,    1, 1530,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220,   69,   27,  105,  106,    1,  493,  102,  698,   37, 1180,\n",
      "           28,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  420, 3103,  726,    1,  444,  683,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,  565,  920, 1573,    9, 1411,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  420, 1158, 2867,  848, 2102,  132, 3011,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,  166,  223,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 1021,  791,  105, 1894,   84,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2583,    1,   98,  316,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2659,   81,    1, 1236, 3003,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,   12, 3401,   98,    1,   45, 1918,   37, 1752, 1009,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 386, 781,  51, 130,   1,  48,  32,   1, 328,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 288,   9, 865,  37,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3280,    1,  191,  595,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  295,  888,   61,    1,   12,  504,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  405, 3291,  167,  168,    1,  454,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1928,   45, 3025,    1,    1,   98,  777,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  166,    7,    1, 2167, 3213,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2305,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3363,   12,  472,    1, 2726, 3343, 2003, 1585,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  177,  393,  359,   76,   37,  930,  187,  138,    6,  698,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3232,    1,  203,   37, 1155,  105,    1,  631,  220, 1884,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186, 1874,    1, 1918,   32,    1,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  116, 1211, 1819, 1506,    1, 2240,    1, 3000,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2469, 1458, 2275,   98, 2505, 1292,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,  162,  673,  659,   45, 1778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  218, 1187,  193, 1188,  388,   69, 1189, 1190,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  604,  102,  565,    1,  417,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596,  172, 1294,   61, 1242,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1882,   37,  741,   32, 1743,   98, 1459,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  794,    1,  279,  414, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  592,  475, 1070,   69,    1,  497,   37,   92, 1429,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32, 1740,   45, 1479, 1450,  444, 3392,    1,  947,\n",
      "         2190,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  794,    1,  761,  195,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    4,   93, 1071,   32,  385,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2476,   16, 1048,  122,   98,   10, 2521,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  387, 2371, 1033, 1539,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,  395,   37,  949, 1156,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1957, 1285,  902,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  335, 3327,  484,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654, 1586,  848, 2294,    9, 1935,   12,   45,  453,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1594,    1, 1159,  105,    1, 1804,  384, 2948,   98,  105,  227,\n",
      "         1204,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  565,  410,  115,   45,   65, 1953,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1176,  227,   37,   52, 2848,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1570,  325, 1718, 1273, 2367, 2683,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  225,  809,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2122,    1, 1035,  953, 1159, 1038,   63,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  176,    1,  846,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374, 1949, 1856,  186,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  835,    1,  942,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  251, 2355, 1013, 2549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  386,    1,   37,  151, 1159,  742,   12,  214,  315,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2171, 3134, 2628, 2540, 2160, 2049,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  256, 2931, 1211, 1013,   37,  207,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2137,  135, 1537,    1,   32,    1, 2292,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1054,   27,  938, 1075, 1967,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1875, 1542,    9,  414,  100,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,    1,  182,  531,  734,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3280,  190,  168,   37, 2592,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187,  584, 1141,   37,  429,    1,  863,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3109,   45,    1, 1083,  997,   45, 2678,  444,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3067,  342,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  321,    1,    1,    4, 1000, 1076,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1004, 2162,    9, 1956,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  267, 3381,    1,   37, 2764, 3394,  311,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  912,  361,    1, 2285,    1,   32, 2580, 2851,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1427, 2749,   28,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,  957,  251,    1,    1, 1232, 1444,    1, 1515, 1763,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  852,   37,  395,   32,    1,  973,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3379, 2147, 2596, 1260, 2414, 2335,    1, 2766,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275,    1,  562,  547,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314,  551,    1,   82,  796,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1312, 3361, 2844,   32, 3391, 2329,    1, 2597, 1260,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  985, 2611,    1, 1412,  627,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1712,  162,    1,   59, 1215,  105,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2866,   32,   37,  365,  538,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3079, 2844,  384, 2527,  164,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,   22,  861,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1461,  477,   32, 3339, 2766,  176,  177,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  481,  327,  218,   61,   76,   37, 1192,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  709, 1304, 1213,    1,  399,  220,  422,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   77,    1,    1,    1, 1082,  903, 1447,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1870,   37,    1, 1796,  327,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,  335,    1,    1, 1918,  297, 3108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  449,  104, 2819,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  636,    1,    1,  187,  937,  583,  374,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3336,  476, 2187,  384, 1668,  320,  204,  321, 1343,    9,  105,\n",
      "          855,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422, 2660,  399,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  196,   37,  693,  658,  613, 1108,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  256, 2247, 1469,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,  359,  360,    1,  361,  362,    6,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 1009,    1,  449,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  159,   28,  452,  693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1306, 1131, 2522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3230,  546, 2565,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1183, 2113,  560,  347,  245,  424, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  334,  606, 1525,    1,    1,    1,  220,  105,   40,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043, 1738,  245,  118,  176, 2410,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2378, 1686,    1,   28,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  614,   37,  166,  806,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2675, 2539,   12,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1744, 2161,  774, 1325,    1, 2622,  565,  105,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3343, 2161,  693,   37,  335,  913,   45, 1428, 3365,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,    1,  150, 2025,  261,  288,    9,   59, 1821, 2223,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1941,  104, 2548,    1,   32,  602,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,  503,  475,    1,    1,  176,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,    9,  356,  220,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1414,  361,    1,  947, 1048,    1,  401,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2660,    1,    1, 1333,   98, 1973, 2921,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  574,  475,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,  613,    1,  196,  170, 2424,  786, 1463,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  686, 3155,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  475,   37, 1027,  104, 1943,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  842,  353,  118,  197, 1253,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1419,  365, 2786, 2976, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1970, 1194,  367,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   20, 1118, 1539,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 3088,  787, 1827, 2961,  191,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1950,   45, 2162,  361,    1,  897,   32,    1, 2732,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  335,  199,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2311, 1749, 2156,   37,    1,    1,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   12,  861, 1414,   32, 2667,  260,    1,  487, 2924, 2905,\n",
      "            9,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  381,  640,   81,  176, 1047,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2832,  619, 1211, 1697,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 1833,   12,    1,    1,   39,  220,  424,  356,   12,\n",
      "          567,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  570,    1,   45,  406,   98,  166,  341, 2603, 1030,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1652, 2355, 1718, 1542,   37,  271, 1778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 2329,   37,   77,  903,    1, 1447, 2673,   46, 2793,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  539, 1037,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273,    1,  221,   37,  665, 1515, 1008,   98,  388,  618,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3066,    1,    9, 2836,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  729,   32,  166, 1090,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1211, 1819, 1942, 2156,    9,  116, 1904,  378,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,  333,  166,    1, 1323,  874,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  366,    1,    1, 1290,  396,  245,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652, 2182,   39,    1,    1, 2608,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2323,    1, 1095,   12, 2464, 1108,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  113,   98,    9, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1047,  256, 1084,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051, 2287,    1,   37,    1, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  688, 3218,  176,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  396,  631,   32, 2334, 2107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  251,  105, 1133,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3168,  951,    1, 3178,   32,    1, 3222, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,  420, 1386, 1450,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   39,  166,  627, 1935,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,    1, 2932,    1,  365, 2946,   45,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,  256,    1,   37, 1766, 1767, 1108,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,  844,    1,    9,    1,   54,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1173,    1, 1870,   12, 1234, 2528,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2695,  105,  880, 1631,   22,  846,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,    1,  730, 2614,    1, 3269, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  885, 1013, 1626,    9,  829,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,    1,  754,   45,    1, 3403,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  730, 2614, 2462,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2298,    1, 2154, 1783, 1294,   32,  163,    1, 2196,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  166, 1158,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1, 1155,  105,    1,  483,  714,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1571, 1831,    1,  267, 2711,  321,  713,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  328, 1845,  132, 2011,   32, 1904,  477,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2612,    1, 1254, 1465,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  683,  951,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  134,    1,   32, 2459,    1,  287,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1011,    1, 1046,  844, 1281,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596, 1793,    1, 2822, 2378,  176,    1,   67,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1705,   37,  345, 1228,  220,  112, 1188,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  160,  102, 1269,    1,   32,  871, 1068,  568,  361,  754,\n",
      "         2055,   71,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  709,    1,  967,  985, 1857,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 2170, 1566, 1887,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1361,  729,  198,   98,  148,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  443,   12,    1,  565,    1, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2553,   72,   32, 3278,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  985,  640,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  588,  741,   45, 1161,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,    1,   37,  205, 1412,  844,  302,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  912,  605,    1,    1,  765, 1836,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  754,    1, 1986,  418,   32, 1893,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  645,    1, 2329,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2345,  166,    1, 2985,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  176,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2752,   12,  446,   32,  854,   37,  588,  764,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  215,   12,  935,   37, 1539, 1821, 2057,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,   45, 2655,   37,    1, 1815, 1816,  854,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  790, 1579, 2500,  192,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12,  117,  218,    1,  115,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1786, 1535, 1360,  612, 1377,  148,  647,  484,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,  270,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1419,  756, 1108, 1779,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,   28,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 376, 593, 119,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 140,   9,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  845, 2326,   45, 1936, 3155,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   37, 2192,  395,    1,   98,    1, 2108, 1281,  176, 2396,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1,   98, 2336,   12,  627,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  645, 2627, 1027,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3276, 1728, 1114,    1,   45,    1,  404, 2935, 1684,   32,    1,\n",
      "          726,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   42,    1, 1691,  149,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1,   37, 2154,    1, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1391,    1,   12,   93,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3206, 1343,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    1,   12,    1,    1, 2395,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1105,  787,   37, 1468,  727,  613,  124,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1688,  251, 1211,  829, 1228,   37, 2547,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,   12, 1657,   15, 1253,  118,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1720,  166,  707,  162, 1133,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2159,  884,  885, 1173,  176,    1, 1102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  243,    4,  176,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    5, 2080,  252,  176, 2362,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1105,  787,   37, 2446,  840,  612, 1273,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  552,  361,  405,    6,   81, 1049,    1,   32, 1605,  384,    1,\n",
      "           37,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715,  477,  488,   37,    1,    1,  250,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1419, 1785, 2827,  452,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  397,  213, 2927,   46,  220,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2974, 2297,  199,   12,  792,    1,   45,  166,  356,  792,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  600,    1,    1,    1, 1120,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2741, 1188,   37,  619,  311,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228,  275,  681,  176,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  422,   51,   44, 1167,  523,    1,   37,  615,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384, 2201,   37, 2717,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,    1, 2203,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3271, 1421, 3224,    1,    1,   37,    1, 1346,    9, 2941,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1166,   37,  920,    1, 1173,   39, 1315,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   37,    1,    1, 3162,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428,   37,    1, 2416,  345,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  286,  927,    1, 1056,  388,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  458,  113, 1184,  347,  816,  176,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1030, 1559, 2247,    1,  191,  364,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1, 2601,  514,  187, 1231,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  723, 1299,  376,  308,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1062,  458,  686, 1114,  191, 2026, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  542,   32, 3208, 1313,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1048,  855,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56,    1,  147,   20,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,   37,  319,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1629,   90,  233,   45,  286,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,   51, 1079,  147,    9,  138,  591,   87,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   82, 1454,  503,   98,  749,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  164,  165,   13,   12, 1828, 2317,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2046, 2937,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1051,   34,  572,  207,  174,    1,  983,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   53,   85,  166, 2203,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2343,   12, 1389, 2126,  198, 2198, 1590,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3177, 1710,  665,  386,   28,  220,  175, 3277,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2738,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1228,  933, 1412, 2528,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  787,  697,   37, 2192,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,  134, 2416, 2985,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1454,    1,   12,  756,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3275,    1,   39,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3083, 1403,   81,    1,    9, 2172, 2791,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1246,  334,  321,  458,   98,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   95, 2032,  565,  415, 1167,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3326, 2761, 1764,   37,    1, 3265, 1857,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  102,  245,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 2562,  915,  916,   37, 2199, 3107, 3366,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  163,    1,   12,    1,    1,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 1082,    1,  220,  104,   98,  651,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3349, 2785, 2162, 1950,  431,    1,  972,   37,   71,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1573,  220,  844,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  384, 2925,   91,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2547,  336,    1,  191,    1,   69,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  161,    1, 1108,  775,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103, 3228,  729,  288,    9, 1517,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1013,    1, 1273,  616,  764,  116,  700, 2075,   81, 1379,   12,\n",
      "          112,  499,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2551,  665,  460, 1159,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  700,    1, 3358,   66,   37,    1,  247,  706,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3089,    1,    1,   32, 3201,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2318,    1, 1987,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1000,  579, 1444, 1445,  603,    9,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,   12,  103,  147,    1,    1,   45, 3359,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384,    1,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  697,   37,  987,   32,   98, 2463,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727, 2055,  840,  593,  259,   37,  575,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  390,    9, 1479,    1, 1687,    1,  393,   12, 2084,   45,  810,\n",
      "         1010,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2102,    1,  210,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   32, 3181,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  959,  810, 1514,   98, 2375,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2504,  446, 2908,   37, 1833,    9, 2705,   32,  463,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  573,  639,   12,  448,  640,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  596, 1793,    1, 1665,   37,    1, 1204,   32,  166, 2822,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  437,  267,  460, 1683,  963, 3102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  315,  714,    1,  604, 1401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200,  215, 2054,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  496, 2868,    1,    1,  167,  483,   52,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  908,  365, 1056,  356,  132,  220, 3209,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1668,    1, 3259,   32, 2731,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  457, 1446,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1109,    1, 1916,    1, 1085,  220,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  313,   37, 1539, 2978, 2335,   74,    1,   32, 1314,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2733, 1996, 1211,  116,  279, 1484,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   66,  800,  176,   26,   69,  242,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   98, 1220,  116, 1089, 1090, 1085,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,  332, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1, 379,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 140, 220, 105,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  108,  310,    1,   45, 1718, 2039,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,  105,  326,  861,  475, 1380,  289,   98,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1114,  187,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384,  166,  736,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   30,  590,    1,    9, 3260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3375, 2572,  187, 3101, 3372,   37,  736, 3339,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1051,  256,   37,    1,    1,  220,  887,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1581,    1,  131,  693,  384, 1062,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  299, 1579, 1751,  361,    1, 2578,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2733,  794,  912, 2434, 1462,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  671,    1, 2942,  580,    1,  134,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   70,  442,  530,  548,    1,  109,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,   74, 1965, 2237,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3356,   12, 1940,  713,    9, 1140,   37,  856,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1386, 1550, 2819, 1708, 1631,  625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 1281,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  579,    1, 1514,   56,  537, 1490,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,  251, 2146,    9,    1, 2528,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  864,  697,    9, 1718, 2874,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2873,  696, 2977,    1,   98, 3015,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   32,  166,  931, 1022,    1, 2296,  140, 3235, 1684,    1, 2306,\n",
      "          220, 2614,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  329,  330,  331,  332,  333,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  879,  186,   98,  679,  509,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2807,  664,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  761, 2145,   37,  489,    1,  117,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1090,    9, 1100,  784, 1151,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1369, 1229,  603,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   29,  656,  681,  875,    1,  149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,   37,  698, 1299, 2543, 1892,   32, 1169,  361, 2371,   32,\n",
      "          572,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  561, 2833,    1, 2168,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1268, 1429,  458,    1,  852,   37,  987,   32,   98, 2213,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043, 1268,  242,   98,  417,   69,  102,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  684,  685, 1269,   98,   29,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  384,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1200,  572,  244,  600,  579, 1721,   76,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  382, 1091, 1753,   37,  222,  365,  878,    1,  804,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2420,   45,  166, 2171, 2800, 1981,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1794,  267, 2275,   12, 1108, 2577,  562,  705,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3157,  288,    9, 2507,  741,  680, 3384, 1665,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2278,  708,    1,  326, 2469,    1,    1,    9,    1, 2027,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2137, 2856,  176,  177,  176, 2835, 1606,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2202,  608, 1110,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1902, 2753, 1394,  187,  718, 1249,  166, 1367,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,    1,    1,  928,  176,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,   45, 2792, 3273,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,  590,  531,    1,    1,    1,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  896,    1, 1231,  297,    1, 1664,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2246, 3100,    1,    1,    1,    1,    1, 2365,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   31,    1,  454,   81, 1159, 1759,  309,   12,  954,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  877,    1,  698,    1,  664,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2468,   32,  885,    1, 2800, 1559,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  726,   61,  810,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 1571, 1656,   37,  877,    1,  714,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,  448,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3248,    1,  190, 1306,   56,   37, 1700, 2119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  226,  167,  764,  877,  201,  529,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1447,   66, 2587,  463, 3032, 1816,   37,    1,   46,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  633,    1,    1, 2674,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,  163,    1,   12,    1, 1583, 3400,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2079,  614,   26, 1039, 3004,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  744,  365,  569,    9, 1099,    1,  281,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1787, 1472,    1, 1149,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1572, 1414,    1,  429,   98, 2774, 1147,\n",
      "          787,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 1800,  854,    9,    1, 1401,  191,   32,   72, 1463,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  187, 3307, 1348,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938, 2032, 2422,  598,   37, 1343,  691,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1700,  671,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  929,  460,   12,  199,  166,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   98,  593, 1267,    1,  590,  786,    1,    1,   37, 3303,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  228, 1210,   37,  168,   39,  220,  671, 3126,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  108,   45, 2786,    1,   32,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707, 1563,   98,    1, 2200,  736,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2597, 2328, 1260, 2414, 1056,  163,    1,   12,    1, 2548,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 1407, 1190, 2151,    1,   32, 1785, 2044,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1017, 2899, 2790,  200,  111, 1107, 1017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1260,   98, 3361,   30,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  989,  267,    1,   46,  193,   32,  624,   12, 1509,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1597, 1633,  953,   32, 2142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3167,    1,    1, 2295, 3117,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,  291,  494,    1,    1,    1, 1539,   26, 1039,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 1867, 2086,   33, 1017,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  382, 2514, 1345, 2623,    1, 1558,   28,    9,  166, 1948,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453,   12,  721,    1,   98,  231,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808, 1627,  111, 1107,  112,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1611,   32, 1169,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,    1, 2921,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1723,    1, 1178,   45, 2772,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,  449,    1,   26,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1128,    1, 1870,  875, 1159,  166, 2301, 2012,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  297,  191,    1, 1594,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2107, 2886, 2572,   32,  298,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1, 2945, 1478,  224,   32,  147,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3276, 1463, 1515,    1,  444,  368,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  795,  359,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3216,  542,    1,   28,   32,  730, 2614,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   47,   79,    1, 1393, 2166,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  159,  245, 1270,  105, 1524,  187,    1,    1, 1141,   37,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2924,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2800, 1218, 1292, 1281,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  614, 1092,   37,    1,  453, 1299,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  428, 1094,    1, 1634,   37,  678,  166,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2548, 1919,   32,  463,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  498,   98,  149,  297,    1,    1,  361, 2074,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   51,  606, 1846,  166,  915, 1684,    1,  202,  460, 1924,\n",
      "            1,  166, 1509,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  906,    1, 1352, 1194,  446,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  476, 2168,   37, 1027,  756,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  845,  275,  455,  313,   37, 2446,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1802, 2746, 1220,    1,  863,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69, 1337,  832,   98, 1147,  965, 1450,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  879,  801,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3253,  801,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1716, 1718,  218,  190,    1,  131,  191,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  275, 1110, 1539, 1273,  861,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  994,    1,  150,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   91,  159,    1,   27,  356, 1653,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2567,   98,  365, 1417,  551, 1417,  730, 2393, 1090,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2286,    1,  223,  408,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460, 1924, 1977,   37, 2460,  600,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   69,  297,   98,  889,  509,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  614, 1183,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3359,   12,  469,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3013,  891,  750,   45,    1, 1684,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  437,    1, 1411, 2273,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2708,    1,    1, 2909,    1,    1,   32, 1585,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103,  951,    1, 1497, 2027,  191, 2027,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3190,  113,   79,    1,    1, 1036,   37, 2748,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  297,    5,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   45,  455,  140, 2161,   12, 2472,  671,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1072, 1235, 3338,  191, 3344, 1940,   32, 3339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  602,   12,  365, 2276,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1221,    1,  590,  439,   37, 1545,   12, 1356,   45,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3192,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  972,    1,  202, 1120,   12,   37, 2958,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  915,    1,  105,  829, 1013, 2549,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,   12, 2155, 3175, 3214,  729,  686, 2017,  384,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,  879,  693,    9,  647, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  176,    1, 2577,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1, 3205,    1,    1, 2857,   32,    1, 2457,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2425, 1419,    1, 2549,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  117,    1, 1718, 1215,  388,    1,  763, 1778,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,  297,  187,  163,    1,   12,    1,   25, 1155,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3095,  319, 3339,  548, 1887,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,    1,  112, 1258,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1300,  736,  891,   32, 2016,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  103, 2132, 3190, 1249,    1,   37,    1,  914,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1035,  545,  952,    1,  331,   32,  822, 1469,  384,    1,  700,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3152, 2000,  605,  810, 1292, 2967,   37, 2290, 3259,    9,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  916,   66,   37,    1, 2024,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  346,  347,   98,  429, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1,  744,   28, 2018, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 3385, 1822,  690,  864,   12,  917,   37,    1, 3107,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  709, 1682,  875,  422,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1065, 1190,  939,    1, 1378,    1,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  676,    1,   79, 1401,   37, 2095, 3109,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2476, 2075,   81,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  902, 2712, 3322,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3230, 2034, 3329,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2630,   45,  166,   74, 2161,   12,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1591, 1908,  105, 2242,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 2023,  521,    1,  721,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  794,  365,  535,  656,  327,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3309,  162,  786,  427, 1281,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  741,   32,  581,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,   12, 1861, 1827,  220, 2179,    1,  548,    7, 1190,  939,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  565, 3049, 2440,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,   61, 1658, 1872,    1,    1, 1370,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2620, 2070, 1193,   32, 1037,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1049,  162,  535,  656, 2367,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  149,  444, 2902,   61, 1139,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190,  460,   52,    1,  357,    1,    1,    1, 1544,   98,  166,\n",
      "         1285,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1013,    1, 1835,  466,    1,    9,  777,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  753, 3238,  833,  612,  606,   37, 1330, 1114,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98, 1821, 2190, 1464,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1433, 2768, 2288,    1,  606, 1183,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1802,    1,    1, 2578,   37,   26,   32,  385,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1221,   12,  590, 2148,  547,   45,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   34, 1463,  916,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  874,  779,  453,  613,    1, 1605, 3004,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,  335, 1909,  913,   32, 1674, 2701,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1827,    1,  388,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   12,  551,  552,  338,  548,    1,    1,   12,  156, 2290,  308,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  632, 1202,  298,    1, 1389,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1027, 1713, 2627, 1218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  245,   98,  861,    1,  156,  509,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1132,  221,  284,  977,   37,   91,    1, 1033,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1472, 2518,    1,   26,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  548,  713,    1,  224,  288,    9,  218,  714,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 3007, 2933, 2683,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  195,  595,  802,  842,  241, 1641,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1668,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2096, 1478,  176, 1818,  147,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169, 1388,  125, 1139,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1350,  695,    1, 2928,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1,    1,  829, 2035,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147,  379,    1,    1,  808,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,  116,    1, 1744, 2730, 1506,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  231,    1, 1230, 2053,  810,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1708,   37, 1551,   32,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3264,   12, 2792,  627,   32,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,    1,  639, 1419, 1211, 1718,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  854, 1287,  187,  691,    1,    1, 2471,  119,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  561,  335,   98,    1,    1,   32, 2650,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  228, 1439,   32, 1405,  776,   32, 2110,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  743,   12, 1958,    1,    1,   32, 2486,    1,  440,  616,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094, 2414, 2708, 3006,   32,  717,    1,  458, 2625,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1214,  458,  213,  220,  561,   98, 1064,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1147, 1009, 1458,  740,    1,  890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3029, 2981,    1,  220, 2875,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1557,    1,   28,    9,  365,  863, 1523,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967,  166,  915,    1,  548, 2472,  713,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3324, 1287,   37,  688, 2578,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,  889, 2731,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,    1, 1607, 1167,  733,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2730,  302,  928,   32,  233,  187, 1130, 1758,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 2505,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066,   37, 1195, 1125, 2172, 1371,    1,  774,  311,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,  571,   37, 1428,   37, 1079,    9,  764,   32,  531,  187,\n",
      "            1,  488,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,    1, 1602, 2539,    1,  162,   75,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3096,    1, 1921,   32, 2028,    9,  195,  351,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1771, 1022,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  638,  913,   37,  698,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1622, 2548,  582,   37, 3369,   12, 2245, 3118, 2517,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   42,  220, 2163,    1,  190,    1,  195,  506,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3226, 1421,    1,   37,  881,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403,  464, 1461, 1463, 2385,  612, 1954,    1,  455, 1190,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  183,  357,  803, 2977, 1821, 1135,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275,    1,  297,  223, 2135,  315,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1645, 2548, 1388,  220, 3352,   32,  557,  540,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967,    1,  600,    1,  647,  142,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2162, 1950,  384,  395, 2201, 2003, 1585,  418,   37,  600,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232,    1, 3231, 1296, 2258,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  986,    1,   32, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    5,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,  578,    1,   98,  395, 2108, 1281,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,  716,  995,  242,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1033,   37,  529,   22, 1697,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1,   37,  712,   28, 1234,   12,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  691,  123,   37, 1918,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3326,    1,   39,    9,    1,   45,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2108,    1,  267, 3342, 2556,   37,  151, 1056,  622,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3256, 1676,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1691,    1,   61,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  104,  267,  517,   37, 2000,    1,    1,  220,  395,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2823, 1708,    1,  128,   32, 2069,    1,   37, 1169,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2173, 1542,   37, 2962,   28,    1,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,  488,  365, 1934,  909,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2042, 1231,  220,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  156,   28,  118,   32,  572,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  763,  415,  105, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3092,    1, 3213,  220,  119,    1,  599,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  221,  744,    1,    9,  786,    1, 1131, 1246,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  645, 3005, 1260, 2134, 1140,    9,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1041,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1, 2611, 1983,  109,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1559, 2897,  187,  103, 3359, 2431,  267, 1221,  190,   52,  590,\n",
      "         2708,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  758,    1, 2577,  593,   12, 1509,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 1557,  650,  820,  384, 2611,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  433, 2104,  908, 2730,    1, 2650, 1879,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  291,    1,    1,  220,  645,    1, 1907,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2, 666,   1, 390,  37,  27,   1, 372,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 882, 623, 884, 152,  44,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  487,  597, 3127,    1, 1753, 3128,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   81,   37,  236,    1, 1110,  750,   96,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  159,   71,   98,  420,    1,   51,  142,  388,  763,  131,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885,  140, 2941,   37, 2833,   72, 1479, 1684,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051,    1, 1039, 2690, 2827,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162, 2429,   23, 1689,  492, 1234,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  410,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1221,   12,  105,    1,   32, 2310,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,  342, 2104,   37,  506,  230,   45,    1,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 1303,   37,  693, 1285, 1766, 1767,    1,  327,  841,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 1774,   39,    1,    1, 1310, 1114,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  585,    1,    1,   37, 1251,  286,  293,   28,   37,  104,  182,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 1447, 2369,  861,  548, 1610, 2764, 2765, 1665,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  291,   12,    1,  696,   37,    1,  777, 1085,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3282, 2468,    1,  104, 1159,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  320,  224,   61,  959, 1300,    1,  920, 1494,  166, 2177, 1370,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3256, 2379,    1,  140, 2507, 1427,  297,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   32,  636,  714,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  262,  263,  353,  354,    1,    1,   15,  570,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  691,  676,  389,  378,    1,   32, 1893,  951,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,    1,  242,    1,    1,   25,    1,  107,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808, 1627, 1412, 1107,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2004, 2922, 2616, 1564,    1,  436, 2051,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  703,  837,    9,    5,  865,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,  140,    1,  361, 2513,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  954,    1,  658,  763,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  894,   52, 2889,   32, 1975, 1167,    1, 1763, 1983,  437,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2292, 2897, 1969, 1853, 1260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  656,    1,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962,  686,    1, 1401, 3231,   37,  726,  297, 2685,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  191, 3110,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3075,    1,    9, 3070,   36, 1530,  176, 1327,  350,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   61,  500,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  967,  198,  449,   74,   45, 1300,  605,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2868,  267,    1,   32,  531, 1284,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3255, 2087,    1,  187,  463, 2170, 1174,  220,    1,  726,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,  484,  167,   18,  892,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3228,  665,    1,    1,    1,   98, 1987, 1638,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962, 1245, 1334, 3158,  220,  726,  297, 3206,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2076,  572, 2232, 1828,   28,   98, 1361,    1, 1128, 1565,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,  566, 2992,  613,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  665,   98,  567,  304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2183,  433,    1,   32, 1445,  863,  443,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3171, 1586, 2615,    1,   98,    1,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2254,    1, 1361,  875,  297,    1,   32, 2255, 2096,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962, 1123, 3117, 1285, 3251,   37,    1, 1264,  841, 1224,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  949, 1603, 2088, 1616,  636,    1,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  446, 2559,  403,  404, 2751,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  398,  488,   37,    1, 1369,  297, 1469,  460,  967, 1467,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340,    9,  202,  590, 2907,    1, 2126,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1829, 1966,   12,    1,  573, 1294,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  915,    1,    1,    9, 1204, 2319, 1089, 2294,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  667,  669,   37,  949, 2103,  617,  260,    9, 1211,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393, 1243,  389,    6,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2161,  335,  105, 2230,   37, 1089, 1675,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1763,   12,    1, 1822,  606,  304,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1434,   98,    1, 2041,    1,  162,  356,  881,  384,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2651,  602,   32,  593, 1990,   45, 2701,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3013, 1858,  288,    9,  105,  365,    1,    1,  105,    1,   45,\n",
      "          166, 1361,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1596,  894,   52,  590, 2050,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1022,    1, 2296, 3247,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2537,  220,  331,    1, 2539,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  469, 2030,   37,  470,  531,  734,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1,  469,  313,   37, 1289, 2604,  626,   37, 1219,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,    1,  706,    1,    1,   12, 1691,    1,  714,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 2789,  475,  261,   39, 2381, 2789, 3093,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3144, 1443,  142,   37,  439, 1512,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2075,   81,   37, 1285, 2719,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2974, 2640, 2331,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647, 2120,   82, 1492,    1,  148,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,   25,  242,    1,  277,  191,  479,  157,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1449,    1,   37,  138,    1,  182,    9,  176,  551,  612,   48,\n",
      "           32, 1449,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1579,    1, 1437,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,    1, 1606,  524,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 1902,  900,    1,   37,  764,  797,  574,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1412, 2521,    1,  861,  105,  596, 1995,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2401,    1,   45, 2227,  166, 1963, 2641, 2722, 3074, 1215,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1527, 2664, 3338,   32,  531,  513,    9,  949,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   32, 1820,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1518,    1,  116,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1230,    1, 2370,  166, 1245,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2786, 3028, 2762, 1976,  327,  593,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  580,    1,   44,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  931,  565,    1,   12, 1763,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,    1,  163,  552, 1766, 1767, 1362,  327,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974,  140,  166, 2695, 2223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,  267,    1,  770,   61, 1167,   45, 3340,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 2909, 2856,   32, 2597,   12,  501, 2060,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  684,  734,  102,  335,  105,  686,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1380,  112,   63, 1020,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  200,    1, 1416, 2549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1, 3021,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1537,  954, 2590, 2007,   37, 1538,  477,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  610,    9,  808,   32, 1147, 1038,  287,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2565,  298, 2986,    1,   37, 1633, 2611,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  786, 1680, 3304,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,   46,  220, 1789,  548, 2868, 1140,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,    1,  548,   46,  220,    1, 1306,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1166,  705,  166, 2113,  978, 1151,   18,  384,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1269,  187,    1, 2136,  307,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2227,  725,   37,    1, 1411,    1, 1225,  512,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1, 2097, 1789,    1, 2405, 1159,  395,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,   37, 2000, 2836,   45, 3107, 3366,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593, 2050, 2309,    1, 2493,  247, 1960,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2993,    1,  581,  100,  220, 1117, 1525,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3098,   74,    9,    1,  361,  386,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051, 1605,  280,  837,  803,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  245,  914,  852, 1735,    9,  773,    1,  202, 2063,  167,   52,\n",
      "          885,  724,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  623,    1, 1967,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1407,    1,    1, 2521,    9,    1, 1953,  892,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1676,    1, 2572,   32,    1,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  365,  957,  162, 2571,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2056, 2822,    1,  488,  249,    1,    1, 2321,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  885, 2454,  220,    1,  372,  354,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1870, 1774,   39,  838,  202, 2204, 2355,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2834, 2797,    9,  786,  632,  851,  298,    1, 2710,  437,  396,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3211, 3159, 1853,   37, 2962,   28, 2522,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1, 1178,    9, 1887,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3303,  765,   37,  166,  103,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2701, 2954,  588, 1407,    1,   45,  270,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1821, 2190, 2640, 1373,   37,  125,   81,   98, 1011,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129,    1,   32,    1,   32, 2315, 2957,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3257,  338,   37,    1,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  302, 1712,   61,  917,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  647,    1,   37,  688,  689,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   26, 2779, 1287, 3230, 1957,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  957,  546, 1149,  297,  777, 2931,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  657,  155, 1194,  401,   15,  570,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1266,  721, 2120,  475, 1213, 1432,    1,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1,   37,    1,  529,   25,   37,  245,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  455, 2308,   37,  168,   98,  449, 2085,  477,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  156, 1192,  176,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2590,    1, 2890, 2022,   32, 3096,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  954, 1625, 1198,  219,   25,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3147, 1648,   37,   16,    1,   32, 3114,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   21,    1,   37,  698,  951,    1, 3110,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1013, 1522,  256,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,    1,  872,   98,    1,  280,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,   69,  669, 1236,   49,  297,  595,   37, 1195, 1828,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2578, 1258,   37,  631,  176, 1181,  593, 3154,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1924,    1, 1018,    1, 1881,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497,    1, 3103,    1,   98,    1, 1602, 2539, 1953,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1013,  891,    9,  455, 3121, 2372,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,    1,  638,  786,    1,   32, 1014,  600,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1785, 1877,   37,    1,   69, 1588,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3245,   37, 1306,  581,   73, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,   32,    9, 1764, 1990, 2856,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1773,   38, 2827, 1090, 1671,   37,  714,   32,  104,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  917, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107, 1288,   37, 1289,  568,   37,   62,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  746,    1,  829,  872,   28,   98,  844,  297,  858, 3000,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  382, 1311,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158,    1,    1,  228,   39,   45,  228,  191,    1,    1,    1,\n",
      "            1,    1,    1,    1, 1158,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790, 1579,    1,    1,   37,    1, 1881,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1349,  751,  110,  384, 1349,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2902, 2287,   28,    9,   80,  297, 1766, 1767,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  845,  147,   37, 1709, 1842,  116,  400,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2315,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  952,    1,  220,  234, 3041,  235,    1,  234, 3041,\n",
      "          235,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3167,  936,  356,  132,  220, 1122,  853,  538,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  121,  794, 3029,    1, 2328,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  238,  361,    1, 1000, 1394,   37, 1204,   98, 1965,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1096, 1090,  891,  297,  183, 1272,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2179,  378,    1,   37,  258,    8,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 1034,  115,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1304,   37,  875,  220,  422,    9,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2822, 1793,  488,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282, 1938, 2809, 1798,  288,  187, 2779,  580, 3174,   32,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,   32,  501,  827,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  375, 1924,  195,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1787,  136,  624,    1,   32,  147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   12, 1126,  636,  288,  176,   63,  714,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  295, 1373,   37,    1,   28,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  251,   37,  151,  989,    1,    9,    1,  372,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 1937,    1, 1709,  361,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,    1,  517, 1871,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1303, 1478,  331,   24,  384,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 3255, 2335, 2286,  365, 2036, 3055,  608, 1327,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  256,    1, 2943, 1499,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3108,  186,   37,  688, 2838,   32, 2799,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2931,  625,    1,   85,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 1450, 2086,  220, 1211, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3302,  936,  593, 1863,   45,  166,  356,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  800, 2379,    1,   66,    1,  163,    1,   12,    1,  424,  245,\n",
      "            1,  889,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1673,    1,    1, 1592,  774,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,  818,   15,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2343,  379,   37,   52,  665,   98,  776, 1411, 1034,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  947,    1,  320, 1744, 1878,  487,    1,  298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  177, 2572,   32, 3389,   32, 2597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  632, 2003, 1585, 2414,    1, 2803,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340, 2297, 3235, 3212,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307, 1500,  157, 2007,   37, 1732, 1220,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1687, 1022,    1, 3008,    1, 1954,    1, 1592,  774,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3363,   96,   37,  443,   98,  229,  361, 3045,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  773,    1,  297, 1893,    1,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1,  596,    1,   45, 2359, 1021,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  434,  105, 1488, 1693,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1176,  845,    9,  105,    1, 2810,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,   71,    1,  845,  275,  111,    1,  674,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,   91,  498,   98,  864, 3146,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,   27,  339,  340,  951, 1547,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3213, 1444,  565,   39,   37,  619,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,  167, 1752,  105,  183,   23,   32,  166,  341,    1, 2498,\n",
      "         1379,   12,  112,  499,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,   12, 1733, 1484, 3093,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783,   21,   37,  125,   28,   37,    1,    4,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1079, 3063, 2384, 1724,  885, 2355, 1013, 2549,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  375,    1,    1,    1,  105, 2671, 1167,  199, 2632,   28,\n",
      "          220,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 1178, 1492, 2572,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978,    1, 1445,  459,  517,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2, 104, 358,   1, 453,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 224,  98,   1, 495,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  923,    1, 2215,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1177, 1634,   37, 1793,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  614, 2071, 2880,   98, 1766, 1767,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2533, 1862,  528, 2674, 1569,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1236,  923,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1523,  297,  365, 1935, 2294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2279,   51,  686, 2174, 2444,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3317,  476,  542,   37, 1343, 1515, 1370,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2308, 1188,  193,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1192,  105,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2883,    1,    1,    9, 2774, 1527,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,   45,    1,   32,  166,   94, 2060,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1940,    1,  631,    1,  202,  429,   79,    1,   37,  726,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2673, 2728,    1,   32, 1645,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  148,   51,  720,  142, 1232,  647,  615,    1, 1509,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1530,    1, 2728,    1, 2189,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1178,   37, 1046,  776,   32,    1,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1242, 2748,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1, 1287,  608,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190, 1540,  187,  929,   45, 1570,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3101, 2224,   37, 2303,   98, 3359,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  491,  641, 1278,   32,   91,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  311,  593, 1821,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   17,  838,   98,    1, 1228,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    5, 2118,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,  551,  105,  166,  938, 1075,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,    1,    1,   37, 1334,   98,  469,   37,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2540, 1739,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  220,  749, 2626,    1,  920,  579,  544, 2226,  544,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,  193,    1,   37, 1343, 2410, 1090,   45, 3179,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  961,  398,  991,  148,   12,  142,    9,  413,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,    1, 2287,   28,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 3364,  580,    1,    1, 3374, 1355,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1056,  440, 1971,    1, 1857,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  952, 1031,   63,  158,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 2378, 2736,   61,  583,   32,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  622,  190, 1314, 1030,  361,  656,  176,    1,    1, 2722, 3074,\n",
      "         1215,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2154,  104,  442,  910,    1,   65, 2104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1715,  170,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    4,   37,  168,  220,    1,   45,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   79,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  523,  580,  365, 1938, 1723,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  547,    1, 2258, 1658,    1,  321,  612,  544,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1,   32, 3273,    9,  449, 1056, 1867,  631,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  487, 2700,  469, 2699,   37, 1965,    1, 1114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  242, 1893,    1,   15,    1,    1, 1527,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2002,  695, 2789, 1564,  682,   32,  258,  890,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968,  140,    1,   98,  442,    8,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  107,  213,   37,    1,   39,    1,  109,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3269,  187, 3132, 2365,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,   82,  669,    1,  384, 1607,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,   26,   98,    1,   32, 2163,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 2334, 2545,    9,  104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  200,  365,    1,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,    1,    9,  395, 1597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,  407,   81, 1159, 3044, 2232,  218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,   82,  267,   10,    1, 2275,    1,    1,  275, 1285,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2442, 2911,   81, 2103,  617, 1116,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,  879,  647,  693,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3403, 1396, 2597,  947,    1, 2924, 2625, 3392,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,    1, 1500,    1,  570,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492,    1,  580, 3148,  134,    9,  840,    1,   37,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3186,    1, 3256,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1, 1454,  112,  119,    1,    1,   37,   52,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  388,  861,    1,    9, 2997,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1,    1,  242,    1,    1,   25,    1,  107,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  970,  156,  817,   98, 1043,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,    1,   32, 1029,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,    1,  176, 2933,   16,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  670,  187,  109, 2429,  470,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  709,  702,  494, 1231,  220,  133,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,    1,  657,    1,  220,  846,    9, 2691,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2796,   38, 2614,  581,   73,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,   45,    1, 2261,    1,  499,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2735,  947, 2572,   32,    1, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  157,    1, 1259,   12,  439,   51, 1719,  395,  104,  442,  443,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3177,  719,   37,  877,   28, 1737,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  312, 1995,    1,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2002,  947, 2625,    1,    1,  877, 3109,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1249,  572,  739,  220,    1, 1124,   32, 1230,   15,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  712,  105, 2101,    1,  460,   12,    1,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    1,  405,    1,  565,  103,  316,\n",
      "         2855,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3216,    1,  903,    1,  904,    1,    1, 1496, 2764,  404,  753,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700, 2572,    1,    1,  583,   32, 2702,    1,   32, 2741,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 1583, 3400,    1, 1841, 2684,   32, 1404,   12, 1796,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1089, 1090,    1,  921,    1,   59,  449, 1034,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1390,    4,   51,   52,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  316,  692,   37, 1291,    1, 1251,  176,   59,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1536,  885,  768,  149,  444,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  827,  726, 3252,   45,  166,  356, 2577,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1821, 1697,    9,  166,  252,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1528,  317,  198,  932,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   32, 1869,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3064,    1,    1,  439,  914,  220, 2540,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3252, 2590, 2961, 3131,   32,  714,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1841,   12,    1,   37,    1, 1178,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158,  845,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3164,    1, 1827,   39,   45,  593, 1990, 3273,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1,    1,   12, 2509,  176,  166, 1169, 1194, 1771,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1082,    1, 1891,  652,  384, 1387,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2178, 2500,  663, 2042, 1492,    1,   98,   95, 1924,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1360,  612,   52, 2175,   81,   37, 3296,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  221, 1159, 1832,    9, 3141,   12, 1509,  119,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3173,    1, 3174,  759,    1, 2592, 2069,    1,    1,    1,   39,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  596,  954,  288,    9, 1509,   93,   32,  537,  592,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  258,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  755,    1,    1, 1013, 1522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564, 2171,  388,    1,  166, 1868, 1172,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  531, 1408,  463,   69,  965, 1073,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  662,  220,  141,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3053, 2477,  944,  928,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  205,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1425, 1783, 1794,   24,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2780,   51,   52,  227,    9,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  306,  353,  197,    1,  157,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2744,  726,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1,    1,    1,   37,  726,  112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,  407,   37,  119,   98, 1057,  297,  340,  104, 1588,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1240,  193,    1,  362,  384,  349,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2737, 1013,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  356,  684, 1318,    1,   51,  429,   27,    1,  496,   30,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3072,    1,   37,  119,  166,  792, 3081,    1,  792,   45,  938,\n",
      "         2538,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 1268, 2436,   37,  453, 3044, 2168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,    1,  927,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3021,  598,   37,   77, 1674,  671, 3261,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  177, 2572,   32,   12,    1, 2490, 1602,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  794,  241, 1995,   98, 3356, 1414,   32,\n",
      "         2646,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3242, 1366,    1,  384, 2958,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1571,  720,  105, 1551, 1437,  315,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2217,   12, 1277,   37,   84,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  537,  548,  166,  245,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1725,    1,  221,   37,    1, 1934,  297, 2500,  663,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  707,   79,   98,  166, 1514, 2380,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3204,  967,   37, 1604,    9,  581,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,   12,  938, 1075,   50,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  674,    1, 2320,  775,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  729,  476,  644,  132,  220,  342,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   52,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2292, 2897,   32, 2755, 2490,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3239, 2286,   37,  271, 3106,  176,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  636, 1042, 1270,  104,  105,  106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  391,  371,   91,   37,    1,    1,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1005,    1,  920,   32, 1300,    1,    1,  967,    1,    1,   32,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  414,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,    1,    9,    1,    1, 2148,    1,    1,    1,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  409,    1,  580,  411,  701,   63,    1,  220,  954,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  207, 2323, 2952,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  619, 1542,    9,    1, 2819,  297,  116,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1627,    1, 1101, 1102,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,   17,   18,   19,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2236, 1112,  204,  476,   37, 1343,  885,  356,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1800, 1484,    9,  365, 3343,  741,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1800,  403, 1447,   12,  466, 1450,   98,   10,  187,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  288,   37,  168,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,    1, 2876, 1754,   37, 1021,  282,  517,  260,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  806, 1398,  612, 2116,    9,  445,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   32,  142,   37,    1,    1,   46, 1010, 2673, 2596,  304,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  288,   37,  504,    1, 1311,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,  104, 1992,   37,  651, 1031,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810, 1778, 1117, 1525,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  968,  734,  731,  969,  191,    1,   12,   98,  970,   93,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1354,   22,    1,  193,    1,    9, 2909,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1008, 1312,   37, 2158,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,  361,  602,  619,  448,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1979,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  877, 2362, 1167,    1,  391, 2115, 2143,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1838,  260,    1, 1169,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715,  883,   57,   71,   32, 1352,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  931, 2761, 2236, 1554, 1090,  220,    1, 1987,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1046,   45, 2662,   12,    1, 2918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 2022, 1002,  515, 3363, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187,    1, 1306, 2565,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1577, 2954,  220,  612,  675,   37, 1468, 1872,   32,   91,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2924,  973, 1415,   37, 3346,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1110, 1508,    1,   37,  547,  356,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  322,   79, 1147,  734,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,    1,    1,   32,  296,   20,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1268,  342, 2102, 1107,  525,    1,  942,   32, 1332,    1,\n",
      "         3011,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1138,  315,   37,  125, 1604,   23,  191,    1,  361,  123, 2152,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2692,  640,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1861,    1,  811, 2286,   37,  665,  531,  443, 2072, 2588,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340, 1354,    1,   98,  166, 2498,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  971,   37,  508,   79,   32,  365,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,  113,  297, 3006,  548, 3389,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,  103,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   64, 2414,  176,  177,   32, 3349,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  590, 1031,   76,   98,    1,    1, 1323,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2026,   98,  166,   71,    1,  202, 1398,  612,  335,  166,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1382,    9, 3230,  548,   26,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12, 2840,   37,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  786,   45,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1414,   98, 2731,   32,  531, 2774,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  810,  943,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1185, 2889,    9, 1204,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  755, 1772,    1,    9, 1569,   32,  111, 1697,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425, 1419,   29,  471, 2043,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1,    1,    1,    1,    1,    1,   98,    1,    9,\n",
      "          629,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3130,    1,  166, 2539,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  395, 1500, 1184,  347,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1268,  443,    9,  116,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3108,    1, 3186,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,    1,    1,  328,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  460, 2718,  949,    1, 1211, 1228,    9, 2665,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  197,    1,  983,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1891, 2153,    1,  297, 3140,    1, 1430,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2500,  663, 2849,  297, 2592, 1675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,  315, 2355, 1013, 2549,    9, 1158, 2261,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,    1,  261,    9,  858,  297, 1021,  847,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1151,   25,   28,   98,  657,    1, 1064,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1479,    1,  776,  891,   32,    1,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  612,    1,  405,    1, 1601,  515,   92,   37, 3115, 3130,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043,  640,    1,  181,  340,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  474,    1,    4,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2193, 3093,  437, 2357,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2263,  356, 1691,   98,  134,   45, 1809,  116,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3214,   46,  600,  247,    1, 2814,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1176,  227,   37,   52, 2848,    1,  730, 2614,    1,  754,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,    1,  829, 2880, 2444,   98, 1074,  861,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3151, 1756,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2942,  140,  601,  671,  176, 2890, 2826,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  346,   29,   37,   16,   93,  279,   98,  532,    1,    1,  800,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967, 2563,  603,   81,   37,  166,  627,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2592,   37,    1,  384,    1,  384, 1674, 1468, 2458,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2924, 1523,   37,  674,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  818, 1278,   76,   37,   71,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  159,   16,  590,  459,   45,  383,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    9,  333,  459,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   76, 1133,    1,   37,  270,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1004,    1, 3114, 1002,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1260,   98, 3343, 1513,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3084,   12,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  444, 1737,  332,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  830, 1932,  967,  103,  142,    9, 1933,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  776, 1961,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2899, 2790, 2593,  454,   37,  138,    9,    1, 1536,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,    9,  166,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1926, 1927, 1562, 1009,   10,   32,  365, 1089,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1940,  361, 2161,  388, 2267,  763, 2112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1797,  186,    9,  264,  863,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  103, 2030,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  749,  533,  665,  790,  226,  680,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   98, 1662,    1,    1,  387,  388,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200,  365, 1168,    1,  210,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  187, 1178,   37,    1,  175, 2444,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 1409, 1492,    1,  808,   32, 2971,    1,  928,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2321, 2709,   98, 3284,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,    1,  365, 3388, 3397,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,  952,   37,   92, 1228, 1069,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  105, 2993,    1,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  381, 1310,   37,    1,  453, 1521,   32,  455,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  301,    5,  302,  580, 1557,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 1087,    1,  220,  932,   45,    1,  207,  956,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  857, 1880, 1249, 2807,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3142,  753,    1, 2094, 1513,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,  498,   37,  356,  132,  220,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1133, 2041,  115,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 2744, 1460, 2789, 1819,  680,  531, 1324,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 3065,   12,    1,  193,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299, 1380,    1,   32, 2650,    1, 2730,    1, 2928,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2149,    1,   98, 1658,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12, 2692, 1089, 1090,    1,   98,  116,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,   69,  831,   98,  109,  533,    1,  863,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2800, 1218, 1292, 2845, 1281,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2954,  220,  625,    1,   37,  815,  192,   37, 2199,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,  313,    9,    1, 2242,  220, 2510,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3230,    1,    9, 3329, 1990,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  799,    6, 3038, 1438,   32,    1,    1, 2405,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3330,   32, 1090, 1762,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  884, 1950,   98, 1759,  309, 2746,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  971,  251,    1,  347,   98, 1411, 1056, 1975,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1009,  267, 1349,   37,    1,   24,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  296,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  741,   98,    1, 2829,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2975, 2612,   98, 2692, 1601,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,  474,  458,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  379,  570,  753,    9, 2372,   45,  567,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2637,  315,   37,  151,    1,    9,    1,  372,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2947, 1675,  439,   98,    1, 1318,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2652,    1,  887,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018, 3371, 2237,    1, 2018,    1,  193,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   25,  115,  187,  156,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  854, 2329,  166,  730, 2203,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1198, 3117,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  388, 2558,  220,  829,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2520,  467,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,  753,    1, 1497, 3113,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2514,    1,    9, 1571,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3257,  338,   37,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2475,    1, 2565,    1, 1530,  176,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  832,  548,    1,  365,  845,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260, 2709, 3117,   32, 1264,  841, 2107,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3006,    1,    1, 3365,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1334,   98,  187, 3260,  512,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  548,    1,   98, 1844,    1, 1537,    1, 2572,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,    1,   85,   98,  460,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  168,  105, 1183,  454,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344,  191,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3343, 3006,   51,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3289,    1,  782,   61,  193, 1950, 1211,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2102,  640,   59, 2610,  813,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  323,    1,    1, 2100, 2206, 2989,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1409,    1,    1,   37,    1,    1,  250,   12,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118, 2751,  774, 2024,  449,    1,    1,  548,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  590, 1101,   32,  166,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,    9, 1517, 1798,  220, 1497,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 2329, 2086,  220, 1211, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  818,    1,    9, 2880, 1527,  361, 2102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  196,   37,  815,  176,  551,  612, 1589, 1700,  257,  548,  170,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1183, 2626,    1,  202, 2971, 1564,  284,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  531, 1140,    9,  211,   37,  890,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  238, 1308,    1,   12, 2467,   45,   26, 1684,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1326, 1619, 1835,    1,  845,    1, 2670,    1, 2210,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3125,  949, 3365,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3184, 1952,   31, 1042,   37,  118,  420,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3186, 1421,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  196,  613,  315,   37,   47,    1,   50,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3010,  833,  612, 1844,  460,   28,  361,   61, 1844,   39,   45,\n",
      "         3278,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,    1, 1566,  104,  331,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  442,  910,    1,  187,  215,  532,  120,  115,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  269, 1337,    1,  605,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1, 2889,    9,    1,  220,   38,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2461, 1523,  167,    1, 2487, 2621,   32, 2380,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777, 1450,   28,  191,  105,   72,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  987,  997, 1406,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390, 1118,    7,  741,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  864, 2167,  903,  132,  729,   98,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   37, 1075, 1970,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3118,    1,   37,  619,  331,  384,  342,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 3096,  914,    1,  191, 3265, 1987,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1016,  140, 1385,  786,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2352,    1,   37, 2110, 2771,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  794,  111, 1107,  525,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    4,  157,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  596,  616,  510,  850,   69,  242,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3255, 2080,    1,    1,  497,   37,   52,    1,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2700,    1, 2983,   32,  255,    1,   81,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785, 2044,    1, 1549,   78,  469,   37,   92,   69, 1208,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1559, 1965, 2707,   12, 1022,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1539, 2306,  288,    9,    1,    1,  166,  593,   12,  449, 2604,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  709, 2431,    1,    1,   32,  373,    1,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,  105, 1370, 1051,   12,  678,    1,   98,  166,    1,    1,\n",
      "          471,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  649,    1, 1537, 2924,  429,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2221,  267,    1,  894, 1847, 1461, 1462,\n",
      "         1360,  612, 1604,  963, 2122,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  894,  334, 1272,  424, 1973,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1333, 1530,   32, 1785, 2044,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3188,  361, 1902,  631, 3244,   37,  885, 2651,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 2414, 3111,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1118,  164,  165, 1828,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2960, 2414,  176,  104,  700,   32, 3376,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  380,    1, 1568,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  105,  442, 1167,  272,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1090,  937,  894,   52,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2171,    1,    9,  116, 1090,  293,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1763, 1810, 2572,   32, 2597, 2950,  365, 3365,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2656, 2266, 2874,   45,  531,   61,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2048,   45, 1128, 1021, 1129,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1585,   32, 1815, 2766, 1700,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  980, 3369,  909, 1665,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2689, 1717,    1, 2308,  690,  439,   45, 1045,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1390,  587,  619,  138,  304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3358,   12,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1364,    1, 1794,    1,    1, 2751,    1, 2375,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3339,  469,  167,    1, 2041, 2655, 3101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   21,   37, 1306,   37, 2119,  220, 3131, 1987,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1214,  979,    1,   39,    9,  914,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3380, 1145,   46,  220, 2885,  504,    9, 2024,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596, 1395,    1,   37, 2284,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3253,  765, 1159, 3295,   32, 2936,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,   85,  118,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3204, 1141,  176,   26, 3169,  980, 1159,  581, 1385,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  622,    1,  449,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1425,  166,  593,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3270, 2783,    1, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2286,    1,  424, 1935,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   19,    9, 2661,  652,  786, 3136,    1,  361,  105,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1326,   37,  877,    1, 1736, 1975,   32,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  571,   37, 1046, 2741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  794,    1,  384, 1327,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,    1,  242,  187,  615,  240,  156,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1074,    1,  256,   37, 1499,  260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380,  167,   52,  105,  826,   37, 3093,    1,  267,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  551,    1, 1536,    9, 2240,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3297,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 2067, 1488,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310,    1, 3046,   61, 1509,   45,  487,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1100,  951,  657,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  475,  387,  596,  275, 1278,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  221,  242,   98,  410,  996,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1479,  460,  298,  640,  215,  957, 1535,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 1173,  176,  166, 1317,   45, 1104,   27,  627,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,   37,  360,  148,   12, 1509,  361, 2069,  693,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  645,    1,  338,  526,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2922,    1, 1140,    9,  442,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1249,    1,   32, 2941,    9,  449,  219, 2579,  726,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2500, 2485,    1, 1186,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2844,    1, 2347,   32,  455,   12, 2164,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  669,  794, 3039, 3040, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  709,   20,  232,    1,  610,   37, 1038,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2279,  140,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051,  675,  156,   71,  118,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123,   37, 2286,   37,    1, 3251,  221,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2868,  267,  163,    1,   12,    1,  321,  612, 2884,  864, 2439,\n",
      "           32,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   25,  504,   98, 1986,  600,  863,  180,  801,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,    1,   98, 1104,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,   37, 1599,  522,   37,  299,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  267,  903,    1, 1447, 1585,    1,  193,\n",
      "         2673,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1189,    1, 1683,  191, 1147, 3125,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962, 3231,    1, 1110,   32,    1,    1, 1090,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1380,    1,   98, 2210, 1151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  487, 3102, 1025,  729, 2793,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3361,  774, 1444,    1,    1,    7, 2343, 2431,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   27,  104, 2541,   45,  171,    1, 2868, 1897,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  603, 1488,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,  315,   37,  606,  297,  566,   32,  166, 2391,  191,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3222, 3275,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  177, 1295, 3156,    1, 1999, 1530,   32,  395, 2003, 1585,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1890,  565, 2218,    9, 3276,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  378,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2921,  533,    1,  304,    9, 1054,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 2138,  261,   37,  335, 1601,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2107,   32, 1990, 1948, 1360,  191,  364,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1671, 1197, 1017,  162,   92,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584, 3271,  872,  420,  385,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3348,  497, 1648,   37,  907,  600, 2646,  191,  864,  650,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962, 1024,  542, 2685,  187, 2142, 2418,  832,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  103, 2807,    1,  271, 1044, 1045,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  954,    1,  845,   69,  102,  973,   25,    1,  417,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3345,  576, 1089,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3140,    1,  284,  861, 1414,   32, 1430,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  709,    1, 2049,  512,    1, 1530,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,  494,  388, 1862,  600, 1278,  506,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2628, 1249,  590,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1419,  675, 1499, 2232, 2851,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1658, 1762,    1, 1456,  327,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 3096, 3275, 2462,  288,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169,  801,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  361,  657,  872,   37,    1,  166, 2301, 2012,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1008, 2501,  475,    1,  433,  566,  388,\n",
      "            1,    9,  389,   88,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158,   37,  693, 1442, 2581,  163, 1230,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,   37,    1,  195,  625,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  225, 1042,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  681,  187,  289,   96,   37,  163,    1,   12,    1,   29,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2341, 1147,    1,    1, 1057,   98,  104, 2924,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3257, 3205,    1,   37,   77, 3329, 1625, 2793,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158, 2659,   81,  444, 2546,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1425, 1340,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  326, 1380,  978,    1,   98,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2476, 1988,   45,    1,  610,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3058,    1, 2924,   32,    1,    1,   46,   37, 1195,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1974,   56,  548, 1367, 3206,  856,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1190, 3086, 2548,  606,    1, 3114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 1287, 3263,  608,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  997,  166, 2491,  220, 3078, 1987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  142,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2408,  460, 1924,  105,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1, 1372,   37,  138,    9, 1107, 3049,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  550, 1730, 1192,    1,   98, 2215, 2574,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  142, 2619,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  223,    1,  172,  681,  103, 2567, 2804,   12, 1509, 1638,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,   37, 1584, 3358, 1697,    9, 1983,  351,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1345, 1995,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  650,  884,  365,  389,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1138,  387,  197, 1103, 1139,   45, 1396,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141,    1, 2370,    1,  548,    1,  354,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1268, 1778,   37,  166,  754,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2347, 3204, 2257,   39,   45, 3023,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,    1, 1604,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092,  794,  822, 1995,   98, 2189,  668,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  350,    1, 1178,   61, 1951, 1223,   12,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,    1,    1, 1627, 3101,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1461,  640, 3006,   32, 3339, 2791,    1,  583,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3402,    1,   32,  147,   98,  134,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  253,   81,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  381, 2503,  236,  237,  220, 1296,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1808,  437,  313,  176, 1230, 2543,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275, 2892, 1827,   37,  132,  220, 2453,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1658,  327,   32,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2924,    1,  548, 3391,  477,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3363,  108,   45, 3343,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2388, 1654,  202,  140,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  294, 1456, 1236, 2180,    1,    1,  361,  217,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  197,  418,   98,    5, 1639,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3066,    1,  311,   37, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   81,   37,  166, 2601,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 954, 897, 176, 105,   1,  67,  32,  72, 401,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 267,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3181,    1,   32,   98,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9, 1436,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3359, 1707,    1, 3339,  741, 1004,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1645,    1,  220,  105, 1427,  686,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  518, 1149,   32,  474,  170,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2759, 1294, 2094, 2627,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1773, 1455,  197,   28,  118,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  382,  286,   67,  423,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2372,    1,   37,  877,    1,    1,   32,    1,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1183,    1, 2288,    1,    1,   28,   98, 2372,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,    1, 2769,  220,  449,  593, 2522, 1684,  452,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1459, 1877,   37, 1000, 2231,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3363,    1, 1708, 2290,    1, 2770,  602,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3376, 3345, 1542,   37,  943,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2379,    1,  315,   37,  322,   85,    1,  131,   32,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  580, 2484, 1798,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   32,  289,   32, 1084,    1,  788,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1545, 1090,   61, 1797,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  627,    1,    9, 2710,  518,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   25,   71,   98,  148,   12,  647,  349,    1,   14,   15,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,   28,  202,  605,  953,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  542, 2368,   28,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  481,    1,  480,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  331,   32, 1212,  250,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1380,  166,  661,   32, 2693,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2841,  550, 2074,   74,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1076,    1,  741,   98,  142, 1552,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  464, 2673,   46,  972,    1, 2191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  298, 1867,   45, 2006,    1, 2704,  594, 1994,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,    1,   32,   64,    1, 3349,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,    1, 1839,    1,   37, 1428,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1712,   37, 1776, 1778,  328, 2549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  794,  365, 2895, 1857, 1294,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 3103, 2844,  548,    1,   98,  667,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  203,   12, 2310,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1778, 2580, 2851,  105,    1,    1,  193,  105,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1594, 1967,    1, 1159,    1,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3252, 1254,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  538,  786, 1564,  221,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  369,    1,  253, 1947,  104,  221,  225,   37, 1413,   12,\n",
      "          551,  552,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1345,    1,   32, 2646,  548, 2024,  142, 1464,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1090,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2964,  619, 2312, 2056,  176,    1,  829, 2558,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,  267,   37, 1195,   46, 1232,  163,    1,   12,\n",
      "            1, 1086,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1645,    1,    1,  365,    1,  844, 1049,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1157, 2817,  361,    1, 2572,  249,    1,  101,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1260,   98, 3101, 1583,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3216,  631, 2615,  548,  228, 2799,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2832,    1, 1484,    9,    1,  521,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1899, 1271, 2263,  220, 2099,   37,  720,  134,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  854,  964,    1, 1159,  854,   12,  460, 1633,  631,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1218,  897,    1,  994,  782,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1363,  794,  350,  218,  517, 1273,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1571, 2514,    1, 2030,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  411, 1104,    1,   98,  347,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1936,  105,  298, 1434,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1043, 1268,  242,    1, 1946,  191,  496,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  991,  454,    9, 3398, 1377,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3244,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1658, 2702,  190,   52,  857,    1, 2289,  267,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1818,  147, 1360,  612,  665,    1,   98, 1771, 2661,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118,   61,  810,  600,  943,  361,  590,  522,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 895,  32, 754, 757, 400,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 978, 769, 670,  98, 119,  68, 102,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  537,  548,    1,    1, 1081,   61, 2040,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,    1,  297, 3339, 3065,   12, 2162,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2087, 2903,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1690,  312,    1, 1316,  942,    1,  176, 1818,  147,  695,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1290,  396, 1269,    1,  427,  739,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,  787, 1167,  125,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826, 1178,   98,    1,  134,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1652,   12,   26, 2798, 2232,   37, 2728,  411,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,   25,  245,   98,  303,   12,  304,   98,  442,  448,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  848,  200,  365,  526, 2186, 2105,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 1021,   37,    1, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 3001,  162,  449, 1333,  176, 2468,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1827,  220, 1018,    1, 2067,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  137,  836,  567, 1582,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1112,  176, 1759,  309,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  187,  531, 1002, 1708,  891,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  510, 2126,  686,    1,  163,    1,   12,    1,    1, 2785, 1219,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1926, 1927,   12, 2290, 2626,  984, 3380,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2350,    1, 2018,   37, 2579, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1606, 1149,   98,  166,    1,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2599,  342, 3341,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2345,    1,  856,    1,  220,    1,  318,  361,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1301,    1,   12,  365, 3262,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1936,   98, 1158,   12, 1107,  525,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  180,  267,   75,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  647,    1, 1632,  453,  533,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  331,   12, 1421,    1,    1,   37,  786,  356,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,    1, 1428,   12, 2266,   37, 2396,   37,   16, 1876,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,   12,  103,  331,   12,    1,    1,  631,  297, 3175,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1128, 1353,  160, 1085,   37, 2650,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  389,  173,    1,    1,  388, 1275,  495,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3264, 2792,    1,  320, 1103,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3317,  321,  726,  220,  104,    1,  267,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1018,   69, 1242, 1167,  167,   52, 1018,  996,    1,   32,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2605,   37,  877,  864,  915,  693,   98, 2439,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  476,  388,  977,   37,  856,  195,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,    1,   59, 2610,  813,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3398,   51,  865,  191,  339,   12,  439,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938,   37,  319,  941, 1201,    1,    1,  225, 1137,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  551, 2860,    1,   79,   37,   14,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1405, 2281,  400,  288,    9,  776,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2979, 1151,  614, 2613,   98,  911,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2474,  980, 1159, 2818, 1425, 2918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1855,  947,  927,    1, 1585,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2587,    1, 2304,    1,   32,  531,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  236, 1022,  288,   37, 1269,    1,  458,  932,  184,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  829,   37,  877,  116, 2542,  388,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  548, 3358,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,    1,    1,    1,  580,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1100,  200,  453, 1254, 2355, 1151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,  197,  418,   88,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2696,   37,  949, 1243,   45, 2462,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  530,  548,  365,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  316,  719,   37, 2446, 3194, 3195,  472, 1090,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   37, 1155,   69,  965,   37, 2752,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  848, 1303,    1,  572,  244,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1082,    1,   45,  164, 1593,  187,  109,\n",
      "           61,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2944,   12,  171,  793,    9,  333,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2214,  125,  384, 2804,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1117,    1,    1,   37,  194,  776,  199,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1597,  325,    1,    1,   12,  395, 1184,    9,  104,  331,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056, 2748, 2547, 2844,   45,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3066, 1293,   32,   44,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1199,    1, 2175,   45,  823,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2002, 2924,   37, 2449,   32, 3349,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 1117,    1,  565,   81,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  775, 1021, 2232,  260,    9, 1718,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  726,    1,    1, 1161,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1583, 2625, 1159, 3339, 2414, 3375,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  579,   12, 1411,    9, 2993,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  833,  612, 1210,   37,   52, 2016,  872,   12,  971,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2306,  288,    9, 1147,  890, 2292, 1071,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  897,  187, 1756, 1627,  581, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1812, 2103, 2727, 1976,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1261, 2794,    1,   37,  970,    1, 2884,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2592,  115,   45, 1675,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,  155,  568,  191,   59,    1,    1, 1310,   37,  504,  160,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2352, 3380,  484,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,  256,    1,    9,  517, 1085,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 104,   1, 395, 297,   1, 265,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 593,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1292,  614,   39,  220,  105, 1551,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   66,    1,  187,   69,  765,  242,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1794, 1118, 2823,    1,  132,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  161, 1294, 1229,   37,  211, 1029,  480,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2911,   98,  105, 2655,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  936,  423,   32, 1184,  347,    9,  166,  449,  199,   32,\n",
      "         2335,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1,   39,  104,   59,   37,  875,    1, 2254,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  522, 2644,  548,    1,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1237,  166,    1,    1, 2784,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189, 1118,  172,    1, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3250,  688, 3103,  202, 1306, 3220,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 1585, 2870,   27,  667, 2147,   32, 2597,    1, 1887,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1420,    1, 2073, 1023,  207, 1660,   98,    1,  102,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111,  834,  641,    1,    1,  361,  124,  420,  562,   15,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  198,   60,   37, 1096,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,   46,   37,  574,   54, 1503,  142,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  345,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2680,  794,    1, 1525,  861, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2597, 1325,    1,    1,  446,  756,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  550,    1, 2885,    1, 2843, 2523,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  416, 1412,    1,  191,  439,   45,    1,  334,   51,  193,  606,\n",
      "          105, 2309,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,  879,  443,  286,    9,   22, 2054,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  405, 3291, 1484, 3311,   12, 2001,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273,    1,    1,  844,   12,   98, 1220,  627,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1178, 1236,    1,  361, 2161,   12,  297, 2162,   45,  247, 1404,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  589,    9,    1,  190,    1,  104,  954,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1953,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1559,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  296,  387, 1273,  259,  815,   98, 1202,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  430, 2008,  352, 1495,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  632, 1821, 1539, 1961, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1854,    1,   14,    1,  102,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  183, 2068, 1924,    1,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,   84,   85,  384,  593,  458,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  288,   37, 2225, 1477, 1990,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,    1,   28, 1181, 1775,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1190,  251,  516,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3329,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3178, 2963,  176,    1,    1, 2779,  140,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  719, 2202,   37, 1832, 1463, 3192, 2522,  220,  691,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,  794, 1021, 1151,  662,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2069,  932,   45,  715,    1,    1,    1,  890, 2601,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,    1, 1900,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1013,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3303,    1,    1,  631,  593,  427, 1343,   12, 3179,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2548,    1,    1, 1388,   32, 2646,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1051,   37,  151,   80, 1228, 1873,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596,   27, 2147,   32, 1081, 2414,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2031,  777,  778,    1,    1,  669,   12,  822,  396,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3198,   39,   37, 2155, 3204, 1456,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  242,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1617,    1, 2741,    1,  447, 2827,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051,   37,  130, 1074, 1499, 1873,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  787,   98, 2041,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3402,    1,   37, 1046,  134,   32, 1186,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,  854,  726,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2615, 2935, 1194,   73, 2764,  404, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 1118, 1539,   45, 2080, 2056,  880,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1604,  125,   39,    9,  691,  361, 1081,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,  193, 2245,  191,   69,   71, 1724,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  990,  108,  550,  535,   98,    1,  378,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2685, 1229,   37, 1982,    1,    9,  501,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3237,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25, 1838,  410,    1,   60,  242,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2871,  625, 1240, 1306, 2119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3344, 1940, 1260, 3343,    1, 2190,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   18, 1632,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1251,  745, 1632, 2544, 1998, 1499,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1523,    1, 3382,   12,    1, 1521,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1322,  896,    1,   37, 2230,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,   86,  160,  102,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2765, 1928, 1082, 1450,   98,  104, 2860,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035, 1070,  398,    9,  611,  917, 2017,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  744,  241,  119,    1,  181,  530,  105,  106,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 1665,    1,  267,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162, 1159,  166, 2014,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3097, 2591,   32,  123,  890,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296,  387, 1273,  259,  815,   98, 1202,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1437,    1, 2294,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  957,   37,    1, 2924,   37, 1619,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  501, 1900,    1,  632,  484,   37,    1, 1839,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,   37,  125,    1,    4,   37,   92,  197,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1497,  907,    1, 2631,   32,    1,  404, 1798,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  806,   10,    1, 2275,   32,  365, 1788,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  691,   12,    1, 1380,  750, 1625,   32,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,   12, 1445,  863,   61,  972,   37,    1,  104,  395, 2471,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2569,  650,  952,  388, 1663, 1876,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3325,  267,    1, 1031, 1360,  612,  583, 1477, 1990,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2614,  542,    1,   28,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1693, 1292,    1, 3066,    1, 1211, 2460,    1,   32, 3096,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2999,    1, 1994, 2819, 3050,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  393,    1,  467,  220, 1384,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3404,  774, 3358,  967, 2644, 1594,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1215,    1,  474,  759, 1845,  132,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  207,  526,  267, 2331,   98,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1940,  726, 2942, 2347,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  581,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2746, 2360,   10,   12, 1108,    1,  408,   45,  443,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321,  749, 1443,  335,  166,   97,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  301,    5,    1,  240, 2069,  233,  562,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,    1,  853, 1732, 2107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  561,    1,    1,   37,  582, 1739,  105,  551,  331,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  957,  460,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2804,   45, 3096, 1292, 3340,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2587,  105,  365, 2829,   32, 2170,   37, 1154,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1162,  159, 1374,   98,  197,  304,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1879, 3229,    1,   37,  606, 1857,   98, 3078,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,   37,  665, 1772,  384,  638, 1410,   98,  116,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2531,    1,  445,  388,  763,  105, 3192,  427,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  166, 2252,   45,  777,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  292,  365, 1021, 2168,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  475,  267, 3372,    1, 2559,  894,    1, 3380, 1559,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  765,   28,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3296,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  919,  570,  187,  207,  418,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  667,  446, 1112,  204,  190,  193,   52, 1425,    9,  885,  863,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1395,  102, 1556,  388,  763,   76,   32,  367,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2860,  176, 3385, 1953,  360,  104, 1734,   98,  864,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  750,  924,  907,    9, 1022,  199,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1465,    1,  162,  356,   24,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963, 2873,  105, 2409,   37, 1154, 3015,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2598,   32, 1742,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  936,  647, 1220, 2014,  883,  361,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   32, 2482,   78,    1,   93,   45,    4,  967,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,   37,   92, 1462,  361,  861,    1, 1897,   10, 2237,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1199,  769,   37,   77, 1171,   45,  195,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1458, 3366,  187,  957, 1004,    1,  384,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  204,   12,  193, 1139,   98, 1161,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1546, 3182,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  219, 2005,   37,  693,  864,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  560,  347,  866,   98,    4,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1603,  597,    1,  972, 2582,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,    6,    1, 3406,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3379, 2147, 3035,  193, 1810,  166, 2335, 2372,  947,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  432,  731,  418,    1,  573,  652,  921, 1057,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  671, 1078, 1707,    1,  182, 1076,  671,  142,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  439,   37,  550,   45, 2811,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3168,    1, 2779,  361,  683,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  365,  454,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   71,  528,   14,   15,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1107,  542,    1,    1,  166,  183,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1531, 3263,  872,  420, 1657,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3172,    1,    1, 2653, 2171,    1,    8,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2862,   12, 1678,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 3289, 3263,  661,  885, 1684, 1333,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1789,  218,  103,  547, 1273,  259, 2718, 2428,   45,  166,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 2056,  116,  815, 1660,   32,  163,    1,   12,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  342,  476, 1778,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1654,  442, 1655,  361,  580,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1433, 1444, 1348,   37, 2772,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  397,  908,  442,  909,  444,  163,    1,   12,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2614, 1822,  920, 1911,  105,  365,    1,   45, 2769,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1087,   37, 1403, 1222, 2359,   37, 2759,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  652, 1140,   66, 1370,   45,    1,    5,  221,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   51,  335, 2230,   79,    1,  977,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  656,   37,  506,    1,  351,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  224, 1126, 2509, 1542,   37,  168,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2025,  402,  696,  590,    1, 2321, 2428,    1,  726,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1178, 1179,   32, 3177,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2569,    1, 1174,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  105,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 2170, 3109,  786,   32,    1,    1, 2673,  927,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  386, 1858, 2153,  690,  573,  132,    1,  118,  138,    6,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  952,   37,    1,  616,   98,   67,   71,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  581, 3212, 1624,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  420, 1770,  347,   98,  429,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  590, 2293, 1176,  638,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2347,    1,    1,  321,  612, 1838,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3167, 1739,    1,  718,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  886,  325,  104,  275,  700,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2349,    1,   51, 2226,  606, 1658, 1311,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  833,  612,  804,   39,  311, 1605,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1060, 2827, 3102,   32,  121,   36,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  721,  155,  158,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1520,   21,  119, 1455,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3256, 3299, 3159,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1883,  325, 2215,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2127, 2432,  193,  320, 2127,    1,  187,  104,  996,   93,\n",
      "            1,  242,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3186,  542,    1,  220,  405,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,  672,    1,   32,   91,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  600, 1485, 3365,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2571, 2153, 1421,  638,    1, 2024, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,   37, 1075,  906,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2811,  220,  542, 1965, 3226, 1918,   32, 1531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  340,    1,    1,  187,  227,  187,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3378,  443, 2938,  776, 2361,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,  547,    1,   98, 2393,  548, 2817, 2856,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3076,    1,  851, 2249,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  477, 2047,  548,  455, 2164, 2414,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2476, 1980,   37,  427, 3052, 1722,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1173,  854, 2230,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  647, 1489,    1,  147,  695,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1554, 2685,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  634,   37,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2909,    1,  176,    1,    1,  217,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1766, 1767, 1074,  412,   32,  166, 2391,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1557, 1070, 1386,   37,  843,  861,   37, 1537,  872,   32,  182,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 166,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 374,   1, 329,   1,  12, 552, 720, 118,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,  294, 1827,  187,    1,    1, 1159, 2069, 1385,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147,    1,    1, 1248,  863, 1860,    9, 3155, 3071,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2298,    1,  764,   61,  105,    1, 2017,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3359, 2559, 1384,    9, 3057,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,  256, 3005,  361, 2693, 1942,   37,    1, 1108,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  548,  810,    1,  606, 1366, 1752,    1,  955, 2274,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  705,    1,  967, 1056,  251,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  518, 2153, 1248,    1,   98, 2095,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,  794,  104, 1107, 3049,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1178,  928,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1867,    1,  218,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3079,    1,  176,  590,    1,   32, 3278,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2208,   37,   52,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2999, 2257, 1994, 2819, 3050,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2557,   32,  273,  187,  730, 2614,  661, 1918,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  183,    1, 1564,  247,  813,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,   37, 2230,  220,    1,    1,    1, 3004,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2960,    1, 1632, 3101,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  180,  197,   28,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  632,  880, 2421, 2856,  176,  177,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1034,   32,  231, 1272, 1167,    1,  688,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1051,  515,    1,    1,   37,  166,    1, 1273,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  702,   37,   47,  124,   37,  754,  757,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3103,  442,    9, 2477,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,   37,  776,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  195,  749, 1997,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1877,  573,  574, 1296,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3245,    1,  220,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437, 1679,    1,  548,  669,  796,  531,  844,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1592, 1248,  522,  187,  163,    1,   12,    1,  847,   28,    9,\n",
      "          164, 1593,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,    1,   37,  151, 1928,  413,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 3054, 1631,  846,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2197,  787, 2158,    1,  176, 1718, 1605,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1858,   46, 1348,  187,  393,  159,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,   79, 1515,   81,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1062,    1,  733,    1,    1,  419,   48,   32,    1,  596,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2832,    1, 1861, 1819,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 3191,  361, 3312,  877, 2315, 2055,   32,    1,  105,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   22,  359,  741,   37,  335,  138,    6,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  389,    6,  176,  339,  845,   32,   86,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1173,    1,   12,    1, 2528,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  485,  190, 1334,  187,  671, 1078,    1, 1039,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2498,  220,    1,  118,  916,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1861, 1550,  707,   37,  443,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3112,    1,    9, 3302, 1624,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  686,  965,   32, 1850,  531,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  921,  449, 1412, 1107,   15, 2577,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3172, 1090, 1829, 2142,  171,  176,  878,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,   78, 2449,  577,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,  200, 1787,   37, 2278,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2720, 2796,    1, 3266,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,  852,  176,  166, 1772,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1116,   32,    1,  197,    1,   15,  554,   32,  581,  401,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,  134,   32, 2095,  722, 1634,   37,  104, 2393,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1127,   51, 1046, 1994, 2015,  599,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 3361, 3340,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3375, 2856, 3101, 2924,   32, 3339,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  424,  651,    1, 1918,   12,  590,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3076, 2886,    1,   61, 1558,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,   96, 1273,  259, 1159,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2891, 2986,   37, 1753, 1428,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1933,  295, 1536,    9,  467, 1942,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1985, 1530,   32, 2596, 1585,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2749,   28,    1, 2791,    1, 2337,    1,  429, 3314,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   25, 1376,  187,  615, 2346,  997,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1, 1961,  304,   98,    1,  195,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612, 1353,  389,  125,  469,  191,  600,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  691,   12,  711,  936, 1243,   45,  105,   59,  332,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  612,    1,    1,  636,  353,  118,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2504,  446,  251, 2609,    9, 2705,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3349,   64,  799, 2817, 1950,  418,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  696, 3117,  619,  115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2857, 1443,    1, 2468,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,  779,  861, 2043,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401, 3256,  191,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2018, 1194, 1354,    1,  171,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3385, 1566,  522,   98,    1,   37,  420, 2673,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056,  356,    1,    1,    1,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2332, 1865,  365, 1421, 2829,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2,  91, 509, 297, 632, 493, 633,  12,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 352, 589,  51,  52,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2528,    1,    9,  105, 2441,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3354, 1414, 1260, 3345,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   55,    1,    1, 2236,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  188,  548,    1,  985,  776,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,   37,  151,    1,  681,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004, 1643,  708, 1013, 1017,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1951,  379,    1, 2670, 2735,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1388,   45,  166, 2807,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2838, 3224, 1333,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1740,   45,    1,  429,    7,   37,  104, 2841, 3126, 1625,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  136,    1,    1,  759,  399,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1187,    1, 1188,  105,    1,    1,  105,    1,    1,  321,  764,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,   45, 1663,    1,  446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380,   37,    1,  247, 1583,  317,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1240,  415,   52,  166, 1178,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3032,    1,  251,    1,   37,    1, 2359,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  123,  242,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  267, 2366,   37,   52,    1,   26, 1039,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1191,    1,    1,  498,   37, 1650, 3000,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2279,    1,   79,    1,   12, 2081,   45,    1,  175,  132,   32,\n",
      "          223,  895,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2863,    1,  885,  822, 1641,   32, 2956,  149,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2899,  251, 1108,   37,  176,  551,  612,  613, 2264,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1938, 2607,  382, 2206, 2989,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3152,  183, 1940,    7,   32, 2093, 3268,  726, 1045,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   98,  116,   12, 1194,    1,    1, 2896,  729,    1,  600,  453,\n",
      "         2252, 3000,    1,  150,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98, 2436,   37, 1978,    1, 1220,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1661,  551,  704,  222,  580,   44,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  615,   51, 1371,  619,  284,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2307, 2213,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181,   37,   47,  104,  845,  846,  259,   32,  411,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  686,  236,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2645,    1, 2890,    1,    9,  638, 1675,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  224, 1126,  361, 1601,   98, 1597, 1633,  293,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  535,  669,  315,   37,    1,    1,  225,  809,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  883,   93, 1071,   32, 1352,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2922,  162,  247,    1, 2672,  132,    1,   37, 3323,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  132,   51, 1584, 1850, 1423,    1,    1,   32,    1,   12, 3372,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  453,  199,    9,  166, 1940,   32, 2087,    1,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  388,  888,   32, 2468,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2225,    1,    1,  512,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1530,    1, 1941,   32, 1157, 2596, 2960,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,    1,    1,  657,  246,   98,  329,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12,  260,   32,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2235, 1158,  525, 1268,   37,  535,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,  98,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 592, 420, 193, 810, 227, 550,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,    1,  680, 1665,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  181,  166,    1,   98,  105, 2177, 1204,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2041, 3022,    1,  162, 1415,   37, 3024,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,    1,  716,   45,  365, 1088, 2527,  164,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2835, 2596, 2137, 2856,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  565,  410,   98,    1,   69,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 853, 354, 488, 333,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 176, 612, 315, 388,   6,  32,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   28,  129, 1541,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299, 1518,   32,   98,    1,  207,    5, 1281,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2959,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3200,  877,  186, 2116,  444, 2551,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2095, 2985,    1,   32,  447,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37,  693, 1442,  158,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3344,  437,  396,   37,  606,    1, 2249, 3373,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  108,   98,    1,   45,    1,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2903, 1509,    9,  915,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1691,    1,    1,  248,  659,   45, 2268,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1260, 2414,  176,    1, 3392,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  620,   33,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1021,  260,   12, 1251,  167, 1192,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,    1,    1,    1,  176, 1821, 2190,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1100,  879, 1151,  132,  220,  326,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1440, 2642, 3224,    1,    1,    1,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,   61, 1372,   37, 1421,    1, 1259,  220, 1725,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  709,  730, 1777, 1644,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  388, 2580, 2851,  861, 2538,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   98, 2131,  848,    1, 1523,   45,  166, 2166,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3340,    1,    1,    1,  183, 2455,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  370,  371,  716, 2738, 1023,  356,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3322,    1,   32, 3201,  176,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 1090, 1829,  365, 1546,  176, 1022,    1, 2296,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  828,  498,   37,  365, 1281,   98,  116,  962,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  412,   37,    1,   32, 3311, 3310,  776,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  596,    1,  936,  283,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200, 2071, 1331,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158,  542,    1,  297,  365, 2452,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192, 1956,  135, 2741,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1388, 2420,    1, 1981,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,   37,   92, 1069,  837,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  119,  532,  764, 1403,  104,  442,  448,   85,  105,  784,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2250,    1,  361,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   37, 1876, 1561,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,   85,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   23,    1,   39,   32,  632, 3071,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  299,    1,   28, 1604,  220,  445,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2957, 2914,    1,    1, 1935,    1, 3016, 1935, 1027,    1, 3011,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1736, 2695, 2193,    1,  841,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  187,    1, 2827,    9,  632,  318,   12, 2772,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2682, 1693, 3255,  361,    1,   37, 2551,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  361, 2018,   37,  288,   28,  105, 2673,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3196, 1542,   37, 1838, 2227,  914,   98,  845, 1318,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  561,  774,  590,   37, 2757,   12,  493,    5, 2099,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094,   12, 3359,  847,   28, 1876,    9,    1,  741,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2308,    1,  612,  319,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3100,  921,  590,    1, 3110,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,    1,   98,  579,  224, 1126,    1,    9, 2670,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2117, 3369, 1905,   37,   52,    1,  622, 2731,   32, 3118,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  670,    1,  289,   98,  800,   60,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1237, 1658, 1117, 1525,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  992,   85,  187,    1, 2800, 2565,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 2227,  187, 1233, 1418,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3054, 2598,  176,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1186, 1782, 2924,    1,   37, 3045,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938,   37,    1,  941, 1201,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,   25,   51,  245,  548,  957,  884,  297,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1427,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,    1, 1554,    1, 2249,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708,  171,   79,  166, 2521,    1,  267, 2183, 3359, 2431,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    9, 1512,    1,    1,    1,    1,   61,    1,  202, 2638,   12,\n",
      "         1343,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2747,  166,  282, 2423,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  388,  224, 1437,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   78,  361, 1443, 1260,  425,  426,  223, 1563,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  557,  540,   32,    1,   62,    1,  187, 2703, 1348,   37, 2816,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  291,    1,  808,   45, 2544,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2419, 2264,  190, 1876, 1766, 1767,  408, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1, 1361, 1413,  220,  829,   98,  777, 1085, 2630,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3290,    1,    9, 1691,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  294,   32, 1640,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2720, 2796,    1,   32,  584, 2074,   63, 1090,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105,    1, 1311,  176,  166, 1831,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3358,   32,  166,  985,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  982, 1353,  617,  259,  218,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3101, 3162, 2856, 3339,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2105,  631,    1,  636,  948,   32,   86,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   65,   66,    1,  347,  528,  509,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2470,    1, 2471,  220,    1,  507,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   25, 1473,  187,  197,  509,  470,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1450, 2856, 1056,  104,    1,   32, 3360,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1, 1130,    1,  627, 2759,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   51, 2370,  647,   12,  888, 2552,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1652,    1, 1718,    1,  280,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649,  700,   32, 2205,  548, 1044,  331,   32, 1801,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3231,  335, 3235,  539,  220,  726,  297, 1110,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2986,  729, 1139,   98, 1983,  351,  361,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1802,  700, 2914, 2501,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  774,  388,  894,  619,  487,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  460, 1320,  829, 1774,   39, 1778,  279,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,  725,   37,    1,    1,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  103,    1,   32, 3201,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  325,  647,    9,    1,  131,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3361, 2572,   32, 1656, 2950,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  580,    1, 2322,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2476,  726, 1089, 1090,  671, 3126,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  869,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2500, 2798,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,   12,    1,    1,   37, 1862,   93,  570,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  217,  489,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647, 1276,  548,    1,  148,   12,  645,  142,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2943, 1228, 1396,  803,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,  166, 1730,  582,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  902,  688, 2463,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  792,    1,    1,  792,  449,   37,   52, 2399,    9,  531,\n",
      "          443, 2938,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2754,    1,    1, 1465, 2086,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1042,   39,   45,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2216,    1,  361,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1231,   32, 3040,  722,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3300, 2861, 1159,    1,   45, 2462,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  438,  449,   32,    1,  861, 2060,  804,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3358,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2964,  722,    1,   45, 1108, 1260,  444, 2425,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 397, 908, 442, 909, 444, 163,   1,  12,   1,  88,   1,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 173,  45, 829,  12, 365, 535, 656, 973,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1583, 3400,   37,  221,   37,  455,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  149,   66,  972,   32,    1,    1, 2162,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  199,  421,  459,  132,   37,  771, 1200,  194,   48,   32, 1842,\n",
      "           50,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1539,  365, 1230,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  503,  225,  884,  183,  686,  548,  480,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1082, 2855,   37,  838,   85,    1,  859,  129,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2902, 2619,   28,   98,  284,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967, 1668,   32, 2364,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2711,  321,  713,    1,  267,  730, 1571, 1831,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,    1, 1380,    1,   32,  105, 1510,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 159, 554,  32, 218, 714,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  25, 670,  98, 971, 156,   1, 242,  69,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3389,  176, 1056,    1,    1,  217, 2856,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2579,  288,    9,  914, 2093,    1, 3154,  176, 1257,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  615,  672,  166, 1285,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,  782,  464, 2547, 1509,  176,    1, 2298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  567,  510, 2682, 1549,  540, 1530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1930,  619,    1,  600, 1107, 1655,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3094,   45,  365, 1147, 2924, 2844,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    8, 1250,   37,    1,  597,    1, 3289, 3139,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  902, 2206,    1,   37,    1, 3141,  698,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1185, 2685,  583, 3117,   32,  105, 1090, 1444,  110,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1430, 1726,  319,  297, 1009,   12, 1400, 2113,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,   98,  166,  260,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299,  300,   10,    5,  125,  302,    1, 1918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   65, 1188,  193,  221,   98,   31,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2699,  288,    9, 1539,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   25, 1838,  198,   98,  863,    1,  156,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374,  650,    1,   32,    1,   37, 2000, 1094,   12, 2129,  384,\n",
      "         3339,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,  872,   37,    1,    1, 1064,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2971,    1,    1,  444,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3176,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2936,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  700, 3007, 2679, 1912,    1,    9,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  187,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1796, 1284,    1,  187,  119, 1397,  759,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1411,  633,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2835, 1360,  612,    1,  531, 1557, 1900,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  430, 2774,  650, 1261,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1273,  259,  681,  345,    9,  365,  845,  846, 2146,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2610,   98, 1412,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   49, 1536,    9,  467, 1942,   32,   10,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3260,  606,  166, 1021,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  683,    1,  376, 1194, 1843,    1,  570,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3277,    1,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1105,  787,    6,  354,    1,  225, 1137,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 1976,   27, 2893,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   20,  256,    1,   37, 1766, 1767, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,  593, 2153, 1248, 2433,   97,   98,  964,  297,  171,   45,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  496,  267,  617,  618, 1827,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2571, 3372, 1268,  220,  845, 1625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  700,  187,    1,    1,  531,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3364,  738, 2708, 3384, 2153,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1366,  606, 2560,    1,  220, 1778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1930,  804,  912, 2285, 1228,  822,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2868,   37,  289,   98,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,  810,   32,  247,  582,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2126,  800,  548,    1,    1,  384,  458,   45, 2741,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1764,    9, 2926,   32, 1034,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1063,  884,   98,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453, 1229,   27,  132,   98, 1633,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69, 1631, 1632,  104,  105,  106,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1829, 2028, 1679,  547,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1821, 2385,  612,  810, 3033,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1904, 1426, 1845,  132,  220, 1149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   20,   82, 1702,    9, 2199,   37,  296, 1859,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2068,   45,  215, 3102, 1082, 1861,   37, 1335,    9, 3102,  949,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  341,    1, 1746, 1896,    9,    1,    1,    1,   79, 2792,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2885,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    4,  997,  187,    1,    1,  285,   37, 1033,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2628, 2696,  476, 1281,   98,    1, 1089, 1675,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  547,   37,  619, 1542,    1, 1056,  190,  168,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2583, 2554,    1,   12,  183, 1625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3036,  384,  166, 1530,  798,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,    1, 2844,   32,  403,  531, 3279,    1,    1,    1,   98,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,  187, 2909,    1, 2747, 2597,  501, 2060,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3116,  922,  437, 1117, 2246,    1,  105, 2775,   45,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69, 1071,  883,   93,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2642, 1054, 1056,   45,  166, 2308,   98, 3167, 3273,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 835,   1,  45, 104,  32,   1, 810, 987, 132,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 303,   1, 997,  45,  69, 805,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,   37,  125, 1060,   45,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1811,  404,  864,  729,    1,    9,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3160, 2572,   32, 2137,   32, 1147, 1633,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  166,    1,  384,  636,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,  113,  700,   63,    1,    1,  925,   65,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2301,    9,  892,    1,    1,   32,  105,    1,  770,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  716,  531, 3102,    1,   37,  365,  437,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  119,    1,    1, 2137, 3260, 1159, 1832,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2081,   45,  163,    1,   12,    1,    1,  176,  531, 1929,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1594,   37,  457,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  107,   51, 1198,   69,  636,  837,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  369,    1,  315,    1,    1,   37,    1, 1823,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1744,  920, 1406, 2141,  195,  190,   52,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   12,  365, 2759, 1343,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2775,  384,   96,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  247, 1509,    9,  311,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  166, 1534,   98, 1549,  443,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2238,  313,   37,  335,  631,   32, 2196,    1,  218,  220,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  168, 1264,    1,  619, 2219,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275,  168,  582,   37,  582,   98, 2948,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 1667, 2297, 2734,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  954, 1071,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  183,    1,   32, 1407, 1429,   32,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1221,   12,  671,   32, 1167, 1221, 1530,   22,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,  338,    1,  640,  119,  340,  951,    1,   94,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3188,    1, 3244,   22,   39, 3227,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158,   12,    1,  361,    1, 1230, 2528, 2385,  612,    9,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,    1,  533,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056,  388, 1333, 1530,  187, 2490,    1, 2024,    9,  463,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398, 1203, 2800, 3098,   32, 1708,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2868,  561, 1822,  815, 1125, 2589,   98,  207,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3276,  774, 1444, 1445,    1,   98, 1879,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2102, 2175,   37,  942,   32, 1169,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2371,    1,    1, 1773, 2898,  320,    1, 2371,    1, 2510,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2144,  104, 3111, 2572,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3281,   12, 3181, 1249,  247,  709, 1218,    1, 3314,   32, 3116,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,   83, 1360,  612,   52,   98,  654,   12,  721,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  358,  244,  554,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  202,    1,    1,  105,  365,  454,   37,  166, 2918,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  615,    1,    9,  805,   45,  242,   69,  102,    1,  104, 1184,\n",
      "           67,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,  737,  207,  174,  418,  419,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  295,  952,  365, 1084,  260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1437,   37,   28, 1640,    1,  568,  191,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  744,  166, 1224,   32, 1742,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,  613, 1086,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968, 2620, 2049,    1,  105, 1479,    1,  493, 1389,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  885,    1, 1838,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3176, 3164,    1,    1,   39,  191, 1987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3345, 2035, 1757,   98,  487, 3102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1688,   37, 1155,    1, 3001,  656,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3186, 1384,   32,  818,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2965, 1685, 3261, 2322,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1683,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   37, 1488,    1,  220,  500,    1,  268,   61,    1,  453,  857,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,  12,   1, 361,   1, 181,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 375,  37, 151,   1,  32, 152, 132,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3375,  774, 3101, 2262,    1,    1,   45, 2024,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178, 1179,  542,    1,  444,  742,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2144, 2572,  187,    1, 1325,  236,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  191,    1, 1602, 2539, 1484,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,   37,  856,  996,    1,    1,  202,    1,   61,    1,   89,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1707, 1140,   37, 1746,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  159, 1821, 2721,  220,    1, 2547,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1641,  187, 3204,  796,  754, 2630,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 107, 919,  69,   1,  37, 720,  68, 636,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,  61,   1, 227,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  964,  991,  454,    9, 1839, 3037,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2104,    1,  211,    1,   32,  105, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2087,  967,  916,   37,  877, 3193, 2218,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  619,  356,  881,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  903,    1,  904,    1,  292,  453, 1209,  861,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  833,  612,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  584, 2696,   96,   37,  104, 1818,  147,   32,    1,  400,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  811,    1, 2877,  176,  342,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  596,  954,   37,  686,    1, 1411,  356,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3001,    1,   29,    1, 2223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  603,    9,  238,   98,  166,  730, 3022,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 2018,    1,    1, 3354,  446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 1585, 2414,   32,  531,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1851,    1,  852,   37,    1,  365, 2294,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   26,   27,    1,   20,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785, 2044,    6,   69,  102,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    5, 1178,   51,  335,  105, 1526,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,  271,    9, 3169,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  311,    1,  548, 2596, 1665,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2702,  338, 1159,    1,   32,    1,    1, 1530,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  853,    1,    1, 2324,  395,   98,  593,   12,  103, 1722,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   32,  195,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,    1,  854,    1, 1194, 1385,   45,  442,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   64,  799, 2023,   32, 1895,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  286,    1,    1, 2286,   39,  382,  938,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  169, 2222,  162,  460,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   28,  364, 2545,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3282, 1480,    1,    1, 2865,   79,    1,    9,   72, 1286,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2884,    9,    1,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1957, 2856, 1056,   32, 3339, 2831, 2791,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1189, 2177,    1,    1, 2708, 3035,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  121, 2216, 2834,    9,    1,  880,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,    1,  180,   51, 2123,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1,   37, 2835,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 2306,   32, 1123,    9, 1893,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  561,  570, 1488,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1459, 1082,    1,   37,  690, 2712,    1,    1,  176,  133,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1033,    1, 1415, 2471,  220,  395,    1,  455,    1,   12,\n",
      "            1, 1447,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 3312,  865,   37, 1505,   32, 2304,  220,   56, 1567,  726,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 1334, 1167,  454,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   89,   37, 2449,  684,   12,  475,    1, 2087,  433,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,    1, 1409,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1844,  938,    1,  361,  649, 2844,   45,  505,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1773,  200, 2340,    9, 2510, 2480,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117, 2208,  155,  365,    8,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,  365,  848, 2501, 1333,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,    1,    1,    1,  936,  356, 1259,  220,  326,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  171, 2861,   32,  917,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  669,   42,  134,   98,  977,   53,   37, 2548,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2700,   37,  506,  166,    1,   45,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,  379,  774, 1583,    1, 1321,    1, 2099,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   26,  189,   12, 1772,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1242,  187,    1,  861, 2762, 2794, 2964, 1159,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3141, 1090, 1829, 1717, 2920,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755, 1536,   43,  444, 2492,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  405, 3291,  884, 1333,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   64,   12,    1,    1, 1030, 2320,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428,  108,   45, 3136,   32, 1853,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  315, 1996,   45,  259,   50,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2227, 3196, 1254,   32, 2620,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3099,   12,  449,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1720,  460, 1494,   37, 2354,    1,    1,  204,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 3131,  509, 3132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1100,    1,    1, 1539,  116,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2154,  567,  666,    1,  584,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  196,   37, 2654,  517, 1085,  279,   98,    1,  361,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,  872,    1,    1,  410,    1,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2672, 1809, 1647,   32,  365,  750,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1712,  193,    1,   45,  166,  183, 1628, 1718,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   58,  737,  156,  388,  763, 1427,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  206,   12,  174,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  610,   37,  537,    9, 2772,  722,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 2170,    1,   37, 1479,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1695,    1, 1639, 2504,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1797,  104,    1, 1536, 2240,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092,    1, 3016, 1935,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  228, 1530,   32,    1, 1325,  434,  778, 1686,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2292, 2134,    1,   32,    1, 1633,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 1431,  155,  572,    1,  356,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1009,    1,    1,  939,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1646,   13,  190,    1,  985,  762,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159,  565,    1,  548,  156, 1306,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1882,  261, 3304,   39,   45, 2846,  512,   12,  389,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2939,  190,  865,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1668,  152, 1704,    1,  333,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1823,  662,    1,  326, 1086,    1,    1, 1713,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  845,  147, 1655,   16, 2621,   45,    1, 2722, 3074, 1215,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   12,   89, 1360,  612, 2000,  247,  389,\n",
      "          627,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 437, 108,  98,   1,  45,   1, 428,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 983, 921,   1, 969, 157,   1,  28,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2103,  617, 1563,    1, 1514,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 2062,  140, 2161,   12,  331, 1674,  671,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37,    1,  302,   37,    1,  233,    1,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 1539,  162,    1,  942,  168,  115,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  422,  562,   12,    1,  349,   45,    1,  369,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284,    1, 1229,    1,   37, 2095,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428,  864,  420, 2827,   28,  187, 2390, 1806,   46,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1918,    1, 2205,    9,  104,   91,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1523, 1158,   82,    1,    4,  297,  247,    1,   45,  105,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3121,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2700,    1,  365,    1, 1463,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1674, 2293,  861, 1004, 1758,  330,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1283, 1449, 2740,    9,  914,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  539, 1401,    1,    1,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  936, 2871, 1465,  220, 1768,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 1699, 1746,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  597,  446,    1, 2936, 1585, 1536,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,  852,   55,  206,    9, 1090,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  116,    1,  125,    1,  361, 2227,    1, 1417,    1, 1417,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  985,    1,  928,  548, 1890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  732,  475,   37,  927, 1118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 2087,    1, 1480,  176,  647,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  291,    1,  777, 2544, 2043,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1102, 2537, 2134,  766, 2871,  480,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3015,    1, 2699,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1966,    8,  420,   98, 1899,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2504, 3105,    1,  548, 2263,  176, 1313,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  270,  321,   52,    1,    1, 1158,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1994, 2819, 2567,  437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,   39,   45,  581, 1463,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  650,  115,   32,  806,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203,  321,  154,   45, 2317, 2308,    1,  548, 2811,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1333,  665,    1, 1594,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1232,  334,  606, 2330, 1931,  600, 1614,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  942, 1249,    1,   32,  593, 1990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3337,    1, 1477, 1990,    1,   37, 1343, 1898, 3154,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,  779,  453, 2215, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   69,  967,    1,   65,   93,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1821, 2190, 2640, 1542,   37,  168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1050,  446,    1, 2205,    1,   10,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1295, 3156,   32,  395, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  326, 2334, 1997,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1585,   27, 3150,   45, 2708,  861,  475,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  442,  448, 1137, 1290,  396,   71,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3240,    1,  600, 3134, 2811,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973, 2773,    1, 2577,  548,    1, 1464, 1463,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2920,    1,  476,   37,  877,   28,  220,  405, 3291,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1408,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  121, 2567,   98,  365, 2273, 3032, 2596,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  953,    1,  166, 2497,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1701,   84,   28,  856,  444,  111, 2086,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708,  379,  774, 3358,   12, 3137,   61,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1505, 2224,  187,   45, 1893,    1, 1190,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2012,  176,  166,  756,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2, 148,  12, 156, 415, 103, 689, 428,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  39,  45, 166,   1, 176, 915,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1815,    1, 2572,    1,   56, 2347,   32, 2774,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3194, 3195, 2871,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  387,  590,    1,  973,    9,  909,   98,\n",
      "          864,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  132,  220,  730, 1571,  515,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3140,  637, 2707, 2183,    1, 3384,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497, 1176, 1371,   37,    1, 2787,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1668,    1, 3083,   32, 1600,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,    1, 1566,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  487, 3397, 1114, 2137, 3099,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3355,   32,  105,    1,  548,  465,   22,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  782,  363, 1569,  176,  415,  166,  917,  199,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,  187, 2101, 1056, 1674, 1833,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  741,    9, 2018, 1065, 1190,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  191,  166,    1,  786, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2347,   32,  245,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1,    1,  259,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1064,  176,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2321,  664,    1,    9,  914,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1, 1178,    1,    1,  162,  105, 1412,    1,  361,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,    1, 1421,   45,  270,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3380,  361, 2885,  907, 1282,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   27,  526,    1, 1487,    1,  185,  245,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1512, 2396,    9,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1778,    1,    1, 2473, 2367, 1828,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1695,    1, 1683,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3099,  476, 1354,    1, 1323,    9, 2551,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2645,  361,  227,    1,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,  697,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1478,  105,  365,  971,  389,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468, 2909, 2535, 3387,  304,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   28, 3332,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  882,  108,   98, 1151,   15,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1931,  297,    1, 1046,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   46,  190,   52, 2133,    1, 1625, 1009,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2225,    1,  629, 2064, 1140,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1021, 2043,    9,  166,    1, 1852,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2946, 1976,   32,  903,    1, 1256,    1,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  246, 1189, 2673,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3382, 1231,   32, 3379, 1606, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  251,  105,    1,  131,    9,    1, 2115,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,  327, 1768,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 3005,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37, 1343,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1070,  398,   37,  899,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,    1, 1821,  210,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  267,  321,  350,    1,    1, 2320, 3162,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3066, 1830,  247, 1462,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  313,    9, 2102,  220, 2441,    1, 1539,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  260,   28,   37,  151, 1092, 1089,  124,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  169,  942,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  961, 1482,   12,    1,  825,  267,   69,  636, 2109, 1278,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2685, 2225,    1,    1,  187,  512,    1,    1,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  469,   54,  170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1, 2686,  801,   37,  449, 1125,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   98, 1978,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3362, 2892,  186,  187, 3349, 2292, 1258,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2836,  686, 3226, 1421, 1056, 2308,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  183, 2525,  176,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  267,  453, 2334,   61,  593,   12, 1254,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3278,    1, 1739,   32,    1,    1,    1,   37, 1672,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  818, 1625,    1,    9,  773,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741, 1660,   28, 2839,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  935,  449, 1821,    1,  920, 1107,   37,  168,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1064,  453, 2866,   98,    1, 2851, 2996,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3238, 3288,    1, 2052,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193,    1,   98,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 1198,   97,   79, 3155,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1325,  861,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    7,    1,    1, 2517,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3069,    1,  121,   37,  907,  297, 3070,   36, 3071,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  168,   37,  166,  806,   98, 1893,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 1917, 2018,  449, 1463,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3059,  103, 2672,    1,  726,    1,  463, 1684,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  430,  919,    1, 1193,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1541,  245,  331,   32,  367,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,   12,   32,  166, 1510,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,   12, 1021,    1,  884,   98, 1361,    1, 1087,  361,  326,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2137,   27, 3339, 2835, 2735,    1, 2006,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  529,  201,  627,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2468,   12,    1,  140, 3129, 1802,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2002, 1068,  568,  614,   28,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  105,    1,    1,    9,   36,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1674,    1, 2965,    1,   39,   45, 1675,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2431, 1439,   45, 2589,   28,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  282,   37,   40,    1, 2706, 1781,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1699,  365, 1675, 2560,    1,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1811,  404, 3355,  577,   98,    1, 3388, 2024, 1896,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1354,  295, 1083,    1,   37,    1,  529,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1309, 1284,   81,   37,  112,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2943,  725, 2654,   98, 1220, 2515,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  536,  800, 1837,    1,   15,  187,  773,    1,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1428,    1,    1, 1094, 1910, 3339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1880,    1,  841,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 200, 469,  37, 470, 448, 261,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  94,  12,  95,  96,  28,  97,  98,  99,  37, 100, 101,   1,   3,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  181,  862,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3245,  614, 1632, 3200, 2305,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  463, 1447,   37,    1, 3107,    1,  176, 3385,    1,  424,  339,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12, 2815,  469,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2343,  776,    1,  191, 2292,   32,  531,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  753,    9, 1764, 1990, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  920,  460,   12,  232,  104,   93,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1110,  168,   98, 1278,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,   85, 1778, 2580,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,    1,  199,  187, 3231,    1, 3232,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  835,    1, 1228,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   15,    1,  689,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  140,    1,   59,   32,   81,  138,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2069, 2162, 1950,   32,  395, 2003, 1585,  972,   37,  759,  232,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,  832,  967, 1851,  105,    1, 1139, 2113,  805,   98,  621,\n",
      "           82,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,  220,    1,   45,    1,    1,    1,   45,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  716,  402,   37,    1,   45,  596, 1793,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,    1, 1200,  494, 2809,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2050, 1424,   32,  215,   31,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  200, 1437,  315,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2170, 1107, 1292, 1489,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1238,    1,    1,  220,  651,  506,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  388, 2181, 2198,  375,    1,  267, 3277,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203,   37,   77,   69,    1,    1, 1706,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2975,  256, 1089,    1, 1108,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1, 1117, 1525, 1013,  669,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 1589,    1,  113,    7,    9,  324,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2414, 1029, 2231,  366, 2282,  927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1924, 1159,  424, 1090,  411,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  980,   63,  646,   29,    1,  303,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  597,    1,   45,  455, 2789,    1, 1061,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  166, 2354,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2107, 1559,  187, 3405, 2725, 2443,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1184,   32,    1, 2355,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  868,  671, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 2575,   18,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  393,  176,  467, 1838,  260,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545, 2479, 1689,  726,    1,  386,   12, 1141, 1348,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  810,   12,  264,   32, 1821,  443,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  842,    1, 2534,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 1841, 1167,    1,   37,  166,  439,    9, 1515, 1178,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1427,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1861,   90, 1016, 2789,  204, 1360,  612,  319,  297,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2615, 1173,   37,  335,  674,   45,    1, 3108,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  700,    1,   37, 3345, 1004,    1, 2151, 1604,   32,  531,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1016,   37,  741,   98,  531, 2129,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  790, 1877,   37, 1124, 1896,   37,    1,  195,  230,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  809, 2595,  565, 1018,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1450, 2856,   32,  403,  404,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 2539,   37,    1,  176,    1,  220, 1918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2921,    1,    1, 2372,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386, 1260,    1, 2570,  787,  750,  167,    1,  105,  628,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  989,   12,  547, 1551,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,    1,  459, 1259,  220, 1652,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1412, 1748, 1992,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1648,  193,   37,    1, 3364,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1545, 2471, 3320,    1,  879, 3158, 1045,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  350,    1,  275, 2683,   37,   52,   53,    9,  331,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612,  458,   98, 1427,    1,  571,  384,  977,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700, 1000, 1389,   45, 3012,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  220, 3262,   84, 1836,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,   12, 3019,    1,  220,  810, 1766, 1767, 2461,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  125,    4,  481,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1419, 2355, 1013, 2549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3016, 1935,    1,  460,   37, 2723, 2724,    1,    1,    1,    1,\n",
      "            1,    1, 1114,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  381, 2609,  604,    1, 1167, 1572,   37,  215,  927,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051,    1,    1,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26, 1039, 2995,  288,    9, 1787,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  776,   45, 1640, 2774,  650,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,  833,  612, 1210, 1658,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1940,   12,    1, 1435,  220,  903,    1,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,  421,  207,  953,   98,  822, 1482,   88,    1,  365, 1788,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  409,   25,  686,  228,  361,  105, 1023, 1034,  340,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1570, 1008,    1, 2296,    1,  929,   45,  166,  721,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  620,  661,    1,   37,  764,    1, 1731,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  520, 1553,  548,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,  355, 1994, 2143,  132,  193,  288,   32,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,    1, 1361,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  870,  176,  612, 2182,   79,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  741, 1457, 1458, 1459,    1,  782,  590,  133,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  387,   86,    1,   15,   28,  419,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,   74,    1, 2675,    1, 1352,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 2813,    9,  166,  460, 3088,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3381,  437, 1550,  420,  460,    1,    1,  777,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1966,    6, 1649,    1,  696,  455,    1,  942,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  833,  612, 2192,   28,   98,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,   12,  442,    1,  407,    1,  118,   32,  871,   98,  310,\n",
      "         1220,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,    1, 1935,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1, 2274,    9,  617,  259,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2509,  384,    1,   98,  166,  915,   65,   67,  423,   45,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  183,  978, 2469, 2405,   37, 2278,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1236,  297,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3048, 2923, 1360,  612,    1, 1114,    9,   56,  537,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  286,  441, 2286,   39,  382,  938,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3354, 1414, 1260, 3384,    1, 2572,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1809, 2012,    9, 2647,  280,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,   12, 1065, 1190,  267,  650,  361,  893,   45, 3384,  437,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1090, 1829, 2307,  176, 1531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1340,    1,    1,  726,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   51, 1031,  465,  218, 1872, 1090,  918,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3257, 1380, 1645,    1, 2072, 1590,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2939,   39,    9,  519, 3182, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3206,    1,  245, 1159,  913, 3206,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  207,    1,    1,  162,   79,  166, 1737,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3272,    1,  176, 1858,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1375,    6,    4,   37, 1154,  152,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3253,    1,   39,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359, 2224,  288,   37, 1947, 3339, 2271,  797,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,    1, 2229, 1054,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1329,  325, 2326,   32,  971,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  294, 1456,  197,  418,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3324,   37, 1343, 2523,   32,    1, 1090,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1771, 1022,    1,  879,    1,   12,   24,    1, 1760,    1, 1343,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  565, 1061,  187, 1711, 1747,   32, 1313,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  310, 2153,  907,   98,  395,  442,    1, 2862,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280,   12,  311, 1463,  614, 1533,  760,  166,  888,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  388,    9,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  176,  105, 1224,  445,    1,  763,    1, 2112,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  458,   45,    1,   37,  151, 2451,  458,    9,    1,  152,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  558,  325,    1,    9,    1,  131,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  121,  469, 3261, 1313,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  641,    1,    1,  476,  388,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1485, 2161, 3340,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,   12,    1,  446,  939,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2786,    1,  630,  220,   20,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1425,  166,  593,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  790, 1579,  105,    1,    1,  195,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 2246, 1902,  696,  166, 3287,  271,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  619,   59,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3384,  650, 2827,   32, 2018,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056, 2572,    1,  583,   32,  645, 1853, 1585,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,    1,  993,   55,  204, 2768,   32,  531,  104, 2221,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  215, 3105,   32,  531,   98,    1, 2699,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  572,  156,   28,  118,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  405,    1,   12,    1,    1,  406,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  871,  754,   15, 1269,    1,  202,  729, 1913, 1637,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2974,  614,    9, 1411,   95,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  879,    1,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  700,  514,   45,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2308,  899,  477,  444, 3302,  791,  261,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  447,    1,   45,  365, 2915,    9,  949,   45, 3365,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1971, 2222,  619, 3217,   37,   77,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  437, 1082, 3128,  443, 2938,  927,   32,  602,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3092,   37, 1281,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1024, 1581,  105, 1263,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 3006,  774,   37,  429,   46,   98, 1428, 3365,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  119,   68,   69,  102,   71,    9, 1913,   74,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,   81,   37,  166,  627,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2562, 3358,   12, 1983, 2078,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2104,    1,  977,    9,  626,  861,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  271, 2174,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2217,   12, 1277,    1, 2167,    1,   61, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1431,  315,   37,  259,  460,   32,   98,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2692,    1, 1225, 2960,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1309, 2591,   37,    1,  170,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,  698, 1680,    1,  220,  105,  845,  275,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   74, 2246,    1, 1550,  395, 1913, 1805, 2872,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2527,  164,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3144,  580, 1066,    1,    1,    1,  964,    1,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3365, 1046, 2162,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  25,  71,  98,   1, 479, 420,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,  396, 1876,   45,  647,  253,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1255,  297,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3372,   37,    1, 2038,   98,   86,    1,    1,    1,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,  288,   37,   26,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  774,    1,    1,   37,    1, 1314, 2225,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  361, 1790,   37,   92, 1013, 2549,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1940,   12, 3282, 3204, 1426, 2490,   26, 3179,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1361,  744,   98,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1142,  884, 1734,   32, 2733,  776,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  900,  475, 1544, 1483,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  647,  148,   12,  693,   61,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   45,  365, 1788,  737,  197,  418,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2913,   37,  168,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  430,  147,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  636, 1042,   37,  680, 1146,  106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1591, 1666,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2956,  765,   37,  221, 2863,   43,   37, 2197,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1101, 2817, 1950,    1,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  975,  197,  388,  763, 1660,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   37,  973,    9,  388,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  785,  786, 3298,  850, 2017,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,  680, 1665,  384,  861,  328,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  187, 1487, 2236,  315,   37,  930,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652, 1419,  365, 1718, 1499, 2549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  547,  487, 3105, 1413, 3381, 2416,  437,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311,  794,    1,   45, 2309, 1708, 3011,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  131,  141,   48,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  231,  166, 2869, 1089, 1863,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  342,  108,   45, 1534,  444,    1,  104,    1, 1859,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  524,    1,  733,  124,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3005,    1, 1632, 1106,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  176,  551,  612,  353,    1,  372,  354,   98,    1,    1,\n",
      "          389,    6,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   52,    1,    9, 2081,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3334,    1,  105,    1,   32,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  328, 1471,  716,  720,   32,  207,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,  361, 1361,    1,  875, 2255,  149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3270, 2783,    1, 1684,  220,  667,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  168, 1515, 2267, 1262,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  558,  251,   54,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984,  782, 1056,  365,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3012,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 1009, 1877,   37,    1, 2028, 2471,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  715,  957,    1,  191,    1,   12,    1,   98,   93,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671, 1078,    1,  142,  125,  191,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 3123,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3134,  163,    1,   12,    1, 1940, 3055,  608,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1459, 1702, 1994, 2834,  469,  548, 2596, 1260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1570,  200, 2474,  259, 1455, 1294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  657, 2808,   98,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  948,  998,   45,    1,    1,   27,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1800,  487,    1,   37, 1994, 1718,  117,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  596, 1732,   15, 2011,  119,   32, 2073,  401,  496,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1414, 1000, 1056,  388, 2496,   27, 3383, 3384,  437,  396,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1956,    1,    1, 3184, 1281,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3365, 2572,   32,  531,    1, 1928,   30,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  903, 1447,  267, 2960, 1924,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2355, 1013, 2549, 1680,  166,    1,    1,  267,  829,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1676,    1, 1231,  297,    1,  229, 1463,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  675,  572,  207,   28,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1701, 1539,  822, 2731,  444,  111,  668, 2852,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1022, 2350,    1, 1017,   98,  105, 1194, 2350,  673,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3103, 1496,  365, 2036,    1,  384,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  931,    1,  415, 2745,   37,   52,   98, 2498,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1625,   37, 1594, 3068,   12, 2056, 1239,  116,  259,\n",
      "         1108,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,  778,  884, 1003,  176, 2108, 2107,   45,  559,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2843, 2523,    1,    1, 2876,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 1778, 2232, 2762,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  590,  916,   45, 2330,  411,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  515, 3019, 1151,  260,  105,  613, 1901,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  447, 2192, 1198,   37,  342,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 1361,   37,  943,  600, 2532,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1778, 2580,  861,  328, 1961,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1, 2018, 2153,    1,  365, 2240,   32, 2471,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  709, 2882, 3096, 3164,    1,  928,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   93,   32,  957,    1, 1604,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   42,  453,  449, 2194,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1701,   81,  766,   12, 3016, 1935,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403, 1447,  894, 2446,    1,  361,  865,   37,    1, 2601,  104,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  622,  459,  132,   37, 1835, 1994,    1,    1,  963, 2122,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,  191, 1081,   12,    1,    1, 2116,   27,  439,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,  631, 2466,  233, 1708, 2104,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230,    1, 3001,   37,  631,  104,  444, 2062,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2500,    1,  166,    7,    9,  365, 2977, 1831,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2912,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  295,  439,   54,   32,  730,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3290,    1,    1,  683,    1, 3288,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  166,  645, 2566,  176,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  524,  525,   15, 1121,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  592,    1,   37,  498,   98,  734,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2800, 2565,  459,  881,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 2416,    1,    1, 2024,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2415, 2620,    1,   39, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,  251,   37,  109,    1,   37, 2531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3335, 1851,  105,  726,  190,  544,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,  688,  614,   98,   32,  365, 2741,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  977,    1,    1,  875,  134,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2800, 2741, 1917, 2839,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3172,  991,    1,    1,    1,  316,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,    1, 1034, 1315, 1146,  106,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3244,    1, 1568, 1045, 1159, 1531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612, 1470, 1167, 1521,    1,  460,   51,  606,    1, 2690,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   37,    1,  138,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  515,  854,  590,    1, 2788,   32,    1,   32, 1033,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700, 1864, 2859, 2955,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3003, 1536, 1107, 2039,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2214,    1,    1, 2289,  321,  907, 1922,  439,   32,  166,    1,\n",
      "           45,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1850,    1,  442, 1281, 1946,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2239,    1,   32,  298,   45, 3012,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 3005,    1, 2997, 2762,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 2414,  176,  177, 1700,   32, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1789, 1229,   37,    1,    1, 1867,   32,   12,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  100,   45,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1676,    1,  319, 1675,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092, 1236, 1662, 2633,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  531,  877,  408,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1450, 2856,   32, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1758, 2029, 3346, 1884, 3279,   32, 2646,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,  716,  118,   71,   32,  572,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  640,  187,  109,  509,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1333,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  275,   25,  439,  242,    1,   69,  102, 1473,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2924,    1, 2764, 2765,  893,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  294,   32, 1640,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1880,  325,  163,    1,   12,    1,   14,  458,    1, 1680,  158,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,   37, 1911,    1,    1,  176,    4,   29,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,  790,  475,  686,   98,  735,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2804,   45, 2772, 2566,    1,    1,    1,    1, 1103,  176,    1,\n",
      "         2322,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1980,   37,    1, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3126,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1173,   37,    1,    1,  384, 2242,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   12,  302, 1712,  162, 2048,   45, 2819,  499,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  961, 1938, 1723,  839,  523,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  664,  581,   73,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  434,    1,    9, 1610,  405,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  405,  260, 1822, 1496, 3188,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3403, 2414,   32, 1260,   98, 1147,  947,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,  315, 2355, 1013, 2549,    9, 1158, 2261,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1, 2211, 1008,    1,   82,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  992,   28, 1450,   98,  531, 3045,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2442, 1663,   22,  847,  353,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1569,    1, 2983, 1724,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181, 2373,    1,   45,  593,   12,  449,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  395, 1484,    9,   91,   37, 1198, 2108, 3368,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1840,    1,   37,  151,   39, 1300,  253,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1128,    1,  829,  877,  105, 2432, 1259,    9, 2168,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3163, 3273, 1077,   37,   77,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  449, 2547,    1,  297, 1645,  625,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,  548,  531,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1233,    1,  331,  479, 1527,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343,  162, 2162, 1780,    9, 1887,   56,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,    1, 1827,  803,  615,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  584, 1140, 3327,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1691, 2193,    1,   42,   32,   37,  581,  100,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3384, 2572,   32, 3339,  477,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2408,    1,  297,  463,  464,    1,  176,  409, 1606, 1554,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   28,  995,   98,  198,  996,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1247,    1, 2807, 1844,  191, 3227,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496,    1,  603,   37, 1012,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1948,    1,  588,    1,  932,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,  172,    1,   37,   52, 1961,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  596,  616, 1986,  919,   25,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  810,    1,    1,    1,   45, 2181,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361, 3096, 1173,   37, 1092,   37,   92,    1,   32,  104,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1818,  147,   37,  231, 1842,  116,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2090,   12,    1,    1,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640, 1434,  119,  176, 1548,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  898, 2558,   32, 1778, 2580, 2851,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043, 1993,   85,  191,  123,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2658,   39,   45, 2589,  220, 1580,    1,  267, 3124,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1592, 1248, 1032,  522,  444,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  531, 2577,  449,  317,  443,    1, 1495,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1896, 2644,   37, 1746, 3340,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  352,  353,  354,   98,    1,   44,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363, 1401,   44,   32,  517, 2731,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,    1, 2768,  166,  389,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  488,   37,    1, 1428, 3118, 2824,  386,  497,   88,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1304,  213,   37,  138,   59,   37,  875,  133,  549,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  234,    1,  235,    1,  234,    1,  235,    1, 1154,  116,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2999,  877, 2518,  193, 2819,  515,  916,    9, 2966,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,  183, 1107,    1, 1421,   28,    9,    1,  805,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1452,    1,    1,    1,  525,   12, 2069,  333,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2448,  386, 1625,   37, 2204,    1, 3320,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  743,   12, 1690,  525,   15,   71,    1,  419,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1461, 2414, 3374,  650,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   32,  870, 1051,  835,    1,    1,  675, 3004,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938, 1075,  891,  453, 1183,    1,  403,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3161,  750,    1, 1787,   45, 1739,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3108,  877,  460,   73,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1235,  102,    1,   28,    1,  118,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,    1,    1, 2997, 2762,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2708, 1572, 3393, 2137,    1, 2835,  267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,  682,    9,    1, 3000,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 1473, 2222, 1086,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303,    1,  805,   45,    1,   69,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2615,  726, 2764,  404, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386, 1542,   37,  125,  388,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1627,  166, 2355, 1013, 1681,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  792,  829,   12,    1,    1,  255, 1718, 1560,    1,   74,\n",
      "            1,  792,  267,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,   12,  365,    1,   98, 1718,  313,   37, 1140, 2031,   12,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  200,  365, 1234, 2177,  988,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1417,    1, 1831, 2182,   79,  384,    1, 3380,  297,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2001,   98, 2371, 1402,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  374,  375,   11,    1,    9,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,  138, 1652,   59,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   98, 1965,    1,  590, 1204, 1724,    1,  202,    1,  978,    1,\n",
      "           45, 2162,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 3029, 3027,  571,   37, 3024,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  755,  765,  760,    1,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,   45, 1789,  249, 1313,  104, 2108,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3310,    1,  405, 3291, 1246,  289,   45,  365, 3141,  914,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   36, 1680,    1,  191,  707,  111,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1861,  261,   39,  531,    1, 2162, 1950,  927,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3256, 3261,    1, 1984,   37,    1,    1,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1043,   28,  297,  118,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 1458,    1,    1,    1,  778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   42,  220,  492, 2173,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1173,    1,   12, 1568,  365,    1, 1234, 1863,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1077,   37,   77, 1345,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 2317,    9, 1890,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  698,   28,  852,   37,  764,  681,    1,   39, 1515, 1117,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  173,   45,  403, 2288, 3001,  276,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  539, 2198, 3332,    1, 1492,   12, 1509,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2279, 1224,    1,   37, 1948,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1046, 3169,   32, 3179,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  132,   37,    1,  293,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3100, 1293, 3158,  220,  726,  297,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  566,  999, 2690, 1967,    9, 3018,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  294,  396,    1, 2545,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,    1,    9,  166,  116,  823,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3221, 2865,   39, 2689, 1717,    1,  247,  454,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3114,  709,    1,  582,   37,   12,    1, 2170,    9,   46,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977,   61,  330,   98,  105,    1,  686,  220,  105,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    5,    1,    9,  754, 2261,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 579, 460, 884,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 224,   1,   9, 301,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3334,  603,   37,    1,  166,  608,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  418,   37,  119,  187,  395,   12,   93,   76,   37,   92,\n",
      "         1220,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1384,  200,    5,  125, 1563,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  814,  353,  354,   32,  401,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1147,  446,   51,    1,    1,   37,  691,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,    1,   10,   12,  443, 1513,    1,  267, 1875, 2535,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  584,  972,   37,  619,  686, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3180, 3055, 1750,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   22,  365, 2036,  225,    1,    1,   35,  695,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,   37,  349,  649,   98,  260, 1885,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1,    1,    1, 1201,    1,   82,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,  418, 2131,   93,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  547,  332,    1,    1,  631,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1144,  267,  365, 1273,   29,  841,   37, 1539,   32, 1332,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3111,    1,  187,    1,  475, 2414,  885,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,    1,  321,  334,    1,    1,  517,    1, 1821,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  544, 1658,    1,   98,  315,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1306,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,  996, 2401, 1071,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2486,  921,  903,    1, 1417,    1,  105,  612,    1,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   28,   98,  156,    1,   29,   69,  246,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2751, 1211, 3365,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  147,  958, 3401,   12, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  952,  977,    9, 2883,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  292,  453,    1, 2436,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3286,  794, 2882,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  102,    1,   28, 2007,   37, 1538,  477,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  967, 1938,  223,  315,  284,  565,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  275,    1,  876,  321,    1, 2103,  166, 2650,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,    1,  150,  777,  778,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  462,  744,   28,  365,    1,  669,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  780,   96,   98,    1, 1901,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051,  583,   98,  509,  600, 2054,   12,  471,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1, 1100,  846,  769,  191,    1, 2670,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3111,    1,    1,  317,   32, 3155,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,  140,    1,  182,    1, 1250,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1147,    1, 1065, 1190,  513,    9, 1527,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,   98,  303, 2001,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  815,  111,  378,  187,  840,  402,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1256,    1, 1751,   39, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1161, 1279,  640,  339,  340,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2740,    9,  166,  356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   14,   15,   85,  442,  910,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1156,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  176,  551,  612,  872,    9,  160,   80,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   94,  654,  566,  152,    1,   45, 2095, 1039,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 3301,   12, 2667,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1654,  388, 1737,    1,  640,    1,  340,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,  256, 2238, 1021,   37, 2255,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3001,  639, 1297,    1,   79, 2904,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2440,  548,  851, 2596, 2716,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,    1,  180,   37, 1155,   98,  613, 1565,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  715,  112, 1161,  831,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  845, 2393,  548,    1, 2137,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  634,    1,    1,  534,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  326,  132,    9, 1766, 1767, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  275,  389,    6,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1492,   12,  166, 1178,    1,    1,    1, 2523,  332,  631,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,   45,    1, 3240,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1747,  845,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1457,    1, 1464,  183, 1463,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3328,  386, 2800, 1218,   81,   32,    9, 3177,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1701, 1936, 2621,   32,  856,    9, 1351,   37,  166, 1935,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614, 1173,   37,    1,  166, 2769,  220, 1090,  726,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1085, 1564, 2133, 1126,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2953,    1, 1634,   37,    1,  361,  985, 2205,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2226,    1,  331,    1, 2227,    1, 1070,  395,   37, 1211,  453,\n",
      "            1,  384,   60,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196, 1625,   37,    1, 1402, 1160,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3260,    1, 1159,  332,   45, 1264,  841,  631,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  321,  612, 2155,  105,  271,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1228,  633,  325,  633, 1228,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,    1,    1, 1976,  403,   45, 2597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2700, 2286,   37,  815, 3012,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649,  446,    1, 1096,    9,    1,  347,   37,  316,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2037,  885,    1, 1090,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2406,  162,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3167, 3271,    1, 3117, 1066, 1427,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  865,   37,    1,  754,  548,    1,  537,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  506,  845,  275,  681,    1,    9,  111, 1889,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  213,   37, 1121,   12, 1447,  489,   39,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  242,  187,  510,  640,  163,    1,   12,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1459,  396, 1918,   32, 1743,   98,  247,  804,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  315,   37, 1776,  365,  535,  656,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1188, 1513,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,   71,  530,  104,  187,  889,    1,   37, 1594,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2551,  726,   98, 2041, 1114,    1, 2148, 1110,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 331,   1,  85, 374,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 105, 803,   1,  45, 105, 669,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1, 2806, 2041, 2655,   37,  726,    9, 3318,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2445, 2576, 1856,   45,    1, 2423,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2628, 2696,  476,   37,   77,    1,    1, 2692,   39,   45, 2332,\n",
      "          637,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2615,  606, 1846,  176,  754,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1481,  315,    1, 2968,   36,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2013,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  297,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3304,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2018,   37, 1694,  846, 2422,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299, 1086,    1,   98,  657,  788,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  241, 2842,   45, 2292,   32, 2597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1026,    1, 2965,    1,    8,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  942, 1586, 1690,  312,    1,  187, 1930,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974, 1602, 1539,   61,   98,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  779, 3044, 2168,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  934,   30, 1677,    9,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3172,  140,  917,   37, 2010,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 3223,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   22,  942,    1, 1048,    1,   12,  467,  469,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,  170,    1,    1, 1064, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  983,   28,   32,  401,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  601, 1585,   32, 2074,  640, 2755, 2490,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2226, 2768,  460,    1,  337,  544,  460, 1114,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1171,    1, 3043,   45,    1, 2702,  298,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 2741, 1045, 1086,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2393,    1,  750, 1408,  501,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    7,    1,   32,  166, 3118,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1108,    1,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1625,   98, 1283,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  590,   37,  388,  987,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 3160,  610,   37,   74,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2899, 2790,  200,  111, 1107, 1017,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,  104, 2494,  872,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 2453,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,  730, 2614,  565,    1, 1123,   12,    1, 1463,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2327, 1477, 1990,    1,  445,  202,    1, 1298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   69, 1086, 1270,   85,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303, 1082, 1173,  176, 2183,  362,  408,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  527,    6,    1,    1, 1564,  152,  745,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2162, 1950,    1,  317,  443,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  558,   37,  151,    1,    9,    1,  131,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 2170,   32, 2095,  856,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1, 1368,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2328,  794,  220,  163,    1,   12,    1,  861,  853,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3307, 1910, 3326,  220,  590,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1766, 1767, 1351,  653,  845,  846,    1,    1,    9,  920,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 140, 449,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 455, 147, 991, 454,   9,   1, 458, 132,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1433, 1444, 1343,  166, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1542,   37, 1413, 3182,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  202,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  592, 1579, 1527,    9,  531,    1, 1702,    9,  734,  591,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1671,    1,    1,    1,  947,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  335,  105,  581, 1173,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,  200,  593,   12,    1,  826,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  168, 1300,   98, 1916,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  565,  410,   98,  303,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,   29,   30, 1424,   32,   94, 2060,   93,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  168,   37, 2447,    9,  166, 2561,  548,  354,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,   98,    1,  934,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1557,  186,   32, 3144,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1009,   10,  313,   37, 1911,    1,   98,\n",
      "          232, 2237,   37,  942,  963, 2122,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   64, 2162, 1950,  418,   37,   32, 3349,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2617, 2072, 2008,    1,  888,   61,  920,    1,  112,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766,  844,    1,   39,    1,  300,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   47,   79,  453, 1050,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  419,  720,   32,  156,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094,  140,  449, 1674,  671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,    1,  220, 2789, 1322,    1,    1, 1016, 1159, 1386,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  670,   32, 1220,  376,  102,    9,    1,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1257,  960, 1086,  152,   46,  220,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  378,  877,  181,    1,   32, 1708,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   12, 1888,  315, 1046,    1, 1457,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1712,  951,    1,    4,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2335, 3052, 2249,    1,  176,  177,  786, 1530,  548, 2835, 2137,\n",
      "          632,    1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2496,   45, 1056,    1, 1976,  463,   45, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613, 1614,  166, 1615, 2474,  259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1, 1343,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1320,   32, 1081,  313,   37,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1796, 3145,   37, 1211, 3102, 1625,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2672,    1, 2740,    9,  166,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  920,  105,  837,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2789,  110,   37, 1504, 1827,    1, 2746,    1,  267,  274,\n",
      "         1178,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  233, 1392,    1,   98, 2931,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  865, 2070, 1971,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  297,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  251,  138,  187,  334,  168, 2359, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 2151,    1,   98, 1106,    1, 1626,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  872,   37, 1013,    9, 2126,   45,    1, 2548,   32,  403,\n",
      "         1447,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1100, 1774,   39,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1441, 3014,    9, 1718,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 2858, 2665,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018, 1862,  495,  570,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1091,    1,  163,    1,   12,    1,  469,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,    1,   26, 1039,  777, 2995,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,   28,   79,  119,  340,    1,   25,  526,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2398,   37,  877,  334,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,  612,    1,    1, 1101, 1102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1848,  494,  168,   37,  611,    9,    1,  636, 1336,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  742,  967, 2966,   98, 1178, 1179,  721,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2945,  725,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3378,    1,    1,   45, 1786,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700, 1413, 3134, 2158,   45, 2121,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  388,  861, 1450,    1,  191,    1,    1, 2425,  716,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386, 1426, 1845,  132,  220,  359,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  888,   32,  525,  548, 1479,  195,  480,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    6,    1,  156,  570,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2708,  650, 3358,  928,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1183, 2113, 2135,  286,    1,  453,  248,  288,   45,  762,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3213,    1,  219,   97,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2948, 2663,    1,   51,   52, 2742,   45,  810,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1674, 2965,    1,  729,    1,  384, 2693,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2887, 1523,   32, 1081,   12,    1, 2414, 1700, 1791, 2751,  622,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1123,  154,    1,  562, 3251,  221,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3373, 1976,   32,  632,  298,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3051, 1386,    1, 1542,   37, 1421, 3118,  802, 1190,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783, 1586, 1577,  187,  453,    1, 1872, 1873,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1547,   79,  687,  951,   60,  187,   69,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826,    1,    1,    1, 1542,    9, 2196,  331, 3179,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  195,  105,  985, 1260,  629,    1,  506,  782,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187, 2476,    1,  600, 1756,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  306,  765, 1159,  395,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102, 1269, 1750,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1353, 2285,   45, 1039, 2690,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  515, 3089, 3078,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  166,    1, 1277,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299,  908, 2703,    4,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  459,   45,    1,  187,    1, 2018, 1726,  907,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790, 1249,  308,   98,  198,    1,   93,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 1464,   37, 1403, 1428, 1159,  864, 2673,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,   45, 2837, 1313,  443,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  761,  267,    1,    1,  985, 2298, 1634,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1427,  632,   22,  139,  105, 2416,  100,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1084,    1, 1021,    1,    1,    1,  774,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  708,  709,  355,  710,  187,  365,   82,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777, 1635, 1361,   12,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2573,   51,    1, 2527,  164,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  463,  464,   69,  669,  929,  580,  822,  522,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1022, 1023,  207,  197,  640,    1,  182,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3235, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2264,  565,  166, 1509, 1876,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2789, 1401,   32, 3097,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    7,    1,    9, 3361,    1,   66,  187,    1,    1,  920,  105,\n",
      "         3102,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1245,    1, 1834,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  582,   45,  395,   69,  624,    1,  812,  934, 1539,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,  69, 953,   1, 202, 729,   1, 530,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 105, 276,  32,  69, 102, 902, 105, 857, 186,  32, 332, 102,   3,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2329,    9,  674,   45, 2115,  633,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3332,  187, 1245,  686,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  864, 1707,  342, 2673, 2362,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  289, 1086,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  726,    1,  664,    1,   61,  590,  789,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713, 2087, 2614,  187, 2565,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2076,    1,    1,  861,    1,  613,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1794,  315,   37,  151,  377, 2373,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1097, 2960, 2414,  249,   32, 2490,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964, 1458,   10,   32,  104, 1002,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 3160, 1156,    9,    1, 1147,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  743,   12,  862,  992,   85, 2007,   37,  505,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1070, 1749,   37,  335,  138,  125,    1,  249,  774,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1229,    1,   98,  104,  841,  285,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2906, 1042,  166,  873,   32,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  890,   32,  531,  190,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2881,  590,  454, 1158,  190,  726, 1412,  535,  443,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102, 1124,  548,  107, 1650,    1, 1069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2631,  548, 2804,   12, 2162,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181,  618,    1,  982,   12,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2924, 2856, 2751,   32, 1815,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1029, 1489, 1578,   45, 2823,  480,  741, 1457,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2162, 1075,  994,    1,  150,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  267,  864, 2390, 1806,  693,  105,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1170,  307,  237,   12,  837,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1319,   30, 1021,  187,    1,    1, 1320,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,  387, 1884, 1429,   32,  208,   32,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2623,  176,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,   37,  927, 1232, 1583, 2891, 1924, 2747,  389,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273,  681, 1421, 2080,  517,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,    1, 1492,    1,   79,    1,    5,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  338,   98,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3290,   84,   28,   37, 1602, 2539, 1787,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2306,  288,    9,  854,    1,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  852,   37,    1, 1085,    9,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1035,  159, 1758,   98,    1,  214,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1713, 1414,  220,    1,  485,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715,  217,   37,    1,  171, 1527,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  108,  297, 3144, 1803,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2658, 1040,  696,    1, 2116,  166, 1251,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1234, 2790,  108,  275,    1,    1, 3049,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1178,    1, 2332,   37, 2162,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1, 2226,    1,  517,    1,  213,   37,  183, 1197,   32,\n",
      "          163,    1,   12,    1, 1655,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1317,  704,  104,  353, 1455,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213,  992,   98,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,  884,  104,   37,  397, 1969,  221,   98,  296, 1527,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  798,  444, 2013, 1176, 2353,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3101, 2924, 2856,   32, 3339, 2649, 2791,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1013, 1522,    1, 1381,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  204,  190,  193,  588,    1,   45,  365,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,   76,   37,  670,  176, 2410,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,  708,    1,   82,    1,  187,  365, 1943, 2541,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 1918,   32,  584,  191,    1,  384,    1, 1438,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1203,   32,    1,    1, 1871,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585, 2414, 1178,  176, 3149,    1, 2190,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,   81,   37,  166,  627,    9, 3281,  361,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  877,  460,  232,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2547,    1,   37, 1911,  166,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2779,    1, 3168, 2365, 2337, 3173, 1141,  176,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,  190,  193,   81,  864,  443,    1,  267, 3355,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  965,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1660, 1208,   45,  803, 1505,    1, 1102,  931,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2686,    1, 2669,  388, 2776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 3055, 1461,  469,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  631,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835, 3109, 2985,   32,    1, 3389,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 818, 834, 914, 773, 606, 786, 915, 916,  37, 619, 460, 917, 918,\n",
      "           1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 942, 140, 856, 220, 104,  98,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2120, 3001,    1,  682, 2033,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  885, 1912,  170,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1494,   39,  444,  342,  768,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 1572,  132,    9,  849,  288,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   79,    1,  626,  159,   85,    1,   69,  338,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187,    1,  588, 1515,  248, 2024,    1, 2924,  565,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,  365,  845,  187, 2046,  477,  640,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1699,    1,    1, 2094,   39, 1658,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  282, 2367, 2695,    1,   45,  166, 1034,   52,  105,   16,   79,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2476,  332, 2376, 2223,    9,    1, 1199,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1068, 1069,    1,   32, 1352,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1345,   37,   77,    1, 2819,   32,  105, 1247,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 166,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  32, 449, 913,  32,   1, 463, 428,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  305,  102,    1,  670,  548,  925,   65,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  557,  540, 1557,    1,    1,  443,  997, 1192,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,   12,  103, 3382,  140,  630,  384, 2774,  361,  957,    9,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  331,  463, 3165,    1,   32, 2809,  361, 2819,  126,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  782,  454, 1159, 2708,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3253,    1,    1,  489,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1128, 3044, 2232, 1017,  696,    1, 1865,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,  295,  420,    1,  331,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1017,  384, 1100,  361,  326,   34, 1151, 1998,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  163,    1,   12,    1,    1,  977,  661,  602,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2596, 1665,    1,    1,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 2924, 3395,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  761, 1500,  304,   98,    1,    1,  629,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   63,  166,  862,    1,  338,    1, 1176,  418,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1958,    1,    9, 3228,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868, 1301, 2646, 2024,  630,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  162,  166, 1488,   45,  902,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2850,   85,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,  839,  829,  199,  421,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2238,   12,    1,  705,    9,  618,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,    1,    1,  901,   32, 1260,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2386,  163,    1,  903,    1,   45,    1,\n",
      "            1,  297,    1,   88,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056,  514,   32,  449,    1, 2819,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1693,    1,  365,  844,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2930,   44,  444, 3141, 1292, 3311, 3310, 2917,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  697,   37,  335,  104,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  121, 2682,  539,    9, 1427, 2461,   98, 3070,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  443,    1, 1964,  361, 2141,    1, 1023,   45,  593,   12, 1763,\n",
      "           37, 1673,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2472, 1578,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3185,    1, 2849,  297, 2826, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1970,   12, 1283, 2600,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  326,    1,  612,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  375,   37, 1753,    1,  297, 3185,  396,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,  288,   37,    1,  365, 2480,  772, 1294,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  915,   45,    1, 1691, 2681,    1,  622,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3297,    1,    1,    1, 2260,    9,  590,    1,   32,  428, 1002,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1005, 2942,  105, 2312,    1,    1,    1,  449,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,  353,  197,    1,    1,    1, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3354,  861, 1414, 1211,  649, 3365,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1432, 3207,   12, 3126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  743,   12,  244,   32,  260,  220,  308,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2158, 2740,    9,  914,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  693, 1211,    1,  548,  402,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2288, 1031,    1,   98,  103,   45,  166,  593,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,   64, 2334,  922,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  200, 1273, 1013,    1,  224, 1246,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3324, 1408,    1, 2318,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715, 2161, 2428, 2701,  671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,  129,  975, 1707,    1,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,   12, 2452,   61,  590, 1400,    1, 1607,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  793, 1149, 1937, 1515,  861,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3140,    1, 1430, 1724,   37,    1, 1428, 1004,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  657, 2424,  297,  968,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  773,   66,    1, 1595, 1332,    1,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,    1,  213,   37, 1198, 3368,   98,  976,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  435,  864, 2673,  630,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  275, 1565,    1,  720,   32,   69,  102, 2200,  236,  237,  186,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  851, 2421, 1159,    1,    1,    1, 1887,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2719,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1, 3101,  539,  458,  754,  469,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  218,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1187,    1,  361,  162, 2523,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,  496, 2483,  777, 2129,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3198, 1564,  411, 2022,  176,  163,    1,   12,    1,   26,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,   37, 1463,    9,  683,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596,  640,  531, 1386,    1,    1,  356,  548, 2343, 2555,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2732,   37,  843, 1211,  207,  412,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1851,  753,    9,  593,  238,  109,    1,  267, 2468,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018, 2950, 2134, 1281,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1628,   22,  361,  238,    1,  361,  105,    1,    1,   32,  395,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2912,  483,  894,   52,  686,  191, 3141,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2050,   98,  166, 1821, 2190,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  437,  396,    1,    9,   22, 2421,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1059, 2617,  388, 1876, 1460,   37,  223,  652,    1, 1906,  582,\n",
      "          267,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3270,  810,    1,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  430, 2363, 1267,  187,   69,  239,  661,  365, 1653,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1773,  155,  207,  197,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096, 1366, 1445,  590,  874,   45,    1,    1,  531, 2565,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  766,  140, 3016, 1935, 1876,  384,   32, 1092,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  630,   98,  531,  734,  591,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1, 2083,    1,  220, 2255,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147, 2617,    1, 1899,    9,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   98,  129, 1267,    1,    1,  361, 1678, 1844,  297,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   64,   30, 3349,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777, 2264, 1648,   37, 2432,  220, 2980,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  730,  841, 1377, 2443,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  411,  218,  459,    1, 1894,    9,  698,   45,  601,  172,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  631, 2024, 2699,   37,    1,  531,  787,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  220,  247,  248,    1,    1, 3358,    1,  612, 2654,  247,\n",
      "          249,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   64, 2405,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1542,  357,  193,  361,    1,  193,    1,  620, 2208,  614,  129,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2563,   16,  284,    1,  914, 2489,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  453,  315,    9, 3018,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  876,  612,  288,   37,  877,   69,    1,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  562,  548,    1,  873,   79, 3265,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3305,    1, 1973,    9, 3239,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,   82,  387,  590, 1188,   37, 1413,  535,  170,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  773, 1332,    1, 1690,  525,   15,   71,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428, 3369,  967,    1,   37,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  775,    1,  195,  776,  777,  778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2468,  267,  915,   69,    1,   39,   45,    1,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,    1, 3009,   32, 2507, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  315,  342, 1437,   45, 2102, 1411,  339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,   29,    1, 1965, 1204, 1534,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  700,  852,   37,  130,    1,   12,  103,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3238,    1,    9, 1090,  220,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,   12,  818,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1230,    1, 1993, 1750,  225,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,    9, 1786,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  815,    1,   37,  477, 2095,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1234, 1863,  565,    1,  202,  105,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  764,    1,    1,   45,  166,  193,  320,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403, 1447, 1004, 1031,   32,  104, 1563,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2275, 1708,    1,  987,   98,  777,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1741,    1,  275,  162,  183,  916,  220,  590,    1, 3190,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051,  108,   45, 2558,   32,    1, 1607,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105, 1292,    1, 1021,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3277,  256,    1,   37, 3092,  686, 1638,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3364,  288,   37,  726, 2708,  741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1132,   37,  130,    1,   48,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  146,    9,  671,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  798,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2537,  220,    1,  365, 2699, 1710,  927,    1,    1, 1821,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  340,  104,    1,   45,   68,  529,  636,  423,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    4,   29, 2192,   65,  501, 1125,    9,   86,   67,  423,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1127, 2239,  453, 1140, 2363, 1074,   37,   80,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2015,   61, 1881,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 1684,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,  548,  186,   98,   65,  943,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2688, 2572,   32,  531,   12,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447, 1665,  297,  909,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  886,    1,  325,  104,  275,  700,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1796, 1866,    1,  187,    1,    1, 1884, 1950,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3121,    1, 2682,  403,  455,    1, 2162, 1950,  640,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  439,   37,    1,  339,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3330,    1,    1,  912,    9, 1211,  639,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3142,    1,    1, 1857,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  839, 1486,    5,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  204,   12,    1, 1997,  686,   98,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  179,  156,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200,    1, 2948,  210,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  312,  821,  456, 1325,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1,  193,    1,   37, 2163,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051,    1,   39,   59,  225,  809,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3075, 1310,   37,    1,    1, 2471,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   77, 1658,  661,   98,    1,    1, 1879,    1,   12, 1133,   37,\n",
      "            1,   39,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1, 2334, 2545,    9,  163,    1,   12,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1363, 1660,    1,  158,    1,  879,  151,   81,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  354, 1052,  983,  417,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3144, 3372, 2591,    9,    1,    1, 1064,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 1832,    9,  166,  631,  176,  572,   36,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2, 702,  37, 151, 169,  32,   1, 131, 132,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 342,   6, 346,  93, 570,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  492,  147,  556,    1, 2774, 2251,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2640, 1542,    9, 1821, 2190, 2699,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1995,   32,    1, 2614,    1, 3175,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  619, 2588, 2632,    1,  619,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  241, 2817, 2856,  176,  177,   32,  166, 2140,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  987,    1, 2010,  288,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2984,  839, 2662,   12, 2918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  396,  590,    1,   32, 1887,   45,    1,   32,  531,    1,\n",
      "         2198,    1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26, 1039, 1659,    1,  600,  829,   12, 3042,  161, 2234, 2973,\n",
      "         1764,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  199, 1270,   28,    9,  531, 2024,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  769,  764,  185, 1180,  242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,  140,    1,    1,   29,  246,   98, 1547,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796, 3102,  898, 2572,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  811,    1, 1861,  753,   37,  665, 1628, 2725, 2072, 2588,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  252,  730,    1, 2408,   51,    1,  742,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1542,   37, 1539, 1013, 1522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2584, 2290, 3259,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1940, 2192, 1186, 1011,    9, 2112,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,   66,    1,  365, 1766, 1767,  769,  424, 1034,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3297,    1,   98,  422, 3154, 1569,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   13, 1536, 2240,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,   51,  771, 2161,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,   16,   45,    1,    1,  384,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1009,   10,   12, 1001,    9, 1821,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,   69,  934,   37,   52,    1,    9,    1, 1665,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   22,    1, 1737, 1414, 2497, 1147, 3357,\n",
      "          353,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  365, 1914,   76,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3359,  267,    1,    1, 1585, 2493,  590, 1031,   32, 2708,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  581,  726,   45,  356,  176,    1, 1494,   32,  166,  915, 2755,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1713,    1,   12, 1994, 2141, 1708,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1484,    9,    1,  531,  734,  591,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  709, 1292,    1,    1, 1086,    1,  808,  176,  667,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  206, 1542,   37,    1,   32, 2330,  808,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   80,  700,    1,  220,   78,  297,  259, 1397,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3244,    1, 3200,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  654, 2037,    1, 2072, 2723, 2724, 1935, 2294,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  561,  927, 1797,  878,   29,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  365,    1, 1277,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  121, 2065,  365,    1,   45, 2673, 1461,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1189, 1234, 1874, 2877, 2237,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,    1, 1523,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  331,   12,   32,   46,   37,    1, 2606,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 1220,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  219,  474,  879,  231,   45,  829,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089,   30, 3006, 1887, 1485, 1147,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 2876, 3198,    1, 1568, 1593,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1310,   37,    1, 1039,   45, 2378, 1167,    1,  433,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2925,  653,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1570,  213,   37,  151, 1718, 2683,  395,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3352, 3353, 1056, 2476,    1, 3347,   32, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  768,    1,  484,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2941, 2522,    1,   96,  444, 3108,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1138,    1,   37,  125,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  664,    1, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,    1,    1,  168,   32, 1940,   12,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  633,    1,  680,  549,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1003,   37,    1,   32,    1, 2472,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2779, 1308, 3173,   32,    1, 2069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,    1,  150, 2025,  275,    1,    1,  384,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2494,  872,  946, 1684,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978,    1,   98,  730, 3022,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1935, 2294,  443,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,    1,   39, 2546,  220, 1230,  328,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1718,    1, 1173,   37,   77,  166, 2367, 2444,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9, 2129,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1428,   46,  142,   37, 1154, 3001,    1, 2152,  361,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,   12,    1, 1489,  932,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  314,  225,  407,   98,  943,   45,   82, 1031,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158,  225,  407, 1969,  586,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868, 1082,  395,   37,  429, 1789,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2972,  756,   51,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,  661,   98,  195,   25,    1,  166,  440,   98,  863,   74,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2745,  571,    9, 2423,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1726, 1677,    1,  231,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  782,  247,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 1070,  163,    1,  903,    1,   37,    1, 3118, 2649,  571,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  259, 1091, 1594,   98, 1273,  844,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  527,  744,    1,    6,  313,    9,  745,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  107,  520,  636, 2880,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1647,  220, 2018,  193,    1, 1537,  446,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3134,    1, 3141,    1,   26,  191,    1, 3202,   12, 1957,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1106, 2355, 1013,   61,   39,   32, 1626,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,   12,  119, 1194, 3121,  166, 2162, 1950,   61,  176,  177,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2170,  361,  453, 1763,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  865,   37,   95,   32,   51,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  455,  190, 1334,   32,  531,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092,   12,    1, 2959,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3320,   81,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  897,   37, 1215, 2293,   45, 3024, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428, 2673, 1063, 1004,  864, 1806, 3366,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1, 1363,  973,    9, 1273, 2255, 2461,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3167, 1834,    1, 2459,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  858,  191, 1021,  847,  765, 1836,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  121, 2660,   79, 3071,   36, 2517,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  845,  147,  884,    1,   79, 2661,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1017,    1,  626,  631,  276,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,   69,  624,    1,  729,  123,   37,  467,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1640,    1, 1438,  582,  580, 1332,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  700,  115,   45,  303,    1,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  600,    1, 1530,  357, 2249,   32, 2140, 2817,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,   56,    1,  631, 1879, 2651,   45, 1214,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3141, 1090, 1829, 2295,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2785,   45,  365, 2911, 2825,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  526,   69,    1,  567, 1389, 1057,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311,    8,    1,  193,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  321,  334, 1824,  220, 1778, 2580, 2851,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,    1,    1,  361,  800,    1,   61, 2861,   37, 2197,    9,\n",
      "          351,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  750, 1461,    9,  104, 1294, 1464,   37, 1539,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2508,    1,   59, 1960,   45, 2189, 1228,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1484,    9,  439,   37, 1756,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,   30,    1,  675,  125,  298,  629,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2475, 1421, 1211, 2256,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  751,   37,    1,   61,  193,   37, 2338,  202,   37,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  183,  730, 1542,   37, 1937,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   51,  771,  449,    1,    1,    9,  333, 1316,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  275,  681, 1248,   10,   37,  289,   98, 2972,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  166,  318,  594, 2413,    9, 2080,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3405,   98,  557,  540, 2024, 2784,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  620,   81, 1311, 2886, 1294,   37,   52,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,  187, 3233,  512,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835, 1830,    9, 3358,   12,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2862,    1,  891, 2507,  854, 2237,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2672,    1, 2347,  444,  519,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  415,    9, 2181,    1,   25,    1,  506,  782,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  361,    1,  875,  400,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   61, 1754,   37,  166, 1183, 1638,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   59,  388,   32,  858,   12,  759,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3286, 2120, 2885,   32,  593,  427, 1343,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,  852,   37,  221,   98,  548,    1,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  329, 1086,   28,    1,  374,  953,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2765,  722,   37, 1641,   28,    7,    1,   32, 2531,    1,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  361,  342,  665,   22, 2096,   98,  429,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3274,   32, 3009, 3295,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,   98, 2071, 1331, 2355,  361, 2232,  315,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1, 1985, 2097, 1789,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  968, 2260,   32,  671, 3126,  427,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845, 2176, 2653,    1,   32, 2160,   45, 3226, 2811,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  219, 2153,   32,    1,    9,  342, 3341, 2825,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2433,  921,    1,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 1447,   12,  695, 2789,  582,  939,   98, 2742,   12,\n",
      "          608,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190,  964,   12, 1021, 1343,  877,  121, 2219,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 166, 638, 978, 951,   1, 730, 171, 736,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 162, 104, 562,   9,   1, 786, 151,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1250,    1,  191, 2592,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12,    1,    1,   37,    1,  409,  957,  232,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  645, 2452,   98,  166,  454,    1, 1230,   93, 2072,  739,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1074,   37,  123,  191,  465, 1657,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  882,   37,    1,    1,  131,   98,  365,  526, 2104,\n",
      "          844, 1097,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1260, 1924, 2041,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3155,   46,    1,  361, 1523,  330,    1, 1348,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548, 1118,    1,  705, 1102,  769,  619, 1415,   37,  218,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2953,    1,   37,    1,  195,  595,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  765,   37,    1, 2106,   12, 1021,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1492,   12, 1658,    1,  920,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1465, 1222,   37,  764,  166,  593,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  581, 1023,  207,  418,   98, 1251,    6,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  790, 1574,    1,  230,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3271,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  640,   81,  176, 2964,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  632,    1,  288,   37,    1, 1839,    1, 1259,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  455, 2185,    1, 1014,  646,   29,   85,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  753,   37,    1, 2800,  210,  220, 3301,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,    1,    1, 1894,  195, 1958,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2822,    1,  167,   26,    1,   69,  361,  493, 2517,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284, 1244, 2401,  548, 1817,    1,  585,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1220,    1,    9,  111,  663,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  179,  716,  807,  354,   32,  572,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  539,    1, 2900,    1, 1080,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,  711,   82, 1013,   51,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1721,  119,    1,   51, 1198,   25,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  191, 3273,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  420, 1033,  580,  238,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1, 1051, 1664,  861,   12,  800,  345,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  674,   45, 1965, 2982, 2344,   37,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861,    9,  116, 2264,    1,  800,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  656,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2685,    1, 1340, 1560,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  551,    1,  325,  104,  669,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  842,  162, 1754,    1,  790,  562,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   45, 3077,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1807,    1, 2329,   37, 1134,  166, 3220,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2832,  588,    1,  548,  114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,    1,  931,   37,  907,   32, 1090,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2249,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2606,   30,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2587,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  800,  389,   29, 1360,  612,    1,   65,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  503, 2297,   32,  422,    1,    1,  839,  297,  749,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 2911,  582,   37,  806,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  220,  591,  202, 3134,  122,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066, 2741,  110,  424,   92,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 3111,    1,   37,   64,    1, 2140,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3349, 1141,    9, 2785,  591,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  947, 1061,   32, 2638, 2931, 2262,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   94,  744,  365,  119,  845,  176,    1, 1714,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1614,  282, 2367, 2695,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,   78, 3111, 1174, 2262,   98, 3155,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2862,    1, 1021, 1343,    1,  652, 1625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  161, 1499,    1,  191,  829,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  931,  590,    1,    9,    1,  932,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  195,   25,  832,    9, 1034,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105,  365, 1151,   98,  166,  222,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   79,   37,  507,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  407, 1159,  915, 2144,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1739,  105,  331,    1,    1,    1,   37,  907,   32,    1, 2771,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,    1,   37,  885,    1,  726,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  393, 1419,  365, 1243,   98,   28,   37,    1,  389,    6,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9, 2376, 2024,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3374, 3352, 1207,  388, 1450,   98, 1094,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713, 2723, 2724, 2636,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1887, 1391,  492, 1388,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1,   37, 1539, 2355, 1013,   32,  166,  365,  356,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98, 2295,   12,  403,  175,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2015,  313,   37,  335, 1526,   39,   45, 1230,   12,  112,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1598,    1, 2375, 2617,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1254,   32, 1463,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2998,  147, 1707, 1603,    1,    9, 1117, 2208,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284,  943, 2385,  612,  824,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,  952, 1945,   98,  864,    1,  403, 1447,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938,   12,  941, 1201,    1, 1077,   37,  168,  457,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2738,    1,    1,    1,  191, 3024,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  247, 2742, 1532, 1590,  105, 3232, 2408,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2971, 2502,  302, 1036,   37,   10,    9,  247,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2748, 1245,  914, 2677,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2583,    1,  191,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870,  794,  365,  535,  656, 2261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1447, 1877,  190, 1745,    1, 2673, 2108,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614, 1284,  183, 1705,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  477,  449,    1,   37,  915, 1890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2807,    1, 3103,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1537,  159,   37,    1, 1183, 2113,  682,  187,  596,  615,  260,\n",
      "           28,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  575,    1,    1,   32,  367,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  105, 1442, 1211, 2256,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 3155,    1,    1, 2688,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1230, 1107, 1863, 2315,  297,  455,  542,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363, 1396, 1230,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  460,  321,  612, 2354,  361,    1,   55,  105,    1,    1,  202,\n",
      "          365, 2527,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,    1,    1,  600,  793,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  193,    1,  191, 2466,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  671,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1796, 1340,  245,  187,  104,   15, 1347,  838,  970, 1057,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380,    1,    1,  475,    1,    1, 3350,   37,  103,  353,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3292,    1,  140, 1194, 1267,   45, 2579,   45, 2468,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2366,  861, 2590, 1521, 2537,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  848, 2501, 1333,    1,  552,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1, 2202, 2017,  220,  460,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1520,  200,  453,  449, 2723, 2724, 2636,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  706,  774,  964, 1822, 2653,  861,  926,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,   22,  359,  498,   37,  365,   46,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   78,  663,  750,    1,   32, 1983,    1,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1906,    1,  365, 1994, 2095, 3146,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  439,   37,    1,    1, 1648,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056, 3375, 2572,   32, 1850, 3339,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2834,    1,   96,    1,  202,  190,  204, 1031,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  250, 1149,  759, 1845,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2978,  865,   37,   95, 1961,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3303,    1,   59,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,   37,    1, 1423,  444, 2442,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   10, 1708,  155,   59, 2300,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  491,  952,   37,    1,  615,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1917, 3176,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,   46,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,   37,  121,  792,    1,  792, 2404,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3277,   32,  142,    9,    1, 3177,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1327,    1,    1,  865,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171,  828,  588,    1,    1, 2157,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  224, 2355,    1, 1778,  912, 1013,    1, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   25,   71,  187,   69,  102, 1150,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,  794,  248,  400,  444, 3382, 2156,  191,  163,    1,   12,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1708,  777,  778,  556, 2311, 2770,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  373,  197,  338,   98,  417,  605,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,   85,    1, 1056,   37,  168,  111,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2265, 1190,  939,   37, 1313, 2823, 2113,  881,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  387,   59,  449,   74,    9, 2692, 1090,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1956,    1,   37, 2447,   32,   72,  786,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  270,    1,  270,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158,  280,  726, 1700, 2577,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  853, 1294, 1380, 2617,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  756,    1,  884,    1,  220,  386,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,  199,    9,  104,  522,   98,  596, 1793,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2424, 3183,  608, 3232,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  162,  829, 1912,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1765,    1, 1821, 2611,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1477, 1990, 2308, 1188,  365,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1213,   46,   28,    1, 1560,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3108,  877, 1139, 1604,   45, 3186,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  142,    9, 1423,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  542, 1066,   98, 3194, 3195, 2565,   12, 2667,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  140,    1, 1990,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,  357,  105,  638, 1801,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1643,  744,   81,    1, 2113,    1, 1396,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1689,  202,    1,    1,   45,    1, 3358,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  321,    1,    1,    1,  706,  774,    1,  168,  608, 2948,   12,\n",
      "          759,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282,    1, 2783,  449, 1684,   45,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  105, 1173,  176,  163,    1,   12,    1,  622, 2705,   32,  531,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  811,    1, 1861,  774,    1,  193,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2832,  350,   32,  365, 1788,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1707, 1140,    9, 3207,   37,  865,  671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  536,  433,  636,  245,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1949,  103,  846,  660, 1151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3343, 2751,  588,  949,   45, 3127, 3080,   32,  865,    9,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 1090, 1829,    1,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1502,    1,  587,  997,  297, 1503,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826,  455,   12,    1, 2652,    1, 1427,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  954,   98, 1171,  187,   14,   15, 1253,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   42,  755,  133,    9,  152,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1823,   12, 2409,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2904,  167,   18,    9, 3301,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  635,  304,  167,   52,    1,  191,  885,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  784,   45, 2516,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  176,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 1016,   46,  686,    1,  548, 2621,  360, 2021,  440,   12,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3277, 2137, 1863,  548,  594,    1,   16,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1934,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2707,  668,    1,  114, 2803, 3094,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260, 3330, 1229,  123,   37, 1888,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   39,    9,    1, 3141,  914,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  166,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  683,   61,  603, 2342,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1266,    1,   37,  125,    1,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 3055,  674,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1076, 1654,  645, 1385,   32,    1,  214,  142,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3121,    1, 1985,    1, 1789,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713,    1,  176,    1,    1,  813,    1,  744, 3172,  119,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1304,   37,  138,  331,   32,  399,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2547, 1116,  140,  129, 2015,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  387, 1169,   15,   28,    1,  419,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3318, 2651,    1, 2672,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 758,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 328,  69,   1, 530,  98, 531, 532, 533,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1825,   79,   37, 2277,  105,  449,   98,  166, 3129, 1434,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800, 1824,  716,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  647,  721, 1830,    9, 2491, 1160,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,   32,   46,   37,  151,    1,  551,  517,  178,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2710,  437,  396,  632,  851, 2421,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1,    9,    1, 3194, 3195,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,  466, 1523,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401, 2720, 2796,  608,  978, 3138,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2964,  837, 2997, 1632,  117,  725,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   68,   69,  102,  245, 1315,  105,  106,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1853, 1557, 1484,  365,  477,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   12,  332,  636,  288,  176, 1714,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,   38,   37, 1154,  166,   74,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3356, 1974, 1450,    1,  315,   37, 1237, 2325,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  220, 2971,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267, 1099, 1453,    1, 1590,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1013, 1522,    1,  251,  388,    1, 1013,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2048, 1413,   37,  856, 2527,  164,   32, 2490,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  484,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  944,    1,  294, 2773,  361, 3053,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2004,    1,  292,    1, 1151,  220,   80,    1, 1766, 1767,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,    1, 3169,  167,    1,  268,   26, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  487,  137,   32,    1,  297,    1, 1469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  683, 1625,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  147, 1707, 1787,   37,  544,  193, 1140, 1638,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102, 1348,  245,   32, 1033,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,   42,  220, 1652,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1818,  147, 1650,    1, 1942,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1712,  267,    1,  844, 2876,  580,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3075,   12, 1645, 2237, 1554,  734,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  267, 3140,    1,   37, 2392, 2735,  220,\n",
      "          531,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  224, 2355, 1013, 2549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  292,  453,    1, 2436,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  670,   98,   69,    1,  829,  570,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3038, 1177, 1910, 1530,  187,    1, 1518,   32,   98,  409,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   37,  125,  448,    1, 1598,  957, 1429,   32,  232,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2045,  328,  386,  295,  952,  152,  388,   32, 1251,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755, 1536,   43,  444, 2492, 2819,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 2518,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1147, 2924,    1,    1, 1089,   30,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  273, 1609,  162,  790,    1,  562,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  475, 1288,  388, 1346,   37,  531, 1720, 1610,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  709,  195,    1,    1,   85,   32,  968,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159,  554,  187,  425,  426,  958, 1184,   32, 2314, 1885,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2350,    1, 2741,   37,    9, 1312,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  249,  277, 2349,  726,   32,  365, 1788,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2116,   39, 3116,  548, 2195,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,  325, 1989, 1990,    1,  180,    9,  131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  302,  405,    1,    1, 1235,  875,    1,  149,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1918,  190,    1,  218,    1,  176,  177,   32, 1139, 2113,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1306, 1640,    1, 1306,  593,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  338,   37,    1,  529,  408,  686,  954,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  770,   45, 2729, 3102, 1976,   32,  531,  947,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1142,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  403, 1447,   46,  729,   98,    1,  395,   90,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   30,   79, 2071, 1331, 1021,  327, 1151,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1325,   33,   32, 1704, 2679, 2665,   98,  617,  618,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  756,  757,    6,    4,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1380, 2108, 1281,   98,  557,  540,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220,  661,   98,   64,    1,    1,    1, 1013,    9,  230,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  220,  356, 1281,    1,    1,    1,  580,  439,   45,\n",
      "         1922,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  700,  548,  118, 1253,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3097,  267, 1884,    1,    1, 1159,  403, 2203,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2633,    1, 1938, 2607,  382, 2206, 2989,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1497, 2279, 2471, 2925,    1,  813,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1191,  207,  354,  703,    1, 1192,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3194, 3195, 1187,    1, 1084,    9, 2093,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994, 1645,    1,   32,  557,  540,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 1550,    1,  220, 3374,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  178,  770,   45, 3347, 3025,    1,   27, 2597,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  885, 3143,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1988,  207,  912,    1,   61, 1976,  514,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1691,   61,  671,  361,    1,  187,  227,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  961, 2700, 1013,    9,  901, 1661, 2596,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3398, 1489,    7,  147,  484,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,    6,  395, 1588,    1,   69,  530,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3138,  798, 2441,   79,    1,  384,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,    1,  104,   22,  701,  187,    1,  343,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 575,   1,  37, 111,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 313, 176, 119,   1, 846,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018,    1,  854, 2153,   37,  907,   86,    1,   32,  163,    1,\n",
      "           12,    1,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3119, 1774,  608,    1,  171,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3064,  801,   37,  907, 2779,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2269,    1,  516,   37, 1040,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2802,  949, 1380,  460,   28,   32,   22,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2663,    1, 1247, 2321,    1,  463,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977,  475,  387,    1,    9,   10, 1821,  210,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   37,  588, 1461,    1,  176,   46,  220,  903,    1, 1447,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  853,  844,  682,   32, 2107,  444, 1842,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  902,    1,  267, 2467,   45,    1,    1,  340,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3186,  335,  631,   81,  220,    1,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1, 1361,   37,    1,  365,  845,  439, 2634,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2500, 2955,  353,    1,  572,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  288,   37,   26,  526,   69,  343,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,   71,    1,   64,  997,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340, 1229,    1, 1991,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  307, 2741, 1388,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1527, 1149, 2139,   37,    1,    1,    1, 1223,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,    1,   27,  105,  106,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,  267,  219,   24, 2015,   61,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  192,    1,  166,  249,  774,  590,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2786, 2976,    1,   32,  829,   12, 1657,  861,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1,  829,  221,  289,   45, 1718, 1523,   37,  650,  730,\n",
      "         1777,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  166, 1376,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  496,  207,  912, 2285,  833,  612,  583, 1354,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 3145,  444,    1,   37, 1211, 3102,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3182,  186,   37,  688,  153,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3083, 2368, 1090, 1044, 1045,    1,  103, 3331,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3327, 1025,   37,  631, 3190,  548,    1,   12, 1888,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 3109, 1532,  297,  667, 2147, 2950,   32, 3379,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  649,   32,  166,    1,  187, 2153,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  266,   37,  142,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1614, 1778, 2232,    1,  590,    1,    9,  334,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12,    1, 2432,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1386,   51,    1,    1,   98,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200,  845,  275,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,   69,    1,  202,  471,    1,   65,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1, 1835, 3016, 1935,  220,  766,    1, 2957,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1861,    1,  351,    9,    1,    1,    1,  744,   79,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1966,   37,  788, 3341,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  613,   37, 1027,  116,   93,    1,  275, 2153,  774,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1917,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  442,  448,    1,   37,  119,    1,  182,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1013, 1522,    1,    1,   98,  224,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,   60, 1287,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826,  104, 3141, 3009,    1,   37,  166,    1,   63,    1, 1617,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  183, 1034,    9, 2458,    1,    9, 1675,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715,    1, 1471,  716,  720,   32,  207,  197,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1497,    1, 3244,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   86,  642,  643,   15,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 1178, 1492,    1,  166,  961, 1482,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 2377,    1, 1755,  176,  903,    1, 1447,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  159,   28,   98, 1610,  333,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2995, 1288,   37,    1,   79,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3387, 2985, 2827,   32, 2262,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437,  388,    1, 2844,   32, 3360,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  147, 1566, 1720,    1,  321,  815,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1286,  376,  572,  157,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1147, 1414,    1,  163,    1,   12,    1, 2924,   64, 2597, 3392,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 2808,   98,    1,    1,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  220,  105,    1,   45, 2463,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2055,    9, 3204,  361, 3168,  176,   26,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  602,    6, 1062,    1,   48,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2965, 1973,    1, 1464,  581,    1, 1463,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  163,    1,   12,    1, 2972,  475,    1,  939,    1, 1261,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,   12,  103, 3382, 1921,   32, 2646,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380,    1, 3390,   32,  187, 2018,  446,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,  154,    1,  388,    1,  983,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  773,   66,    1, 1595, 1332,    1,   15,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2143, 1639,    1,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3398, 2786,   45, 1088, 1002,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  872, 1118, 1539,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  753,    9, 1894,    1, 2406,  907,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2733, 1564, 1727,    9,  822, 1323,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   14,   15,  120,   98,  104,  818,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3374, 3006, 2856, 3101, 3160,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2572,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2956, 1249, 2863,   12, 1350,  798,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,    1, 3360,  588,    1, 1527,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1232, 1221, 1924, 1820,    1,  153,  565, 2491, 3130,  321,  612,\n",
      "            1,  750,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2717,    1,   37, 3141,   12, 1628,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  303,  163,    1,   12,    1,  719,   37,  125,  673,  910,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1,    1, 3015, 2699,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2584, 1021,  608, 3331,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,   28,    1,  157, 1315,  237,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1918,    1,   55, 1691, 1215,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2871, 2620, 1086, 3076, 3275,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1186,  108,  864,   37, 2446, 3107,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  693,   37, 1413,  585, 1030,  756,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    4, 1782,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1619,  507, 1229,   98, 2393,    9, 1260,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1147, 2153,  907,   32, 2024, 1705,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537, 2548, 2856, 3006,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  593,  590,    1, 2885, 1249, 2843, 2523,  156,  119,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,  566,    1, 2969, 1766, 1767,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  365, 1737, 2056,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1512,  765, 1159, 2025,  199,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1074,  256,  211,   37, 3076,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  359,  759,  630,  220,  793,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3270,   32,  176,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  750, 1924,   28,    9, 1787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1261,  197,  191, 2476,   32,  333,   45, 1147,   69,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  108,   45, 2987,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492,    1, 2716,    1,   37,  447,  361, 2468,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  613,   15, 1027,   28,    1,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 1290,  176,  356,  340,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2478,   28, 1499,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1754,   37,    1,   45, 2894, 1273, 2980,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1955,  884,   48,   32,  487,  294,   12, 2227,  872,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3161,    1, 2570, 1022,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1465, 1091, 1046, 1424,    1,  700,  536,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 2641,  738,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1955,  155,  570,   98,  198, 1220,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37,  166,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,  446,    1,   10,    1,  167,    1,  220, 2275,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2670,    1, 2175, 1371,   37,  105, 1151,   27,  334,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  766,    1,    1,   37,    1,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1035, 1070,   37,  698,    1, 1922, 1038, 1175,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   6, 156, 570,   1, 159, 245,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 879, 251,   9,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  818, 1697,   51,    1,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3114, 2003,    1, 1039,   45,    1, 2909,    1, 1293, 1073, 1428,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 3308,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463,  464,    1,    1,    1,   32, 1013,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  247,  454,   37, 2218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 2355, 1013, 2706, 1297,  334,  224, 1658, 1778,  327,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,  852, 2083, 1033,    9,  331,  105,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1604,   98,    1,    1,  297,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2455,   98,  166,  168,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1295, 3156,  548,  493, 2960,   32,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  654,   12,  721,   98,  776,  187,  253, 1539,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,    1,  625,  190,   52,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2573, 2122,    1,  176, 3398,  949,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,    1, 1159, 1147,  890,    1,  191, 1338,   45,  861,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  275, 1900,  973,    9,  704,  705, 1084,    1,  116,    5, 1281,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9, 1517,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  971,    1,  479,   15,  276,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2529, 3121,    1,   85,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  447, 1355,   69,    9, 1011,  420,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  359,  562,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2848,    1,  140,  105,    1,  786,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105,  365,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2753,  270,   32, 1013,    9,  166, 3088,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  520,  297, 1167,  857,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2977,   10,    1,  596, 1793, 1534,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1065, 1190, 2279,  838,   37,    1,   45,  129, 1743,   98, 3153,\n",
      "         2220,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  475,  939,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  148,    1,    1,  647,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1137,   98,  355,  214,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32,  298,   45,  104,  803,  851,   32, 1037,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,  297,  176, 1771, 1688,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1028, 2922,   37,    1,    1,   45,   10,   12, 1135,    9,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2672,  688, 3248,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 2452,    1, 1465, 1159,  526, 2186,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103,    1,  273, 2317,   56, 1675,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,   82,   12,    1,    1,  327,    1,   47,   79,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3381,    1, 1877, 2764, 3394,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2103, 2727,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3356,    1,   37,    1,  680,  531, 2024,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  980,    1,    1, 1680,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2562,  885,  916,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,  166, 2107,    1,    1, 1918,    1, 1560,  361,  166,\n",
      "          395,  934,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,   10, 1268,  631,  528,    1,    1,   32,  496,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2700, 1116,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437,  190,  856, 2492, 2429,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  103, 1985,  129,    1,  550,    1,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1757, 1552,   32, 3369, 1512,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,   70,    1,    1,  972,   37,  582,  242,   32, 2088,  442,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1829,    1, 3358,   32,  105,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 1117,  741, 1604,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,    1,    1,  343,   32, 3089,   12, 1013,    9,    1,\n",
      "           12, 1351,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 2024,   46,    1, 1364, 1365,   12,  996,  533,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2871, 3175,    1,  571,  411,  384, 1857,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1591,    1, 1126,  155,  152,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1187,  111, 1446,  665, 1658, 1001,  176,  629,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  166,    1,  100,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,   14,   15,  619, 1104,   92,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2544, 2298,   32, 1778, 2580, 2851,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  733,    1, 1541,   37,  289,   98, 1331, 1244,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 1044, 2084, 1889,  391,  371,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  938, 1282, 2094,    1,   37,  258,  124,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  479, 1825,  236, 1022,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  973,   37,    1, 1147,  890,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3228,  288,   37, 2192, 3276,  105, 1787,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  726,  193,  105,    1,  810,    9,   25,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   56,  569,    1,  202,  321, 3181, 2595,  726,  810,   56,    1,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  352, 1518,  242,   98, 1583,   12,  484,   37,  138,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  147,  267,  163,    1,   12,    1,  669, 1822,  138,   32,  864,\n",
      "         2772,  400,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   93,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1427,  300,    1,  547, 1394, 1048,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  219,    1,    1,    1,  187,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,   61, 1648,   37,    1,  365,    1,    1,  626, 1563,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800, 2226, 1398,  612, 2135, 1232,  460,   12,    1,  357,    1,\n",
      "         2226,  705, 1831,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,  952,   37, 2035, 2108,    9,  987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1726,   37, 1664,  596,  518,    8,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  646,   93,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1763,    1,    1, 2844,   32,    1,    1,  114, 2337,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2114, 1713, 2723, 2724,  437,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3351,  162, 2227,    9,  495,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,  21,  37, 698,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 109, 509, 973,  69,  37, 119,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3303,    1,  631,  176,  294, 1456, 3154,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  612, 1846,  288,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   63,  166,  862,    1,  407,    1,  419,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2871, 3297,  159, 2073,   32,  428, 1002,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1127,   37,  151,    1,   32,  132, 1960,  600,  182,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2514, 1233,  627,   37,   52,    1,  424, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2252, 3358, 1351,   37, 2449,   32, 3101, 1038,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2382,  618, 1665,   37, 2387,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2753,  565, 1530,  548, 2292,    1,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  773, 1937,    1,  698,   37,  818,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3253,    1, 3204,    1,  221, 1159,    1,  176,  104,   26,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128, 2055,   37,  480, 2400, 1021, 1129,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   12,  361,    1, 3361,   98, 1260,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  612,  613, 1361,    1,    1,  361,  517,    1,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035,  716,   37, 1038,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  898, 1530,   32, 1081,  851,  298,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  398, 1550,   10, 1705,   37,  846,  695,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   37, 1192,  176,    9,  537, 2404,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2991,   37,    1, 1089,   98,  166,  777,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3117, 1421,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  102,   71,   32, 1169,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  474,    1,  477,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  818,   15,    1,   32,  365, 1262,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1687, 1022,    1, 3008, 1419,  388,  128,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  162,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1136,  802,  105, 1641,   37,  706,   45,    1,    1, 2054,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  200, 2603, 1108,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1674,  671,   12,  636,  372,    9, 2890,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   10, 1082,  903,    1, 1423, 2153,   37,  690,    1, 1973, 2362,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  353,  242,  737,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  386,    1, 1915,    1,  641, 1663,  289,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796,  669, 2414,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   64,   79,    1, 1308, 2728,    1, 2844,    1, 2249,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,  310, 2064,    1,  123,   37,    1, 2862,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  279,  280,  606,  805,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103,  943,   37, 3089,   12,    1,  600,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  931,    1,   37,  698,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2151, 1139,   45, 1322,  968,   98, 1428, 1906, 1311,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3401,  193,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  879, 2851,  382,  328,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  879, 1056,   74,  245,  187,  395,   12,   67,   71,   51,\n",
      "          125, 1220,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311, 2936, 3283,    1,   32, 3387, 2596, 1665,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1870,    1,    1,  176, 1087,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  546,   98,  810,    1,  176, 1548,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2170,    1,    1, 2139,  220,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1229,   37,    1,    1,   32, 2073,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  183, 1158,  363,   37, 1854,    1, 3117,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  193,    1,  191,  632, 2657,   45, 2673, 1461,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  912, 2285,  675,   32,  822,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1947,   45, 1477, 1990,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  447,  782,  183, 3387, 2108,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2333,    1, 1229,    1,   79, 2926,  540,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  374,  375,   37,    1, 1981,  236,  237,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564,  365,  693,    9,    1,  187, 1757, 1552,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2336,  193, 1953,  657,   12,  569,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2140,   64, 1950,  297,  187,  365, 3121,  640,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  352,  267, 1583,  321,    1,  589,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3303,  980, 1159,  166, 2069,   32, 2741,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  227,    1,    1,  567, 2372,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614, 3055, 1159,  631,  297, 3175,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   30,  803,  112, 1228,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1839,    1,  162,  501, 1125,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1818,  147,  884,   28,    1,    1, 2208,  400,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,   39, 1021,  260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  147, 1118,  776,  191,  786, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 2075,   81,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  405, 3291,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938,  343,    1,   37,    1, 1107,    9,    1, 1090,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1771,  171,   12,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2292, 2612,   28,   32, 3349,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  758,   37,    1,  111, 1197, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739,  614, 1264,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3124,    1,  449,  726,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504,  446, 2958, 1532,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  691, 1838,   79,  365, 2036,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    4,  361,   15, 1347,    1,    1,  954,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  168,  548,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  565,   79,  187, 1503,  443,   96,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2615, 1247, 1631,   38,    1,  236,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  652,  967,  453, 1650,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  147,    1, 2412,   98,  170,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 1023,   45,  331,    1,   32,   86,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1777, 2739,   42,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3005,    1, 1074, 2261,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  316,    1, 3251, 1000,  166, 1001,    9,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  176, 3113,    1,    1,   39,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3236,    1, 1631,    1,   12, 2210,  356,  686,  813,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  361,  342,    1,   20,  296, 1523,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  125,    4,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453,    8,   54,  354,  304,    9,  572,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2464, 2329,   37,    1, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  755,    1,  148, 1664, 1228,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2906,  361,  224,   37,  877, 2641, 1772, 2812,  111,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  848,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1419,  365,  650,   45,  660,  331, 1779,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1181,    1,  848, 1303,  317,  682,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1558,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  348,   37,  151,    1,  114,    1,   50,    9,    1,  372,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9, 2371,  187,  848, 1237,  166,    1, 2371,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  386, 2249,    7, 2422,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1661,  551,  704,  222, 1536,  786, 2017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1645,  924, 1070,  730, 1731,   37, 1173, 1159,  716,   45, 2343,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1138,  315,   37,  125, 1604,   23,  191,    1,  361,  123, 2152,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1, 2202,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  366,  996,    1,  276,    9,  601,   73,  339,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3139,  146,   37, 2868,   37,  764, 1590,    1,  163,    1,   12,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,  714,    1, 2544,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3021,   12,  857,  120, 2005, 3088, 1731,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 2673,  475,  140,   12,    1,  464, 2532,  543,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2921, 1940, 1439,   98,  312,  134,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2266,    1,    1,  600,    1,   45,  531,  443,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  794,  293,    1,    9, 1021,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1746, 1149,    1,   64,  686,    1,    1,  548, 1101, 2785,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2226,  552, 2422,  105,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1523,  297,  365,    1,  891,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  409,  410,  115,   45,  104, 1002,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2055,    9, 3180,   32, 2046,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2292, 2897, 1316,  531,  176, 2165, 1533,  384, 3155,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  542,  713,    9,  214,  550,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  615,  489,   39,   45,    1,   25,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458, 1501, 1120,    4,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  792, 2602,  792,   61,    1, 1357,    9, 1861,   98,  531,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  667,    1,    1,    1,  328,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1759,  309,  159,   71,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  984,  238,   98,    1,   54,  142,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  885,  565, 2644,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2640,  744,   79,    9, 1821, 2190,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  305,    1,   98,  997,   65,   37,  423,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1956, 3255,  288,   37, 2277,  183,  220, 2080,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  910,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   37, 1289,   28,   37,    4,   32,  704,    1, 2226,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2634,    1,    1,    1,  766,   32, 1597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3002, 2988,  829, 2432,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  705,    1,   45,    1,    1, 1976,   37,  606, 1328, 2762,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  683, 1040,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  491,    1,    1, 1539,  104,  331, 1108, 1597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  581, 2132, 2160, 2049, 1249, 1037,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  571,   37, 1923,    1,  202, 1654, 1090,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3308, 2535, 3302,  361,  913,    1,  680,    1,  549,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1988,   32, 3147, 3148, 1464,   37, 1030,    9,  776,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   27,    1,  687,   98,   29,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  445,    1,   37,    1,   12,    1,  767,    1,  202, 1166,   12,\n",
      "          166,  114,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2202,  297,    1,    1, 3059,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,  383,  574, 1469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3043, 3348, 3045, 2856,  398,   32,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   76,   37,  877,  221,   37, 1718,  232,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1183, 2784,    9,    1,  229,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   37,    1,    9, 2080, 3255,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,   12,  838,   32,  166,    1,    1,    1,    1,    1,    1,\n",
      "            1,  361, 1568,   98,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 1983, 1671,    1,   77,   25,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035,   37,  398,  611, 2349,  920,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  219,  159,  720,    1,    1,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2642,    1, 3225, 2642,    1, 3225,    1, 2799,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  506,    1,   32,   98,  275,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1583,   37,    1,    1,   45,  352,  589,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,  593, 1990,    9,  395,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3252, 1256,    1,  375,    1, 3285,   28,  361,  472,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  190, 1504, 1792,    1,   45, 2580,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  580,  365, 2118,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  654,    1, 2925, 1173, 1628,  548,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548, 3358, 2162,    1, 3359, 1877,   37,    1, 3339,  469,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    1,  131,  746,   24,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2658, 1040,    1,  215,  443, 1530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   72,  553,  163,    1,   12,    1,  617,  259,  669,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755, 1536,    1,   43,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   61,  654,  105,   93,  225,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  266,  197,  418,   98, 2374,  378,  315,  372,  752,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2974,  140,  331, 2223,    9, 2784,   37, 1821,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1529,   45, 3039,   37,  207,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 829, 768,   1, 400,  37, 168,  37, 776,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  550,    1,  861,  578, 1705,   37,    1, 2972,  475,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1844, 3299, 1198, 3175,  297, 3108,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2018,  361,  854,   32,   46,   37,    1, 2673,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,    1, 2073, 1843,  207,  418,  159,  554,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1360,  612,   52,    1,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  636,   28,    1,    1,  640,  119,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  774,    1,    1, 2175,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  108, 3369,   98, 3357,    1, 1484,    9, 2117, 3406,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428,  719,  388, 1021,   37, 1000, 2330,  864, 2439,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,   26,   28,   98,   69,  636, 2338,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2442, 2911,   81, 2103,  617,  625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,    1,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  190,  664,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  411, 1055,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1625,   37,    1, 3012, 3027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  200,   49,  333,  315,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3266,  176,  861, 1665,  384, 2177,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1642,  187,    1,    1, 1009,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 429, 458,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  69, 102, 103, 105, 106,   1, 288, 119,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  196, 1426,  132,  220,    1,   98,  176,  551,  612,  613,  214,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  439,   28,  185,  504,   98, 1125,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   46, 1647,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  167,  691,   12, 3038,    1,  665, 1526,   98,  505,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1122,  538,  315,  111, 1107, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089,    1,  487, 3102,    1,    9, 2924, 2129,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,   98,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1223,   12,  591,    1,  191,    1, 1574,   32, 2160,   45, 3310,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  275,  681, 2274,   98, 2858, 2665, 1665,  656,  918,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1, 2131,    1,  680, 1629,  399,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  845,  147,   57,  231,   45, 1739,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711, 2816, 3279,   32,  404, 3114,  163,    1,  903,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2640,    1, 1440,    1, 1832,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2602,    1,    1,    1,  894,   52,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1138,   37,  125, 1604,   23,    1,  123, 2152,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,  251,  412,   37,    1,  414,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3242,  315,  522,  297, 3066,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,   37,    1,  996,  468,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 1540,  187,   82,   45, 1163,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2602, 3177, 2226,  331, 1514,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  397,  497,  321,    1,  444,  104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 1566,    1,    1, 1234, 1876,   37,  453, 2308,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  190,    1,   39,  670, 1680, 2912,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280, 1910,  453,  857,    9,    1,    1,  484,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2102,  193, 1542,   37,    1,  405,  942,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537, 2860,    1,  548, 1002,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2104, 1419,  420,   98,  596, 2429,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   12,  365, 2371,   37,  686,  455,   32, 1657,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2846,  463, 2170,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2016,   12, 1123,  726,  232,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1417,    1,    1, 2748,  103,  182,    1,\n",
      "         1417,    1,   12,    1,    1,    1,  193, 3161,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2380,    1, 2584,  683,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  427, 1336, 2047, 2134, 3308,  290,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 2547, 1046,  365,  582,    1, 1281,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1542,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1487,    1, 1169,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  463, 1447,    1,    1, 2924,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2862,  936,  365, 1065, 1190,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 1876,   45,    1,  628,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700,  388, 2844,   32, 2504, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,    1, 1766, 1767,  218, 1119, 1936,  913,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1854,  156, 1253,  118,   32,  572,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1497, 2279, 2471,    1, 2925,  813,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175, 3159, 3266,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3310,    1,  191,    1,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 3372,  765, 1750,  741,   98, 3339, 2129,  469,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2519,   51,   52,    1,  763, 1178,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1409,  272,   98,    1, 1345, 1011,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  182,    1, 1417,    1,  833,  612,  606,   37,  138,    9, 1442,\n",
      "            1,  351, 1818,  147,  963, 2122,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  439,  856,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,  954, 1071,   32,   72,  401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2433,  615,  661,  121,   12,  613,  218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2672,  442, 2922,    1,  664,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3253,  801,   37, 2069,   45,    1,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  136,   37,  508,   79, 1149,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  539,    1,  288,   37,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  199,   37,  943,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203,   12, 1167,    1,  105, 3192,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1110,    1, 2967, 2740,  220,    1, 1987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,    1,  354,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  691, 2393,   98, 1081, 1260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1345,    1,   32, 2646,  548, 2024,  142, 1464,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1851,    1,    1,  202, 2110,  852, 1542,   37,  865,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2862,   12,  597,  650, 1988,   45,  926,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1178, 2145,   37,    1, 2650, 1699,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 2673, 1063,  812,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 2599,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1984, 1243,    1,  163,    1,   12,    1,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  224, 1991,   37,    1, 2566,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2472,    1,  879,    1,    1,    1,    1,  388, 3011,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1840,  846,   92, 1554,  284,  893, 2072,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 1130,  912,  388, 1994, 2819, 2039,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3101, 2551,    1,   45, 2024,  176, 2708,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,    1,   81, 3339, 2731,  187, 3375,  813,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  582,   45, 2245, 1796, 1885,  939,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,  243,  682,  548,  646,   29,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,   34, 2798, 2943, 1499,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497, 1735,    1,    1, 1103,    9, 1515,  627,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2617, 1000, 2383, 1533,   79,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2746,    1,    1, 1003,   37,    1,   10, 2049,  469,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2819,   30,  459,   45,    1,   79,  202, 1398,  612,  429, 1658,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9, 1833,   12, 1633,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,  315, 2738,    1, 3339, 2456,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  395,    1,  384, 2970, 2357,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,  640,  365,  119,   94,  340,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1074,   37,  123,  191,  465, 1657,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  480,    1, 1129,    9, 2871, 2910,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1812, 2103, 2727, 2252,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  647,    1,   37,  943,  220,  148,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  342,  518,  475, 2682, 1140,    9,  673,  125,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2046,  614,   32,    1,  179,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2747,  166,  103,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  150,  292, 1889, 1108, 2515,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1301, 3405,   12, 2226,  540, 2024,  142,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    9, 1090, 1091,    1,  105, 1328, 1057,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   37,    1,    1,   98,  284,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,  593, 2522, 2789,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1818,  147,   37, 1709,    1, 1842, 2096,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37, 1155,    1, 1904,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1542,    9, 1663,  147,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2741,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  952,  388,   12,    1, 2571,  112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  512,    1,    1,  191,  422,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1023, 1204, 1539, 1243,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   32,  166, 1523,   45,  166,    1,    1, 2994,  313,  176,  829,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,   12,  395,  778,   37, 1413,  481, 1074,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  298,    1, 2950, 1289,   37,  104, 2162, 1950,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    1,    9,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  809,    1,  804,  665,   79, 2191, 1014,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,    9,  365,  317, 1010,  927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  649,  947, 2263,   36,    1, 3060,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579, 1366,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 2369, 1778,    1,  345,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2970,    1, 1856,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3257,    1, 3169, 1758, 1159, 2197,   72, 1385,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  716,  774,   46,  220, 1973, 2422,  606,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  306,    1,  150,  162,  312, 1377,  220,    1,    1,  132,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1010,  555,    1,  531, 1009,  267,  741,  211, 1710, 1527,  792,\n",
      "         1414,   45,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2547,    9,  861,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,  266,  475,    1,    1, 1170,  853,  538,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  458,    1,   30,  242,  449, 1023,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2714,  487, 3222,  132,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3171,    1,    9,  228, 2202,    1,  640,   32, 2712,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  894,   52,    1,   37, 1343,   98,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   37,    1, 3358,  357,  247, 1135,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,   50,    1, 1813, 2615,  361,  705, 1458,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  894,  664, 1515,  917,   37,  741,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  342,  232,    1,  600, 1327, 1347,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3010, 2702, 1293,   98, 1171,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  612, 1273, 2094, 1766, 1767,   37,    1,  215,  124,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2108,    1, 1975,  103,    1,  395, 2784,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  168,  115,    9,  365,  116, 1008,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  929, 1345,    9,  669, 1010,  286,  549,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  667,  446,   66,    1,   79,  863,   98,    1, 1737,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3084,  796,  548,    1,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3271,  554,   37,  754,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3377,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2140,    1,    1, 1101, 2817, 2856, 1060,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,   98,  166,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2236,    1,    1,    1,    9,    1,  551,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  365,  192,   50,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2, 389,   1,   1,   1, 220, 629,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 755,   1,  28, 861,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  463,    1, 1414, 1348, 1345,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2554, 3206,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1123,   32,  316,   32,    1, 1160,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107, 1702,   28,   69,  568,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3001, 2865,   79,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  590,  199,  187,    1,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1009, 2137, 2667,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 2469, 1388,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  550,  369,  615,  498,  104,  221,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,   66,  972,   37, 1083, 1184,  347,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2078,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  460,  729,  653,  105, 1597,  574, 1720,  334,  815, 1658,\n",
      "          248, 1001,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1458,    1,  230, 1116,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2932,  506,    1,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977,  744, 3072, 1539,    9, 2675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  736,   98, 2275,   12,  622,  119,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3290,    1, 3103,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,    1,  562,   35,  170,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  755,  794,  834, 1108,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861,    1,    1, 1188,    9,    1,  289,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2062, 1008,    1,   37, 1764, 1990,  872,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  393,  267,  719,   32, 1754,    1,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  902, 2565, 1216,  122,  548,    1, 2712,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3325, 2222, 1564,  460,   37, 1938, 2809,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  129,    1,  197,  490,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3340, 2135,  940, 1082,  487, 1414,   37, 1910,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3003, 1236,  885,  297,  912, 2285,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3048, 2981, 2474, 1542,   37, 2818, 1425,  166, 2918,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3132,   18,  384, 2072,   37,  726, 3201,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  316,  317, 1106, 1107,  338,  415, 1139,   45, 2102,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2, 585, 565,  32, 105,   1, 171,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 168,  37, 166, 806,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2144,  388, 3338,   32,  531,  187,    1,   45,    1, 1258,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  546,    9,  631,  176,    1, 1759,  309,   26,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2821,    1,    1, 1373,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426, 1310,   37, 2230,  453, 1521,  191,    1, 1300,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  207, 1450,   85,    1,    1,  725,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 1769,   37,   77, 3118, 1288,  163,    1,  903,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  134,  297, 3369, 2282,  722,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1118, 2851, 2568, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3215,  551,    1, 2297,   98,  593, 1863, 1139, 1638,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425, 1713,    1,  437,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  561,  168,  548, 2819, 1277,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2685,    1, 3117,    1, 2799,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 2650,    1, 2286,  885, 2995,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325,    1,  172,    9,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1860,    1,  909,  997,   32, 1094,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  942,  716,  572,  354,  897,   37,    1,   59,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  458,   45,  507,  710,   37,  619,    1,  138,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1410,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2472,    1,  191,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1430,  446,  939,    1,  267,  190,  193,  582,  365, 1386,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  812,  792,    1, 2250,  792,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1268, 2102, 1107,  525,   32,  942,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3270,  424, 1684,   61,  166, 1509,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  291,  675,    1,  176,  148,   12, 2789,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1051,  675,  835,  552,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,   12,    1,    1,   37,  930, 1411,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1023,   45,  163,    1,   12,    1, 2698,  469,   37,  151,    1,\n",
      "          496,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1419,    1, 1101,  931,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2445, 1188,    1,  764,  548, 3116,  922, 2712,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  775, 1106,    1,    9,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  365,  389,   61,  103,  195,    1, 2722, 3074, 1215,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2643,    1, 1398,  612,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  631,  105,  120,   32, 1278,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  848,  315, 2869, 2723, 2724, 2636, 1825,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  620,   29,   51,  125,    1,    4,   37, 1154,  372,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  393,   12, 2027,  729,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843, 1450,  356, 1691, 1667,    1,    1,  176,  264,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1681,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343,  861, 1414,  190, 1188, 1663, 1527,    9,  537,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   12, 1172,    1, 1360,  612, 2565, 2643,\n",
      "         3322,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2137,  135,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  303, 1484,  163,    1,   12,    1, 1446, 1294,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 1466,   37,  130,  861,  669,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  700,    1,  810,    1, 1102,  931,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  638,  786,    1, 1914, 2565,  808,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 326,  42, 284, 573, 149,   8,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1,   1,   1,  80,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018,  162,  453, 1178,    1,    1,    1,    1,   45,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2960,   32, 3374, 1178,   12,  754,   32, 3339, 2414,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  449, 2281,  776,   98, 1405,   37, 1174,  892,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1108, 1779,    1,  167,   52,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1028,   10,   12,    1, 2082,   32,  166, 3388,  361,  403, 1447,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  705,  140,    1, 2771,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  558,   27,  132,   37,  151,    1, 1039,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2139,   37,  271, 2774,  429,   98, 1633,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,    1, 1211,  245,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1800,  487,    1,   37, 1994, 1718,  117, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  273,    1,  665,    1,   98, 1247,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2089, 1535,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2842,   45, 2292,   32, 3339, 2831,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1774,   37,  119,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2192,  166, 1055,   45,  987,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1607,  231,  982,    1, 1775,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,    1,   98,  776,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  506,    1,    1, 2392, 1011, 1039,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2929,  115,   45,  166, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   85,  699,  996,   29,  410,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1561, 2339, 2107, 2415,  551,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,   37,  151,  294, 1983,    9,  152,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1166,   12,  166, 1107,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2676, 2275,   12, 1470,   45, 2834,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3168,    1,    1,   45, 3052, 1159, 2033,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  735,  441,    1,    1,   37,  973,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1124,    1,   32,  818, 1697,    1,  463,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2454,   32,  786,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2415,    1,    1,  809,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,  698,    1,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   12, 2979, 2869,   53,   39,   98,  453,  449,   74,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  867, 1396,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,  737,  197,   28,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1458,  487,    4,  707,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1940,   12,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  879,  119, 1844,    1,    1,  297,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147, 1707, 2638, 2931,  116,  625, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2162,  347,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,   12,  472,    1, 3090, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2563, 1041,  297,  730,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2352, 2376, 2024, 2223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1283, 2741,    1, 2222, 1921,   32, 3184,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1497,  686, 3356, 1940,  187,    1,   27, 2646, 3346,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  982,    1, 2801,   37,  877,  517,  618,    9, 1244,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178,  610,  297,  668, 3049,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1645, 2176,    1,  680,  365,    1,  625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181,    1, 2445,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2, 935, 936, 698,  45, 365, 793,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 121,  32,   1, 297,  36,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1936, 1003,  176, 2108, 2107,   45,  559,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,  166,    1,    1,  460,   39,   85,  680,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2179,    1, 2626, 2623,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247, 1484,   98,  342, 1749,   37,   26,   28,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  510,   12,    1, 1414,  365,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2114,  546,  947,  475,  297,    1, 1450,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1532,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 2962, 3228,  439, 1879, 2941, 1625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1423, 2272,   85,   98,  111,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1523,   45,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1861, 1627, 2611,    9,  985,    1,  952,  786,  388, 2113,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2592, 1988,   45,    1,   32, 1802,  890,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  642,  643,   28,  699,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089, 1090,    1, 2162,   45,  608, 1009,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  302, 1712,  162,   59,    1,  105,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1004, 2149, 1578,   98,  296,    1, 2096,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1280,   45, 2983, 1976,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3245,   37, 1306,  449, 1090,   45,  903,    1, 2227,    1, 1007,\n",
      "            1, 2318,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1485,    1, 1542,    9, 1821, 2190,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  680,    1,  187, 1107, 2015,  418,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3272,    1,  163,    1,   12,    1,   26, 3289,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2932, 1835,  705,  259, 1017,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1744, 3105, 2572,   32,  649, 2169, 3279,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1976,   32,  183,    1,    1,  171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1211, 2256, 3171,    1, 3132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  550,  369,   34,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1119,    4,   37,  854,    1, 1364, 1365,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   12,    1, 1494, 2848,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   10, 2407,    1, 2681, 2417,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123, 1863,   12,    1,  818,  719,  590,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1877,   37,    1,  829,    9,    1,  453, 2027,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   28,  104, 1674,  872,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3099,   12,    1,  140, 2376, 2024, 2223,   98,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2561,   61, 1264,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 1396,   37,   52, 2030,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1, 2531,  943, 2532,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1539, 2177, 2636, 2869, 1107, 1863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 2609,    1,  267,    1, 2977, 1831,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3143,  113, 1545,    1, 3181,  614, 1056, 1394, 1048,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,  134, 2144, 2416, 2985,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2243,  469,    9, 1674, 2578,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   61,  553,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  571,   37,    1,  872,    9, 2741,  427,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  155,  737,  983,  837,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2414,  176,  177,  176,  531,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3164, 1586, 1705, 1979,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1648,   37,    1,   10, 1727,    9, 2500, 3036, 1281,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,    1,  949,    1,    1, 2886,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,  476, 2673,    1,    1,   32,  447,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2787,   37,  698,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3232, 2555,    1,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3279, 1348, 1813,  861, 1414,  361, 3006,   32,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1379,  149,  176,  654, 1380,    1,   32,  105, 1381,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  337,    1,    1,    1,    1, 1210,  365,  961,    1, 2616,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,   98, 2501, 2502,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,   32, 2027,    9,  865,    1,  202,  972,  193,   37, 2748,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  105, 1257,  884, 1173,  176, 1447,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    1,    9,  105,  590,    1, 2635,  917,  920,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1390,   37,  243,   95,    1,    4,    9, 2300,   45,    1,    6,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2110, 1542,    9, 1411,   84,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2266, 3118,  399, 1610,  191,  356,  439,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1032, 3238, 2151, 3138,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1448,  716,  331,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3303, 1518,  220,    1, 1993,    1,   37,  726,    1, 1684,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   45, 2823,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  920,  606,  105, 2495,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  721,  991, 2269,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1105,  787, 1690,  525,   15,  245,   32,  572,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2618,   37, 1154,    1, 1223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2378,    1,    1,  361, 1313,  202,    1, 2745,  220, 1524,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2315, 2385,  612,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  903,  193,  320, 2056,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  488, 1123,  297, 2901,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 1923,  113,   79,    1,  171,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2977, 2914,    1,    1,  993,    9,    1, 2982,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,   37,  125,    1,    4,    1,  335,   59,   44,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,  692, 1064,   37,    1, 1259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  750,   15,   92,   20,  197,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 2402,    1,   98,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2693,   61,    1, 2789,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  704, 2232,    9,  949,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,    1,   98, 1108, 1779, 1614,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2069, 2074,    9,    1, 3358,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359, 2794,    1,  388,    1, 1219,   32,  539,  458,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  358, 1149,  894,  193, 2116,   98,  573,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,   37, 2237,  567,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1227, 1774,   39,  581,    1, 1626,   45,    1, 2232,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   95,  473,  474,  475,  952,    1,  477,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  952,  562,   37,   47,  159,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1118, 1783,  156, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2091,  861,  187, 3363,   61, 3390,   32,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2347,    1, 1910, 2748,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1279,  977,  321,   52,  105,  638, 2549,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  782,   22,  298,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3124, 1086,  443,   45, 1886,  220,    1,  249,   12, 2658,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  863, 1825,  111, 1225,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1907,  365, 1230,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3125,    1, 3091, 1103,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1657, 2306,    9,   49,   47,   79,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  720,  374,   79,  388,  763, 1394,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  978, 3138,    1,    1, 1976, 1530,   32, 1606, 2012,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,    1, 1901, 2683, 2043,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  515,    1,  807,  808,   32,  247,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2202,  340,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2724,    1,  191, 1497,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3153,    1,  437, 1360,  612,    1,   10, 2163, 1215,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   49, 1536,    9,  104,  467,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1261, 2794,    1,   37,  970,    1, 2884,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2297,  115,   45,    1,    9, 2792, 1463,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  267, 3369, 2162, 1950, 1426,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  294, 2965,    1,    1,  140, 1383,    1,  671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2998, 1249,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  619,  516,  384, 3375,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3294,    1, 3132, 1360,  612, 2000,    1,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  211,   61, 1114,    1,   98,    1, 2722, 3074, 1215,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  475, 1190,   45, 1537, 2827, 1815, 2726,    1,   32,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,   82,  267,  669,    1,   45, 1611, 2304, 1126,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 2830,   51,   52, 2170,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,   37,   47,  327,  112,   37,  324,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115, 2035,    1,   12,   24, 1632,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3303, 1293, 1048,   32, 1423,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1186,    1, 1159,  183, 2068,  171,    1, 1063,  108,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,    1, 2885,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1817,    1, 1688, 1173,   37,    1, 2359, 1116,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2884,    9, 2719, 1005,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2546,  267, 1158,  556,  453, 1107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2308,    1, 2954, 1542,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1617,   12, 1799,  680, 1665,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1793,  488,  878, 1393,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  342,  640,   81,  297,   20,   12,  792, 2154,  792, 1527,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1258, 1604,  528, 1757,    1, 3399,  774,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3296,    1, 3117,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,   60,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,  140, 3082,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  511,  852,    9,    1,  444, 3089,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2862, 1679, 2101, 1056, 2179, 3082, 1039,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,    1, 1539, 1994, 2819, 2731,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3096, 3309,  321, 1403,  227, 1215,   37, 3328,    1,  267,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  224,   37, 1013,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2604,    1,    1,  384,    1, 3027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  744,    1,    9, 1411,  659,   45, 1778,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3185, 2322,  288,    9,  411, 1169,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2685,    1, 3209,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  746,    1, 1536,    1,  372,  410,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537, 1190,  267,  460,  486,    1,   32,    1,  131,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1505, 2590, 1641,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  475,  387, 1488,  596, 1998,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1191,    1,  500,  123,   37,  116,  668,  132,  420,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2948, 2977,   37, 1195, 2978,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2565,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2909, 3043, 2774,  778,   32,  531,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1,   61, 1628,    9, 1123,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,   37,  335, 2937,   98,  777,   37,  105,  365,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  433,    1, 1229,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  142, 1464,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1485, 2107,    1,    1, 3308, 1990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3130,  614,   81,   32,  199,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 2018,  719,  105,  427,  855,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2936, 1260, 3060,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 1140,   61,  824,    1,  166,    1,   61, 2025,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,    1,    9,    1, 2167,    1, 1477, 1990,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1326,  104,   15,  120,   32,  385,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   28,    9,  166,  806,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  166, 3126, 2116,    1, 2942,  967, 1533,    1,  689,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463,  464,  147,  556,    1,  469,   37,  221, 1633,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 971,  91,  37,   1,   1,   4, 191, 428,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 328, 342,   1, 148, 142,   9, 647,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   10, 1679, 2339, 1108, 2256,  384, 1966,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1024, 1024,   37,  130, 1026,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1054,   47,   79,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1412,    1, 2254,    1,  159,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1481,  967,  590, 2609,   98,  531,  187, 1002, 1523,  614,   85,\n",
      "           37,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  374,    1, 1641,   32,    1,   45, 2275,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2275,   12,    1,  117,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,    1,  829,  872,    9, 1499,   45, 1128, 2168,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  903,    1,  182,    1, 2611, 1149,    1,  690, 1845,   24,  220,\n",
      "            1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  742,    1,  331,   37,   28, 1178, 1179,   48,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1577,  708,    1, 1228,   37,  860,    1,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1631,  248,  593,  119,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,    1, 1996,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  415,  162, 1032,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2576, 1856,  220,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2571,  474, 1121,   32, 3118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1140,    9, 2509,   98,  487, 1938, 3197,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3000,    1,  150,  829,   37, 1539,  111, 1107,  525,  424,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1663, 1680,  158,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,    1,  190, 1330, 1632,  888,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  901, 1147, 3373, 2626,   63,  104,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1409,  782, 2918,  135,   98,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2806, 3276,  199,   37,  506,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   12, 3356,    1, 2024,    1,   32, 2646,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   61,  424, 1140,    9,  334,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3219, 1421,  103,  712,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2741,   12, 2087, 1542,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,  197,  452,    9,  780,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2352,    1,  922,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  221,  242,  187,   69,  102, 1269,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,  388,    4,   37,  854,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1044,  640,    1,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1744,    1, 1334, 2017,  384,  890,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 2594,    1,   32, 1477, 1990,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,    1,    1,    1, 2629,  865,  754,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  852,  680,  166,    1,    1,    9,  459,   45, 1718,   93,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,    1,    1,    1,   32,  971,  808,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61, 2580,   12, 2324, 2440,    1,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3359, 2794,    1,  388,    1, 1219,   32,  539,  458,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1791,  163,    1,   12,    1, 3400,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1459, 2237,   37, 2468, 2070, 2282, 2795,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  276,   98,  800,    4,   93,  550,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1024,    1,    1,  197,   28,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004, 1128,    1,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  733,   50,   37,  854,  259,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2793,  361,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 828,   1, 381, 297, 287,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  72, 401, 197, 418,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1749,    9, 1467, 1013,    1, 1614,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  703, 1942,  469,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1023,   45,  116,    1,  167,   52, 1792,  506,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3250,   51,   52, 2198,    1,  444, 3115,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2417,   16, 3104,    1,   45, 1029, 2282,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1260,    1, 2832,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  460,   12,  463, 2170, 1917,  365, 2036, 1917,  455,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   46,  288,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  515,  166, 1110,  105, 1585,  384,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2535,  166,    1,    1,  454,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,  256,    1, 2232,   37,    1, 2340,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  577,  528, 2333, 2712,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2737, 1755,  297,    1, 1089,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   64,    1,    1, 2100,  584,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3365, 1229, 2572,   32,  531,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2332, 2192, 2829,  453, 1134,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3161,  140,  183, 1684, 1090,  297, 1440,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,    1,  140, 1523,    9,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1693,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 2306,  288,    9,  903,    1, 1447,   46,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1340,  162,   74,   79,   32, 3135,  951,    1, 3319,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,    1,  645,  104, 1563, 1119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 1188,  193, 1406,  600,  395,    1,  854, 1712,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1759,  309,  159,  123,  242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2999,   91, 1337, 1994, 2819,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  437,  251,   37,  151,  989,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  293,  315,   37,   77,   28,  166,   97,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  872,  420, 1657,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  136, 2373,    1,  704, 2079,    9, 1718,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1,    1,   32,  365,  825,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1106,    1, 2750, 1626,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,  256, 3005,  361, 2693, 1942,   37,    1, 1108,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  395, 1877,   37,  973,    9,    1,  652,   45,  945,  293,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  190,  693,    1, 1778, 1232,  342, 2167,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  338,   98, 1801, 1220,  833,  612,    1,  119,  636,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2197, 2576,    1,  384,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1206,    1, 2176, 2506,   45, 2608, 2607,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  155,  453,  693,    9,    1,  361,  162, 1415,   37,    1,\n",
      "           54,  132,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2895,  506,   30, 1433, 2966,   61,  363,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,  947,  655, 2572,   32, 3279,  220, 3006,  403,   45, 1785,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2546,   37,  693, 1467,  111, 2943,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2131,  288,    9,    1,  356,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3257, 1396, 2110,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,  494,    1, 1852, 2228,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   65,   12,    1,  267,  954,  729,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1944,   32,  342,  400,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,  716,  264,  341,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1118, 1539,   45,  365,    1,  844, 1151,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977,    1,   12, 1821, 2978,  127,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  729,  606,  590, 1021,   32,  584,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2252,    1,    1,   32, 3310,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,   37,    1,    1, 1085,    9, 1003,  575,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962,    1,    1,    1,  631,    1,   37,  726,  297, 1957,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3344,  437,  396,   37,  606,  531, 3373,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  647,  721, 1707,  148,  142, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 2593,    1,  825, 2641,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2477,    1,    1,    1,  365, 1355,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344,    1,    1, 1656, 2596,   32, 1619, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  758,   37,  151,  111, 1107,    1,    9,   59,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  761,   12,    1,  580,    1,  629,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  230, 1553,  764, 2922, 1575, 2017,  384,    1, 2291,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  147,    1, 3139,  321,   52,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3349, 1988,   45, 1809, 2189, 3109,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171,   12,    1,  321,  619, 1001, 1232, 2189,    1, 2192, 1323,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2708,  650,    1, 3358,  928,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123,  730, 2614, 1832, 2522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2158,   45, 2121, 2080,  363,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  730, 1110,    1, 2747,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   85,  361,   39,   32, 1717,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1919, 1920, 1921,   37,    1, 1922, 1841,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2276,  176,    1, 1521,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1950,  677,   98, 3354,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  493,  408,    1, 1278,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,    1, 2264,  220,    1, 2131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2254,    6,    4,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973,   39,   37, 1496,  754,    1,  444,  694,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 1206,    1, 1249,  903,    1, 1212, 1022,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  469, 1484,    9,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,  267, 1147,  741, 1822,    1,  740,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 3220,    1, 1572, 2163,  782,  105,  454,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1094,   37, 1910, 2708, 2458, 1897,  863,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  747, 1830, 1074, 1901,    9, 1089,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  219,  872, 2055,   37,  335, 1134,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  355,  267, 2073, 1023,  197,  190, 1306,  837,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  777,  412,   32, 2391,  288,   37,  335,   79,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 1273, 1074, 2094, 1639,  361, 2909,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3168, 2951,    1, 2069,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2463,  140,  220, 1006, 3226, 1809,  544,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,  190,  837, 3162,  176,  104,    1,  267, 1789,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,  359,  498,   37,  943,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1656, 1585, 1396, 1147,  232,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 2703,  565, 2623,  600,  166,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  220, 2227,    1, 1417,    1, 1417,    1,    1,    1,  196,  325,\n",
      "          176,  612,  613,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358, 2617,   37,    1,   39,  365, 1867,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   21,   37,  698,  528,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1,    1, 2500, 3036, 3037, 1281,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1599, 2018,  489,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  831,  530,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1720,    1,   61,  193,  264, 1343,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1354, 2476,    1, 1444,  606,  227,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3181,    1,    1,   32, 2038,  922,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  488,   37, 1539,  622,  522,  444, 3140,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  726,    1,  182,  704, 1569,   32,  166, 3220,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  281,  282,  782,    1,   32,  424, 1034,   12,  560,  347,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1001,    1,   98,   71,    1, 1002,  782,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,  839,  395,  700,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2227, 1831,   37, 1753, 1035,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2163,  671, 1086,   27,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2053,  218, 2861,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1479,  922, 1123,   37, 1865, 1049,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2954,  220, 1361,   98,    1,  517,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2767, 1169, 1100,    1,    1, 1539,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1645,    1,  105,    1, 2537,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1844, 2041,  186,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,  894, 2286,   37,    1,  105, 1610, 3388, 2666,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2266,    1, 3093,  190, 1980, 2198,    1,  191, 1557,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2700,   37,  764, 2977, 1155,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  155,  156,  157,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1435,  691,   12,    1,   37,    1,   28,  568,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3307, 1348,   37,    1, 3232,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  827,  967,  581,  401,  354,  187,   15,    1,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,    1,    1, 1922,  248, 1438,   37,  105,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  856, 1405, 2251,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403, 1447,  894, 2446,    1,  361,  865,   37,    1, 2601,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2708, 3065, 2572,   32, 3339, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2076, 1151,  983,   37, 1937,  816,   93,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  176,  612, 1353,  389,  125,  469,  191,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61, 2322,  460,  810, 1114,  384,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3219,    1, 3240, 2051, 3226, 3219,    1, 3226,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,    1, 1883, 2365,   39, 2759,  280,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1796, 2224,  939,   63,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437, 2414,  581,  104, 3102,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  430,  476, 2117, 2924,   37,    1, 3118, 2751,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1380, 1682,   98, 1910,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,    1,    1,    9, 1887,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  862,    1,  105,    1,  202, 2133,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2050,    1,    1,   12,  872,  321, 1343,   37,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  406, 1610,   98,    1,  760,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,    1,    1,  112,    9,    1,   54, 1714,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2238,  794,    1, 2403,    9, 1273, 2515,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,    1,  220,  327, 1151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2255,    1,  176, 3120, 2099,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,   5,   1,   9,   1,  12, 632,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 297,   1, 104,  12,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1002, 1001, 1132,    1,   98,   25,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  147,    8,    1,   98, 3139,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1118, 2924,    1,  384,   12,    1, 1447,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3339,  477, 2414, 1056, 3006,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1228, 1297, 1132, 1075, 1604,   32, 1647,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,    1,  166, 1146,  106,  813,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,  472,    9, 3278,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  365,    1,  142,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3198, 1877,   37, 1403, 1764, 1990,   81,   37,  121,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  763,    1,    1, 1174,  443,   98, 2527,  164,   32, 2490,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,  326,  840,  466, 1465,   50,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   12,  633,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1240,    1,   37,  166,  116,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   98,   65,    1,    1, 2964,  588,   37, 1154,  507,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1053,   12,  954,  897,   32,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2676,  108,   45, 2095,  629, 1232, 2275,  140,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2079,    1,    1,  193,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1366,  565, 1120,   37, 2856,  361, 1366,  606, 2398,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 2980, 1195,    1,    1,    1,  389, 1727,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1231, 2715,   23,   39, 1443,   32,  539,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1323, 2156,    9, 1206,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   12,  265,  921,  758,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  206,    1,   39, 3232, 1632, 1700, 2799,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796,   25,   51,  504,    1, 1572,  191, 1326,    1,  548,   69,\n",
      "          636, 1042,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1523, 1004, 1533,    1, 1028,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1386, 1500,    1, 1291,   32,  521,  945,   37,  327,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460, 1924,  166, 2829,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1224,   37, 2288,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2424, 2498, 1463,  220, 1480,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3069,    1,  121,   37, 2000,   36, 3071,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  370,    1,   37, 2446, 1809, 2738, 1395,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1100, 2744,  365, 1273, 2403,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  631, 3260, 1159, 1090,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1001,  590,    1,  187,  632, 2954,  168,  548,    1,   39, 3151,\n",
      "         3009,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1699,    9,    1,    1,    1,    1,   61,  105,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   42,  220, 1498,  297,    1,  844, 2495,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3064,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1622, 1386,    1,  952,    1,   37, 2199,  477,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1046, 1629, 1107,  293,  927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  952,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  581, 3386, 1178,  513,  514,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   75,   37,  231,    1,    1,   37, 1602, 2539, 2800,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  335,  166, 1245,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 1194,  401,  354,   37,    1,  384, 1913,  401,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 1372,   37, 1421,    1,    1, 1259,  220, 1725,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428, 2924,    1, 3362,   12,  709,    1, 3338,  191,  597,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  690,    1,   12, 1596,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  245, 1315,   32,  601,   74,   45,  840,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1996,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2332,  804,    9,   81,   37,   36,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2300,  132,   30,    1,    9,  632,   69,    1,  202, 1650, 1407,\n",
      "          808,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 2051,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1764, 1990, 3098,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3307, 1910,    1,  220,  590,  439,   32, 1881,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1592, 1406,  600, 2249, 1147, 2108,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2932,  506,  311, 3002,   37,    1, 2229,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2431, 2764,    1,    1, 2646, 2024,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  596,  739,    9,   93,  565,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   25, 1758,   32, 1034,    1,    1,   12,  551,  552,    9,\n",
      "         1022, 1034,   32,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2528, 2957,   12,  365,    1, 2334,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,  475, 2520,    1,   54,  469,   37,  125,  408,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  297,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1584,  166,    1, 2586, 1747, 1174,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  777, 1075,  224, 2355,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,  475,  387, 1298,  753,    9,   69,  633,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  321,  612,    1,  204,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  225,  333,  191,  508,   12, 1404,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  675,   50,   37,  151,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  313,   37,  439, 1567, 3106,   32, 2448,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1, 2336,    1,   15,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 3404,    1,   79,    1,  736,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  632,    1, 1550,  105,  142,    9, 3187, 1218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1,    1,   32,  453, 1525, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3352,  335,  547, 3102,  176,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  591,   61,  454,  115,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2957,  879,    1,    1, 2320,  361,  846,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510, 1774, 2029, 2028,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3388,    1, 1458,   10,   98,  399, 1806,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537,  446,  251, 1815,  365,  698,  187,  449, 2924, 2271,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,  267,    1, 1671, 1976,  176,  453,    1,\n",
      "            1,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2677, 2857,  951, 3123,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3249,  606,   79, 2539,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  921, 2601,  187, 3315,    1,    1,  664,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1940, 3338,   32, 2597,  254, 2476,    1,  487,  947,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1154, 2349,    1,    1,    1, 1861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 2673, 1063,  475, 1484,    9,    1,   98, 2673, 2834,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1,   32,    1,    1, 1533,  917,  682,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213, 2450,   37,  168,   98,    1,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  105, 2038, 1998,  191,    1,   32,  511,  714,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1952, 2015,    9, 1300, 1821,   95,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3271,    1,    1,    1,  548,    1,  105, 1056, 1844,  754, 1844,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1227, 1346,    1,    1,  331,   32, 1228,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428, 3118, 3397,    8,  365,  304,   37, 3369,  115,   45, 1757,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,    1,    9,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 527,   1,   1, 498,  37,  74, 881,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 609, 140,   1, 384, 611,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2254,    1,  157,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1086, 2154, 3339, 2831, 2731,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  217, 1210,    1,   12,   37,  138,    9, 1084,  841,  133,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  295,  571,   37,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,  166,  261,    9,   80,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230,    1, 3257,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2197, 1218,  213,   98,  531,  734,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   43,  297,  931,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2592, 1082,    1,   98, 2357,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984, 2981,  387, 2662,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  657, 1447,  200,    1,  660,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  715,  652, 2357, 2007,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2832,    1, 3339, 2129,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123,   32, 1340,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1671, 1976,   98,  667,  851,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2942,  140,  449, 3126,    1,    1,  140,  547,  176, 1139, 1434,\n",
      "          593,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3369,    1,   45,  337,  351,  191, 1428,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  365,  804,   45,    1,  674,  415, 2535, 1658,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  179,   82,  343,  187,  972,  650, 1232,  180,  132,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2317,  548, 1997,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 2693,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700, 3386, 2921, 1940,  610,   28,   37, 1700,  537,    9,  312,\n",
      "         1450,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  337,    1,    1, 1173, 1628,  680, 2749,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  907,  166,  872, 2107,  872,    1, 1178,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 2540,  166,  342,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1658,  112,    9,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  239, 1492, 2582,    1,   98,  105,   71,  565,    1,   39,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2379,    1,  546,  129, 3096,  872, 2565,  548, 1056,  390,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1363,  246,   98,  219,  159,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,   98, 2515,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,  871, 1290,   67,    1,  118,    1, 1721, 1937,  590,  996,\n",
      "            1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  395,    1, 1159, 1300, 1313,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1164,   45,  365, 1675,    1,  191, 2086,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2920,  688, 3142,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   96,   28, 1204,   98,    1, 1965, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2804,   45, 1530,  215, 3160,   37, 1753,  957,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  146,  147, 2744, 1641,   37,  758,  297,    1,    1, 1559,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  792,    1,  792,   98,  166,    1, 3143,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 2946,   45,    1, 2527,   12, 1890,   51,   52,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,  825,  176, 2069,  914, 1705,   45, 2737,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1345,   32, 2433, 3360, 2414,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1898, 1340,   37,  229,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  381,   12,    1,   37,  619,  590,    1,  317,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1284,   81,   32,  166, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3231,    1, 1110,   32,    1,    1, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  342,  665,  296,   20,    1,   98,  429,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  144,  145,    1,  197, 1396,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 2170,    1,   37, 2447,  449,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1293, 3158,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  370,   51, 2274,  220,  373,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1168,    1,   37,   52,  388,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 2489,  750,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158,    1,   39, 2546,  220, 1230,  328,  327,  593,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1240,    1,  909,   98, 1537, 2700,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1861,   37, 1248, 2789, 1945,  680,  531, 1324,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 3036, 3037,   98,  429, 2191,  548,  163,    1,   12,    1,\n",
      "          863,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2218,   45, 1013, 1522,    1,  361, 1299, 1958,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  697,   37,   52,  233,    1,  650,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  187,    1,  991,    1, 1411, 2329,  565, 2179,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1,  464, 2153,    1,   10,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1704, 2914,    1, 1331, 2403,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1592,   37,    1,    1,   37,  506, 2130,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,   37,  130,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593, 3009, 1876,  310, 2734,    1,  427,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1860,  958,    1,  729,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  429,   79, 3175,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  327,   15, 1673,  105, 2195,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  581,    1, 3382,    1,   85,   32,  531,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,   71,  765,    1,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1194, 1856,   45, 1523,   37, 2225, 1515, 1833,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  193,  105, 1797, 1090,    1,  202,  105, 1797, 2155,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  650,    1,   98, 2107,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  806,   16,   10,    1,  115,   45, 2275,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 1537, 2673, 1409, 1530,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  148,   37,    1,  647, 1889,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1794,    1,  608,    1, 1583,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,  957, 2361, 3391,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2822, 2517, 2879,  191,    1,    1,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2414,  176,  177,  176,  531,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,  614,  680,  166,    1, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2508, 2272,   85,   98, 2899,   55,  552,  552, 1074,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   51, 1083,  122,    9,  224,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1497, 2136,  267, 2787,   61,  729,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1676,  851, 1554, 1423,    9,  365, 1788,  548, 2596, 2393,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3140, 1800, 1094,   12,    1,   46,  693,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2217,  288,   37, 2545,  365, 1277,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3169,    1, 1159, 2033,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967,  198, 1838,  176,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1056, 2548,   32, 1850,  622,    1, 2249,   98,    1,    1,    1,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2512,    1,   37,  319, 2227,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2508,  522,  297, 2189,  912, 2434,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2476,    1,   98,  872,    1,    9, 1764, 1990, 2069,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,   37,    1,    1,    9,  317, 1527,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1738,    1,  979,    1,   37, 2449,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   91,  515,  971, 2635,  501, 1125,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708,    1,  580,  172, 1512,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,  113,   79,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,   39,   45, 2707,  427,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1338,   45,  987, 2797,    9,    1,  595,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  253, 1753, 2302,  624,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  691,  884,   44,   32, 2410, 1463,  444,  854,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  488, 1378,    1,  868,   98, 3006,   32, 3140,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 758,   1,  39,  59,   9,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 353,   1, 354, 548,  44,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  996,   93, 1488,  763, 2112,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1,  277,    1,  688, 3147,    1, 1167,    1, 1590,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3369,  630,    1,  191,  104,  379,  176, 1428,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,    1,  602,   12, 1428,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  861, 1906, 3146,   98, 3339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  800, 2378,    1,   15,    1,    1,   12,  197,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2178,  947, 2263,  667, 2147, 3035,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947,   37, 2360,  344, 1259, 3065,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3375,    1,   39,    1,  297, 3358,   12, 2162,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564, 1735,  714,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   56,  947, 1530,   32, 1640, 3246, 2774,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,  315,  481,  517, 1437, 2013,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  792,    1,    1,    1,  792,  614,  671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2232, 1828,    1,    1,   32,  166,  218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1751,  132,  167,    1,  611,  199,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  331,  354,  833,  612,  149,    1,  519,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1920, 2590, 1267,    1,  176,  736,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   74, 1494,    9,    1,  183, 1178,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1656, 2596, 1260, 2414, 3361,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1360,  612, 2728,    1,  220, 3018,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1345,   32, 3155,  431,  439,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2314,  104,  475, 1786,   37, 1306, 1604, 1114,  420,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   47,   79,  636,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2164,  396, 2853,   32, 1081,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 1292, 1681,    1, 2175,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  844,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1874,  241, 2658,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2136,    1,   32,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 183, 785,   9,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 408,  71,   1, 197, 338, 176, 196,  88,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  162,  790,  562,    9,  803,  506,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,   14, 1110,  214, 1523,   32,    1,  548, 1852,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,  104, 2274,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  884,  118,   45,  647,  159,  202, 1090,   61,  193,  297,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2028, 2357,  163,    1,   12,    1, 1104, 2749,  220,  105, 1263,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1,  657, 1413, 1414,   37, 1835, 2894,  618,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  572,  156,   71,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2137, 2856,  104, 1149,   32,    1,   45, 2597,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1707,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   77, 1658,    1,   39,   45,  460,    1,  206,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2557,    1,  365, 3005,   98,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993, 2994,  166,    1,   12, 2995,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1340,  140, 3212, 1624,  528,    1,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537, 1228, 1085,    1,    1, 1046, 2664,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  176, 3283,    1, 1183,   74,   12,    1, 1159, 2539,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213,    1,  176,    1, 1292,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  224, 1475, 1126,  636, 2320,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,  548,  245,   98,    4,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3054, 1631,  248,  846,  119,   98, 2069,   95,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  861, 1906, 1082,  439,   37, 2292,   32, 3388,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1426,  166, 2918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390,    1,    1,  453,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   97,  897,   98,    1, 1827,   37, 2192,   28, 1021,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1245, 2712, 2475,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  639,  513,    9, 3102,  949,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1278,    1, 1258,    1,  388,  987,   37,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1186,   12,  442,  910,  703,  187,   69, 1196,  686,  119,  845,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  439,  713,  220,    1,  470,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  403, 1739, 1292,  472,   81,    1,    1,   39,    9,  914,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  958,    1, 2637,   46,  606,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1550,  531,  345,    1, 1454,  808,   32, 2160,   45, 2936,\n",
      "         3389,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649,  650,   37, 2237,    1,    9,    1, 2396,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 202,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 529,  37,   1, 388,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  671, 1426,  356,  845,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2069, 1140,    9, 2774, 1147, 3382,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1726, 2602,    9,  531, 2485,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730,    1,    1,   37,  619, 1766, 1767,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3282, 2246,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1110, 1865,  365,  111, 1107, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2867,    9, 1147,    1,  548,  365, 1450,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3012, 2700, 2040,   45,    1, 2604,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,    1,  647, 2426,  972,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  354,    1,  739,  526,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3118,    1,  865,   37, 1824,   32, 2047,   45, 3357,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3270,   98,    1, 1030, 1559,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1366,    1,    1,    1, 1218,  311, 2936,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1102,   45,    1,    1, 3358, 3405,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  754,   15,  120,    1,  642,  643,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,  267, 2057,    1,  191,  667, 2147, 2596, 1585,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  267, 2997, 1614, 1610,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  622,   46,   98, 1815,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1926, 1927, 2886,    1,   32, 3127,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,  400,   45,    1,    1,   32,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  213,   37,  132,  220,  730, 2614,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3207,  580,  627,  361,    1, 2814,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,  794,  365,  311,  199,    1, 2750,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1874,  287,    1, 2893,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   37, 1289, 1898,   37,    1, 1085,   32, 1411,  659,   45,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,    1,   28,    1,  170,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 105, 474, 488,  37, 477, 176, 942, 317,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  25, 221,  28, 528, 863,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,   42,   43,    9,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37, 1155,    1, 1904,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2771, 2462,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463,  294, 2153, 2000,  365,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  310,   25,  504,    1,  185,  631,   44,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2076,  575,    1,  220,  111,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2375, 2616,    1,   32, 3155,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1353,  138,  187,  334,  168, 2933,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    9,  148,    1,  636,   61, 2222,  917,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,  872,  140,   54, 1074,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  755, 1458, 2017,  384,  829, 2194,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1187,    1,    1,  606,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,  321,  606, 1018, 1230,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  287,  537,   32,  166, 1809,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2472,    1,    1,    9, 2025,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1077,    9, 3098,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1331,   31,    1,  763,   76,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1028, 2950,   61,  105,    1, 1167,   62,   61,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2468, 3109, 3384, 2985,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1492, 2233,   52,    1,  449,    1,  166,    1,   61,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  861,  441,  469,  170,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3067, 1887,   45, 2708,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3386, 2921, 2757, 2526,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1920, 2567,    9,  487,    1, 3047,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  335, 1003,  176,  590,    1, 3161,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3396, 1046, 1011,    6,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428,    1, 3146,   37,    1,  596, 1994, 2095, 1708,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    4, 2867,   37, 1584,  848, 1159, 2102,    1,  420,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  527,  353,    1,  354,  528,  242,  529,  408,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162, 1950,   45,    1,  611,    1,  418,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1047, 1236,  597,    1,   32, 2295,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1720, 1682,    1,    1,  960,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  281,  282,   37,  698,  589,   37,  709,   82,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2137, 3282,  505,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  632, 2095,    1, 3268, 2784,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,   36,    1,   12,    1, 1401,  104, 2872,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 2102,  102,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  273,   12, 1667,    1,  167, 1752,  166, 1178,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1592,    1, 1739,    1, 1450,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  328, 1739,    1,   51, 1937,  613,   92,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102, 1348,    1, 1473,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1877,   37, 1876,  121,    9,  397,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  952,    1, 1511,   32, 2835,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  334, 1445,  384, 1166,    1,    1,    1,    1,    1,    1,    1,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  316, 3206,  872,  420, 1169,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  230, 1498, 1210,  480,   45,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  684,  420,  782,  590,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2673,  639,   12,  522,   98,  864,  338, 1139,   45,  163,    1,\n",
      "           12,    1, 1567,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1273,  132, 1408, 1363,   32,  166, 1381,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  797,    9, 1899, 2372, 1812,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  666,    1, 2977, 1821,  656,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37,   52,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2988, 2690,    1,    9, 2987, 2762,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2685,  361,    1, 1539,  105,  365, 1015,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2741,    1,  854,  565,  590,    1,  267,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   98, 1196,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,   37,  335, 2937,   98,  777,   37,  105,  365,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1237, 1658, 1117, 1525,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,   12,  351,  162,    1, 1323,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,  688, 2615,   32, 2799,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  443,   98,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175,  498,   37,    1,  132,    1,  442,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1117,    1,  163,    1, 1498,  774,  829, 2582,    1,   37,  909,\n",
      "         2928,    1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  458,   45,  507,  267,  765,  388,    4,   37,  273,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2707, 1822,  652, 2559,    1,  108,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2953,    1, 2593,  105,    1, 2519,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1564, 1872,    1,  105, 2276,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2909,  686,  547,    1,  458,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2700,    1,    1, 1563,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,   12, 1411,    1,  452, 2885,  967,    1,    1, 2523,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1242,    1,   92,  853,  538, 2395,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3339, 1627, 1194,   74,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  443, 2938, 3060,    1,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1165,    1,  176,  372,    1,   98,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1178, 1179,  439,  742,  214,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  510,   12,    1, 1408,   69,  102,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,   12, 2975, 1824,    1,  884,   79,   32, 1033,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  460, 2337,  334,  606,  460,    1,  730, 2614, 1833,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1040,    1,   98, 1017,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1674,  142, 2590,  187, 2936,   12, 1521,   61,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,  671,  202, 3046,   30,  247,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2384,  453,  645,    1,    1,  166, 2720,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  557,  540,    1, 2596, 1645, 2924,    1, 1887,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1178,  361,    1,   61,    1,   12, 1567,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  132,   27,   37,  439, 3356,  787, 1523,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  142,   37,  222,    1,   45, 2282,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  155, 2968,  997,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129,    1, 1401,  963,   26,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1574,    9,  166,    1,   32,  475,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,   98,    1,   50,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  112,   93,  176,    1, 1224,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2924, 2625, 1219,   32, 1013,    9, 1428, 3365,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,    9,  808,  220, 3261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1465,    1, 1478,   59,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  744,  478, 2568,   45,    1, 2232,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2107,   98,   37, 1882,  591,   37, 1157, 2785, 2372,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1973,  566,  565,    1,  187,  204,  884, 3194, 3195,  317,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2672,    1, 2347,  444,  519,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9, 3118, 2024,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  657, 1118,    1,  769,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1064,   32,    1,  422,    1,    1, 2156,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,   37,    1,    1, 1279,   56,  638, 1410,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3225,  712,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1,    1, 1273,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 3343, 2137, 2856,  176,  177, 3370,  396,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1181,    1, 1917,  220,    1, 2627, 2177, 1027,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2095, 2985, 2572,   32, 3384, 2678,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2254,   51,    1,  331,   32,  147,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1854,    1,   14,    1,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 647,   1,  32,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 215, 117, 700,   1, 140, 142,   9, 104, 413,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1717,   12,  501,    1,   39, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2135, 1663,    1,   12, 1255,  940,   32,  531, 3340,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   61,  755,  388,  117,    1, 1912,    1,    1,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  754,    9, 2494,  389,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2742,  939,  384,  224,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3339, 2831,    1, 1258,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2503,  163,    1,   12,    1,   32, 2410, 1385,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3245,    1,   39,    9,  501,  827,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2686, 1991,   32,  449, 1463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  388,    1,    9,  312, 1960,  629,   37,  166,  985,    1,\n",
      "          166,  790,  267,  590,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  248, 3234,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1867,  365, 2355, 1013, 2706,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  590, 1421,   45, 2390,  406,  176,  365,  864,  778,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102, 1473,   98,  889,  109,  997,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1109, 1809,  105, 2457,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,  162,  331,   32,  394,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1206,    1, 2042,  325,  449, 1736,  836,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2323, 1554,  284, 1051, 2287,   26,   37, 1260,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  437,    1, 1746, 2699, 2353,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1312,    1, 1940, 2827,  202,  590, 1357,   45, 3340, 1186,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  256,  365,    1,  278,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   72,    1,  785, 1611,  251,    1,   45, 2512, 2227,  872,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1704,  515, 2017,  988,    1, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  855,   32,    1,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1127,   14,  582,  796,   37, 1413, 1291,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  407,   37,    1,  922,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1810,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  361,  819,    1,  565,   39,  411,  424,  914,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1385,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1880,  458,  565,   32,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1984, 1812,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 3316, 1594,   98, 2304,   37, 1413, 3313,  176, 2396,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  424, 1169,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1354, 2529,    1,    1, 2222,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3358,   37,   52,    1,    9,  351,   32,  447,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,  105,  724,    1,  321, 1399,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2810,    1,  167, 2394,    7,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340,    1,  267,  204, 1924,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  790,    1,  410,  297, 1056,  365,  505,  229,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121, 2414,  176,  177,   32,  455,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,  365,  687,    1,   94,    1, 1547,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2175, 1371, 1698,    1, 1935, 2294,  443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,    1,    1,    1, 2367, 2695,    1,    1, 3011,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3051,  947, 2625, 3118, 2791, 1428,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   71,  786,    1,  191, 2822, 2221,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1720,    1,   96,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2964,    1, 2725,   32,    1, 1778,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159,   71,   98,  374,  375,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 2705,   32,  531,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2059,  952,   37,    1,    1, 1277,  193,   37,  319,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2203,   12,    1,    1,  166, 1868, 1172,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  517,    1,  297,   60,  832,    1,  163,    1,   12,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  250, 2960, 2668, 2110,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2310,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3068, 2744, 1273,   80,  918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1439,   45, 1084,  841,  126,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,    1,    9, 1407, 1149,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3339, 3006, 2844,   32, 1094, 2625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2457,    1, 1902,  187, 3300,  650,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  510,    1,    1, 2797,    9,  163,    1,   12,    1, 2705,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2695, 2094,    1,    1,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  327, 1091, 1173,   63, 1936, 2851,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,   51,  221, 2924,  403,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3363,  115,   32, 3343,  863,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  819, 2684,  176,  124,   63,    1,   37,  619, 1253,   98,  818,\n",
      "         1055,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3181,  120, 1159,  228,  402,  631,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,  778,  696,    1, 2911, 1543,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  851, 2421,    1, 1887,   98,  454,   37, 3076,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2871, 1989, 1990,  515, 1684,  753,   37, 2006,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  848,  244,  120,    9,  401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3167,    1, 1900,    1,   37,  151, 3251,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3226,    1,    1,  220,    1, 3265,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  798,  444,    1,  801,    1, 2678,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  420,  647, 1830,    9,    1,  856,  220,  148,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  121,    1,    1,  897,  297,  765,   37, 1598,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,   61,   76,  176, 3076, 2107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1353, 1331,    1,    9,  769,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1127, 1822,   26,   28, 1074,   37, 1443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  852,  176,  105,  104, 1097,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2838, 1805,   28,  220, 2872,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424,  724,    1,   98,    1,    1,  150,   98, 2283,    1,  385,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  716,  730, 2614,  759,  630,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2355, 1013, 2107, 1618,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  315,  632,    1,    1, 1074,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  800,  971,    1,  479,   15,    1, 1069,    6,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 1270, 1660,  453,  572,  156,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  616,  866, 1010,  937,    1,  677,   69,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  602,   12, 1700,    1, 1807,   93,   37, 1121,   37,    1,   32,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2278,   12,    1,  365,  326,    1, 1087,  280,  193, 1090,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1477, 1990,    1, 1380,    1,   98, 1343,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  749, 1634,   37,    1,    1, 2162,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3094, 1231,   32, 2819,    1,  126, 2678,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  429,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3369, 1625,   37,  759, 3118,  132,  191, 1837,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  720,  995,   37,  104, 1146,  106,   32,    1,   45,\n",
      "         1147,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,    1,  176,  395,   26,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796,  872,  396,    1, 2666,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  867, 1236,  449,  668, 2852,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  131,  112,    5,  271, 1907,  162,  562,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3248,    1,  190, 1306,   56,   37, 1700, 2119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 2702,  298, 2414,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3003,    1, 2171, 1107,  802,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,  325,    1,    1,  700,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612, 1713,  166, 1107,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 2203,    1,   32, 1056,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  759,  365,  119, 1653,  608, 1714,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1407,  756,    1,   28,    1,  396, 2917, 3030,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   37, 1427,  117,  983,   82,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1663,  830,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 2234,   37,  132,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2486,    1,  403, 2926,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1537,  340, 1251,  793, 1353,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1848,  494,   37,  619, 1038, 1145,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  590, 2927,    9, 2819,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,    1,  176, 1687, 1022,    1, 3008,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3076,  908,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3349,    1, 1046, 1133,  199,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3381, 1450,  166, 2808,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861,    1,   32,    1,    1,   12,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1, 1411,  659,   45, 2255,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2848,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  150,  105,  356, 2248,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3281,   12, 2463, 2567,    9, 3181,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 3144,  741, 2145,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,    1,   28,  861,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  103, 2680,  710,   37,   84,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,   32,  111, 2502, 2872, 1231,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  103,  931,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  565,    1,    1,   37, 2354,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  453,  315,    9, 3018,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  389,   93, 1137,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  102,  103, 1146,  106,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1537,  379,   32,  182,    1,   37,    1, 3192, 1665,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  467, 1552,  187,  104,  358,  952,  915,    1, 1251,  745,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868, 2609,  531, 2375,  798,    9,  443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1966,    1, 2838,  663,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1479,  458,   12,    1,    1,   32,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2183,  232, 3340,   32, 3339,    1, 3133,  774,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3172, 1090, 1829, 2748,  584,  176, 1037,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1290,  396,    1,    1,   93, 1269,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3184, 2579,  894,   52,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1426, 1183, 2921, 3293,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  600, 2249, 1658,    1,   16,    1,  415,  489,   39, 1658,\n",
      "          617,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2584,  688, 3259,    9,  449, 2041,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 1034,   12, 1586,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1390,  721, 1579,    1,  469,    1, 1612,   37,   52,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2723, 2724, 2636,    1,  794,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  290,  396,    1,  475,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  671, 1078,    1, 1076,  809,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1327, 1484,   37,  439, 1839, 1650,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,   61,  288,   37, 2303,  148,  647, 1523,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  565,   28,  528,  677,   69,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3108,  726,   37, 2872, 3079,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3275, 3196,    1,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  407,  419,   98,  984,    1, 1926, 1927, 1665,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1585,  176, 3407, 3392,   32, 2018, 2414,  176,  177,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2730, 1523,    1,  297,   26, 1039,    1, 2690,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2277, 2250,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1766, 1767,    1, 1702,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,  998,  163,    1,  903,    1, 1149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3178, 1654,   32, 2106, 1990, 3295,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1363,  691,   37,  332,  517, 1074,  220,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159,    1,   98,  605, 2199,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1845,  895, 2011,   32, 2646,   37, 2199, 1345,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1063,    1,    1,   20,    9, 1325,  861,   24,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  758,    1,    1,    1,    1, 1867,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2076,    1, 2017,  384,  824, 1778, 2580,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  867, 1536,  116,  767,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1683, 1428, 1149,  582,  754,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1671, 1976,   32,  429,   45,  105, 1808,  880,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1492,    1, 2826,   32,  966,  776,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2569,  195,    1,    1,   37,  166,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  634,   37,  759,  864,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,   82,    1,   37, 2535, 1690, 1438,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  245,  187,  657,  328,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2162,    1, 2178,  663, 3061,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,  465,  404, 1561, 2545,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  848, 2308,   37,   52,    1,  220, 1234,   12,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777, 1586,   28,    1,   45, 3028,  327,  593,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2737, 1713, 2275, 1708,  187,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1325,  434,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1086, 1684, 3106,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2669,  166, 1509,    1,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3405, 1159,  365,    1,   32,  557,  540,    1,  342, 1082, 2024,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,    1,    1, 1044,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  439, 3344, 1803, 2708,  650,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   37, 2365,   39,  365, 1056,  454,    1, 2232,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2744,  275,    9,  223, 2135,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  708,  709,    1,   12,    1,    1,  582,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2881,  292,  829,   12,    1,   32,    1,   45, 3018,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,    1,    1,  191,    1, 2250,  220,  968,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3155, 1995, 2070,  531, 1849, 1450,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700, 2476, 2572,   32, 3360,  851,  298,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3298,   61,    1,   32, 2760,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 1147,  232, 3047,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  121, 1566, 2095,  868,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1360,  612,   44,    9, 2366,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3101, 2924,  350,  176, 3339, 2735,  548, 2224, 1579,  622,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2315,  166,    1,  443, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1539, 1417,   32, 2573,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1778, 2580, 1108, 1779,   61,  460,  199, 1724,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,  707,   81,   98,  477,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  710,   61, 1345,   37,   77,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1353, 1159,    1,  460, 1085,  218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  119,  293,  837, 1107,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579, 1187,  166,  627,  429,    9,  526, 2105,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  596, 1793,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1252,   51,  698,    1, 3229,   32, 3201,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  506,   32, 2948, 2483,    1,    1,  884,  183, 1526,   45,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1935,  288,    9, 1014,  949, 1704,  848,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 3012,    1,  415,  203, 2342,  565,  453,    1,    1, 1821,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  891,    1, 1821,   95,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1870,  327, 2744,  365,    1, 2146,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2964,  837,  829,   12, 2987, 2762,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  619, 1117,    1,   37,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,  532,  384,  854,   12, 1017, 1153,  554,  118,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1716,  155,    1,    9,  327,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282, 3204,  729,   98, 1978,    9, 2539,    1,  176, 2620,    1,\n",
      "          104,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   28,  105, 2809,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12, 1821,  475, 2175,   37,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,   12,   25,   71,    1, 1572,  191, 1326,    1,   98,   69,\n",
      "          720,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  303,  267, 1488, 1446,  261,  362,  954,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  116, 1107, 2329, 1245,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  454,   37, 2121,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  617,  618,  167,   77, 3032,  199,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  698,    9, 3103, 1517,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  208, 2565,    1,  939,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 3102, 1623, 2619,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  603,   37,  271, 1632,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 1094,  729,    1,    9, 3339,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2700, 2535,    1,    1,   98,  105, 1747, 1425,  105,  938, 2454,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700, 1000,    7,   37, 2322,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3186,  276,  809,   98,    1,    1, 3113,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1509,  151, 1519,  453,  109,  524, 1470, 2973, 1764,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2341,   95,  162, 1587, 2714,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  190,  365, 2757, 2872, 2017,    1,    1,  334,  167,    1,   98,\n",
      "          460,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  744,  365,  119,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  381,   37,    1,  455,  285,   87,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 1949,  810, 1292, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  964, 1484,    9,    1,   45,  365, 1663,  861, 1294,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  354,    9,    1, 2461,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   64, 2414, 1060,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  361,  440, 2064, 2654, 1527,   32, 1081,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  244,  565,  242,    1,  202,  615, 1210,  388,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  335,  105,  271,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  215, 1325,    1,    1,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1920,  515, 3081,  548,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437,   37,    1,  479,  297, 1233,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1783, 1118,   72,  401,  932,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  214, 2832,  429,   28, 2448,  386, 1482,  872, 1090,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3137,   96,    9, 2491,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,  275, 1714,  994,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2700,    1,  105,    1, 2519,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2223,   37, 1459,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  191,    1, 2509,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2637,   12,    1,  140,  449,    1,   45,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3334, 1159, 3295,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,    1,  597,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 326, 256,   1,  37,   1, 918,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 314, 315,  37, 125,   1,   4,  37,   1,   1,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  794, 2869,  535,  656,   32,  166,  215,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2882,    1,   72,   32,    1, 2630,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  864,  267,  190, 1403, 2673, 2426,   37,  105,  582,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3264,  939,  187, 2792, 1831,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3214,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,    1,  910,  897,   37,  119,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  458,   45, 1423,  244,   28,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  590,  388, 2673, 1021,  110, 1724,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2734, 1527,  580,    1,  361,    1, 2633,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1833,   12,  341,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  107,  697,   37,    1,   39,    1,  109,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1581,    1,    1,    1,   32,  442,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   79,  166, 2438,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,    1,  150, 2025, 1592, 1152,   45,  207,  164,  165,  126,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  142, 1336,  798, 2478,  137,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  833,  612,    1, 1719,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  326, 2384,    1,    1,  656,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1017,  297,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  391,  371,    1, 1097, 1656, 1069,    1,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,    1,  163,    1,   12,    1,  297,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  203,    1, 2399,   37,   18,   37, 2310, 1746,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1354,  972,   37,   52, 2713,    1,  286,  437,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2078,   45,    1,    1,  150,    1,   37,   52,    1,    9,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2227,   12,  315,    9, 2235, 2107,    1, 1224,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1838,   79, 2741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   81, 1166,  204,  177,   76,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3289,  967,    1,   45,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1128,    1,  792, 2355,    1, 2871,  820,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  491,   47,  493,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2790,    1,    9, 2500, 3036, 2234,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388, 1645, 2924,    1,   32,  557,  540, 1010, 2357,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  378,    1,   37,  105, 1013, 1299, 1708,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3267,  801,   37, 1742,   26, 2069,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  390,  470,   98,  531,  965, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  616,  120,   98,   69,  720,    1,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1147, 2751, 1910, 2646, 3346,    1,   38,   32, 2375,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1442,    1,   32,    5,  302,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 163,   1,  12,   1,   1, 140, 671,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 241,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1497, 3229, 2787,  459,  331,  881,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713,  166, 2992, 1320,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  388,   45,  166,  224, 1435,   98,    1,    1,  150,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081, 1574,  163,    1,   12,    1, 2003,  475,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3186,  664, 2518,  427,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296, 1523, 1478,  176,  397,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  150,  159,  686,  810,  199,  845,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1997,    1,   32, 2142,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,   81,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1454,  589,   37, 2878,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2953,    1, 2162,  345,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1973, 2463,  415,  105,  183,  717,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  647,  721, 1707,  148,  142,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545,   12,  365,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2097,  519,   32,  581, 1023,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  645, 2851, 2762,    1, 2997,  861, 2060,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2144,  104, 3111, 1810, 2572,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 1500, 1407,    1, 1291,    9,  945,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  408,   45,  111, 1872, 1370,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  954,  488,    1,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,   37,  714,  365,    1, 1332,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1,   37, 1004,    9, 2673, 2836,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  735,  681,  288,    9,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1647,    1,  590, 3146,   98,  409,    1, 1281,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  397,  566,  163,    1,   12,    1,    1,  777,    1, 1281,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1060,  186,   32, 2707,  444,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  947, 1594,    1,    1,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3272, 3253,   37,  726,    1,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1785, 2044,  884, 1084,    9,  417,   69,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1103,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,    1, 1178,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  999,  321,   52, 1488,    1, 1720,  460,   12,  193,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  563, 1327,  187,    1,    6,   85,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 2751,   38,  297, 3080,   45,  443,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1355,    1,  131,  160,  133,  695,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035,    1, 1038,   61,  105,  227, 1265,  917,  600,  920,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1583,   37,    1,  352,   24,   87,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1712, 2261,  245, 1139,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  819,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1073, 1658,    1,    1,  334,    1, 1691, 1178,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2619,    1,   29,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   30,    1,   12, 2080, 2005,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1228,  293,  765,   37,    1, 2019,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 2024, 2699,    1,  191, 2774, 3382, 3356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  574,    1,  191, 2855,    1, 2778,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  844, 1213,    1,  140,  103,  389,  176, 1693, 3092,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1186,    1,  191, 2162,   45,  531, 3102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2990, 1083,  629,   45,   91,    1, 2700,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2844,   32, 2596, 1260,   98, 1147,  947,  434,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3325,   81,   98, 1434,  548,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  747,  156,  686,  191,   64, 1080,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968,  792,    1, 2409,  792,    9,    1,  861, 1906, 2868,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  709,  755,  929, 2405,    1, 1697,  700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  191,    1, 1656,  298, 2372,    1,   45, 2490, 2527,  164,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  398, 1337,  247,    1,   45, 2314,  597,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1414,  596,    1, 1031,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   75,  519,   37, 1604, 1632,    1,  261,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,   37,    1,    1, 1085,    9, 1003,  575,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  143,   15,    1,  144,  145,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  347, 1719,  439,   45,  340, 1184,  408,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  457,    1,   37, 1821,  361,   81,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1221,   12,  590,    1,  105,  872, 1705,   55,  424,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1751,   37, 1046, 1971,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1215,  115,   32,  166,  539,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428,  108, 3369,   37, 2446, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1038,  927,  155, 1574,  600, 3104,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  306,    1,  150, 1627,  215, 1935,  218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1259,   37,  846, 1794,    1,  315,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1144,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118, 2024,   46, 2007,   37, 1195,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2269,    1,  796,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,  105, 1841,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 951,   1,   1, 951,   1,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  63, 166, 862, 262, 263,  85, 419,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  861, 2344,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1774,   39, 1106, 1013, 1626,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  749, 2344,  195,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1794,   37,  168,   98,    1, 2731,   37,    1,    1, 1521,   45,\n",
      "            1,  210,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2685,  321,  612,  836,    1,  220,    1,  424,  889,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  361,    1,  170,   61,  168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1043, 1268,   28,    1, 1572,  191,  185,    1,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,  600, 3184, 2579,    1,  267,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  297,    1, 2555,  798, 2018,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  686, 1850,  455,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  386,   61, 1139, 2845,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  400,   45,  166, 1090,   45, 1056,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  213,   37,  356,  132,  220, 3233,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3053, 2477,  944,  928,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2960,   32, 2597, 2414,  176,  177,  228, 3361,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035, 1036,    9,  717,    1, 1037, 1038, 1039,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,   71,  548, 1785, 1260,    1,    1,  547,   74, 1374,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2476,   98,    1, 1285,  176,    1,  317,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094, 1583, 2414,    1,    1,  356, 1691,    1,   32, 3339,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  935,  315, 1972, 1821,  541,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147,    1,  446,  513,    9, 1527,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2720, 2796,  838,   79,  730, 2614,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275, 2487,   66,    1,   37, 1598,  195,  102,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3102,   32,  531,    1,    1,  957,  146,    9,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  187,    1, 1687,    1, 1221,   61, 1298, 2586,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,    1,  315,    9, 1972, 1821,  541,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  894,  193,  606,    1, 2471,  220,  854,    1, 2018,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  957, 1268, 1099, 1453,  290,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 1722,  325,  179,   12,  116,   50,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,  546, 2410,    1,   32,  517,  443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3180,  951,    1, 2453, 1371, 1221,   51,   52, 1851,  786,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2689,    1,  590,   16,    9, 1485, 1624,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1110, 1296, 3189,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1725,    1,  395,  187,  218,  954,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  691,   12,    1,    1,  267,  590,  214,  693, 1532,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779,  459,  132,  220,    1,  669,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,   28,  453,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  488,  909,  444, 3369,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1043, 1276,   85,    1, 1547,  246,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2096,    1, 3334,  260,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3060, 2827,  176, 2543, 3127,    9,  547,  537,  820,  191,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447, 1887,    1,    1,    1,    1, 1428,  782,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  268,    1,  857, 1469,   37, 1344,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  335,  700, 1734,  444,  649,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3298,  361,  461,  606, 2227,   32, 1515,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1189,    1,  222,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2871,    1,    1,    1,    1,   39,    9, 1517,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   28,  316,   12, 1147, 2537, 1706,    1,   32,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  853,  538, 1167,   12, 1103,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1842,  551,  613, 1475,    4,  202,    1,  615,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  224, 1126, 1954,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1436,    1,   37,  151,    1,    1, 2638, 2135,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  476,   37,  860, 1658, 1521,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1097,   93,  980,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2929,   37,  693,  259, 1108, 1632,  179,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1877,   37, 1835,    1, 2673, 1017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  972,   39,    9,  914,    9,  153,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585,  176,  218,   32, 2755, 2140, 2414,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 1731, 2632,   32,  552,  552,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1285,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  861,    1,   37,   52,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,   12,  954,  353,  388,  183,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 262, 263, 225, 701, 967, 615,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 682, 885,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1363,   12,  365,    1,   37,  688, 1443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  225,   43, 1610,   32, 1109,  170,  469, 1160,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3388,    1,   16,  753,    9, 3375,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  315,   37, 1012,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3036, 2385,  612,  105,    1,  810,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1189,  219, 2673,  895,   61,  227,  550,   98, 2006,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1414, 2856, 1056, 3375,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2448,  386,  244,  245,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  590,  132, 1724,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   55,  105,   23,   45,    1,    1, 3190, 1408,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,   56,    1,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  542,  693, 1030, 1559,    1,   37, 1941, 2548,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2692,  166,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  667,    1,    1,  936, 1901,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  614,   85,  176,  754,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  233,    1, 1579,  613,    1,  302,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1426, 3295,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  549,    1, 1159,    1, 3111, 2572,    1, 1147,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311, 2936,  801,   32, 3116,  922,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   65,  484, 1372,   37,    1,  186,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  448,    6,  110,  187,  455,    1,   91,  837,   93,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1156, 3384,   37,  588,  756,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1292, 1681,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2269,    1,   34,    1,   12,  244,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1670, 2149,    1,    1, 2548, 2107, 1159,  845, 1184,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  793, 1933, 1536,    9,  467,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1707, 1140,   37, 2446, 3032, 1116,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,  275, 1495,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3349,    1,  191,    1,   64,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1018,    1,    1,  384,  166, 3339, 2391,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3188,    1,  590, 1421,   45,  946,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  971,    1,  479,    1, 1326, 1937,   15,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2110,  700,   37,  151,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2301,    1, 2494,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971, 1499,    1,  587,  759,  630,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,    1, 1569,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  382,  293,  420, 1326, 1566,  365,  250,   32,  219,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,  909,  384,  395, 1273,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178, 2911,  168,   37,  166,  806,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3115, 2935,  601,   73, 1131, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,  959,    1,   98,  215,    1,    1,  960,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1023, 1204,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,  162, 2102, 2222,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  133,    1,  561,  103,  122,  187,    1,  907,   32,  365, 1788,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1530,  187, 1797, 3121, 2682,  455,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  166, 2854,  183,  686,   32, 2466, 1089,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  677, 1361,    9,    1, 1362,  166, 1868, 1172,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   94,  640,  119,  845,   45,    1, 1714,   32,  219,  442,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1, 1867, 1894,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2875, 2786, 3028, 2762,  167,   52,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   71,    1, 1340,  832,  187,  615,    1,   98,   10,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2563,  978,  548,  354,   37, 1971,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  446,    1,  104, 1260,   37,    1, 3391,   45, 1730,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  302, 1712,  593,   12, 1354,  792,    1,  792,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,   50,  132,   32,  272,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3308, 1990, 2962,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280, 1924,    1, 3078, 1987,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  550,  104, 1084,  841,  700, 2659,    1, 1260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2476, 2160,   28,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  350,  444, 3339,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  267,   10, 1769,   37, 1119,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1928, 3377, 1082,  487,   37, 1910,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  977,  335, 2505,   98,    1,  504, 1379,   12,  112,  499,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  325, 1412,    1,  669,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903, 1447,  315,  388, 2137,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  805,  384,  793,  573,  533, 1999,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  469,  384,  103, 2918, 1178,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1537,    1, 2414, 1312,    1,   32, 1815,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1157,  954,  580,  388,   31,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056,  336, 2909,   32,  854, 2856,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  680,   97,    1,  289,   98,   65,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  168,  115,    1,    1,   39, 1658,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,  332,  756, 1228, 2690,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  224, 1268,  365,  756,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,  716,    1,  996,   93,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2235,  167,    1,  297, 1815, 3380,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  388,    1,    9, 2672,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  514, 1727,   32, 1405,  133,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388, 2218,    9,  166, 3276,  726, 1045,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 398, 261, 148, 321,   1, 647, 214,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 709,   1, 475, 213,  37, 517, 599, 428,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  474, 2153, 1248,  786,  388, 2286,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  441, 1822,    1,  225,  809,    1, 2461,  721,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  928,    1,    1,   32, 3098, 1890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597, 1405,    1,    1,  868, 1727,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2980, 1450, 2894,  618,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2994,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,  590, 2609, 2825,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56,  709,    1, 1530,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3200,    1,    1, 1452,  220, 3245,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2918,  493,  167,  907,    1,  627,  626, 1004,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1076,  353,  214,  693,   37,  671, 1078,  253,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2841, 3221, 1345,    9,  913, 1810,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,  227, 1333,  176, 1997,  449,    1, 3193,  855,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3147, 2924,  698, 2117, 2699,   32, 3118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1994, 1094, 1428, 3146,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1230,    1, 2175,   32, 1837,    1, 3011,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  105,   72,  401,   93,   45,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2687,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 365,   5,  37,  52,   1,  98, 284,   1, 532,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 829, 251,   1,   9, 810,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1386, 1666,  529,  636,  423,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2264,   37,  619,  192, 1647,  328,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018, 1867,  465, 2320, 1461,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  389,  378,   98,  166,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,  236,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2235,   69,  636,  921,    9,  449,  199,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1249,    1,  176, 2936, 3329,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  560,    9,  680,  339,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  458,   45,  507,  267,  765,  388,    4,   37,  273,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  884,  631,  808,   32, 2103,  617, 1116,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,  176,  166,   65,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  515, 3019,  105,  846,   92,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  691,  300, 3102, 1592,   37,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2975, 1914, 1236,  297,    1,  988, 1825,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  219,  398, 1574,  765,  444,  829,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  191,    1,    1,    1,    1,   39,  176,  163,    1,   12,\n",
      "            1,    1,  633,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  953,  680,  105,  106,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2906,  801,   37, 3172, 3154,  220,  726,  297,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  848, 2767,  845,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2336,    1,    9,    1,    1,  657,  267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  422,   37,  877,    1,   45,    1,  482,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3124,  140,    1, 3329,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  160,  102, 1672,   32,  385,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  261,   39, 3149,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1778, 1901, 1401,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707, 3372,  908,  342,    1, 1511,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  366,  996, 1279,  245,    9,   72,   73,  339,   32,  367,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3227, 1398,  612,  619, 2623,    1, 1444,  415,  753,   37,  619,\n",
      "         1452,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1002,  590,    1,   45, 1918,  446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   37, 1079,  457, 1592,   37,    1,    1,   45,    1,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 1117,    1, 1417,    1,  267, 1099, 1453,    1, 2089,\n",
      "          261,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  315,   37,  271,   28,  182,  352,   24,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018, 1867, 2673, 3085, 1461,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   90, 3242,  204,   61, 2741,   12, 2389,   37,    1, 1827,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   16, 1851, 1370,   45, 2275, 1662,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  889,  341,  157,  410,    1, 2379,    1, 1552,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  959, 1762,  163,    1,   12,    1,  140,    1,  671,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1033,    1,   91,  588, 1488,  112, 2471,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  178,  342,  839,  148,    1,  647,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2700,  798, 2666,   32,  201,  529, 1116,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  964, 1458,  462,  159,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178, 1179,   12,  896,    1, 1987,  415,  105,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2828,    1, 3313,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,    1,    1,    1,  202,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  582,    1,   37, 1540,    1,  455,    1,    1,  187, 1351,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3186,  298,   39,   45,   91,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1166,  894, 1658, 1001,  168,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1017,   37, 1027, 1064,   32, 1013, 1522, 1299,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2210,   32, 1194, 1380, 2017, 3231,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343,  132,   37, 1211, 1428, 3365,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 386, 482,   1, 191, 742,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 176, 177, 228, 229,   1, 105, 230, 231,   1, 232,  90, 233, 234,\n",
      "         182, 235,   1,   1,   1, 234, 182, 235,   1,   3,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,    1,  297, 1260,   98,   10,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129, 3286,  520,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  147, 1380, 1018,  439,   37, 1633,    1, 2795,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  501,    1,  519,  193, 1023, 1628,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  294,    1,   37,  619,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 1583, 2556,   32, 1223, 1166, 2950,  361, 2772,  565,  166,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3215,   98,  837,    9,  311,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,  361,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1730, 2797,    9,  632,  851, 2421,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2307,  952,  726,    1,  193, 2966,  951,    1,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,   90,  104,  193,   37,  576, 1514,    1,   37,    1, 1730,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868, 2061,  395,   98,    1,    1, 1789,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1405,   82,   12,  700,  952,  270,  278,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1576,    9,  584,    1, 1079,    1,   37,    1,  735,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1896,   37, 1154,  487, 3102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  613,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,    1, 1048,   45,  119,  340,  951,   94,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187, 1833,   12, 1909, 1354, 2342,  787,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018, 2414, 3384, 2556,    9, 3380,  722,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,   98,    1,   37, 1910,    1,   37,    1,    1, 1505,\n",
      "            1,  662,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1640, 2527,    1,  884,   95,  220,    1, 2946,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2822, 1793,    1,    1,    1,  596,  651,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3225,  420,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3203,  162,  449,  726,   98,    1, 2579,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  845,  275,  787,   37,  168,   28,   32, 2755,  854,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144,   12,    1,  446,    1,  693,   37, 1557,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,    8, 1442, 2432,    9, 2997, 2454,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  103, 2521,  176,   16,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 3224, 1625,   37,    1,   79,  166, 1987,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3094, 2572,   32,  163,    1,   12,    1, 2731,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 1926, 1927,   32, 1523,    9, 1186,   12,    1, 2223,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,  267, 1220,    1,  548,  863,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   56,  610,    9,  777, 2931,   32, 2592,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2608, 2607, 2985,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,  477,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  776,  297, 1887,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2018, 1009,   37, 1334,  187, 1583,  475, 1190,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  288,  810,  199, 1653,   27, 1714,   32,  310,  442,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2047, 1408, 3118,  249,   32,    1,  357, 1223,  487, 1190,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2415,    1,    1,  384, 1708,   32, 1771,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2463,  872,  420, 1169,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3151, 1360,  612, 1982, 1715,    1,    5,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  199,  472,   39,   32,  296,   20, 1559,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  516,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  361,    1,   37, 1604,   98, 2992, 2444,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1396,  105, 2069,  671,    9,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2733,  776, 2420,  552,  552,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,  166,  645,  550,    1, 2111,    1,  424,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1547,    6,  390,  202,   69, 1665,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  733,  445,   45,    1,  998,    9,    1,  152,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1414,    1, 2183, 3374, 3384,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 2516,    1,  565,  193,  424, 1628,    1,    1,    1,  191,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  258,   25,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 1819,   98,  853,  538,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  617,  618,  289,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   94,  347,   98,  429,    9, 1194,  339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   25,  616,  439,  242,  156,    1,  170,  550, 1257,   69,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,   81,    1, 1172,  951,    1, 1172, 1158,   61,    1,  361,\n",
      "            1,    1,    1,  320,  234,  182,  235,    1,    1,    1,  234,  182,\n",
      "          235,    1,    3,    0,    0],\n",
      "        [   2, 1123, 3238,  515,  730, 2614,  593, 2522,  631,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2824,   45, 2624, 1204, 2690,  820,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,    1,  384, 2028,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  908,  131,  225,  752,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2380,    1, 1414,    1,   37,  930,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1936,  166,   44,   39,   45,    1, 2056,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2222,    1,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  958,    1,  176, 1411,  356,   12,    1,  442,  264,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2697,   98,  844,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  105, 2527,    1,  460,   12,  105, 3022,    1,  460,\n",
      "           12,  166, 1821, 2190,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1591,  159, 1269,   98,    1,  211,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,   69,  102,  245,   98,   92,   32,   68, 1588,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2734, 1950,  640,    1, 1530,  357, 2249,   32,  854,  232,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  183,  978,    1,    1,   32,  221,   37,    1,  414,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 1585, 2414,  786,    1, 2803,   32,    1, 2018,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2339, 1108,    1, 2501,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3312,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  233, 2424,  301,    5,  302,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  919, 2108, 3368,   98, 3349,  187,    1, 1687,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  449,    1,  487, 3160,  928,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  761,   37,  574,  506,   45, 1646,  187,  985, 1527,   87,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  228,    1, 2996,   32, 1227, 1657, 2432,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  592,  536,    1,   93,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1050,    1,    1,   37,  151, 2152,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1426, 2197, 3295,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2431, 2520,  529,  315,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2315,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  437,  733,   48,   32,    1,   91,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,    1, 2682,  957,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,   12,    1,  852,   81,   98,    1, 1747,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,    1, 2257,    1,  328,    9,  282,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2508,    1, 2252, 2466, 2832,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3077, 1241,   28,    9,    1, 2013,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  668,  293,    1,  767,   98,  912, 2285,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91, 1906,  852,   37,  856,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  224, 1258,   37, 1192,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3092,    1, 3213,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  218, 2246,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2188, 1343,    9, 1412,  754,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1583, 1216, 1899, 1015,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178,  163, 1631,   79,   46,  220,  742,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1445, 1627, 1551,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3373, 1000,  958, 2095,  345,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   64,  754,    9,  449,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,  794,    1,  861, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  864,  267,  460, 1360,  612, 2199, 2673, 1017, 1027,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496,   30,    1,  565,  810,    9,  840, 1107,  297,  166,  116,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  460,   12, 2613,   37,    1,  501, 1862,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  253,  562,  158,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  755,    1,  829,    1,   98, 2819,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   61,   62,   63,    1,   64,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2514,    1,  396,  460,  967,    1, 1145,   37,   77, 3243,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2313, 1988,   45, 1809, 2429,  600,   36,    1,    1, 2375,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 928,  32, 854,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 493, 636,  28,  27,   1, 105,   1, 496,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  620,    1, 1240,  193,    1,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089,   51,   16,  531, 1527, 2664, 2572,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1631,    1,    1,   39,  105,  339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   98, 2393,  548,    1,  191, 3043,  649, 2673, 2949,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  773,    1,   32,  166,  818,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  626, 1070, 1700,  482,   37,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,   37,  125,    4,    1,  335,   44,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2266, 1458, 2103,  617,    1,    1,    1,  220,   10,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  840,    1,  229,   37,  166,  160,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,  437,   37, 1539,  104,  111, 1107, 1108,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3115, 3200,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1693, 3096, 2671,    1,  928,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2476,  222, 3207,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2728,  154,    1,  105,    1,  754,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1,  915,   45, 2336,    1,   37,  657,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1890,   37, 1399, 1232, 2164,    1,  917,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  863, 1908,  198,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116, 2542,  951,    1,  166, 1298,    1,    1, 2994,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  547, 2476,    1, 1056, 3157, 2572,   32, 3376, 1585,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1,  864,   37,  907, 1114,   98, 2673,  693,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 2532,  361,  365,    1,   32, 2416, 2884,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3076,  919,  453, 1281,   98,    1,  378,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1118,    1,  726, 2580, 1614,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1829, 2280,  782,  365,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  108,   45, 1115,   93,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  879, 1204,   45, 2580, 2851, 2610,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 1096,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3266, 3224,   37, 1937,   81,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  312,  361,  166,  787, 1292, 2239,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  908, 1193,   69,  209,   37, 1194,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1023,   45,  810, 1149,   98,  105,   74,  357, 2051,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885, 1564,    1,  471,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1481,    1,  612, 1210, 1197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2501,  861,  475,  939,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1186,   66, 1782,  531, 2924,  981, 1159,    1,   12,  454,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3228,  913,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3318,  190,  664,    1,    9,  356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1924, 1018,  836,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1503,  129,  214,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3020,   12,  845,    1,  571,  220,  365, 2775,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    1,  671,    1,    1,  593,  119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766, 2914, 1736, 1935,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1789,   25,  123,  417,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1581,    1,  600,    1, 1299,  328,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3358,   12, 2840,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1169,  160,  102,   71,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 303, 193,   1, 600, 626, 102, 428,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 267,   1,   1, 773,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2806,    1,  182,   32,  209,    1,    9, 1266,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1628, 1215,   92, 1896,   37,    1,  460,    1,  112,  569,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  223, 2420,   86,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 1550,    1,  469,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3120,  720,    1,   32,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  749,  480, 2134,    1,   37, 1173,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  100,   46,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800,    1, 1398,  612,    1, 1590,   39,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1252, 2034,  105, 1298,    1, 2712,   45,  511,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2017,  384,   72, 2113,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1156, 2708,  650,  190,  920, 1844,   32,  890,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,    1, 1564,    1,  714,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  249, 1594,   37,  116,   37, 1000, 2518,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2830,  907,    1,    1,    1, 1822,   52,  166, 1121, 1011,\n",
      "         2227,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2096,  297, 1717,    1, 1842, 1402,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,    1,  530,  104,   32, 1033,  202,  218,   62,  548,\n",
      "         1785,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,    1, 1175,   98,  581,    1,    1,   44,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  975,  197,  388,  763, 1660,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,  338,    1,  108,   98,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1204,  357, 2162, 2360,  203,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,  267,  810,  675,  168,    9, 2371, 1539,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  288,   37, 1611,   69, 1110, 2223,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2073, 1023,  197,  418,   98,  786,  199,  682,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 1178,    1,   32,  531,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2922,    1,  590,    1, 1739,  190, 1844,  917,  176, 2021,  440,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   28, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3367, 1760,    1,    1,   37,   26,  114,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  734, 1401,   37,  119,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  449, 1521,   45,  105,    1, 3022,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  534,  140,  741,   37, 1119,  550,  369,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,  874,  877,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3276,  726,   32,  810, 2915,  444,  810,    1,   45, 2954,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2628,  696, 2629,    1,    1,  229,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 1463,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3261, 1581,  142, 1772,  384,  810,  228,  142, 2458,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 1494,   39, 1345,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 227,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 588, 949,  45, 649,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  670,  105,    1,  825,  680,  166, 2209,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   25,   71,  187,  169,    1,  702,  504, 1017,  159, 1473,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   64,    1,  636,   45,   69,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,    1,  631,   32, 1361,  787,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1,    1,    1, 2206,    1,    1, 3044,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727, 1353, 1159,  365,  613,  616,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2397, 1648,   37,  442, 2108,    9, 1021, 2285,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3252,    1,  134,   37,  449, 3258,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3331, 2712,    1, 1367,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1658,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,    1,    1, 1046, 1350,  927,    1,    1,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2551,  489, 2963,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  671, 2424, 1146,    1,    9,  166, 1022,  199,  452,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810,  566,   98,  409,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  186,  444, 1107, 2086,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1777, 2739,  696, 3181,   37, 1387, 1056, 1394,   45, 1545,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  203,  361, 1433,    9, 3132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3155, 2456,    1,   85,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,   37,   77,   37,    1,    1, 1563, 1603,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    8,  228,    1,   98, 1778, 2558,  327,  593,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  306,  777, 1085,  256,    1,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 3365, 1335,    9, 1515,  949,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1561,  614,  166, 3034,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,  671,  833,  612,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   32,  443,   98,    1,    1, 1592,   37,  815,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2241,  650,  580,    1,  100,   32,  233, 2722, 3074, 1215,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,  284,  856,    9, 1973,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1,   32,    1,  361, 1013, 1522, 2788,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2217, 1830,   37, 2714,  365, 1277,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1674, 1443,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2948,    1,    1,    9,  810,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,   12, 1509,  729,  590,  427,    9, 3289, 3303,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  125,    1, 1608, 1478,  220, 3115,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  905, 2166, 1455,  156,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  749, 2129, 2900, 1057,  600,  790,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2466, 1209, 1125,   98, 3009,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1154, 2853,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  244,  565,  242,    1,  202,  615, 1210,  388,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 823,  37,   1, 104,   1, 303,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 105,   1, 173,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1419, 1657,  861,  328, 3011,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746,  515,  829,  152,  116,  844,  132,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3144,   12,  863,   46,  245, 1979,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  420,  958,  111, 2165,  565,  672, 1159, 2488,    1,  378,\n",
      "          318,  361,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1932,  295,    1,    1,    1, 1240, 2354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,  967, 1781,  453, 1935,    1, 1108,   32,  166,  215,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  528, 1511,    1,  584,  741,   51, 1046, 1787,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2244,    1,    1, 2286,   37, 1154, 1029, 2821,  272,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1527, 2664, 1999, 2572,   32,  531, 1841,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    8,    1,  304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  694,  845,  456,   85,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2507,  865,  202,  203,  445,  967,  460,  810, 1382,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  479,  267, 1056,  103, 1682,    1,    1, 2297, 1009,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  379, 1982,    1, 2208,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1100, 2071, 1331,  275,    1,    1,  191,  388,  763,  118,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   65,   12,    1,  267,   67,  418,  606,  105,  454,   37,  168,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,  716, 1913,  401,  197,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  275,    1,  608, 2388,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1620,   45,    1, 2047,    9, 3049,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3088,    1,    1, 1095,    1, 1936,  119, 1077,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   69,    1, 1044,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3337,    1,  187, 2773,   45,    1, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  361, 1724,  460,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 1827,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1473,  528,   71,   32,   69,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,   37,    1, 2147,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  546,  494,    1, 1132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  864, 1707,  342, 2673, 2362,    1,  476,  388,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2424,  547,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2126,   32, 2884,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1333, 1530,   32, 1785, 2044,   32,  645, 1260,   98, 2703,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   20, 1259, 1523,  193, 1634,   37,  741,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  538,    1,    1,   12, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  215,    1, 2147, 1074,   37, 1046,  365, 2429,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325,  163,    1,   12,    1,    1,    1,    9,  372,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  191, 1691, 1206,    1,    1, 1223,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2976, 2786, 2580,    1, 2762,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  384,  166, 1264,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700,    1,   37,   26,  238, 2578,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1674, 1123, 1564,  105,  686,   32, 1617,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1, 1273, 1151,  102,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2494,  872,    1,  608,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 1022,    1,    1,   26,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437,  562,  220, 1354, 2800, 2565, 2937,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1810,    1, 2308,   45,  166, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 1572,    1,   37,  151,    1,   12,    1,  112,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  176,  361,  612,   37,  125,    1,  191,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  924,  952, 1771, 2661,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  931,  729, 1573,  581,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2563,  949,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3117,   77, 1224,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1716, 1718,  327,   15,   37,  686,  131,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  398,    1,   59, 1634,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,  365, 2983,   51,  335, 1400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1591,    1,  884,   79,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,    1, 1796, 1726,   37, 2000, 2024, 3037, 2537,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2939, 2562, 1674,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496,  575, 1111,   98,  104,  954,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  245,   32, 2800,    1, 3109,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  177, 2844,   32, 2729, 2137,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453, 1822,    1,  453,  156,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1309, 1009,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1059,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  879,  693,    9,  647, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2804,   45,  709,    1,    1,  928,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  370,  371,   37,  619,  104,   59,   32, 2025, 1527,  384,  437,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1107,  519, 1594,   37,  625,   37, 2446,  116,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  134,  938,  220,  133,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  539,    1,    9,    1,    1, 2401,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2742,   45, 1163,    1, 1299,    1,  515,   28,  317,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  846,  115,    1,  575,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1584,  105,    1,    1,    1,  395,   61,  105,  365,    1,   45,\n",
      "         1116,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1808,  978,  673,  793,  936,  529,    1,  423,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708, 2409,  267, 3101, 2548,  688, 1590,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2840,  675,    1, 1583,    1,  138,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  352,  162,  388,  199,   37,    1, 1879,   37,  104, 1583,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  503, 1581,    1,    1,    9,    1,    1,  453,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   95,  473,  474,  908,  477,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  291, 1774,   39,    1, 2232,    1,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1586,    1, 1351,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1070, 3207,   37, 2192,   28,  671, 3126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1312, 1530,   32, 3279,  548, 3343, 2696,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  366,    1,  890,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1782,   85,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1006,    1,  765,   37,   62,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1122,  361, 1170,    1,   98,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1801,    1,   89,  190, 2449,  684, 2541,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  288,   37, 1527,  968,  195,    1,  469,\n",
      "          379,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  207, 2931,    1,   37,  619, 1204,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2692,    1,   32,   59,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2, 225, 218, 801,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 104, 442, 448, 490,  37, 182,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3204,  361, 3253,  865,   37, 1523,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1403,  365,    1,   37, 1364, 1365, 2734, 2372,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056,    1, 1612, 1584,  168,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 2932, 1079,  777, 2264,   37, 1413, 2948, 1222,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3352,    1,  531,  793, 1346,  215,   37,  221, 2924,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1977,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  103,  381, 1682, 2434,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2455,    1,  640,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   50, 1765,  388,  972,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,    1,   81,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3128,  267,  163,    1,   12,    1,  580, 1463,   45,    1,   32,\n",
      "          531,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,    1, 2172,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    9, 1888,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,    1, 3257, 1758,  176,  104,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3334,    1, 2018,    1,  754, 1280,  910,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  591,    9,   91,  187,  517,    1,  522,   37, 2199,   60,\n",
      "          832,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2475,    1, 3263,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640,  306,    1,  500,  361, 1130,  220,  768,  149,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  726, 1380,    1,   32, 1394,  631,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2227,    1,    1, 1636, 1017,    9,    1, 2706, 1998,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,  361,  326,  221,    1,   37,  166,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283, 3260, 3232,  548,  547,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  546,  494,    1, 1132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,  105,    1,   82, 1484,  112,  993,    1,  105,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2514,   37,  688,  166, 1411, 2596,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2877,  488, 3155,  220,  622, 1995,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1481,  859, 1994, 2095, 3273,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,  179,  361,  180,    1,  105, 1523,  220, 2807,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   75,  980,  845,  846, 1074,  261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3329, 1990, 3295,   37, 2560,  166,   56, 1509, 2308,   32,  166,\n",
      "          593,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1118, 2978,   12,    1, 1539, 2306,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1829,    1, 1011, 1039,  948,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1987, 1554,    1, 1685,    1, 1512,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1419,  365, 1718,    1, 2079, 1228,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  552,  552,  725,  193,    1,    9, 2730,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 3192,    1, 1464,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2343, 3404,    1, 1011,    1,  104,  622,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  945, 1294, 1564, 1480, 2219,    1, 2150, 1211,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1117, 3058,    1,   37,    1, 3342,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2680, 2329, 2650,  220, 2798, 1289,   98,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  649,   31, 1042,  995,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  335, 1056,  387,  242, 1283,  102,    9,  365,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  795, 1458,   85, 1969,    1,    1,    1,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  306,  912, 2026,    1,    1, 2039,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  889, 1675,  475, 1454,  673,  910,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,    1,    1,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  500,  225, 1042,   98,    1,   45,  306, 2015,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3079,   37, 1195,    1, 2139, 1232,   46,  193,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 1281,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  573,  639, 1587,   45,  527,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,    1,  215,  819,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,   37,   52, 1066, 1159,   56,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1492, 1976, 1039,   45,  985, 2130,    1,  928,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  295,  289,   98,   32,   95, 2913,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3129, 3324,    1, 1056,   59, 1714,   32,  914,  156,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497, 2192, 3229,  331,  881,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1818,  147, 1550,    1, 1377,   37, 1994,    1,  625,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043, 2418, 2335,   74,  245,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1165, 1278,   85,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,    1,  191, 1063,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1594,   85,  742, 1992,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   26, 3282, 1133, 2250,    9, 3253,    1, 3230,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  360,    1,  142,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3033,   51, 1371,    1,    1, 1345,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1711,    1,   32,    1,    9, 1485, 3365,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  857, 1567,  515, 3187,  726,  297,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1481,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1640,  267,  103,  147,    1,    1, 1175,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2964,    1, 2102, 1107, 2285,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  879,    1,    1,   32,  531,  191,  786,  356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1186, 3109, 2985, 1634,   37,  104, 2095, 2393,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777,  779,  861,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  870, 1087,  835,    1,    9,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 1090, 1829, 1252,  176,  501,  827,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   45, 2382,  618, 1167, 2259,    1,   12, 1140,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1542,    9, 1929, 1523,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1731, 1895,    1,    1,  297,  864,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,   13,   12,  475,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 1527,   32, 3349, 2827,   28,  191, 1338,\n",
      "           45,  764,  384,  957,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  782,  590,    1,   45, 2673, 2375,   32,  864,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1390,  474,   51,  498,  389,    6,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,   37, 2446,   69,  532,   37,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  640, 1034,  340,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3355, 2040,  187,  204, 2770, 3358,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  275,   81,   37, 3024,  220,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1102,   92,    9, 1307,  618,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  792, 1101,  792,    1, 1401,    1,  786, 1056,  176, 2388,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739,  852,   37,    1,  730, 2203, 1044, 1045,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3221, 2689, 1717,    1,    1,   30,   28,  202,  614,   85,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,  373,    1,    1, 1405, 1213, 1439,  297, 1622,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1700, 3340,   32,  531,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1723,    1,  891,   32, 3311, 3310,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   26, 1039,  911,    1,  365, 1718, 1967, 2146,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,   37, 1124, 1821,  191,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2106,    1,  429,   98,  121,   12,   69,  361,  493,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  361,   10, 1046,   79,  297,  443,    1,    4,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  386,  295,   82,  387,    1,  389,  390,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  580, 1787,   45, 1300,  669, 1323, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 616, 120,  98,  69, 720,   1, 863,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 167, 860,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  561, 1755,    1,    1, 2888,    1,  597,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  108,   45,    1,  173,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  452,    1,  252,    1, 1114,    1,   32, 1430,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  863,    1,  817,    1,   32, 3360,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  393, 2520,  365,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1935,    1,    9,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  288,   37,   52, 1018,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671, 1078,   51, 1403, 1836,  741,   98,    1,  142,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1060,   45,    1,   45, 3373,  901,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1605,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,  325, 1412,    1,  669,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1082, 3105,   37,  686,  163,    1,   12,    1, 2860,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3110,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  586,  387,  196,    1,  132, 1371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  602,    1,   98, 2673,  315,  548,  864,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3403,  176, 2018, 3392, 2414,  547,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  355,    1,    1,   37, 1638,    1,    1,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2266, 1428, 1906,  894,  741,    1,   98, 3369, 2824,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  215, 1275,    1,  560,    1,    1,  452, 1014,    1,    1,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2384,  810,   32,  786, 1766, 1767, 1499,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1849,   26,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  936,  845, 1208, 2759, 2168,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,  750, 1563,  872,  606, 1953,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433, 2424,  302,    1, 1038,  199,  297, 2650,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  289, 1502,  267,    1,    1,   37, 1046, 2298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2565, 2908,    9,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1477, 1990,    1,   98,  166,  260,  176,    1,    1,    1, 1401,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,  530,    1,  687,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  694, 2055, 2056,    1,    1,  198,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   94, 2060,   93, 1258,   37,    1,   32,  572,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  691,   51,   92, 1184,  347,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593, 2153, 1816,    1,    9, 2868,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2097, 3391,    1, 2292,   32,  403,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98, 1915, 1975,    1, 1521,    1,   17,  774,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  727,  590, 1954,  469,    9,  179,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2531,    1,  854,  606,    1, 1744,    1,    9,   46, 3371,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  312,  821,  456,  667, 1325,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537,  872, 1921,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3325,   12,  638,  356, 2093,   98,    1, 1318,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965,    1,    1, 2550,  384, 1821,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  288,    9,    1,   26,   14,  343,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1509, 1228,    1,  100,    1,  200,    1, 2581,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,  192,  220,    1,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  132, 1710,    1,  439,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  999,    1,  388, 2529,  327,  529,  617,   61,   98,  166,  454,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,    9,  947,  764,  444, 2834,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1181,  739,  596, 1151,   15,   37, 1121, 1411,  356,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  938, 1231,  220,  133,   32,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  388,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,    1,    1, 3396,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2777, 2202, 1264,  187, 3115,    1, 3285,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3323, 1173,   55, 1444,  565,   32,  105,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2279, 1874,    1, 1429,  191,  395,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2795,   51,   52,  415,  579, 3076,  719,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051,   96,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  794, 1273,  777, 1013,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2993,    1,    1, 1117, 1525,    1, 1781,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3169,    9, 2069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  399,    1, 2091,    1,    9,  755,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  507,  539,  948,   37,  142,    9, 1933,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1891,  652, 2721, 1844,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  167,  664, 3238,    9, 1090,  228,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  831,   98,  889,  109,  509,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  289, 1512,   32, 3118,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,    1,   12,  432,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2500, 2485,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1, 2657, 2043,  260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3072, 2884,    9,  938, 2538,  920,   98,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3241, 1284,    1,    1,  202, 1444,  729,  245,   37, 1245,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,   37,  693, 1108,  176, 1105,  787,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2993,    1,  829,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2751, 2572,   32,  531,   12, 3383, 2337,  104,  315,   37,\n",
      "            1,   28, 1414,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  755,    1,   98,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3403,   12,  433,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  678,    1, 1908, 2925,  914,   12,  449,  599,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  936,  131,  332,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2279,  288,    9,  786,   74, 2237,   37, 3349,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190,    1,  374,    1,  166,  855,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  117,  633,  267, 1723,   61,   39,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777, 1008, 1644,  548,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  361, 2254,  875,   39,   45,  147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158,  542,    1,  297,  365, 2452,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2008,  597,    1,  609,    9, 1204,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  176,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,  103, 2184,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2068,    1,  213,   37, 1421,  220,  730, 2614,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1174,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  487, 3160, 2572,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1337,  506,   45,    1,  361, 2332,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  398,  868,   85,    1,    1, 1994,    1,  625,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1550, 1861,    1,  361, 2582,    1,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   63, 2930, 2263,    1, 3310,    1, 2047,   37,  947,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  456, 3149, 2774,  778,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1025,    1,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  197,   32,  260,  220,  570,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  299,  952,   37,  439,  804, 1167,    1,  217,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938,    1,    9,    1,    1,    1,    9, 3262,  542,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  953,    1, 2405, 1750, 1034,  340,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868, 1484,    9,    1,    1,   98,   80,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   89,  387,  317, 2457,    9,  954,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 1065, 1190,   37, 2122, 3051,  957,   98, 3118, 2299,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3087,  640,    1,    1, 1897, 2396,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,    1,    1,  437,   32,  395,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1123,  892,  428,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  736, 3380,  808,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  691, 2122,    1, 2418,   28,  807,  550,  369,   48,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2238,  361,  657,  498,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   95,  473,  360,  104,   22, 2362,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2937, 2910,    1, 1769,   37,    1, 2086,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  640,  365, 1653,    1,  395,   93, 1441,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1304,   37,  875,  220,  422,    9,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  632,    1,  469,   37, 2123,  493,  361,   69,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,    1,  353,  242, 1661,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  190, 1343,   32,  593, 1990,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2688, 2572,   32, 2433,  531,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2468, 1822,  138, 1884,  636,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1713, 1027,    9,  501, 1975,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  398, 1579,  399,   98,    1,    1, 2326,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 1429,  217,  875,  220,  422,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3227, 1421,  709, 1110, 2125,  439,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  957,  692,   37,    1, 2971,   45,    1, 1439,   45, 1809,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  622,    1,   28, 2140,  591,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   26, 1039,    1, 1522, 3031,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  697,   37,  720,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  387,  121,    1,   98, 3093,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    9, 2249,  777,    1,    1,  105, 1535,   45,  901,  361, 1976,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3271,    1, 2805,    1,   12,   24,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2809,  919, 3231,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  884,  845,  629,  342,  789,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  567,  510,    1, 1750, 2433, 2028,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  684,  685,  686,  339,  687,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   49, 1974, 1828,   37,  395,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3277, 1082, 3112,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2843, 2523, 2742,    1,  220,  505,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596, 1151,   15,   37, 2449,  526,  424,  401,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  475,   45,  743,   12,  967,  388, 1857,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  917, 1594,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  864, 1877,   37, 1806, 3107, 3366,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  805, 1825,   28, 1290,  396,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1189,    1,    1, 2729, 1231,  297, 3040,  722,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321, 2993,  688,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  335,  829, 1310,    1,  844,    1, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2819,  126, 1478,    1,   32,  166,  321,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  974,  975,  737,  197,  418,  419,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1109,  727,    1, 1200,  494, 2809,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2974,  872,  288,   37, 2354, 1114, 1602,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1147, 2548, 1976, 1333,   37, 2162,   98, 2041,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  105, 1173,  176, 2039,    1, 2208, 2298,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,   37,  582,  539,   37, 2884,    9, 2591,  187,   10, 1293,\n",
      "           81,  404,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  388,  777,    1,    1,  166,  227, 2728,  116, 2542,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  705,    1,  810, 2621,  543,    1,   37, 2024,  226, 1114,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  506,  782,    1,  354,   45,  275,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1717,    1,  669, 1478,   24,    1,  220,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2274,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2423, 1188,  857,   44,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1290,  396,  701,    1,    1,  102, 1253,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3072, 2981,    1,  183,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2409, 1638, 1112,  176,  531,   12, 2179,  627,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2309,   98,  166,  448,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  507,  539,  190,  193,  142,    9, 1933,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  221,   98,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1128, 2384,  365, 3044, 2168,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1838,    1,  191, 2505,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1550,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1968,  200,  365,   40,    1, 1775,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  858,   12,    1,  599,    1, 2645,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1430,    1,  531,  361, 3388,  103, 1891, 1726,  122,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2018,  251, 3343, 2095, 1527,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1536,    9, 1211,  639,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  779, 1778, 2580,  535,  656,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1618,   28, 1013, 1522,  443,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  964, 2386,    1,  539,   45,    1, 3149, 1730,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 3005,  272,   39,  220, 3142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1221,   12,    1,    9,  166, 1251,   45,    1,   37,  168,    1,\n",
      "           28,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087, 2614,   12,    1,    1,  220,  579,   51,   52,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,    1, 1425,  105,  106,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2291,  321,  612,   77, 2565, 2017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  422, 1268,  290, 1159,  224,  225, 1816,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1740, 1380, 3144, 1048,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1092, 1236,  104,  116,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  949,    1,  650,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1656, 1091, 1542,   37,  865,   37, 1604,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1772,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2032,   79,  632,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3244, 1902,    1,    1,  951,    1, 3227,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  582,   37, 1081,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1176,    1,   45,    1,   12,  861,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3057, 2520, 2362,    9,    1,  903,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  431,   98,  430,  109,  509,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1572, 1414,    1, 2029, 1619, 3391,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  331,    1,  612,    1,  105,    1,  952,    5,  641,  297,  537,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977,  880,  190, 2286,   37,  168,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1157, 2785, 2372,  664,  753,  187,   64,  431,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1234,    1, 1112,   45,  211,    9, 2979, 2869,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  656,  940,   61,   62,   23,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  294,    1,    6,    1,  636,  443,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1825,   94, 2334, 1222,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,  140,  449, 2085, 1674,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1360,  612,   52,    1,   37,    1,    1,    5,   98,  199,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2238,   12,  365, 1151,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   37,  130, 2943,    1,  700,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1537,    1, 2572,  191,  947,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  640,  187,  163,    1,   12,    1,   68,   25,  832,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  105, 1438,   37, 2024,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 1082, 1853,  193,   37, 2856,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2858, 2665,  614,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 3397, 2682,    1,  446,   98,  443, 2938,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1488,  632,  330, 1710,    1, 3071, 2705,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504, 3043, 2527,  164,  400,  542, 2500,  345, 2047,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2526, 1114, 2631, 2446,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,   37, 1174, 1958, 2355, 1013,   32, 2020,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3343, 2924,   64, 3376,  611, 2144, 2572,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151, 2511,  535,    9,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1260, 1478,    1,   32,  166,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  148,  459,  132,   37,  151,  647,    9,    1,  182,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1821, 2057,  580,  230,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  218, 1086,  176,  119,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1340, 1194,    1,  873,    1,    1,  384, 1611,  222,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1117,  741, 1211,   45, 1328, 2298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  330,  183, 2258,  220, 1772,  361, 3034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2950, 3060,    1,  176, 3360, 1325,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98, 1796, 2164, 2372,    1,  947, 1152,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1238,  398,   57,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  740,    1,  741,  288,   32,    1,    1,    1,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2884,    9, 1938, 2607,  382, 2633,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3343, 3365, 1066,   28,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1,    1,  590,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 1339, 1167,  833,  612, 1604,  176,  166, 1606,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1222, 2932,  168,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,    1,  691,    1,    1,    1,  119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2048,   32,    1, 1075, 3048, 2923,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,    1,  691,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  176,    1, 3009,    1, 3024,   12,    1, 1821,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3369, 1583,    1, 3118, 2649,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1177, 1403,  388,    1,   37, 3349,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2838,   37, 1918,  297,  331,   12,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116,  437, 1707,  829,   12, 1994, 2819, 2389,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1773,  571,   37,  197,   98,    1,  682,    1,  677, 1228,   15,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3117,  688, 2633, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  844,    1, 2536,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3239, 1542,   37,    1,  166,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  203,   37,    1, 1051,  361,    1, 1074,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,    1, 1354, 2556, 1730, 1638,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3335, 1082,    1,   37,  877, 1515,  813,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   35,    1,  191,  333,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,    1,   37, 1194,   73,    1,  726,   32,  492,  922,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1186,  140,  163,    1,   12,    1, 1876,    9, 3388,   46,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  538,  681,  837,    1,  218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1384,  408,    1,  567,  686, 1162,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3389, 2856,   32, 2597,    1, 3383,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3006, 1439,   45, 2834,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,   52,    1,  202, 1444,    1,  612,    1,  384, 1338,\n",
      "           45,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   12, 3098, 1139,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1885,   12,  159,   28,   98,  425,  426, 1184,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1214,  571,  754,  548, 1056, 1797, 2041,  140,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  626,  721,   37,  907,   32, 1411, 1875, 1890,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1245,   30,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  942,  958, 2623, 2624,  400,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  716,  143,  763,   76,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2480, 2910, 1527, 1209,  861,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  369, 1249,  308,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1475,  636,   45,    1,  170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1170,   37,   22, 1940,   12,    1, 3023,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  709, 2925,    1,  707,   37,  611,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2266,   12,  627, 2126,   28,   32,  166,   22,  220,  287,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2823,  736,    1,    1,    1,    1,    1,\n",
      "          388,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  897,   79,    1,    1,  540,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  657, 1702,  981, 1159, 1273, 1821,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3290,  686,  135,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  550,    1, 2650,   61, 1778, 1851,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61, 2793,    1,  267, 2068,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  671, 1078,   37,    1,  142, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  256, 2025, 1718,  361,    1,   37,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1087,  733,  340,    1,  327,   32,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1189,    1,  287,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  300, 2924,   37,  764, 1157, 2785,  591,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2231,  449, 1405,  776,  600,    1,  361,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  398,  868,   85,    1,   45,    1,  100,    1, 2339,    1,   45,\n",
      "          116,   29,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403, 1447,  267,   10,    1,  763,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3267,  801,   32, 1742,    1,    1,   39,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,  315,  365, 2294,    9, 1412, 2945,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  694, 1408,  166, 1973,    1,   32,  453,    1, 3115,  335, 1194,\n",
      "           73,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,  492,  947, 2347,   32, 1994, 2095, 2625,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  386, 1086,  742,   46,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647, 2120,   82,   32,  148, 1523,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1380,  667, 1260,   37,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282,  873,    1,  147, 2795,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1962,  140, 1479, 2656,   24,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1503,  615,    1,  929,  202,  166, 1502,  132,   61,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  129,    1,    1,    1,    1,    1,  361,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3209,    1, 3231,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  203,  166,    1,  612,    1,    1,  453,    1,  175,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1056, 1485,    1, 3365,    1,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3161,  951,    1, 1739,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 1656, 2909,   32,  531, 2856,  176,  177,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2003, 2960, 2414,   32,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  992,   85,  528,  198,  478,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3151, 2308,  894, 2286,  105, 2276,   33,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,    1,  140, 3292,  671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1414,  856,   32, 3383, 3102,   61,    1, 1919,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 1585,  640,  104, 3150,   32,    1,    1,   56, 2572,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,   12,    1,  387, 2012,    9, 1151,   93,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1178,    1, 1064,  247, 2225,   37, 1444,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  160,  783, 1519,   32, 1169,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  442,  475,   45,  342,  884,  104,   37, 2082,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  218,  913, 1591,    1,  155,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3244,    1,  198, 3130,    1,  750,   32,  354,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2713, 2692,  640,    1, 2165,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,    1, 2830,    1,    9, 1797,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1891,  922,   37,  429, 1193, 1953,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2583,  792,    1,  792,   37,  631, 2741,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 325, 663,  37,   1,   1, 195,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 579,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  597,    1,  366, 3354, 3006,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  476,  864, 1806, 3107, 3366, 1604,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  787,   12, 1844,   45, 1505, 1258,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3265,    1, 1650,    1,   12, 1573,  199,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1900, 2286,   37, 1527,    1, 1582, 2372,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2066,   69,  102,  576,   25,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1280,   45, 2758,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,    1,  365, 2452,  517,   12,  176, 2197,   16,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1390, 2405,    9,    1,   45,  219,  295,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1708, 2290, 2151,  176, 2087,  433,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1458, 1211, 2071, 1331,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,    1,  150, 2773,  580,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  583,   32,    1, 2137,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178, 1592,    1,    1, 1178, 2663,  798,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,  132,    9, 2274,   12,  517, 1089,  776,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2722, 3074, 3219,  872,  420, 1169,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1500,    1,  102,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  269, 2264,   37,  619,  388, 2043,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  816,  187,  104, 2767, 2250,   98,  955, 1356,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 2924, 2856, 3149, 2751,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 1880,    1,    1,   61, 2175,   79,  105,\n",
      "          320,  320,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2620,    1,    1,   37, 1758,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2, 548, 166,   1,   1,   1, 938, 729, 580,   1,  74,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 105, 613,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  611, 2113,    9,    1, 2042,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,  311, 2936, 3159,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2001, 1389,    1,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,  251,    1,  279, 1402,    9,    1, 2043,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1512,   32, 3118,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2819,    1,  365,    1,   37,  116, 2264,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2144, 1530,   32,  531, 1656, 2950,    1,   98,  104,  863,   74,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 2279,   81,    1,  321,  612,    1,    1,    1,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  617,  259, 1091, 2056, 1284,   32, 2866,  220,    1,   45, 1412,\n",
      "         1107, 1379,   12,  112,  499,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2267,  872,    1, 2267,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2614,    1, 3132,  619, 1542,   37,    1, 1728, 1114,    1,   12,\n",
      "         1846,   32,  272,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0],\n",
      "        [   2, 1390, 1426,  132,  220, 1354,  587,   98, 1066,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  552,    1,    1,   46,  600, 2638, 1876,   43,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  705, 1458,   37,   26,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  286, 1479,   37,    1,    1,    4,   37,  854,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,  331, 1159,  636,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2238,  794,    1,  168,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   69,    1,  388, 1328,  763,    1, 2112,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  193,    1,    1,    1,  267,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  858,   93, 1071,  586,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  379, 2286,   37,    1,    1, 1675,  475,    1,   37, 1334,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,  361,  326, 1413, 1414,   37,  504, 1285,  176,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3354,  477,   98, 2095, 2172, 2791, 2414,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 2246,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  165,    1,   32,    1,  420,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  437, 1635,  103,  314, 1630,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1422,  132,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1877,    1,    9,  647,   17,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1717, 1606, 1756,  167,    1,  388, 1384,  522,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  819, 1587,   45, 1151,  361,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2596,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2648, 2801,    1,  196,   37,  345,   32,  517, 1339,  112,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,  103, 3370, 3350, 1025, 2572,   32, 2625,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2043, 2962,  777, 1085,    1, 1117, 1943,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  293,    1,   37,  275, 2211,  151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 2246,  856,    1,    9, 1971,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 119,   1,   1,   1, 753,   1, 311,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 219, 927,  45, 657,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2807,    1,   37,  606, 1857,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  300, 3079,    1,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2028,    1,    1,  548, 1404,   12, 1313,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1527,  567,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1684,  856,    1,   61, 2175,   98,  198,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1891,  844,    1, 1089,   45, 1428, 3365,   32, 3360,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   56, 2548,    1,    1, 2844,   32, 1815,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  764,    1,    1,  166,  844,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1, 2623,    1, 1354,    1,  220, 1230,  132,    1, 2408,\n",
      "         2606,  318,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,    1,   81,   37, 1204,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  657, 1148, 1033,   37,  815, 1718,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2059,   12, 3081,    1,  443,    1,    1, 2322, 1373,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1083,    1,   45, 2471, 1813, 2163,    1,  361,    1,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,  476,  590,  171,    1,    1,   37,   80,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  123,   28,  548,  198,    4,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   98,    1,   45, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  696,    1, 2507,  726,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  291,    1, 1539,  365, 1992,   37,   26, 1039, 1085,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  375,   37,  151,    1,   32,   59,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1917,    1,    1, 1355,    9,  647,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  479, 1337,  250,  568,    9, 1338,   45,  436,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  688,  447,   37,  726,  453,  449,   65, 1990,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 1021,  261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3337, 2660,  119, 1477, 1990,    1,    9,   91,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  957,  396,    1,    9,  166,  449,  199,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,   37, 2192,    1, 1228, 2017,   32,  659,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  844, 1151,  669,  162,   59,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,   98, 2631,    1, 2347,   32, 2291,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2514,    1,   32,   44,  187,  479,  288,  105, 1480, 1224,   32,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   64,   12, 1950,  418,   37,    1,   32, 3349,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1919,    1,  492,    1, 1532,    1, 1167,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3043, 3370, 2856,  228, 3343, 2924,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   99,  347,   66,  816,  187,   94,    1,   69,  817,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2900, 3232, 1057,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2835, 3109,  228,  297, 3393, 3389,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,  733,    1,  118,   45,   22,  447,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  220,  425,  426,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  714,    9,  829,    1, 2639, 2690,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  384, 1902,    1,   32, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  609, 1070,   37, 1334,   39,   45, 1038,    1, 1377,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3161,    1,  590,    1,   32, 2487,  806,    1, 1268,   72,   32,\n",
      "          182,    1, 1417,    1,   12,    1, 2788,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2041, 1463,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2868, 1554,   98,  310, 2579,    9,   46,   98,    1,    1,  104,\n",
      "         2924,    1, 1789,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  557,  540, 2292,    1, 1645,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   59,    1,  606,    1,  617, 1397,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1211, 2256, 1166,  166,    1,  565, 1936,  104,  327,  593,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1306,  581, 1463,  444, 1364, 1365,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  794, 1537, 1463, 1708,  220,    1, 1844,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  597,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9, 1185,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   89,  163,    1,   12,    1, 1458,    1,  734,  591,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3262,    1,    1,    1,  101,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2746, 2825,   28,  388,  365, 2911,  420,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129,    1,  200,    1, 1151,    9, 2261, 2973, 1764,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1431,  325,  487,  700,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3342,   12, 2059, 1550,  808,   32, 2282, 2564,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1861,    1,    1, 2122, 1850, 1423, 1443,   32,   46,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1169, 1194, 2581,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1523,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1429, 2327, 1420,    1,  191,  395,  471,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2953,   51,  345,    1,  361,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2452,  517,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2071,    1, 2192, 2691,  365,  809,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3231, 2277,  228, 2202,   32, 2513,    9, 1460, 1918,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3363,  431, 1918,   32, 3343,  863,  187,  741, 2116,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2290, 3259, 1285, 3241,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  794, 1106, 1107,  111,  525,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    6,  157,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  755, 1958,  207,  259, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3233,  186,   37,  688, 3234,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2504,  614,    9,  633,  296,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3381,  396, 1887,   45, 1147,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2843, 1464,   37,    1, 1990,    1,  176, 2916,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,    1, 1527,  710,  610,   37,  537,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  297,  864,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2153,    1,  202,  193,  104,    1,   81, 1428,    1,  469,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1450,    1,  284, 1084,  841, 2600,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  398,   98,  829,  786,  339, 2191,  695,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  964,  313,   37,  470,  112,  997,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2562,  885, 2092,  881,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1051, 1039, 2690, 2867,    9,  333,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,   12,    1,    1, 3053,   37,  930,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 477, 515,   1, 857, 726,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 487, 433, 102, 119,   1, 245,  32, 537,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1603, 1170,    1,  528, 1481, 1349,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  975,   21,  156,   45,   37,    1, 1146,  332,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1965, 2982,   37,   77,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3292,  474, 1707,    1,    1, 1377,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  645,   70,  550,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1237, 1658, 1117, 1525,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  213,   37,  331,  132,  220, 3236,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  105,  686,  176, 2798, 1499,  593,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  275, 1002,  460, 1278,    1,   85,   32, 1657,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  461,   98,  103,   32, 2760,    9, 2002, 3222,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3066,  396,  204,    1,   98,  166,    1,   45, 3215,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  671,    1, 2525,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2383, 2218,  361,    1, 3289,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1143,   83,    1,  315,    9,  654,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   99,  721, 1098,  108,  297,   94,   12,   71,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,    1,  919,  310,   25,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  844, 1235,    1,    1,  513,  514,   37,  228,  312, 1491,\n",
      "          134,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   98, 2095, 2393,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3247,    1,   37, 2192,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,   12,  103, 3382, 1921,   32, 2646,   98, 2024, 2699,  187,\n",
      "          105,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 1212, 3109,  258,  232,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3204,  361,    1,    1,  619,  166,  103, 1669,    9,  163,    1,\n",
      "           12,    1,   26,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1125,   98, 1019,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1419, 1657,  861,  328,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  590,    1,    9, 2974,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2748,    1,   32, 2138,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2345,  944,  416,  507,  707,   32, 1821,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777, 1419,  365, 1718,  328,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  213,   37,   24,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1774,  220,  166,  762,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,   37, 1413,   32,  105,  934,   37, 2035,  613,  815,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  159,  554,   98,  505,  195,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1839,    1,  991,    7,    1,   32,  121,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1458,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141,  892,    1,    1,    1,  135, 3152,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2106, 2309, 1905,   37,  726,   32, 3367,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3244, 3188,  744, 2925,    1,  119,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  102,  120,   37,  365, 1653,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   82, 2964, 1284,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  715,    1,   98,  111, 2086,  778, 1668, 1711,   45,    1, 1008,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3371,  140, 2018,  806,    1,    1,  454,   37,   52,  446,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 1230, 1825,   28, 1158,  225,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2010,  363,  802,    9, 1099, 1453,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,   32,  751,   37, 1789, 1002,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2781,    1,    1, 2593, 2218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2275, 1898,  531,  443, 1251,    1, 1915,  533,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2502,    1, 1347,   98,  832,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428,  859,  764,    9, 3118, 3396,    1, 3369,  476,  152,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 3375, 2572,   32, 3339,   22,  868,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  137, 1174,    1, 1582,  390,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  690,  331,  142,  384,  212,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3029,    1, 1539,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  261,   39, 1864, 2673,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  719,    1, 1323,  187,    1,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,  361,  326, 1604, 2444,   37,  860, 1151, 1998,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1008,    1, 2800, 2565,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1656, 2909,    1,   32, 2597,    1, 1887,  176,  177,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 1939, 1554,  163,    1,   12,    1, 2083,  603,\n",
      "           32,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  796,  395, 1513,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3331,  168,    1, 3083,   28,  119,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2692,    9, 2975,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  877,  460,  105,    1, 1463,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3035, 2856, 1147, 2924,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 2924,  439, 2335,  537,   32,    1, 2024,   23,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1034, 2925,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  717,    1,  903,    1,  182,    1,  105,    1, 1009,   37,   84,\n",
      "           85,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1699,    1,    1,    1,  166, 2463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  384, 1718,   37, 1778, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  225, 1515, 2549,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  864, 1360,  612, 2199, 2673,  210,    1,   51,  899, 1428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  879, 1106,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612, 1734,    9,    1, 2800,  475,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  200,    1, 1294,    9, 1021, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1818,  147,  884,  858,    1,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  361, 2275, 1523,  297, 2948,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1081,   12, 3401, 1707, 1407,  764,   37,    1,    1, 2299,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2841,   12, 3221, 1917, 2689, 1717,    1,  856,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2867,    9, 3149, 2751,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  629,  810, 2465,   32, 1003,    9, 3098,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69, 1042,   98,  574,  840,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387,   28,   37,    1,  131,   44,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,  108,  600, 1628, 1871,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2557,    1,    1,  176, 1604,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3051, 1527, 1149,  820,  191, 2751,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,    1,   37,    1, 3388, 2024,  226,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   90,  398,   45,    1,   32, 2319, 1778,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  585, 1021,    1,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  100, 1554, 2388, 1218,  984,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1394,    1,  375,    1, 1593, 1198, 1245,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  566,  531, 2022,   32, 1657,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  559,   79,  139,   50,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  437,    1, 1159,    1,    1,    1, 1651, 1597,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1,    1, 2762, 1167, 2572, 3033,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1384, 2299, 1552,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12,    1,  165, 1867,   37,   52,    1,  191, 2020,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  485, 1454, 3184, 2579,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3370, 1260, 3343,  957,  756,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 1450, 2275,    9,    1,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3099,    1,  571,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  828,  661,    1,  195,  804, 1031,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   19,  727,  361,  196,  361,  105,   61,  562, 1379,   12,  112,\n",
      "          499,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1797, 1622, 1027,  444,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  949,  365,  659,   45, 1417, 2522,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2888,  640,  878, 1688, 1465,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2752,  952,   37,  271, 2774, 3071,  220,   22,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 3149,  650, 1877, 2024,    1, 1002,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3238,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  884, 3130,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325, 2528, 1228,   13,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 1996,  411,  861,  937,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1,   12,  131,    1,   32, 1470,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,   51,  693,   98, 2041,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  218,    1,  219,   25,   71,  220,   69,  159,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2611,  669,   42,  133,  396,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826, 2962,  395, 2479, 1022, 1940,   12,  671,   32, 1171,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  500,    1, 1191, 1003,   37,  693,  111, 1108,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1756,   32,  903,    1, 1661,    1, 1007,    1, 1380, 1244,   98,\n",
      "          166,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,  453,  847,   85,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  456,   85,  730, 2614,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1128,  603,    9,  807, 3044,  332,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,    9, 3101,  890,  548,    1, 1707,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2278,  775, 1117, 1525,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2068,   51,  151, 3025,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  283,    1, 1937,   74,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  203,   37,  815,    1,    1,  220,  786, 1158,  282,  357,  829,\n",
      "         1778,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,   12,  168,   85,   32,  166, 1194,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2700,  753,   37, 1000,  388, 1199, 1081,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,   12,  603,    1, 2806,  705, 1470,  327,  593,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2102,    1, 1997, 1073,   39,    1, 1158,  108,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 2355,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3102,   12, 2068, 2386,  104,  297,    1,  765,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,   37, 2000,    1,  721,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,  603,   37, 1334,  220,  654,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  638, 2087,    1,  744,  119,  176,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3102,   12,  949,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  288,   37, 1079,  398,   37,  899,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2680,   37,  151,    1,    9,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3403,  640, 3376,  237,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  147,    1, 2095, 2985,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2067,  166, 1245,    1,  249,  856,  444,  596, 1793,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  200, 1604, 2014, 1522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  910,    1,   60,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1651, 1973, 2708, 1377,    9,  949,   45, 3340, 1527,  475,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  275,   82,   61,    1,   98, 2517,   12,  996,  627,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3164,    1, 2236,  939,  220,  872,   98,  166,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3250, 1173,  115,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1581,  411, 1104,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  517, 2064,    1,  600,  269,  347,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 2712,    9, 3166,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3115,    1, 1509,  634, 2321,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2767, 1230,  413,  327,  593,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  877, 1836,  221,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2971, 1867,    1, 2147,  344, 3403,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2888,  640,  878, 1688, 1465,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1082,    1,   37,  741,  176, 1817,    1,  186,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  758,   37,  151,    1,    9,   59,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1971,    1,  598,   37, 1343,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1214,    1,    1,    1,  908,   24,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  183, 1001,    1,    1, 1515, 2121,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 2640,   45, 2692,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2602,    9, 2891,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,   90, 3380,  204,  190,  289,   98, 3388, 1816,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1628, 1886,    1,    1, 1028,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  491,   37,  138,    1,   54,  187,    1,  396,   32,  430,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2997, 3005, 1396,    1,  117,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1138,    1,   28,  950,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   34,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1107,  868,   28,  176,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   25,  439,  242,  187,   68,   69,  102, 1348,  276,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2104, 1118, 2322, 2159,  781,    1,  605,  400,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,   45,  365,  361, 1991, 1975,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  116,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,    1, 3206,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1497, 2596,    1, 2827,  531, 2458,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   42,  220, 1652,    1,  442,  437,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1327,    1,    1,   37,  976,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1031,  665, 1018,  439,   37,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2677,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  467,  578,  388,    1, 1215,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2666,   34,  858, 1186,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 1447, 2369,  861, 1969,  365, 2764, 3394, 1665,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  358, 1536,    1,    9,  138,  125,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2821,   45,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  105, 1875, 1886,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  641,  453,  499,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,   97,  384, 2531,    1,  774,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,  908,  196,    1,  176,  551,  612,  613,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1445, 1421, 3164,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  125, 1649,    1,  138,  521,  599,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  968,  794,  449, 1463, 2328,  452, 2291,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   43,  396, 1211, 1819,    9,  111, 1904,  378,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  810,    1, 1821, 2579,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1124,   32,    1,    1,    1,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2142, 1178,   37,  720, 2805,    1, 1656, 2148,  134,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,    1,    1, 1151, 1828,  554,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   10, 2559,    1,    1,  202, 2198,    1,   98,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3284,   61,  105, 2360,  813,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1902,  900,  156,   37, 1306,  308,   98, 1860,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1212,    1, 1878, 2534,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  297, 2851,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  348,  156, 1124,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056, 3375,  361,  786, 3101, 2572,   32, 3339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1851, 1292, 1681,    1, 1188,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843,  729,    1,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2321,    1,   37, 2286,   39,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,   82, 1877,   37,   77,   28,  166,  856,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,   37,  319, 3327,   37,  335,  297,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   94,    1, 2497, 1937,    1,   71,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  848,    1, 1234, 2294,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3117,  245, 1114,   37, 2685,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1447,  879,    1,  191,    1, 2673,   46,    1,  104,\n",
      "          267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  612,  353,    1,  131,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  615,  240,  303,    9,   67, 1112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971, 1937,  730,    1, 1154,  501,    1,  987,   81,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  709,    1,    1,  844,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3237,  132,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1697, 1013,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  476,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 1215,  614,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  153, 2192,    1,   24,  881,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  952,   37,   62,  443,   45, 1886,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178,    1, 1178,    1, 2772,    1,   37,  606, 1368, 2322, 1411,\n",
      "          339,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3343,  344, 1585, 1950,  418,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  359,  361, 1091,   45,    1,    1,  166,  945,  701,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   21,    1,    1,  118,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  835, 2215,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3243, 2917,  384,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585,    1,    1, 1324,  898,   32,  903,    1, 1447,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1089,   30, 2936, 1260,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  531,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2102, 1107,  525, 3049,  103,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2374, 1454,  420,   98,   10, 2681,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1785, 1414, 2263, 3043, 3006,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  582,    1,    1,  173,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1018,    1,   12,    1,    1,    9,  573,  639,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1,  864,   37,  907, 1114,   98, 2673,  693,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  572,  996,   93,    1,  176,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,    1, 2915,  191,  403, 1447,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  160,  102,   71,    1,  118,   32,  385,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   37,  619, 1778, 2580,    1, 2581,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 3102, 1757,  288,   32, 3360,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,   12, 1514,  220, 1497,    1,  193, 2398, 1394,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   75,  765, 1750, 1067,    1,   29,    1,  858,   98, 1202,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1185,    1, 3141,    1,    1,  220, 3186,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2862, 2652,  949,   45,    1, 1038,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  512,   12, 1521,   61,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2700,  712,   28,    1,   45, 1821, 3027,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,  814, 1501,   87,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1851,    1,    1,    9, 2125, 1343,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1851,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1785,  947,    1, 1530, 3060, 3384,   32,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  490,   37,   98,  889,  529,  509,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3282, 3230,    1, 3267,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1511,   32,  945, 2054,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,  267,  460,  967, 1461,  220,    1,    1, 2320,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  776,   45, 3043, 3086, 3148,    1, 2361,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  409,   25, 1269,    1,  289,   98,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273,   12,    1,   98,    1,   45,  449, 1684,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1821, 2190, 2640,   51,  606,   37,  865,  754,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363, 2037,   85,  517,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  647,    1,  148,  856,   61,  105,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1800, 2467,   45,  547, 1656, 2954,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  422, 1566,    1,  597,  780,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  590,    1,    1,  515,    1,    1, 1194, 1918,  187,\n",
      "          512,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1676,    1, 1418,  384, 2826,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1421, 2469, 2681, 2236,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2004, 1087, 1749,  220,  517, 2287,   13,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  132,   66,  187, 1059,    1,    1,  365,  759,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1256, 1256,   32,   46,   37,  151, 1026,  178,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3321,   39,   45, 2611,    1,    1,  176,  754,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  792, 3054,  792, 1631,  846,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,    1,  548,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  422,  891,    1, 1017,  290,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118,   46,   37,   26,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3108,    1, 2297, 2764,    1, 1185,  855,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2127, 1220,    9,    1,    1,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 1022,  698,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1663, 1385,   28,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   64,    1,    1, 2856, 1270,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967,  365,  724,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2523,    1,   32, 1477, 1990,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  980, 2108,  970, 1281,    9,  365, 1461,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  476, 1698,  199,  389,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  227, 1017,    1, 1307,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2862,    1,    1, 2396,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183, 2438,  297, 2175, 2452,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,   37, 1982,    1, 2708, 3080,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2072,  166, 1107,  829,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 1668,  872,  420, 1169,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  104, 2548, 3043,  297, 2705,   45, 1056, 3343,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  291,  738,    1,  689,    9,  572,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,   12, 1411,    9, 2507, 3339, 2271,  469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  203, 2983, 1505,  460,   12,  105,    1,   39, 1221, 1821,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12, 2813,   37,    1, 2069,    1,  891,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1211, 1819,    9,  111,    1,  378, 2156,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  166, 1183, 1844,    1, 2990,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1465, 1466, 1008,  326,  710,  187,   82,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2002, 1009, 1484,    9,  596,  956,   37,  856, 3136,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1224,  459,  220, 3247,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12,  365,  149,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  449, 2318, 1684,  384,    1,  176,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3402,    1,    1, 2572,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2975,    1,    1,   37, 1267,    1,  593, 1990,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  266,  267,  268,  269,  105,  270,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1509, 1090, 1724,    9,  166, 2975,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,  476,  911,   37,  619,  166, 1263,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3118, 2751,  774, 2024,   46, 1961,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2328,  529,   32,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  137,    1,   37,  105, 1479, 1370,   45,    1,  625,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1995, 1999,   32, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1785, 1140,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3065, 3090,    1, 2198,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  864, 2185, 3341,   37,  771,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  673, 1574,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2937,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 2972,    1, 2690,    1, 2043,  110,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1227,    1,  297, 1994, 1718,  378,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1,   37, 1463,  365, 1994, 2819, 2549,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1778,  205,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  105,  686,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,    1, 2925, 1675,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401, 1548, 3154,  548,  119,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1557, 2789, 2405,    9,  726,   32,    1,  863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  711,  369,    1, 1532,    1,    1,   32, 1033,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,  837,   45, 2281,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1366,  606,   37,  943,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1178,  928,   32, 3101, 2625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  903,    1, 1417,    1,  921,    1,   45, 2295,    1,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  442,  448, 1137,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  102,  686,  810,  199,  845,   32,  548, 2074,  605,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1069,   28,  118,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1107,  293,   61, 1769,   39,  365, 1419,  187, 1412, 1851,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  941,    1, 1536,  420,   98,  938,    1,  482,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  468, 1362, 2744, 1273,  861,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3188,  515, 2110, 2298,   32, 2651,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1, 2786,   37, 1126,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  645, 2997, 3005,    1,   32,  119,  199,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   32, 1440,    1,  105,  170,   45,    1,  361,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1181,    1,  198,  197,  528,  526,  259,   93,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  365,  372,    5,  798, 1552,  297,   49,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  455, 1380,   79,  502,    1,    1,  548, 1841, 2162,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49, 1550,  315,   37,   47,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3095,   37,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1200,   28,    1,  268,   79,   63,  862,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  885, 1056, 2729, 3365, 1683,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  170, 2023,  553,    1,  624,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,  475, 1082,  304,   98, 3369, 1345,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1019, 1178,    1,  166, 2518, 1425,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  864, 1974,  453, 3107, 3366,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1231,  220,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  447,  200,  593,   12,    1,  826,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2675,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  236,  237,    1,  238,  187,  239,  240,  241,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230,   37,   26,  104, 1764, 1990,  142,  444, 2062,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1542,    9,  247,    1,   32,  166,    1, 1381,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2877,  292,  531, 1647,    1, 2645,  163,    1,   12,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,    1,   98,  355,   12,    1,  570,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  691,   12,    1,  566,  808,   32,  535, 1296,   28,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051,   12,    1,  572,  197,  407,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 3151, 2308, 1231,  220,    1, 2162, 2429,  176, 2184,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  732,  288,   37,  429,    7,  477,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2786,    1,  384,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  171, 2565,    1,  459,  881,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,  477,  288,   37,    1, 1159,  601,   74,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  359, 1573,  873,    1, 1421,  393, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2744,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  338,   39,   45,    1,  631,  528,  411, 1567,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3300, 2622, 3263, 2198,  105,  856,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  220,  105, 3252, 3284,   32,  166,  903,    1, 2227,    1, 1007,\n",
      "            1,    1, 1140,  460,   32,  166,   22,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  313,  176,    1,  327, 1499, 2146,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1718,  166,  365, 2355, 2367,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  659,    1,    1,  187, 1069, 1542,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 2307,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  195,    1,   37,    1,  344,  345,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1756,    1, 2826,  606, 1610,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2858, 2665,   61, 1239,   28,    1,  707,   37, 1604,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2991,    1,   28,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2511,   37,   47,  535,   50,   37,    1,    9,  152,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  447,   37,    1, 1147, 1009,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  511, 1564, 2339,    1,  693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1645, 1407, 1190, 1921,   32, 2835,   98, 3102,  949, 2699,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3160, 2399,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  266,   42,    1,   75,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1898, 1813, 1056, 3149, 2161,  897,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3118, 2751,  815, 2500,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3101,    1,   51, 2286,   37, 2856, 3359,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,   26,   28,   98,  217,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567, 1582,  640,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3108,    1,    1,  140, 1194,   73,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2258, 1245,   28,    9,  105,   12,    1, 3186,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1318,    1,  967, 2697,  361, 1056, 1675,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  952,  658,  903, 1423, 2271,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  326, 1243,  327,   50,   12,  172,  533,  327,  593,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1573, 1530,   32,    1, 1939,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2846,   76,   37,    1,    1,  892,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,   51,  843,  284,   45,  453,    1,  164,  165,   37,  163,\n",
      "            1,   12,    1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  105, 2946,   32,  105,  581, 1677,   45, 2971, 2412,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56,    1,    1, 2582,  166, 2309,   45, 2208,  111,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,   12, 2764,    1, 1877,    1, 2774, 2678,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187, 1147, 3407, 3382, 1554,    9, 2646,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158,   12,  365, 2452, 1564, 1961,  714,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1, 2072, 2282,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  305,  685,   27,    1,  687,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2911,    1,  411,    1,  187, 2855,  442, 1520, 1450,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1075,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 2878, 1380, 1212,  289,   98,    1, 1786,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2975, 1914, 1236,  297,    1, 1027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   29,   12,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  420, 1087,   37, 2446, 2587,  657, 2336, 1151,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 2702,   32, 2592,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  581, 3018, 2630,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  376,  570,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1033,   37,  529,   22, 1697,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1349,    1,   32, 1821,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    1, 1898,  548, 2941,  220,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  182,  182, 1463,  851, 2598, 2069, 2699,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3321,    1,   39, 2760, 1114,    1, 2967, 1754,   37, 1987, 1638,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178, 1041, 2196,    9,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  197, 1137,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3370,  774, 1260,   30, 1444,  321,  477,  176,  190,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2845,  547,  427, 1281,  191, 3308,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3176,  565,    1,  191, 1035,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  766,   34, 2177, 1027, 1208,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   81,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1106, 1013,   85,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388, 3177, 2463,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3006, 2253,   37, 2856,    1, 3102,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1405,   37, 1174,  104,  965, 1611,   98,  906,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  405,    1,   37,  194,   95,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9, 1614,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1364, 1365,  456, 2774, 2735,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,   28,   37, 1146, 1703,   45,  531,   12,  734,\n",
      "            1,  715,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  384,    1, 3367,    1, 2161, 1594,   37, 2909,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2102,    1,   37,  160, 1063,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3172, 1090, 1829,    1,  176, 3100,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2909,  686,  547,    1,  458,    1,    1,  786, 1530,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  253,  562,    1,    1,  170,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  888,   37,  221, 1159,    1,   32,  602,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1484,    1, 1176, 1884,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129, 1477, 1990,    1, 2297,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2142, 2257, 2017,    9,  885,    1,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1032,  176,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  795, 2247, 1469, 1248,  777,  815,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2497,   98,  105,   12,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  487, 1938, 3197,   37,   52, 2917,  384,  785,  786, 1411,  356,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1064,  176,  166,  103, 3260,   37, 1504,  971,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 2954,   28,  220,  293, 1749,    9,  111, 2851,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  367, 1290,   67, 1276,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1128,  162,   85,   37,    1,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117, 2208, 1873,   61,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,  365, 2321, 2565,  105, 3189,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  794, 1718,    1,  918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  200,  593,   12, 1254,  201,    1, 1656,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  766,  361, 1102,  275,  168, 2071, 2294, 1935,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1355,  625,    1, 1471,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  172,    1,  702,  435, 1834,    1,  716,  774,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3263, 2446, 1902,  361, 3287,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2321,    1, 2590,  885, 1641,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  809,    9,  316,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,   13,    1,    1,   29,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1953,  778, 1544, 1270,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  597, 3127,    1, 1753, 3128,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3226,  771, 3240,   37,  865,   37, 2340,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1680,   37,  151,    1,  481,    9,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3127, 2104, 1566, 1056, 1655,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3340, 3347,  162, 3343, 1757,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3188,  162,  411,  168,  115,   37,  698,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1, 2871, 2079,    1, 1222,  674,    1, 1416,    1, 3004,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  715,  471, 1621,  472,   39,   45,  128, 1116,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  138,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  251,  116, 3049,   45,  302,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2645,    1,  994,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2500,    1,    1,   32,  810,  453,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1725, 2024, 1259, 2825, 1372,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1603,    1,  972, 2582,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  116,    1,  844,  187,  535, 2309,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,  200, 1766, 1767,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  592, 1862,   98,  593,  996,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1629,  703,  286,  927,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426, 1690,  525,   15,   28,    1,  118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3359, 1484,    9, 1437,   45, 1583,   12, 3339, 2625,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  581, 2596, 2803,   32, 2504,  463, 3133,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  487,    1,    1,    1,   37, 2732,  187,  567,  510, 1518,   32,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  232, 2694, 3363,  855,   32, 3343,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1110,   37,   77, 1340,    9,  176,  177, 1056,  388,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755, 1867,  365, 3028, 2995,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2484, 2423,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746, 1268,   28, 1766, 1767,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  195,    1, 2200,  989,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1625,    1,  321,    1,  632,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2106, 1990, 2963,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1426,  105,  399,  220,  166,   12,    1, 1117,    1, 1417,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  872,  640,  340,  402,   98,  449,   74,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,    1,  449, 2071, 1331, 2403,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  829,   12,   72,   26, 1228,  934, 2973, 1764,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,   12,    1,  582,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3207,  140,  810, 1425, 3208, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1309, 2120,    1,  187,  453, 1009,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  487, 3102, 1564, 1377,    9, 1861,   12,  764, 2928,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1479,  922, 1123,  550,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   37, 1539, 2229, 2232,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,    1,  777, 2995,  593,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,   70,   71,   98,  459,   45,  984,  889,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2850,  680,  176,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3317, 1544,   28,    9,    1,  475,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  462,  582,   57,    1,   45,    1,  669,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3018,  190, 1584, 2264, 2866, 1778,    9, 2267, 2168,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  183, 1198, 1884,  187,    1,  671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  954,  897,  176,    1, 1224,  763,   76,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  200,  365, 2108,   32, 2278,  443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 166,   1,  45,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 596,  25, 186,   1,  69,  28, 187,  10, 140,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  148, 2767, 1872, 1614,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  645, 1597, 1229,   37,   52,   39,   45,  424,  593,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  982,   21,  198,   15,   93,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1660, 1102,  841,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 507, 111,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 191,   1,  45,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  160,  102, 1473, 1290,  396,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424,   61,    1,    1,  202,  931,  193, 1724, 2740,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2249, 1325,    1,    1,  590, 1665,    1,  942,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162, 1094,   12, 1022, 2085,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  655,  927,  187, 3065, 1333, 1530,   32, 3339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,    1,  421, 2225, 3188,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2559,  220,  987,  693,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3248, 2898, 1444, 1445,   81,   98, 1171,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1414,  288,   28,    1,   27, 2764, 3155,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  762,   66,    9,  844,  524,    1, 1662,  600, 2275,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2480, 2910, 1527,    1, 1209,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1984,   37, 1947,  148,  335,  297,   45,  647,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  774,    1,   37,  166,    1,  187,    1, 1627, 1022, 2350,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2522,   45,  803,  216, 1296, 2936,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  160, 1161, 1519,   32, 1657,    1,  496,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  876, 1396, 2650,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  519, 1826, 1086,  220,  810, 1425, 1705,   32,  166,    1,   45,\n",
      "          199,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835, 2061,  400,    9,    1, 1311,   98, 1428,  861, 1906,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  542, 1061,  548, 3181,  539,    1, 1090,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602, 2565,    1,    1,  176, 2081,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  388, 1013,  361,    1, 2181,  220, 2994,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  794, 2686,    1, 2519,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  459,  356,   24,  220, 3250,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3244, 1508,    1,   37,  881, 1039,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1359,   45,  386, 1891,    1,  928,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2597,  274, 2705, 1229,   37,  103,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  650,   32,  395,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1001,    1,   37,  105, 2250,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  190,    1,   37, 1994,    1,  261,   10,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2954,  288,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2800,  705,   74,   98,  132,    9, 3177,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1360,  612,  665, 1096,   98,  103,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2379,    1,    1,    1,    1,    1, 2722,    1, 2689, 1717,    1,\n",
      "          208,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,    1,  223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2206,    1, 2471,   28, 2069,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1662,  293,   37, 1753,  111, 2633,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  400,    1,   98, 1785, 2044,    1,  549,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3046,  738,  247,    1,   32,    1, 3135,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2235, 1140, 3065,  515,   28, 2603,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  780, 1426, 1845,  132,  220,  587,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1744, 3070, 2372,    1,  337,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2171, 3134, 2570,    1, 3161,  171,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2984,  288,   37,    1, 2918,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   28,  419,    1,    1,  163,    1,   12,    1,  679,   69,\n",
      "           25,  245,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,    1, 1315,   37, 2144, 1034,  340,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1906, 1542,   37,    1,  365, 1994, 2095,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2790, 1564, 2494,  714,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2702,  298,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  592,  387,  677,   69,  102,    1, 1298,  805,   98,  596,   93,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   63,  166,  862,    1,   28,    1,  262,  263,   85,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1529, 2515, 1220, 1465,  779,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649,  298,  938,    1, 1976,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2466,    1,    1,   98,  657,  302,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  159, 1285,  417,  548,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,   12,  365,  327, 1013, 2549,    1,  762,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2226, 1876,   10,    1,  247, 1058,   98,  531,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  475,    1,  105,  807,  627,    9,  166, 1589,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  400,  288,    9, 1818,  147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1585,  176,    1, 1606,   32, 2018,   12, 1633,    1, 2006, 2347,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  663,    1,   32, 3367,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1043,   85,  176,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1660,  987,  158,  361,    1,    1,   45,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3242, 1082,  388, 1694,    9,  103, 2308,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,    1,  876, 1398,  612, 1140, 2349,    1, 2226, 2233, 1140,\n",
      "          334,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  864,  361,   91,    1,   37, 2286,   37, 1154, 2673,  630,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3216,  631, 3232,  548,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3363,  288,   37,   52, 3343, 1009,   32, 1551,   45, 1448,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  113,   46,  220,    1,  393, 3006,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2528,   51,   52,  449,   45,    1, 3022,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  627,  852,    1,    9,   49,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    9, 3358,    1,  247, 1204,    1,  247, 2494,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1542,   37,    1, 3366, 2199,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   51,  698,  176, 3229,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  967,  198,  449,   74,   45, 1300,  605,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  882,  387,  526, 1151,  218,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106,  884, 3049,  856,   37, 1158,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  409,  159,  720,  187,    1,    1, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,    9, 1798,  176,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  105,    1,    1,    1,  361,  429,  166,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1409, 1492,    1,  808,   32, 2971,    1,  928,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2994,   55,  105, 2328,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  872,   32,   12,    1, 1447,  187,  903,    1, 1447, 1877,\n",
      "          193,   37,    1, 2673,    1,  101,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  870, 1652,  387,  211,   32,    1,   26, 2798, 2232,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707,   12,  342,  142,   81,   98, 1171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1000,   29,    1,  176,    1,  298,  778,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,  700,   98,  531, 1002, 2306,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101, 3057, 2274,   12, 1665,  155,    1,   45,  411,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1818,  147,  908, 1206,    1, 2887,   16, 1760,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  790,  476,  388,    1, 1243,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479, 1337,  250,  568,    9, 1338,   45,  436,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2563, 2712,  902, 2275, 1625,    9, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  171,  952, 2731,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  854, 1463,  546, 2673, 3085, 1461,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   42,    1, 1402,    1,  396,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 219,  25,   1, 115,  45,  65,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 176, 551, 612, 613,  42,  43, 297,   1,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1698,  724,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  361,  599,    1,   66,  187,    1,    1,  625,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3118, 1345,    1, 2924,  222, 1011, 2568,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136, 2384,    1,  279, 1402,    9,    1, 1228,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  790,    1,  248, 2700,   98,  749,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1708, 2431,  939, 1010, 2795,  297, 1708,  378,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  299,   81,   37, 1046,    1,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1951,  828, 1947, 1689,  971,  625,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1579,    1,  378,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2317,  191, 3261,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   71,  187,  137,  631,  682,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3116,  922,    1,   32,  437,  105,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3292,    1,  140, 2674, 1267,   32, 2468,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390, 1137,  548, 1858, 1259,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,    9,  507,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2386, 2932,   45,    1,  966,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2414, 1056,  176,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1634,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3332,    1,    1, 1224, 3141, 1509,    1, 1638,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171,    1,  565, 2934,   37,    1,  105, 1479,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  297,    1,    1,    9,  103,  731,  384,    1, 1021,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  801,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2005, 1289,  772,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1245,   61,   98,    1,   37,  913,    1,  142,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1013,    1,  810,  600,  224,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2964, 1936, 1003,  176, 1273,  618,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3069, 1141,   37, 1000, 2924,    9,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2838, 1421, 1415,    1,    9,  786,  356,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1380, 3052,   98, 2378,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3010, 1564,  221,   32, 3278,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2482,    1,    1, 2843,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  262,  263,  156,  832, 1031,   32, 1560,   61,  205,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   18,   85,    9, 2254,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485, 2161, 1229, 1530,   32,  531,    1,  215, 3102,  513,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   61,  224, 1542,   37,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3302,    1, 1327,    1, 2499,    1,  447,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  844, 1017, 1627,  105,  365, 2273,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,   12, 1511,  565,    1,  267, 2696,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2523,    1,    1,  331,    1,   37, 2876,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1300,    1, 1133,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1071,    1,  202, 1592, 1248,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984,  884,  105,  123,   28, 1173,  176, 2662,   12,  633, 2918,\n",
      "         2820,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  864,    1,   37, 1094, 1355, 3261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144,    1,    1,  290,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3094, 2572,   32, 2597, 1656, 2596,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,   37,  843,   98, 1220, 1021, 1499,    9,  166,    1,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   12,  551,  552,   51,  125,  268,   12,  731,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3230,    1, 3253,    1,   39,   26,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2751, 1267,   16,   45, 1565,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  206, 2037,    1,    1, 3132, 1594,  460, 1425,  730, 2614,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2226,    1,  182,    1,  331,    1,   12, 1610,    1,   32,\n",
      "          166,  327,  218,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  267, 3369,    1,   98, 3118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  204,  967, 1846, 1809,  247,  813,   98,  750,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  726, 1045, 1086,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  458,   32,  350, 1117, 1525,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  744, 1674,  119,   32,  104, 1838,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,  638, 2268, 1120,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1823, 2034, 2941,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1577, 1627,    1,  662,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1178, 1492,    1,  166,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1019,  361,    1,    1,    1,   32,    1,  825,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3215,  812,  247, 1509, 1034,  176,  311, 2936,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  187, 2685,  512,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1635,    1,  700,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1542,    9, 1108, 1779,    1,  193,  320, 2056,    1, 2580, 2193,\n",
      "         2264,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,   12,    1, 2301,  105, 1718,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  203,    1,    1, 1354,    1, 1178,   32, 3314,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1504,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1808,  437,   37, 1237,  111, 1107,  218,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283,  978, 3138, 2615,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2787,    1,    1,    1,    9, 1517,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796, 2368,   28,    1, 2371, 1089, 1090,    1,   32, 1056, 1890,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  883,  568, 1042,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  369,    1,  197,  418,   98,  242, 1842,  117,   15,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,   16,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141,    1,  203,  227,   61, 1924,    1,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2592,   12, 2057,    1,  683,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  517,  345,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1774,   39,   15,  656,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2695, 2223, 2286,  892,   51,  288, 2218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1210,   37,    5,  961,  876,  612,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3130,    1,  444, 2388,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    9,    1,    1,   74,   45,    1,  361,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401, 1479,    1,   37,  726,   32,  455,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  622, 1950,  921,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 1249,    1,  570,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  933, 1100, 2299,   32, 2851,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  695,    1,  941,  321,  612,    1,    1,  131,  384,  494,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  105, 2775,   45,    1,    9, 2095, 3060,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497,    1,    1,   39,  220,   81, 1987,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  111,  772,    9, 1292,    1,  542,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3203, 2471,  119,  176,  171,    1,  628,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3226,  565,  176,  105,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  167,  197,  220,  845,   69,   82,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1817,    1,  398, 1118, 2208, 2402,   43,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  590, 1188,    9, 1087,    1,   98, 2695,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  224, 1475, 1126,  636, 2320,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1582,    1,  654, 1149,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  792, 2026,  792,    1,  715, 1446,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1623,   45,  104,  531,  443,    1, 2619,   32,    1,  187,    1,\n",
      "          741,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614, 2250,  449, 2725,   32, 1523,   45,  103,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,  531,    1, 2468,   96, 1114, 1750,    1,  507,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2971, 1768,    1,  967,  122,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 3375,    1, 1094,   81, 2024,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  189,  159,   85, 1969,  550,   45,    1,  927,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  633,    1,  716, 1124,   32,  572,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,    1,  847,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1765,  593,   12,   72,  553,    1,  669,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1161, 1042,   32,  602,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3184,  147, 1042, 1603,  400,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 2735,    1,  920, 1634,   37, 2508, 2079,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,  270,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  193,    1,    1,  586,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447, 1450,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  507,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779, 1308, 3173,   32,  914, 2093,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2680,  794,    1, 1525,  861, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,   23, 2565,  162,  228,  356,  881,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  116, 1108,    1,  912,  388, 2819, 2039,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 1405,  518, 1213,    1,   32,    1,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1127, 1412, 1108,  571, 1021,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096, 3177,   61,    1,   32,  247,  386,  714,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2244,    1,    1,  155,  122,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,    1, 1606,  524,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   10, 2411,   37,    1, 3380,   98, 2018,   12,    1,  627,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 2361, 2108,   15,   37,  976,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,   52,  596, 1665, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1427, 2540, 3262,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3151,  922,   76,   37,  360,  474,   12,  693,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  635,   12,  108,   45,  449, 1023,  197, 1269,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,  267,  531,  420,   30,  909,    1,  612, 2567,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  501,  827, 3227,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1301, 2883,   12, 1523,  951,    1,  229,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3129,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3172, 1090, 1829,  463, 2926,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1411, 2273,   45,    1,   98, 1171,   37, 1504,  892,   12,  659,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  539,    1,  726,    1,    1,  665, 2741,   37, 2447,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  193, 1658, 2742,   12,  829,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962,  501, 3299, 1198, 2722, 3074,  608, 1834,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  233, 2153,  753,   37,  100,   98,  302,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,   37,  698,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2708,  446,    1,  288,    9,   46,   32, 2835,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1955,   37,    1, 1208,   32,  395,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1484,    9,  531, 1002,  211,  529,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968,  542,    1, 1330,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  178,  848,  566,  912, 2285, 1597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3364,   37, 1599,  663,   45, 2708, 3396,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1346,   32,    1,  297,  103, 1513,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  550,  361,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1529, 3121,    1, 1789,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2802,   61,  601,   32, 2080,  517,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,  872, 2225, 2175, 1602,    1,    1,  384, 3175,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  792,    1,  792,  297,  104,  693,   98, 2673, 2375,  691,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 3406,  583,   32, 3349,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 1405,  133,  776,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2430,    9,  133,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,    1,   81,    1,    9, 2851,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  104, 1393,   50,    1,    1,   12, 1952,  156,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2224,  859, 1994, 2095, 1553,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  815, 2464,  176,  104, 2102, 1107,  525,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  584,    1, 1252,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,  597, 2038,  939,  622,  317,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,    1,  602,  726, 1990, 3275,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2171, 2800, 2871,  584,   12, 2308, 1585,  484,   37,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,   22,  155,  529,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  105, 2368,  751,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1924,  166,  356,   45,    1, 3005,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1360,  612, 1031, 1560,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2474, 2918,  927, 1426,  837, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  231, 1117, 1525,  210,    1,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2245,  187, 3312,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  463, 2170, 2192,  105,   92,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  647,  439,  431, 2552,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  361, 1147, 1414, 2392,   79,    1,    1,  463,   45, 2597,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2388, 1287,  191,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3343,  957,    1,  105, 2529,    1,  650,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,  741, 2116,  431,  439,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094, 2404, 1484,    9, 2024, 2396,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,    1, 3234,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  657, 1614,  613,  769,    1, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  219, 3096,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3166, 1086,  694,   12, 3278, 1625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303,  536,  537,   45,   69,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  967, 2482, 2389,    9, 2843,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3398,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  355,  376,  156,  361,   15,  689,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2753,    1,  187, 3250,  688, 2551,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3121,    1, 1985,    1, 1789,    1,    1, 1884, 2620,  361,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2673, 1259,  562,  705,    1,  864,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2662,   12, 2820,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614, 1046, 1691,    1,   32, 3232,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1249,    1,    9, 3282, 3077,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1581,  105,  547,  356,  881,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,  693, 3237, 1056,  356,  132,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,   37,    1,    1, 1149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3059,    1, 2934,   37, 1343,   32, 3201,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178, 3382,  580,  134,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  858,   92,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3379,  147,  267, 3382,    1,  776,  321,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  203, 1183,  967,  424, 1846,  707,   98,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  954,  883, 1353,  176,    1, 1224,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087,  599,    1,  861, 1499,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 1562, 2275,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3182,  130, 2469,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3069,  952,   37,   92, 1521,   32, 1811,  404,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3262,   12,    1,    1,    1,  548, 2148,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,  908,  302,    1, 1038,  199,    9, 2650,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1423,    1, 1186, 1195, 1903,    9, 2024,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2546, 1475,  102,    9, 1107, 3049,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,  191, 2339,  590, 2354, 1638,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 2635, 3257,  338,   37,    1,   32, 2936,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,  864, 1877,   37, 2199, 3107, 3366,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2843, 2774, 2153,   37, 1697,   37,   91,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1537, 1841, 1919,   32,  142,   37, 1865,  229, 1030,    1,  147,\n",
      "         1373,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  190, 1745,    1, 2673,    1,   32,    1, 2404,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1924,    1,    1,  218,    1, 2502,    1,  548,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  433,  102, 1911,  215,  701,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  207, 2693,    1,  443, 2361,  548,  413,   12, 2263,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 2190,   12,    1,    1, 1464,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  286,  475, 1380,  293,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  106,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  160,  783,    1,   32, 1352,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294, 1401,  411,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2633,  827,  129,  922, 3252,   45,  166,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,  403, 1447,    1,    1, 2493,  105, 1056,  454,  237,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,  132,   98, 1815,  336,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  954,   32, 1744,    1,    1,   32,  478,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2835, 2137, 1939,    1,    1,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1425,  166, 2925, 1517,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2136,    1, 2922,   98,  531, 2874,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3062,  331,  671, 3098,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  854, 1874,    1,  582,    9,  442,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  517,    1,   92, 1766, 1767,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1, 166,   1, 502,  45, 810,   1, 928, 176,   1,   3,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 105, 183, 688,   9,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3117,  844,  586,    1,  939,  786,  339,  548, 1809, 2786,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 1585, 1464,   37, 2446,  438, 2701,    1,  202, 2427,  489,\n",
      "           39,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326, 1353,  192, 2575,  918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2768,  657,    1,   28, 2071,  660,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3157, 1210,  311,  863,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  941,  733,    1, 2488,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2974,   37, 1539, 1114, 1602,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2734,  304, 1294,  167,   52,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1687, 1022,    1, 3008,    1,    1,  951,    1,  920,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2712,   45,    1, 1710,  665, 1545,   32,    1, 2060,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2307, 3108,  872,  420,  385,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  590,    1,  416,    1,  297,  810,  482,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   22,   23,  418,  297, 1583,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2685,    1,   28,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  190,   52,  166,  449,   32,  166,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2137,  686, 2597,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,    1, 2707,  759,  792, 2507,  792,  630,   98, 2927,   46,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  919,  570,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 558,   1, 754,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 647, 546,  82, 648,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3249,  914,  297,  548,  354,   37, 2906,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 2201, 2003, 1585, 2414,    1, 1746, 1896,  297,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  116,  117,  700,    1,  520,  333,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  204,    1, 2331,    1,  193,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 2861, 1159, 1479,    1, 1995,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2862,  267, 1711,   45, 3080, 1683,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1542,   37,  335,  297,  166,  754,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2978,    1,  894,  193, 2346,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2523,    1, 3325,    1,  163,    1,   12,    1, 1477, 1990, 2457,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3309, 1554, 2982,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2979, 2869,    1, 2691,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1542,   37,    1, 1232, 1377,  901,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  334,    1, 3260,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2573,   12, 1065, 1190, 1550,  132,  297,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1064, 3042,  161,    1,  755,   81,   98,  721,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  801,  176,    1,    1,   26,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2702,  298,   51,  606, 1846, 2007,   37,    1,   12,  344,  142,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2499, 2162,   45,    1,  896,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3115,    1, 2551,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  952,  905, 2673,  210,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 3184,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1645, 3365,   32,  531,   37,   52, 1683, 1371,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2909, 3391,    1, 2751,  477,   32,    1,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1281,   98,    1,  220,    1,    1,  487,    1,  951,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1667,    1,  384, 3087,    1,  476,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3108,  726, 2317, 1090,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1993, 1632,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  342,  893,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 2546, 2118,   32, 1447,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  213,  365,  132,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   32, 3118, 1512,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   99,  361, 1186, 1910,    7, 1184,  347,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   98, 1089, 1675,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3242, 1301, 3066,    9, 1529, 1567,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1537, 2924, 1910, 1815,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,  163,    1,   12,    1,  719,   37,  856,    1,  133,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2856, 1056,  163,    1,   12,    1, 2548,   32,  531,   12,\n",
      "         3383,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1,   37, 1468,    1,  777,  778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158,  483,  936,  219,  659,   45, 2102, 1107,  525,  361,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3290, 3229,   21,   37, 1306, 1879, 1090,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1366, 2233, 1745, 1584, 3317, 1910,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   33,  402, 1249,  739,   32,  572,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,  387, 1230,  844, 1669,  187,    1,    1,  193,    1, 1160,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  159,  554,   98,  142,  191,   26,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2232,  361,    1, 2232,    1,  116, 2943,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2896,  750,  991,  166, 1438,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3281,   37, 1046, 2408,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1481,  631, 2463,  608, 2475,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2414,  531, 2548, 3026, 2304,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,   25,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2571,  671,    1, 1236,    1,   32,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2048,   45, 1128, 1021, 1129,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1785,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  597,   10, 1708,  232,  513,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 3303,    1,  548, 1121,  698,    1,    1, 2660,  119,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  763, 2085,   98, 3258, 2579,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  361,  829,    1,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3170, 2078,    1,    9,    1, 2500, 1997, 2395,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,    6,  102,   98, 2798,    1,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  649, 3222,  967,  445,   32,  525,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  411,    1,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2880,   45,    1,    1,  162,  885,  916,   37,    1, 1123,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  267, 1718,   51, 1719,  636,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2162,    1,    9,  463, 2571,    1,   32, 1117, 3058, 2282,  142,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 1666, 1821, 2978,   95,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32, 3376,  187, 2950,    1,  163,    1,   12,    1,\n",
      "          861,  700,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1988,   45,    1, 1117,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3178,    1,    1,  726,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,   45, 3367,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1527, 1149,  619,  388,  412,   37, 3118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1695,    1,    1,  104,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  947, 2360, 1404,   45,    1,    1,    1,  365, 2950, 3060,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  640,   56,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   61,    1,    1,  425,  426,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3362, 2892, 2253,    1, 2292,   32, 3349,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2571,  474,  859,   37,  576,  388, 2924,   37, 3118,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1210,  105, 1615,    1, 1488,  179,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  859,    1,  114,   32, 1850, 1423,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   26, 1039, 2366,   37,  714,  424,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3209,  166,  458,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 2414, 3375,   32,  403, 3339,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2753,   45, 2332, 2844,   32, 2597, 1656, 2137,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 2572,   32, 1785, 1882,    9,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  252,    1,    1,   28,  593,   12, 1354,    1, 1273,  618,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147, 1707, 2638, 2931,  116,  625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   20,  193,  603,    9,    1, 1895,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  743,   12,  207,  174,   28,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1247, 1141,  411,    1,  202, 2615,  439,  460, 2056,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,   25,  439,  242,    1,   69,  102, 1473,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1585, 1950,  418,    1, 3343, 1002, 2116,   27,  439,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2699,  598,    9, 2820, 1374,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  457, 2328,    1, 1426, 1821,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2108,    1,  776, 2478,  463, 2170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2885,  167,    1, 2523,  187,  590,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  744,   79,  365,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2615, 1139,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1033,    1,  420, 1181,    1,   37,   28,    1,  568,  951, 1101,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1053, 1419, 1056,    1,    1, 3006,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1633, 1680,   35,   48,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3115,    1,    1, 3285,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492,    1, 1492,    1,    1,   61, 1919,   32,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2912,   61, 1797,   32, 3206,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12, 2692, 1089, 1090,    1,   98,  116,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3228, 2415,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1, 2384,    1, 2969, 1766, 1767, 1151,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1364, 1365,   12,    1, 3079, 2856,    1,  650,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,  332,  631,  176, 2755,    1,    1,  628,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  342, 1484,    9, 1211,    1,  741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1938, 2607,    1, 2115,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  275, 1085,    4,   77,  677,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1292,   32, 1092,  268,    1,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1796,  947, 2625,    1, 2673,  250,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   28,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  111,    1,    1, 2626,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  931,    1,    1,  162,    1,  698,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  225,  218,    1,  167,   16,   28, 1371,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999,  251, 2966,    9,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2752, 2751,  899, 2782,    9,  105,  339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1312, 1530,   32, 3343, 1450,  187,  741, 2116, 2361,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32, 1378,  914, 1918,  297, 3152,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1805,    1,    1,  154,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,  311,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  640,  584,    1,  672, 1021,  361,  238,    9, 2048,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  160,    1, 2387, 1900, 1220, 1311,  176, 2733,  776,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,   37, 2192, 1818,  147,    1,    1, 1285,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2136, 2559, 2161, 2911,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1968,  794,   40,  220,    1,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 2056, 1171, 2565,    1,   79,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545, 2024, 1259,  220,  386,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3176,    1,   37,  877, 2118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2884, 2483,    1,   32, 2288,   79,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  328, 3257,  640,   81,   37, 1722,  220, 2637,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 1485, 2572,  191, 3125,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  281,  282,   51, 1046,  422,  521,  522,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  702,    1,  169,   37, 2123, 1159,  786,  669,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1790,  779,    1,  280,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1126, 2092, 1954,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1186, 2375,  420, 2493,    1, 1924,  105, 1665,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325, 1341,   50,    9,    1,   54,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  403,   12,    1, 1036,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2500,    1,   37,   52,    1,    1,   98,  844,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1558,   28,    1,  744, 2364,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3139,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  251, 2264,  822, 1942,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  668, 1701,  469, 2039,  424,  339,  444,  111, 2633,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2918,  190, 1343,    1,  361,  588,  220,  104, 2697,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2347,    1, 2257,   39,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  994,    1,  275, 1946,  191,  342,   12,    1,  432,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1435,  691,   12,    1,  551,    1,  313,    9,   93,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1035,  729, 1555,    9,  247,  916,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  375, 1236,    1, 1359,    1, 1550,    1,  815,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  294, 3091, 1683,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  863,    1, 1210,  183,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147,    1, 2243,    1,  279,    1,  662,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1,  476, 2571,    1,   32, 3118,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3012,    1,  603, 2312,    1, 2312,  227,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,    1,    1,  176, 3402, 3408,    1,  420,  782,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3282, 3230, 1564, 3295,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390,   12,    1,  856,  614,   98,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  420,  746,  744,  844,  132,  220,  829,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790,    1, 2056,  231,   45,  552,  517,  312,  195,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2328,    1,   39,  187, 3260,  245,   37, 3232,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   15,   71,  419,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,  400,    1, 2552,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2500, 2126, 1991,   32,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2731,    1,  939,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2026, 2198,  105, 1344,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1029,  515,  104,  331,   37, 3349,  548,    1,   64,  799,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596, 1395,    1,   37, 2284,   32,  572,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2967,   37, 1306, 1056,    1, 1675,   37,  856,   43,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1310,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  978, 3138,  130,  743,  384, 2838,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  251,  441,    1,  861,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3173, 3205,    1,   37,  759,  401, 3179,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2415,    1, 1454,  484,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,    1,    1, 2861,   32,  917,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,  552,  903,    1,  904,    1,  171,   12,  157,  920,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2051,  157,    1,  220,  365, 1289,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1, 2914, 1273,  618, 3085,   45,    1,  535,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2926,   12, 1764,  190,  193, 1046,  153,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1,    1,    1,   28,    1,  419,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087,  459,  228,  356,    1,  331,  460, 1085,  132,  220,  715,\n",
      "          458,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 3375, 2572,   32, 3101,   22, 2625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158, 2102, 2352, 2464,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2776,  864,  427,   37, 1463, 1185, 2308,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3356, 1484,    9, 2756,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  744,  863,   74,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  766,   37,   47,  526, 2104, 2105,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1373,   10,    1,  583, 2161,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,   37,  429,   49, 1611,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  132,   32, 1904,  477,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1395, 1091,   66,    1, 1437,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1319, 2064,   37,    1,  442,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1000, 2157,   37, 1597, 1633,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  947,    1, 2547, 1388,   32, 1844,   28,   37, 1033, 2211,\n",
      "         2396,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2275,  140,  542,    1,  220,  596, 1793,  469,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  952,  591,    9,    1,   17,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2455,   45,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  688, 2964,  361,    1,   37, 2968,  176, 1327,  275,  264,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  511,  267, 1700, 2548, 2572,   32, 2774, 2517,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1864, 1686,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2018,  854,    1, 2018,  429,   46,   98, 2673,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1002, 1861,    1,    1,  631,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1547,  418,   98,  301,  783, 1002,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  340, 2599,    1, 1625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2331,  600,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2639,    1,  794, 1001,  218, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,  835, 1117, 1525, 1013,  700,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  267,  460,    1,  590, 1665,   37,  903,\n",
      "            1, 1447,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2740,  361,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386, 2503,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  667,   93,  972,    1,  995,   32,  572,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3306,    1,  902,    1, 3335,  361,  440,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1018, 2291,    1, 2167,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12,    1,  140,  754, 3222,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  977, 1543,  315,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,   12,    1,   51, 1188, 3131, 2456,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  969,   32,    1,  928,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,    1,    1,  220,    1, 2560,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676, 2173,   76,   37,  804,   98, 1674, 1740,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  683,    1, 1781,   98, 1102,  841,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 2171, 3134,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1228,   13,  794,    1,  412, 2043,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1048, 1049,  156,    1,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  958,    1, 2129,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  758,    1,  746, 2035,  956,    1,  469,  365, 1085,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1002, 2275,  967, 1849, 1876, 1810,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  500, 1958,    1, 1294,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  581,    1,    1,   32, 3360,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  295, 1210,  439,   37, 1325,  674,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  403, 1447,    1, 1328, 1787,    1, 3385,   12,    1,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2159,  781,   34,  157,  548,  572,  197,  959,    1,   37,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2,  65, 972,  37, 774, 590,  37,   1, 589,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 733,   1,  48,   9,  59,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3024, 2483,  453,    1,  175,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  819, 2056,   39,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  293, 1236,  885, 1465, 2264,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1712, 1353,   98,  829,   12,  460, 1499, 1135,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1879, 3112,   39,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  433,  218, 1044,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1100,  708,    1,   37,  907, 1151, 1220,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2500,  663, 2042,   37, 1734,   32, 2729, 2823,  863,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,  921, 2307,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1552,    1,    1,    1,  187,  105,  311,    1, 2578,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  129,  922, 1090, 1829, 2110,  176, 1022,    1, 2296,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3113,  267, 3206, 1360,  612,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,   70,   71,    9,   72,   73,   74,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1751, 2317,    9, 1056, 1675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2743,   12,  228, 1880, 2424, 1198,  590,    1, 2748,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2527,    1,   32, 2140,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  858, 1542,   37, 1901,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321,    1,    1,  769,    1,  657,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  315, 1710,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1637,  104, 2128, 1722,  115,   45, 3155, 1995,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  777,    1,  220,  103,  932,  357,  166,    1,   37,    1,  388,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 2553,   39,  247,    1,  186,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   10, 2489,   98,    1,  783,   32, 2091, 2087,  433, 2107,  220,\n",
      "         2275,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758, 1898,    1, 2549,   37, 1790,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3333, 2556,    1,    1,   42,    9,  683,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 1648,   37,    1,    1,   32, 1583,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  236,  237,   25,  439,  410, 1969,   15,  304,  384,  425,  426,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,  496,  782,    1,  111, 2429,    1,    1, 2264,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2945,    1,   12,  461, 2871,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,    1,   28,  247,  547,   74, 2237,   37,  854,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1711, 1075, 3317,   12, 2457,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1730,  606,   69,  293,   32, 1731,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3210,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  155,  453,    1,  693,    9,  647,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  415, 1343, 3134, 1294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  711,  369,    1, 1342,    1,   37,  582,    1, 2131,   50,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  550,  369,  253,    1,  104,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  514,   45,    1, 2399,  785,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  632,  433,    1, 1839,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2246,    1,  361,    1,  726,   32, 2743,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  352, 1216,    1,   45,    1,  589,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3005,  729,    1, 2298,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1400,    1,  305,   32, 1220,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12,  954,  897,  191,    1,  118,   32,  449,  547, 2033,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,   26, 1116, 2616,   32,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2355, 1013,    1,  288,   37,  686,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1745,   32, 1820,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  141,   48, 1611,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2692,  460,   61,  388,  763,  415,  105, 1090,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,   12, 2918, 1965,    1,    1, 2948,  294,    1,    1,  420,\n",
      "         1821,    1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,  166,  617,  259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 1447, 1216, 2673,    1,   32,  411,   12,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 3192, 1364, 1365, 1917, 3184,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  396, 1312,    1,  691, 1686,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  297, 2218,  770,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  936, 1273,  132,  220,  180,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1858,  928,   32,  298,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1725,  566,  219, 2876,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,  105,  298, 1434,   32,  166,  183,  199,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2980,    1, 1396, 1273,  618,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  220, 1643,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,   12, 3401,  140, 2823,  863,  328,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1746, 2699,    9,  166, 2328,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3014, 1749,  220,  326,  918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  914,   45, 1059,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,  829, 1149, 1231,  220,    1, 1228,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147,    1, 1710,  619, 2440,    1,  187,    1, 1077,    9, 3032,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2763,  388,  972,  191, 1525,  763,  538,    1,  506,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1907,  802,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2055,    1,   45,  761,  195,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 2452,  517,  105,  449, 1173,  176, 1158,   12,  365,  810,\n",
      "           32,  786,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1183, 1314,   37, 3018,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  421, 1520,   32, 1110,  354,   37, 1497,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  183,  805,   98, 3001,   25,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  815, 2464,   98, 2102,  619,  228,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  409,    1,    1, 1279,  418,    9, 1194,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1808,  140, 1354, 1537,  541,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3258, 1938, 2809,    1,    1, 1998,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  422, 1564,  262,  263,  927,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2691, 1343,    1,    1,  361,  920,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  365,    1,   37,  764, 1821, 2978,  221, 1750,  865,\n",
      "           37,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  286, 1630,  278,  927, 1353,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3236, 1421,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   45,  139,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2473,    1, 1775, 2367,  918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2531, 1360,  612, 2192,   28, 1815, 3380,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,    1, 2347,   32, 1815, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1023, 1553,    9,    1,    1,    1,    1,  215,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2547,   37,  764, 1539, 2977, 2328,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1794,   98,  105, 2699,  444, 3194, 3195,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  223, 2420, 1275,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204, 2257,   39,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,   79,   37, 1480,  698,  444, 1956,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 2024,  872,   37,  168,   37, 2646,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  409,   25,   26,  242,    1,   60,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2789, 1310,   37,  665,    1,   81, 1159, 1918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  668,    1, 1077,   98, 1092,  524,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  475,  487, 1409,  267,  100,  920,   98,    1,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1932, 2611,  361, 1983,  656, 2659,    9, 1204,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  166, 1251,   45,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1479,  922,  810, 3009,  726,   32,  455,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  215,    1,   45,    1, 3058,  722,    1, 1517, 1215,\n",
      "          267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1559, 2897,  187, 2468,   12,    1,   37,    1,   63, 1314,  290,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3053, 2477,    1,  944,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  538,  884,  166,  183,    1, 1836,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1082,    1,   37,  690, 1002,  932,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  475,  387,  741,  187,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  858,    1,    1, 1842,    1, 1109, 2329,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2936,  267,    1,  193,    9,  333,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   37, 2192, 2028,    1,  567, 1527,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051, 2762, 1268,  725,   37, 1450,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3101,  477,   32, 3339, 2414,  176,  177, 3375,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1052,  737,  207,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  305,  720,    1,  753,    1,    9,   65,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,    9, 1281,   32,  442,   45,  638, 2087,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  502,  551, 1361,  662,   37,    1,    1,    4,   32, 1251,  672,\n",
      "          221,   37,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,    1, 1054,    1,  193,  424,  199,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  896,    1, 2903, 1545, 1178, 1179, 1654,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  957, 1579,  196,   12,  887,   45,  176,  551,  612,  613,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2062, 2591,   37, 2035,    1,   12,  804,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3300, 1914,   32, 1328, 1903,   37,   47,  872,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  971, 1937,  730,    1, 1154,  501,    1,  987,   81,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  213,   37,   59,   24,  220, 1214,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  207,  418,    1,  508,   37,  125,    4,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1237,  104,    1,  861,  210,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1353,  285,   32,  854,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,    9,  105,    1,    1,    1,  202,  544, 1444, 1604,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,   45,  449, 3081,    9,  505,    1,   32,  105,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 2336,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,  443,    9, 1021, 1554, 2752,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3171,  476,   37, 1330,    9, 2615,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1461,  750, 1463, 1464,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37, 1539,  453,  248, 1013, 1522,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3262,    1,    1,   98, 1780, 2058,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  335, 1056, 2526,   98,  601,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  247,  248,    1,    1,  267, 1689, 1463, 1330,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 3027,    1,  220, 1821, 2190,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2692,  614,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2107,   61,   98,    9,  730, 1571,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  314,  361, 1692,   12,  929,  992,   85,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,  166, 1215,   32,  395,   61,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   12, 2975, 1824,    1,  884,   79,   32, 1033,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1079, 3063, 1627, 2355, 1013, 1681,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   75,    1,   37,  588,  207,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,  132, 1297, 2459,  221,  115,  220,  613,  469,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   51, 1173,    9,  607,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1313,  251, 1298,  753,    9, 3375,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,  361, 2275,  442, 1450,   32, 1515,  581, 2823,  736,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3160, 2572,  191,    1, 2596,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1332,    1,  389,    1, 2101,  417,  763,   76,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  321,  333, 1086,    1,   12,    1, 1015,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2114,  598,  297, 2378,    1, 1747,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2795,    1,  810, 1425,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  393,   37,  125,   28,   37,    1,    4,   32,  257,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2503, 2779,   37,  335,    1, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1089,   30, 1428, 3365,   32, 3360,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1268,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,  387,  647,  197,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2014,    9,    1, 2802,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  308, 1000,    1,    1,    1, 2855,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,  163,    1,   12,    1, 2872,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2954, 2199,    1,    1, 3222,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 2767, 2255, 2706, 2168,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1968,  768,  149,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226,    1,  405,    1, 1417,    1, 1713,    1,  290,    1,    1,\n",
      "          375,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1009,    1, 2770,  208,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 1230, 1270, 1690,  187, 1158,   12,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  180,   12,  197,  418,    1, 1680,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61, 3148,  415,  105, 1357,   32, 3118,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  872,    1,  671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2071,    1,    1, 1021,  282,  517,    1, 1021,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1095,  614, 2026,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1731,    1,    1,  191,    1,  625,    1,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1028,  730, 2288, 2909, 2810, 2764, 2765,   12,  313,  361,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1029, 2911, 1594,   39,   32, 1797, 1397,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1254, 2107, 2085,  685,  671,    1, 3077,    9,  104,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3233, 3209, 1090, 2052,  191, 2620,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 2855,   37,  690, 3343,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 1002,   61,    1,   62,    1,  202,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  615,  565, 1044, 1737,  187,  286,    1, 1636,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  967,    1, 1285,  297, 2275,   32,  365, 1002,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2578,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3262,  765,   37, 1194,   32, 2038,  922,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2692, 1018,    1,  270,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993,    1, 3056, 1117, 1525, 2706,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2792, 1822,  690,  402,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1257,   12,    1,  912,    9,  467,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   72,  401,  156,    1,   15,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  507,   12, 1656,  426,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,  765,   98,  596, 1793,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    9,   10,    1, 2275,   32,  844,  378,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1027,   37,   52,  166,    1, 1380, 2261,   98,  672, 1285,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1924,  105, 2080, 2042,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2140, 2122, 2474,    1, 1273,  786,   32,   46,    9, 1832,   28,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  514, 1727,   32, 3386,  312,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1238, 1247, 2321,    1,    9, 1952,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178, 2827,  297,  395,   36, 2705,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  364, 3283, 1533,  384,    1,   32, 2304,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1908,   28, 1527,    9, 2024,  693,   37, 3369,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2669,  590, 3001,    1,    1, 1594,   37,    1,    1,  420,  267,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2830,    1,    1,  297,  390,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3386,  776, 1392,  105,    1,   45, 2638,  312,  966,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1008,  365, 1644,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1718, 2146,  162, 1901,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    4,   29,  429, 1677,   45, 1032,   93,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  721,   12,  654,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1842, 1182,   66,  220,  227,  172,  932,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  445, 2051,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,    1, 2149,   37,    1,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1000,  105,    1,  671, 2003,    1, 1283,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  358, 2598,    9,  449,  199,   32,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,  166,    1,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1245,  103,  153,    1, 1334, 3158,   32,  404,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 150,  37, 151,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 256, 105,   1,   9, 453, 170, 220,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  449,  104,   95,   32,  537,   61,  227, 2305,    9,  451,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  256,  861, 1228, 1876,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  170, 1380,  180,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12, 1952, 1619,  996, 1953, 1954,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  140,    1,  628,  297, 2885,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1242,    1,    1,  361,    1,   45,    1,   32,  105,    1,   45,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2925, 1090, 1829, 2295,  176, 1252,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  612, 2593,  258,  207,    1,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,    1,    9,  195,  351,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3166, 3272,  590,    1,  273, 2171,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   37,  504,  384,    5, 1491, 1278,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504,    1,   37,   52, 1231,  297, 2189,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  747, 2776,  365, 1051,    1,   37,  759,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,  197,  418,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1123, 1380, 1340, 2907, 1708,   98,  429,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777,  884, 3028, 2798,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  790,   37, 1117, 1171, 2947,  229,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159,  670,  187,    1,  580,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3190,  546, 3134, 2565, 3112,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  365,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1130,  973,    9,    1,  163,    1,   12,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3173, 2659,   81,    1, 3178,   79,   37,  105,    1,   32, 1717,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1558,  384,    1,  639,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790,   37, 1816,    1,   98, 2244, 1011,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1773, 2005,   28,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,  315,  395, 1273, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   28,  361,   85,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2753,    1,  187,  311, 2936,    1,   37,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  275,    1, 1816, 2501,  861,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1, 2112,    1,   37, 3361,    1, 2588,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2623, 2624, 1463,  193, 1864,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,   12, 1067,  901, 1010, 1428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  786,  339, 2248,    1,  856,  297, 1771, 1258,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3180,  321,  726, 3116,  922,    1,  267, 3213,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  386,    6,   95, 1208,   39,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  331,  197,    9, 2235, 2826,    1,  202, 2197,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,  166,   71,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    9,  327, 1494,  220,  284,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  727,    1,  182,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,  741,   45, 1161,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  548,  228,    1,    1, 2942,    1,   39,   45, 3163,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 1447,   12,  695, 2789,  582,  939,   98, 2742,   12,\n",
      "          608,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2677, 1545,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,  700,   37,    1, 1612, 1736, 1975,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  374, 1226,   37,  356,  340,   98,   69,    1,  829,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640,    1,  156,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 3232,  726,  297,  166, 3260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596, 1510,  756,   71,  570,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2823, 2855,    1,   32,  460,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700, 1530,  187, 2752, 2751, 1207,   37,   84,   28, 2782,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  334,  321,  877, 1484,   98, 1658,  327,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  267,    1,    1, 1564,    1, 1232, 2440,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  938,   32,  693,   37,  151,  941, 1201,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1707,  214,  142,  187,  225,  338,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  602,   12,    1,    1, 3139,  726,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  488,   37,  168,  460,    1,   98, 2673,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2779,  980, 1632,   32, 2592,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,   96,   28, 1245,   98, 2708, 3136,  477,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2302, 2185,    1, 1347,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1755, 1499,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2137,  326,   12,  822, 2465,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  795,   37, 1636,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3188,    1,  288,    1,  119,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,   12, 1113,   67,  338,   32,  572,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428,  958, 3086, 2924,  606,    1, 3114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 1585,  967,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  741,  133,    1,    1,    1,  191, 2780,    1,  565,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  814,    1,    1,  599,   32,  399,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2314, 2708,  650,    1, 3358, 1921,   32, 2197,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,    1,    1, 1581,  142,  384,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1181,  775,    1, 2382,  259,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1162,  936,  105,  244,  304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1002,    1,  606,  695, 2789,  115,   32, 3097,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  756,  757,  929,    1,   82,    1,  939,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   13, 1536,    9,  467,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116,    1,  167,   92, 1998,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2222,    1,  199,   37, 1694,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  829,  697,   37, 1753,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  389, 1924,  105,  502,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  182,    1,  915,  356,   37, 2135,    9,  171,   12,\n",
      "            1,    1,  420,  267,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,  331,    1,   53, 1704, 2102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713, 2923,    1, 2055,   26, 1039,    1,  934, 2973, 1764,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  541,   32,  361,   39,   45,    1, 1663, 1325,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  681, 1776,    1,  389,    6,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  476,    1, 1841,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   12,  964, 1484,  104, 1563,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  458,   45,  507,   37, 1289,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3345, 2192, 1645, 2074,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  275, 2054,   12,  410,  578, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2282,  722,    1,  641,  166,   97,   98,  813, 3342,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,   32,    1,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,  762,    1,   32,  531, 2128,  221,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2076, 1862,  600, 1151, 1397,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1496, 2788,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,  166,  931,    9,    1, 3181,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228,   39,   45, 1700,    9,    1, 2885,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2907, 2034,  730, 2614, 1090,  786,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    6,   81,    1,    9, 1913,  401,  983,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  859,   37,   52,  792,    1,    1,  792,  444, 1994,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1204, 1494,   37,  581, 1204,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  245, 1464,   37,  619,  104, 1140,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3328, 1831, 3309,    1, 3186,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3199,    1,    1,   98,  103,  548,  449, 1385,   45, 1948,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  446,    1, 2224,    1, 1408,  284, 1726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 829,  12, 645, 469,   9, 844,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  69, 816, 187, 510,   1, 107, 423,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2235,    1,    1,  593,   12,  103,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,  288,    9,  976,    1,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2136,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220,  105,  365,    1,    1,  166,  730, 2614, 1664, 1515,    1,\n",
      "          608,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2037,    1,    1,    9,  931,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 2005,    1, 3369,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3330,    1,  931,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2152, 1976,   32,    1,  754,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  990, 1536,  149,  444, 1791, 2650,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2554,  971,    1,  119,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,  325, 2215, 1013,  624,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   37,  243,   93,  570,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1874,    1,  220,  365,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  105,    1,  600,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1497,  220,   57,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2584, 1000, 2920, 1762,    1,    9,  698,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  458,   82,   37,    1,    1,   32, 1445,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1421,   45,    1,    9,  634,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1340,    9,  202,  590, 2907,    1, 2126,  176,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652, 1380, 2355, 1718,   37, 1604,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  810,    1,  619,  764,  384,  671,    1,    1, 1001,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  259,   61,    1, 2160,   28, 1140,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3092,  629,    1,  297,    1,    9, 3066,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597, 1304,   82,   51, 1046,  521,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 657, 353, 242, 197,   1,  15,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  70,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 281, 282,   1, 453, 285,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,  51,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  199,  421,    1,  151,   98,  342,  231,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  837, 1187,  105,    1,   45,  227, 1584,  862,    1,  221,   98,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2528,    1,  778,   32,  961,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1380,  105,    1,  439,   37,  166,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1056,  583,   32, 3099, 1325, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1550, 1995,   44,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3151, 2308,    1,  105,    1,    1,  125,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1236,  923,  297, 2931, 1117,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2995,   37,   18,   37, 1778, 1273,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  455,    1,  460,   12,  844,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  249, 1210,   37, 1937,  105, 3146,   45,  166, 1815, 1816, 3380,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  627,   45, 2157,  626,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  446,   32, 2611,  548, 1656,    1,  639,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,    1,  187, 1574, 1687,    9,  964,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428, 2576, 1856,   45, 2950,   45, 2597, 2699,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   28,   98,  889,  509,    1, 2046,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3096, 2276,    1,    9,    1,    1,  548,    1, 1463,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1077,  152,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596,   32,  531, 2414, 1056,    1, 2766,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1002,   30, 3149,  947,  232,   32,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  739,  354,  370,  409,  197,  948,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,  313,   37,  665,   39,  365, 1788,   12,   10,  546,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  367, 1113, 1276,   37,    1,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,    1,    1,    9, 2018, 1109,  333,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2828,    1,   37, 2613,  726,  297,    1,   32, 3116,  922,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3242,   37,  665, 2557,   37,  786,  175,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,    1, 2542,  413,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2542,    1,  191, 1751,  361,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,  744,  365,  340,  813,  444,   94,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 2224,  213,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2171, 2871,    1, 1306,   37, 1012, 2565,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  353,  242,  572,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  711,  858,   93,  115,   45, 2462,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,    1,  105, 3043, 3348, 2095, 1551,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  531, 3382,  213,   37,  439,    1,    1, 1345,    1,   98,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2453,    1, 3180, 2827,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  938,  796,  941, 1201,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3112,  479,  361,  755, 1776,  956,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  631, 2741,   37,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  361, 1100,   77,  265, 1523, 2793,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  204, 1240,    1, 1411, 2579,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3263,    1,  460,   28,  951,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3207,    1, 1674,  810, 1385,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1029, 1321, 3030,  384,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  148,    1,    1,  647,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 3396,  741,   32, 2018,    1,  864,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2844,   32, 1029,  851,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  782,  633,  493,    1,  176,  166, 1285,   45,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977,  267, 2978,   61,   98, 1171,    9,   51,   95,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1631, 2078,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  170, 1415,   37, 2276,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2555, 2087,  433,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  709,    1,    1, 3169,  361, 3173,  683,  221,   98,  176,  104,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2356, 1978, 1213,   37,  631,  669,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2328,    1,    1,   32, 2823,  736,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  446,  583,   32,  298,  187,  541, 1559,    1, 1255,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1346, 1140,    9, 3343, 2271,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141,  638,    1,    1,   98,  776,    9,  312,  966,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1094,  435,  810,  809,   37, 1598,  864,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2137, 2856,   32, 1619, 2018,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  845,  147,  190,  193, 1709,  176,  551,  612, 1377,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2956,   37,  288,   28,    1,   32, 2170,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,  700,  548,  577,  163,    1,   12,    1,   29,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  575,  442,   32,  754,  618,    9, 1273,  361,  777,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  189,  267,  942,  315, 2089,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2629,  167,  619, 1021,  328, 1970,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,  681,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1173, 1425,  166,  183, 1985,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  296, 1450,  316,   12,  397, 1787,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  501,  626, 2363,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1494, 2793,    1, 3103,  619, 1022,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  163,    1,   12,    1,    1,  691,    1,  455,  140,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,   37, 1706,    1,  182,   32,  208,  297, 1411,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2321,  750,  884,  885,  686,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2007,   37, 1515,    1,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117,    1,  163,    1,    1,  144,  145, 1350,  400,  297,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  187,  166,    1, 2225,  614,   37,  104,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  852,   37,  236,  237,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,    1,   37, 1505,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2377,    1, 1530,  548,    1, 2950,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  358, 1536,    9, 2240,    9,  581,  199,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1166,  565,  166,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1424,   32,  346,   93,   61, 1851,    1,   99,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1765,   72, 2084,  741,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2292,    1, 1316,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3143, 1550, 2269,  861, 1665,   32,  208,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1301, 1922,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2265,  828, 1860,   46,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  632,    1, 2323,   51,  211, 1411, 1539,   37, 2875,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3152,  186,  384,   85,   37,  688,  902,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  459,  813,  596, 1793,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1463,   32,    1,    1, 2838,   32,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,    9, 3121,    1,  548, 1312, 1999, 1530,   32, 1789,\n",
      "            1,  455,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  590,    1,   32,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1128,    1, 1087,  631,   93,   32,  327,  218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2442, 2911,  690, 2103,  617, 1116,  625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2,  60,   1,  37, 682, 951,  94,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  69, 530, 548, 365, 119,  88,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,  365, 2995,   98,  166,  222,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  623,  197,  418,   98, 1732,   15,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2609,   95,  473, 2443, 1384, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1,    1, 1022,    1, 1249,    1, 2110, 1022,    1,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  506,    1,  460,   12,  103,    1, 1008,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3086,    1,    1, 3148,  776,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2355, 1718,  105,    1,    9,    1, 1778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282,  123,  202,  590,    1,  187,    1, 1867,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,  619,   32,    1,  220, 1158,    1, 2880,  361,    1,  369,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1853, 2619, 1056,  597,    1,    9, 2930,    1, 2772,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3175, 1864, 2872,   45, 2615,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228, 2572,   32, 2764, 2765,    1,   32, 3376,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1183,  478,    9,  295,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2227,    1,   37, 1027,    9, 1326,  872, 1411,  356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1528,    1,  612,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  603,   37,    1,   79, 3002,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2995, 1681,    1, 1370,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,    1,  582,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2531,  476,  104,    1,   32, 1815,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    1,    1,   39,    1,    1,    1, 1114,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3077,  823,  778,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  460,   12,  920,  357, 1745,    9, 2397,  548,  590,\n",
      "         1953,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  636,  120,  488,  596,   93,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232, 3159, 3231,   37, 2428, 2522,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1866,  191,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2491,  400,    1, 1494,   37, 2709,    9,  104, 3282,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1492,    1, 2349,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 1484,   39,  163,    1,   12,    1,   98, 3148,  798,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  968,  673,    1,  423,   30, 1735,  674,  592,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 1447,  587,  288,   37,  477,    1, 1267,  186,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   93,   32, 2065, 2064,    1,   32,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3226,  973,  191, 3206,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 3397,  108,   45,  864,  909,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3052,  343,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1095,   37,  151,    1,    1,  150,    9,  152,   32,  987,  361,\n",
      "          225,  328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,  623, 1627, 1234, 1863,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1444, 1445,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1017,  681, 1000,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3279,   32,    1,  187, 3384,  437,    1, 1147,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  990,  456,   85,  734,    1,  669,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1290,  396,  720,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 2094,    1,   85, 2798, 2750,   37,  507,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  316,  984,    1,   91,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 2164, 2414,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3260, 1398,  612,  458,   98,    1,  270,  951,    1,  931,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  553, 2164,  452, 1893,    1,  640, 1022,    1, 3008,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  140,  176,  455,  907,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 2755, 1713,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 3176,    1, 2038,  922,  631,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800, 3302, 2682, 3066,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  854,    1,   81,  463, 2170,  528,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,   12, 2848,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  295, 1851,   37,  197, 1232,   69, 1042,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12,   26,    1, 2814,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1676,    1,    1,   45,    1,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   37, 1289,   28,   37,    4,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,   46,   37,   47,   48,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2751, 1648,   37, 2192,   28, 3346,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2551, 2892,    1, 1515, 2766,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,    1,  645,  400,   45, 2623, 2624,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3329, 2442, 1434,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   37,    1,    1, 2308,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  649, 2038,  859,    1,  220, 1789,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3402,    1,  844,  716,  487, 3102,    1, 3025, 2572,  191, 3125,\n",
      "           32,  531,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  978,  769,  526,  187,  425,  426,  570,  246,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  877,  400,   37,   52, 1009,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3209,  688, 3260,   37,   23, 1524, 1090,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  236, 1686, 2414,   56,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  326,  675,  813, 2759, 2232,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1122,  853,  538,   37,    1,   98,  777,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  203, 2948,    1, 2325,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1528, 2297,  187,  294, 1477, 3164,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  286, 2054,    1,    9,    1,  384,  927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2957,  868, 1641,   32, 2334, 1523,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3040,   45, 3374,  650,   32, 3140, 2070, 1484,    9, 2966,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  361,  954, 1324,   25,  157,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  369,    1,  476,   37,    1,  224,  378,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708,  249,   12, 1030,  396,    1,    9,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1503,  132,  140, 1050,  432,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  477,    1, 1866,   37,  527,   95,  473,  474,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2765, 1098,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1479, 1522, 1064,    9, 2974,    1,    1,  267, 1821,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  716,  134,   76,    9,  228, 3226,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3287,    1,    1,  220,  638,  470,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  136,  672,  118,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 3375, 2572,   32, 3101, 2625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1956, 1260,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  443, 2502, 1916,  190,  698, 1411, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  732,  482,   37,  764, 1346,    1,  220,  818, 1882,  176,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1218,  894,  606,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  487,  883,  568,  338,    9,   72,    1,  339,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,  365,  342, 1984,  884,  756,  548,  211,  220,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   75,    1, 1436,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3168,    1,    1,  288,   37,  907,   32,    1, 2069,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2108, 3368,    1,   98,  557,  540,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 2018,    1, 3389, 2856, 3094,  176,    1,  186,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  449,    1, 1178,    1,    1,   32, 2592,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1126, 1954,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2265,    1, 1273,  618,    9,  105,   74,   32, 1313,  176,  845,\n",
      "          408,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1702,  981, 1159, 1273, 1821,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2136, 1261,    1, 1897,   10,  537,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1017, 2954,  220, 1361,    1,   98,  903, 1222,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  727,   37,  151,    1,  728,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117,    1,  715, 2911,    1,   37,    1, 1900,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2055,   79,   26,  220, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2892,   45,    1, 1558,    1,    1, 1530, 1142,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  782, 2537,  220,  793,    1,  238,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1073,   85, 3059,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  151,  515, 1431,  219,   32, 2041,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  353,    1,  131,  673,  448,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2241,   45,  647,  253,  690,  148,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2016,   32,  449,  913,    9, 3251,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2700,  365, 2983,   51,  335, 1400,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 3313, 2712, 1554, 3316,  228, 1394, 1048,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  314, 1692,   37,  508,   79,    1, 1149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  206, 1542,    9,  105,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  625, 1822,    1,   37,  116, 2423,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1895,  787, 1904, 1149,  741,   37,  439,  477,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1785,    1,  928,   32, 1388,  220, 3006,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  897,  384, 2301,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2387,    1, 1999,  384, 2500,    1, 1151,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2871,  865,   32, 2912,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  198, 2164, 2478, 1157, 1633,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,  597,  655,  513,  514,   32,   22,   23,  495,  400,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  289, 2344,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  225,  338,  187,  332,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3260,  335,  631,  297, 3209,   32, 1090,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087,  986,    9,    1, 1886,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1168,  336,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  217, 1620,    1,   98,  111,  133,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2095, 1928,    1,  163,    1,   12,    1, 1414,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  677, 1810,  531,   12, 1763,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1751, 1042,   79, 1224,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  294,   61,  590,  388,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  159,  245,  548,  413, 1162,  197,  304,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  105, 1298,    1,  600,    1,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3342, 1467, 2059,   12, 1368, 1001,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1178, 2072,  166,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  548,  949,   45, 1485, 1527, 1149, 2644, 3102,   32,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1024,  551, 1024,   37,  151, 1026,    9,    1,  182,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,  984, 1585,  384,  166,  608,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  342,   12,   93, 1560,   79,  837,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3276,  913,    1,   98, 2347, 1482,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3186,    1, 1632,    1, 1826,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2183, 3356, 2431,    1,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2137,  361,    1,  135,  985,   45, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1, 2196,    1,  164,  165, 1372,   37,   52,  598,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 3029, 3027,    1,  632,  104, 2640, 1478,   32,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  887, 1421,   45,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1716,  155,  327,   93, 1470,    1,  202,  392,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2939, 1427,    1,   28,  789,  986,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1602,    1,  579, 1366,    1,   32, 1034,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  397,    1,  695,   98,  963,    1,  721,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2929,   37, 1539, 1273,  259, 1108,   32,  179,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12, 1925,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1716,  155,    1,    9,  327,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  957, 1278,   28,  995,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  388,    1,   98,  994,  252, 1638,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 2104,  992,   28, 1994, 2095, 1708,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3281, 1804,    1,   37,  335,  916,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3204,    1,   98, 3329, 1990,  270,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  405,    1,   37,  664,  671,  187,  195, 1463, 2536,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2984,  782,  105, 1231,   28, 2662,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1061,  297, 3379, 2596,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2800, 1178,  163, 3177,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2068,  958,  487, 3102,   61, 1530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612, 1807,    1,    1, 2885,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2838, 3224, 1333,   98,  872,  336,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  463,    1, 2756,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  915, 1178,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3052, 2175,   32,  785,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  781,  353,  197,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3167,  154,   37,  741,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3310,    1,    1,    1,    1,   32,  521,   43,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2159,  781, 1194, 1843,  197, 1660,  187,   15,   71,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  119,    1,    1, 2682,  706,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,   37,  335,  861, 2521,   37, 1319,  907,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  862,    1,  384,  581,    1, 1857,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  384,  403, 2170,    1, 1632,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181, 1564,  922,   12,  915,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2942,  801,   32,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2689, 1717,    1,   12,  915, 1734,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3276,    1, 1971,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3285, 2761, 2719,    1,    9,  449,  199,   32, 2318,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,    1, 1773,    1,  335,  218,  332, 1523,   37,  365,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1232, 1973, 1344, 3305,    1,  460,  810, 1064,  176,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3167,    1,  405,   12,  943,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2466, 2094,   28, 2824,   37,    1,  460,   85, 2928,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2, 822, 533,   9,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 915, 173,  16,   9,   1, 187, 460, 952,   1, 607,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3405,   32,  557,  540, 2774, 1223,   98, 2024, 2699,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178,  947,  475,   57,  290,  548,  228,  249, 1333,   32, 1313,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  813, 3342,   32,  463, 2571,  147,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,    1,  104,  103, 1764, 1990,    1,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3192, 3170,    1,  119,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  816,  548,  419, 1253,   98,  340,   25,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2090,    1,    1,  353,    1,  331,  572,  197,   98,  417,  408,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  763,    1,    1, 2572,   32,  547,  537,   45, 2169,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3120, 1021,  608, 2920,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671,    1,   37,  138,  331,   37, 1814,  396,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2217,   12,  365, 1277,    1,    1,    1,    1, 1921,  754,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3161,   21,  227,    1,  872,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1883,   98, 1171,    9,  182,  356, 3031,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1064, 2225,    1, 1478,    1,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2171, 3134,  511,  275,    1,    1,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,    1, 2638, 2931,  625,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1444, 1445,  810,   32,  166, 1948,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   26,  220, 1787,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  140,  183,   24,  384,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1756, 1271, 3151,  914,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051,  675,  156,   71,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275,  269,    1, 1886,   98,  531,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1785,   34,   69,  568,   37,    1,   32,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,   59, 3343, 2591,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,    1,   32, 2813,    9,  647,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3070,  449,    1, 1936,  913,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3319,    1,    1, 2685,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,  957,  980,    1,   98, 1527, 1604,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  204,   12, 2073,   12,    1,  920,    1,  202,    4,  176, 2800,\n",
      "            1,  565,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  794,  248,  400,  444, 3382, 2156,  191,  104,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,  920,  967,   37,  619, 1328,  600,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  669,  396,  449, 2848, 2992, 1151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2523,   37,    1,    1,  628,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1818,  147,   37, 1709,  400,   98, 1842,  187,  116,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,   85,  118,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2459,  153,  872,  420, 1169,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2018,   12, 3380,    1,  968,   12,    1,   37,  943,  112,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 2984, 1521, 2820,   12,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1090,   32, 1223, 2929,  259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    1,  680,  442, 1337,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  120,  765,    1,    1,    1,  506,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1380,  105,  211,   98, 3076,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1100, 1519,    1,   12, 1021,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1,  777, 1662,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1858,   46, 1348,  393,  159,  245,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,    1,   98,  195, 1091,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3387,  108,   45, 2909,   98, 1050, 1021,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1199,    1,    1,  288,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  251,    1, 1167, 3033, 1360,  612,  168,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,    1,  984,  238,   98,   10,   12,    1, 1135,   45,  531,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2490,   12, 3038, 1313,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2713, 2729,    1,    1,  754,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   51,  619,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3168, 1632,   37,    1, 3293,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  652, 2409, 1627,    1, 2107,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2431, 3358,  193,   32,    1,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 2896,    1,  928,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,  142,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1089,   51,   16, 2705,   45,    1, 3365,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117,    1,  163,    1, 1518, 1350, 1655,  444, 1700, 1701,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3225,  114,  365,  512,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,  614, 2100,   37,  619, 2100,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  868, 1001,    1,  132,  220,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3161,    1, 3130,  220,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  545, 1508, 2221, 1976,  193,  514,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 2018,    1,    9,  187,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3094,   45, 1583,    1,    1,   32,  531,    1,  449,  104,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  863, 1708,  680,  454,    1,   10,  108,  864,    1, 3140,\n",
      "           37,   77,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  815,    1,   37,    1,  105, 1875,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,  108,    1,   37,  741,    9, 3057,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3096,    1,    1,    1, 3328,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1671, 1976,   98,  667,  851,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1017,   56, 1231,   32,  829,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,  321, 2935,  915, 2941,    1, 1517,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3319, 1510, 2277,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    6,    1,  187,   31,  640,  365,  845,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  891,  286,  927,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861, 1906,    1,   98, 1619, 2571, 2024, 2699,    1, 2770,    1,\n",
      "           45,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  547,  388, 1061,   32, 1693, 2107, 1336,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  199,  421,    1,  755,  875,    1,  133,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2819, 1564,   28, 1023,   45,  810,    1,   32,  395, 2221,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1,  104, 1421, 1461,  750, 2532,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1380, 2468,  115,   32, 1764, 1990, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   28, 1872,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  768,  798,  792,    1,  792,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1445, 1421,    1, 1024,   37,  547,  356,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  978, 2724,  350,  218,  221,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,   61,    1,    1,    1,   32,  166, 3343,  890,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  744,   81,  593,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962,    1,  640,    1,    1,    1, 3271,   37, 2613,  726,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2226, 1824,    9, 2643, 1215,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  228, 1394, 1048,  548, 2613,  726,  297,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  547,  487, 2924, 2572,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2838,  907,  220,    1,  297, 1411,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  251,  581,    1,   37,  222, 2580, 2851, 1614,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  882,  155,  342,  152,  840,    1,    1,  159,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  324, 2483,  326,    1,  408,  677,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,  903,    1, 1417,    1,    1,  513,  514,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  696,  479,  289,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  325, 1117, 1525, 1013,  700,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,    1,    1,  105,   13,   45,    1,    1,  229,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1555,    9,  105,    1,   33,    1,    1,   51,   52,  603,    9,\n",
      "          334,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,   32,  365,  613, 1597,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3174,  921,    1,    9,   26, 1684,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  422,  566, 1509,  636,  804,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1187,  193,  698,  444, 1771,  171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  868, 1727,  630,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2919, 2072,  166,    1,   45,    1, 2796,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12,    1,  167,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3084,  792, 1822,  168,  792, 1232,  396, 2848,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  854,   57,  927, 1159,    1,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942, 3134,    1, 2183, 1940,   12,  129, 2565,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1080,  176,    1,    1,    1,    1,   28,    1,    1,   32, 2646,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2956, 1544,   37,    1,    1,  384,  365, 3017,  278,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1018,    1, 2809,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3267, 2660,   72, 1684,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,  936, 2071, 1331, 1876,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2907,  744,  411,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,   28,  995,    1,   37, 1237,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,  166, 2488,  774,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2715,   45,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,  726,    1,  125,  910,   37, 1023, 1090,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1545, 2800, 1218, 1831, 1458,  680,  114,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  324,   51,   52,   32,  887,   46,  220,  326,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  676,    1, 1258,   37,  276,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3142,    1,  726,  424,  199,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3232,  606,  105, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,  845,    1,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,  338,   98,  800,  455,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1323,  220, 3233,   61,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  403, 2926, 2503,  590,    1, 2748,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962,    1, 1825,   32,  228, 2202,  187, 3232, 2651, 3296,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   32,    1, 1515,    1,    1, 1744,  154,  619,  466,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1024,  361, 1024,  520,    1,   54,  214,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,   42,  331, 1350,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 1414,   64,   36, 2572,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 1439,    1,    1,  388, 2938,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  258,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  842,   12,    1,   51,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2932,    1,  323,    1,  680, 2206, 2989,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2504,  446,  884,  297, 1523,   37,  439, 3348,  555,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,    1,  326, 2035, 1151, 2657,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  774,  443, 2938,    1,   32, 3118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   27,    1, 1926, 1927,    1,  232,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  623,    1,    1,  156,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 2767,  581, 2113,    1,    9,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   65,  996,   93,   98, 1171,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1, 1742,  924,  361,  247,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2747,  166,   49,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  326,  420,  190, 1152,   45, 1465,  861, 2429,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  112,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2990,    1,    9, 3015, 1746,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3190,    1, 3161,  729,    1, 3297,   72,   32, 3278,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  928,   32, 2597, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  342, 1070,   56, 2064,   37,    1, 1140,    9,  657,  769,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1547,  392,  390,  187,    1,    1,  517,  343,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1363,  200,  723, 1108,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2713,  384,    1,   32, 2046,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2414,  176,  177,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3140,  891,    1, 2924,  384, 1430,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  193,    1,    9,    1,   12,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12,  957,   37, 2000,    1,    1, 1867, 1602,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  218,    1,    1,  176,  551,  612,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3340, 1855,    1, 2572,   32, 3360,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  179,  132,   12,  389,  805,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 2171,    1,  706,    1,    1,    1,  320, 1533,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1100, 1774,   39,  340, 1251,  207,  412, 1671,   32,  854,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  809, 1344, 1884,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3322,  619, 2125,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,    1, 1056,  587,  907,   98, 1715,   59, 1251,    6,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1925, 1583,    1,    9, 1133,  574,    1,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  517,  618, 1628,  265,  267,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  420,    1,   32, 2573,  176,  104,    1,    1,  915,  356,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  756,  757,    6,  197,  570,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1744,    1,  115,    9, 1340,   37, 2709,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1236,  297,    1, 2819,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  391,    1,  155,  158,    1,  936,  315,   37,  151,   81,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2909,    1,   32, 2752, 1633,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  504, 1022,    1,    1, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284, 1656,    1,  544,  594,  389,   45,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  335, 2275,   12, 3072,    1,    9,  105,    1,  559,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  157,  384,  303, 1464,   37,    1, 1744,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1622, 2751,    1, 1302,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  355,  737,  197,  338,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2095,  304,  444, 1697,   37, 1081,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  781,  401,  197,  418,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2707,   32,  166,  219, 1841,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  507,   12,  553,  457,  441,  994,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  366,    1,  245,    1,  419,    1,   32, 1893,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  635,   12,  244,  143,  763,   76,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2053, 2055,  245,  419,    1,   32,  385,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3079,   32, 2504,    1,    1,   45, 2527,  164,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2700,    1,    1, 1178, 2669,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2556,    1,  754,  861,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,    1, 1193,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  376,    1,    1, 2659,  505,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  649,  700,  288,   37,  674,    1, 2550,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1879,  913, 3229, 1247,   98, 2347, 1482,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1662,   30, 2693,  707,   32,    9,  166, 2856,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3061, 1237,    1,   37, 1313, 2868, 2237,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  276,  995,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2650,  902, 1128,   37,  693,    1, 1228,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  863,  356,   67,  423,    1,  284,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  425,  426,    1,  166,  365, 1357,   61, 1358,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3188,    1,  943,  600, 1610, 1880, 2424,  119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649,  441,   66, 1969,  324,  326,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  294, 1456,    1,  841,  441,  297,  333,   45,  931,  191,  104,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  230, 2317,  548,    1, 2263,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2747,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,   26,  242,    1,  104,   60,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3190,   98, 1171,  528,    1, 1021,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2719,    1,    1, 2103,  617, 1816,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,  163,    1,   12,    1,   37, 1195,  284,    1, 1196,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  361,    1,  997,   32, 3129,   12,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2529,  510,  431, 2732,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1518,   32,   98,  340,    1,   94,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3321,   37,  606, 1857,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2751,  222, 1054,    1,   37,    1, 1633,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3115,  288,    9, 1779, 1260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3209,    1, 1061,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3322,  384,  166, 2083,    1, 1444, 1445,  603,   32,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,  133,  134,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 1277, 1070,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1810, 2153,  176,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2899, 2790,  200,  111, 1107, 1017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  717,    1, 1037,   12,    1,  729, 1670,  698,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 176,   1,   1, 641,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 104,  60,   1,  98, 509, 297, 395,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3144, 2591,    9,  365,  650,  187,  121,  361,  166,  539, 1075,\n",
      "            1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826, 2962,  885, 3185, 2795,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  393, 1475,    1,    4,    1, 1959, 1153,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437, 1082,    1,    9,  388, 2150,    6,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1923,    1,  590,    1, 2486,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,  267,  460,  190,  125, 2101,   45,    1, 1414, 1455,   32,\n",
      "         3118,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,  859,   59,    9, 1222, 2359,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,  331,  551,  331, 1511,    1, 1629,  261,   39, 1354, 1328,\n",
      "           44,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,  865,   37, 1021,    9, 1963,   32,  316,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 1426,  951,  854,    1,  162, 1194, 1463,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  302,  952,  521,    1,  721,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1829, 1510,    1,    1,  764,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  391,    1,   42,    1,   24,  927,  220, 1498,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  837,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3007,    1,    1,    1,    1, 3016,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,    1,    1, 2631,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,   25,  504,  187,   69,  102, 1150,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1380,   85,    1,   37, 1174,  365, 1204,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,  794,  449, 1580,  853,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596, 1732,   15, 2011,  119,   32, 2073,  401,  496,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  894, 1658, 1411, 1656,   52,  365,  357, 1991,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3123,  311, 2936,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  971, 1149,  429,  219, 1849,   74,   45,  522,  444,  389,    6,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  198,    1,    1,   32, 1802,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1972, 1821, 1697,   37,  335,   95,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1568, 3260, 1285, 3232,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2801,    1, 1718,  551, 2894,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,   12, 3380,  952, 2710,    1,  764,   32, 2095,  856,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  431, 1018,  439,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  550,  235, 2838,    1,  191,    1, 2782,  202,    1,   32,\n",
      "          854,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 2789,  475,  261,   39, 3093,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1935,    1,  844,   32,    1, 2107,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2328,    1,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  364, 1293,   98,  103,  187,  166, 1948,   96,  176,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  116, 2542, 1654, 2995,  218,  332,   37, 1185,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  729, 1555,    9,  105,  365,  754,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2854,    1,   16, 1433,  807, 2385,  612, 1488,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2952,    1,   51,  606, 1846,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1922,  608,   32,  365,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3013,    1,    1,   32,    1, 2771,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2158,   45,  105,  199,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3345,  949,    1,   12, 2804,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  842,   12,    1,  193, 1812,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  764,    9,  754,  872,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1726,   81,  797,  469,    9, 3339,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1571, 1210,   37, 2192,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3276, 1314, 1159,  892,   12,    1, 3344,  220,   73,  140,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  580, 1133,   46,  220,  342,  183,  547,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2789,   12,    1,    1,   61,   45,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,  777, 2544,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  922, 1990,  729,  915,   98,    1,   12, 3217, 1638,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1583, 2414,    1, 3384,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   65,   28,  220,  573,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2127,    1,    1,    1,  361, 1018,  657,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2883,    1,    1, 2924,    9,   10,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162, 1133,  220, 1617,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,  39,   9, 914,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 467, 700,   1, 191, 793,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2957, 1118,  529,  617, 1539,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,  140,  449, 2085,    1,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  691,   37,    1,    1,   37,  877,    1,   32,  865,    9,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 2844,   32,    1, 1461,  477,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  303,  954,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,    1, 2111,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1791, 1926, 1927, 1928, 1301, 1260,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   37,  221, 1750,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,   37,  813,  176,    1,    1,  463,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  732, 2405,   37, 2365,  297,  541, 1803,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3261, 1268,  549, 1159,    1,  444,  375,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1492,  565,  334,    1,  361,  579,  606,  334, 2740,  220, 2614,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2411, 1590,  600,    1,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 3358, 1670, 3364,  865,   37,  406,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1393,    1,    1,   12, 1578,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,    1,    1,   37,    1, 2047,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,  183,   98,    1, 1410,   37,  777,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 2712,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2695, 2223,    1,  469,  440,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  442,  710, 1082,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1081, 1082,  734,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676,    1,    1,    1,   37, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2800, 1824,  716,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  936,  461,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1640,    1,    1,  515, 3315, 1918,  297,  650,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  931, 2192,    1, 1285,  297, 1603,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,  195,    9,  723,    1,  505,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3025, 3026, 1089,    1,   98,  116,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1389, 1057,    9,    1, 1119, 1149,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,  140,  768,   43,  444, 1361,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2087,  433, 1301,  487, 1527, 2664,    1, 2572,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 1965,    1,    1, 1112,  176,    1,  608,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3317,  744, 2364,   98,    1,  120,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1364, 1365, 1648,   37,  693,  388, 1876,   37, 2774,  168, 1813,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  986,   59,    1,    9,    1,   48,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2978, 2798,  884,  656, 1267,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1273,  618,   92,   14,   15,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  633,  640,    1,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1796, 2371,  636,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1070,  398,   37,  899,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,   98,  236,  237,  548, 1056,   74,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,    1,  515,    1,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,  876,    1,  738,  548,  770,  898, 1976,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043,   85,    1,   69,  509,  686,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  691,  688,  854,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 2660,  647,  214,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3375,  582,   37, 2197,   37,  927, 3358,   12, 2162,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  129, 1333, 1530,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3359,  140, 1022,   45, 2591,   98,  399,  469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1993,   28,  384,  687,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  286,  927,  703,  187,  615, 2816,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1848,   37,  138,  105,  599,   32,  166, 1336,   45, 1151,  102,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  317,  863,  973,   98,  903, 1447,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  425,  426, 1793,   28,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2281,  549,   45, 2208, 2402,   13,    1, 2917,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3227,  442,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1508, 2221,    1,  187, 2566,  176,    1,  776,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   63,  166,  862,    1,  159,  554,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  459, 1796,  207,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1,  908,  864,  132,   37,  899, 3366,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 2741, 3276,  726, 1194,   73,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,   37,  125,  104,  541,    1,    1,  474,  138,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3337,   12,   32, 3286,  256,    1,  361, 2594,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2948,  632,  104, 2640,  614,   37, 1821,    1, 2141,    1,  205,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  395, 1800, 1789,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1230, 1443, 2228,   79,  444, 1158,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  132,   37, 1154,    1, 2024,  226,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2153,  665, 1245,   98,    1,  957,  187,    1,  863, 1552,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1380,  671, 1078,   32, 1343,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  223, 1149, 2047, 3038,    1,   32, 3349,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,   37,   33,  104,    1,    1,    1,  384,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2673,    1,   37,    1, 1130,    1,  964,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1789,   12,    1,    1,  453, 1513,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2055,    1,    1, 2365,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  564,   37, 1752,  590,    1,  848,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1658,  327,   12,    1,  199,   37,  764,  166,  593,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  427,    9, 3230,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1100, 1835,  365,  815,   45,    1, 2670,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117, 3058,    1,   37, 2684, 1371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   56, 3111, 2572,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1698,    1,    1,  384,  845,  275, 1721,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3027,   51,  729, 2704, 2604,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,  288,    9, 1996,    1,    6,  332,  636,  191,  600,\n",
      "          105,  401,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,  267,  104, 1220,    9,  296, 1527, 1281,   61,    1,   37,\n",
      "          690,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  410,  751,   37,  477,    1,    1, 1386,  396,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   64,    1,    1, 1744,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  517,   69,  102,  105,  629,   37,  996,   93,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  210,    1, 2332,   37, 1844,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  207,   28,   98,  242,    1,   15,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   79,  220,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  140,    1,    1, 1074,   24,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  738, 3354, 2547,   37,   92, 2471,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1625,  104, 2471,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  769, 2175,   37,  105, 2895,   27,  334,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  288,   37, 2225,  597,  475,   45,  947,    9,  103,  861,\n",
      "          317,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  327,  593,   12,  818,    1, 1638,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2076, 1151,  983,   93,  198,    1,  143,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,  200,  365, 1151, 2639,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  267, 1821, 1539,  288,    9, 1352,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,    1,    9,  270,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  957, 2797,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3095, 2341, 3339,    1, 2060,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2031,  193,    1, 2193, 2031,  778,   61,  105,  227,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  220,  453,    1,    1,  705,  593,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 1418,    1, 2099,    1, 1090,    1,  187, 1370,   45,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1065, 1190,  678, 1481,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1625,   37,  489, 3260, 1452,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   65, 2625,    1,   98,    1,    9, 1412, 2086,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2920,    1, 1957,   32, 1918,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2959,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1458, 1545,    9, 3116,  922, 3098,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1412, 2528,    1,    1, 2261,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  952,  927, 1159,  941,   12,    1, 2600,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  839,  171,  223,  137,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2954,   28,  220, 2801,   37, 1403, 2226, 2969,   37,  215,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 3250, 2791,    1,    1, 1411,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006, 3353, 1056,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  342, 2151,    1,   98,    1,  549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   45,  507,   37,  221, 1370,   45,  112,   37,  273,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  116, 2542, 1408, 1044,  218,  332,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  961, 1482,  155,    7, 1184,   67,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3157,  682, 1046,  183, 1665,   32,  195, 1225,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  377, 2161,   32, 1465,    4, 2643, 1890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3227,  439, 1826,  220,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   96,   37, 2494,  872,   37,    1, 1123,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2819, 1117,    1,    1,  207,  819,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2500, 2103, 2727,   16, 2252,    9,  661,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  460, 1425,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503,   37, 1418,  749,    1,   45,  985,  762,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  481, 1273,  259,  218,  353, 2647,  682,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  227,    1, 1532,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,  744,  365,  647, 2187, 1757, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  649, 1975,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2209, 1178, 1260,  187, 3177,    1, 3215,  361,    1,  698,  444,\n",
      "         2846,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  352,   37,    1,    1,   50,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  193, 3005, 2797,    9, 1227, 2492, 2323,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  475,   45, 1583,   37,    1,    1,  287,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,   85,    1, 1394,    1,  176,    1,  176,  465,   74,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2737,   32,  825, 3311, 1745, 2556,   37,   52,  105,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  388, 1987,    1,    9, 3115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2631,    1,   98, 1130, 2958,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613, 2384,  105, 1102,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3012,  571,   37, 3024,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  384,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  342, 1310,   37,  429,  864,   37, 2673, 2375,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   69,  102,  470,  981, 1010,  395,  765,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1577,  675,    1,   37,  572,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2874,   45,  166,   29,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  519,  631, 2631,  548,  786,  401,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  159,  288,   37,  686,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  398, 1994,    1,  625,   61,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   51,  693,  453,  359,    1,   48,   37,  619,    6,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359,  980, 2915,    9,    1, 2024,   46,  220,  166,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  108,   45,  800,  401,    1,   82,  939,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  628,    1,  443,    1,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1840,  565,  921,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1082,  395,   37, 1403,  403, 1447,   37,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  215,  938, 1075,  893, 1810, 2572,   32,  531, 1450,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1987,    1, 2672, 3229,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,  511,  140, 3201,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,   32, 1067, 1085,  132,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144, 2409, 1924,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2086,    1,  191, 1773,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1478,  512,   12,  389,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  458, 2153, 1980,   37,  759, 1259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  957,  315,  333,   45,  152,    1,  159,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  619,  105,    1,   45, 2828,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3342,    1,   37, 1709, 2282, 1574,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   91, 1070, 2707,   37,  429,    1,   46, 1411,  356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  410,  932,    9,   10,   32, 2329,  297, 1930,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  433,  636,  997,    1,  458,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  361, 1234,    1, 2444,  176,  915,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1861,    1, 2070, 1559,   32,  247, 2789,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,  395,  159,  714,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    9,  503,    1,  105,    1, 2129,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  538,  441,   37, 2123,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,    1,    1, 1428,   90, 3369,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739, 1938, 1723,    1,    1,  220,  211, 2471, 2295, 2302,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  391,    1,  353,  197,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2253, 3343,  806,  663,  437,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  275,  681,  588,   37,    1, 1994, 2086,  302,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2573,    1, 1053,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2443,    9, 3015, 1746,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3132,  191, 3266,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1823, 1249, 1361,   37,  759, 3220,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175,    1, 1684,  187,  105,   12,  245, 1979,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,   28,    1, 1499, 2549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,    1,    9,  438,  625, 1031,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2620,    1,   39, 3076, 3275,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3337, 2660, 1990,    1,    9,   91,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1750, 1018,    1, 1785, 2657,  394,  293,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  315,   37,  764,   92,  532,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1643, 2384,  861, 1108,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  163,    1,   12,    1,   78, 2394, 2947,  176,  651,   46,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  498, 2824,  399,   45,  768,    1, 2096,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1024,   12,    1, 1777, 2739, 1401,  163,    1,   12,    1,  608,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   64, 2817, 2856,  388,  763,   32, 3349,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 2371,   37, 1251,    1,    1, 1547,    1,  686,    1, 1837,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3228,    1, 3115,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  636,    9,   69,  106,    1,  104, 1714,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  234, 3041,  235,    1,  234, 3041,  235,    1,   32,    1,\n",
      "            1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  803, 1064,    1,  183,  244,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1391,  166, 1497,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1926, 1927,   90,    1,   37,  686,  539,   12,   69, 1588,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,  588,   37,    1,  166, 2769,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  477, 1308, 1545,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2275, 1484,    9, 2948,    1,  275, 1429,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,    1,  267, 2095,  443,  190,   52, 1360,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 2108, 2221,  304, 2582, 1628,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2144, 1061,   32,  492,    1,   12, 2772,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  977,  579,   12,  115,    9,  574,  615,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3131, 1987, 1641,    9,  311,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1151, 2287,   15,  920,   76,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1940, 1205,    9, 2819,    1, 1792,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  864,    1,    1, 1004,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  105,    1,    1, 1555,   39,  166,  889,   45, 1204,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   65,    1, 1735,   93,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,    1,  565,    1,  267,    1, 1190,    1,    1,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2694, 1299,  443,  444, 1230, 3011,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2490,  958,  581,  400,   45, 2527,  164,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2547, 2535,  166, 1107,   37, 1158,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,   12, 3184, 2579,  614,  115,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  550, 1087,  267, 2693,    1, 1228,  167, 1121,    1,   45, 1465,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   55, 2959,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2155,  166, 1939, 3009,   32, 2697,   12,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2932,  877,  166, 3024,  221,   37,  506, 2164, 1414,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   14,   15, 1285,   28,  699,    1, 1975,   85,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1416, 2489,    7,  808,   32,  148,   12,    1, 2226,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106,    1, 2464, 1523,  207,  533,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  755,  884,    1,   37,  147,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  903,    1,  464,    1,   32,  594, 1134,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  150,    6, 1126,  636,   37,  105,  332,  384,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3371, 1484,    9, 3146,   45, 1815, 1816,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  193,   11, 1159,  834,   12,  183,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3207, 2192,   28,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  392,  593,   69, 1220,   93,  570,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,    1, 1103,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  864,  232,  108,   45, 2673, 1259, 2271, 1232,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1412, 2287,  320, 2869,    1,  460,   12,    1,  327,  593,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  864,    1,  202, 1554, 2009,   26,    9, 1903,   32, 2673,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   39,    1,   45, 3288,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,  247,    1,  187,    1, 1523,   98,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,  359, 1412,    1,  259, 1916,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1258,   37, 2230,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230,   12, 2457,  338, 1139,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1056,    1,    1,    1, 1851,  786, 1167,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 3102, 1757, 2424,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  155,  158,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1249,  572,  739,   98,  845,   69,  636,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1697,    1, 1539, 1626,   45,  224,    9, 1697,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1139,  202,  363,    1,   45,    1,    9,    1,   12,  542,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1640, 2528,    1,  105, 2529,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1569,    1, 2983, 1724,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  663,  437,  267,    1,  149,    1, 1995,   98, 2490,   12,  535,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 1090, 1829,    1,  176, 2748,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147, 2924, 2625,    7, 2597, 3392,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,  105,  658,  336,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  515, 2466,  574,    1,  916,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  389,  173,    1,  220,  367,  495,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  934, 1380, 2334,   98,  105, 1151, 3000,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2494,   32,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,  326, 1021, 2232,  546, 1718,    1,  176, 1087,    1, 1361,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1619,  217, 1139, 1105,  163,    1,   12,    1,  745,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2539, 2770, 1812,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2483,  183,  390,  361,    6,  215, 1346,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2835,  387,  221, 2029, 1094, 2708, 2024,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1830,    9,  166, 1411,  537,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1861,  571,   37,    1,  237,  548,  985, 2205,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1625,    9, 2056,    1,   98,    1,  932,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2059,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  941,   12,    1,  938,    1, 1590,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1900, 1248,  163,    1,   12,    1,   37, 1121, 2822,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   43, 1229,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2066,   69,  102,    1,  593,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1795, 2279,  140,  183,  104,    1, 1108,   24,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3119,    1,    1,    1,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  329,   32,   46,   37,  221,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3192,  854,    1,  916,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 1430,  548, 2764, 2765, 3060,  928,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1962,   37,   47, 1273,  259,    1,   37,  395,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,  446,  580, 1512,  297, 2949,  114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,   98,  103,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3115, 1376,    1,  440, 2715,   45,    1,   32, 2205,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  331, 1075,    1,  714,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  535,  656,  162,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 1140,    1,   37, 1348,    1, 2311,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1497, 2497, 3384,    1,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2802,  162,  449,    1,  354,   45,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1148,  357,    1, 1149,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   81, 1277,    1,  142,  943,    1,    1, 1841,  267,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  920,    1,    1,   12,  627,  190,   52,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1251, 3290,   32, 1133,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1284,    1,    1,  665,   98,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  677,   69,  102,  686,  455,   12,  442,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3356,    1,   32,   37, 1911, 1995,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1085,    1,   46,   28, 1411, 2273,   29,  656, 3004,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1968,  794,   40,  220,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  636,  176, 1816,  220, 2979, 2869,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 2373, 1413, 3069, 1994, 2095,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  113,   46,    7,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2034, 2241,  484,  297,    1,   32,    1,  427,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,  803,  365, 1788,   36,    1,    1,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1823, 2308,    1,  361, 1075,  166, 1090, 1928,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,   98,  166, 1376,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2719,  415, 1555,    9,  885,  916,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,  879,  829,  117,  132,   37,  465,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1192,   98, 2476,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1900, 1210,  869,   37,    1,  384, 3369,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1366,  190,  907,  854, 1023,  454,    1,    1,  193,    1, 3380,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,  705,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861, 2431,  267,  104,  190,   52, 1032,   32, 1447,  548, 2128,\n",
      "         2129,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2954,  220,    1,   37,   92, 2229, 2168,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  501,  190, 2553,   37,    1,  247,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2802,  140,  633,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340, 2297, 1863,   45,  166,  356,  191, 3167, 2308,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,  387,  647,  197,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,   12,  365,  356,   12, 3146, 2355, 1013,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2789,    1,  994,    1,  150,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2043, 2192,  911, 1018,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3236, 2368,  730, 2614,  726, 1045,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  627, 2524,    1,    1,  361, 2316,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  169,    1,  702,   37, 2123,   32,  131,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  919, 3175,   81, 1159,  449,  913,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2957,    1,    1,    1, 1835, 1718,  279, 2639,    9, 1273,  618,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3228,  565,    1,   37,  726,  166, 2177,  454,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3115, 1508, 1247,   37, 1700,  356,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,    1, 1747,    9, 1255, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  167, 1046,    1,    1, 1371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,   70,  120,   37,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1433,  105,  730, 2614, 2408,    1,  612, 2595, 1210,  247,  872,\n",
      "           37,  439,  166,  593,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  879, 2731,   32, 3339,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  338,    9, 2073,   74,   98,    1,  763,   76,  109,\n",
      "          504,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2382,  259, 1017, 2094, 2149, 2263,   45,    1, 3060,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1339, 1167,    1, 1628,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1583,    1,  352, 1358,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2843, 2523,   81, 1018, 1816,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,  670,    1, 3324,   81,   98,  103,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1404,   45,  903,    1,  464,  650, 3203,    1,    1, 1530,  420,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  458,  859, 1815,  764,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   28,  166,  171,   12,  954,  220,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3267,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1778, 1901,  696,  429,   85,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1204,    1,    1,    9, 3024,  361, 1965, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  649,    1,   45,  652,  588,  764,  384,    1,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1681,    1,    1, 1991,   37,    1,  538, 1292,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,   28,  861, 1705,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9, 1091,   45, 1011,    1,    1,    1, 2116,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  596,  616,  159,   71,    1, 1340,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3227,  542,    1,  220,    1,  442,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3252,    1, 2479,    1,  631,   32,  667, 3258,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 2472,    1,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  116,    1, 1046, 2678,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  140, 2213,  873, 1624,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1708,  378, 1334,   79,  260,    1,   98,   22,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  700,    1,  389,    9, 2693,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 2773,    1,  105,    1,    1,  105, 3388,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1414, 1523,   98, 2735,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  924,    1,  384, 1640, 2774,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1629,    1,  286, 1630,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 1628,  550,    9,  678,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,  572,  156,   71,   37,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1040,  814,  376,    1, 1469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  162,  449,  872,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1128,   37,    1,   59,   98,  365,  250,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2246,  671,  524,    1,    1,  764,  104, 1940,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2685,  512,  738,  220,  872,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1823,    1, 1242,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1107, 1863, 2382,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1430,  446,  939,    1,  267,  190,  193,  582,  365, 1386,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1259, 2011,   98,  864, 2439,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1151,   12,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  671,    1,   72,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  996,   93,    1,   32, 1744,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 1447,  521,    1,  477,  297,  917,   37,  477,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  529, 1702, 1375,   22,   37,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2437,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1531, 1906, 1579,    1,  469,    1,  938,  112,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2843, 2523, 2878,   53,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 2934,    9,    1,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  654,  267,   82,   83,   37,  930,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2323, 1118, 2977,   12, 2695, 1463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1227, 1236,  777,    1,  297, 2819,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   37, 1982,    1, 2108, 3368,   98,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2832, 1248,  211,    9, 1771,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  780, 1749,  220,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  479,    1,  449, 1736,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  295,   37,  664,  182,  182,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  683, 1140,    9,    1, 1945,  338,   98,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2341,   95,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3161, 2540, 2570,  171,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  442,  448,  590, 1389,    9,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,   37, 1463,  365, 3029,    1,   98, 1893,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  434,  105, 2079,   45,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788, 1110,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,  267,  163,    1,   12,    1,    1,  365, 2673,\n",
      "           46,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  422,  992,   28,  927,   45,  262,  263,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26, 1039, 1228,  614,   37, 1604,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,  186, 1258,    1,  220,  374, 2066,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510,    1,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3310,   12, 2099,   37, 2392, 1534,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1024,  551, 1024,   51,  151, 1026,    1, 2163, 1215,  267,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,    1,   98, 2016,    1,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   37,   47,  659,   45, 1158,   12, 1230, 3000,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3375,  698, 1027,    9, 2911,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593, 1171, 3098,  489,    9, 3280,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,  779,    1,    1, 1607,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,  828, 2709,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  719,  547,  388, 2119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 3306,   37, 1348, 2318,   32, 2741,  357, 1327,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3256,  460,   12, 1186,  191,  105,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  870, 2218,   45,  864,   12, 2673,  210,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  313,   37,    1,  454,  903,    1, 1447,\n",
      "           46,  428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  435,    1,   37,    1, 2020,   12,  890,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2018, 2764, 2765, 3060, 2572,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  223,    1, 1253,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  179,  180,  449,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   37, 2192,  331,    9, 3118,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3087, 2478, 1850, 1327,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1017,  353,  197,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  102, 1473,   32, 1169,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3309,  288,    9, 3328,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  854, 3192,    1,  848,  844,   37,    1,    1,  951,  691,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1080,  548,  985, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1530, 2288,    1,    1,   28,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496,  308,    1,   45,  809,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  420, 2722,    1, 2616,  719, 1488,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708,  178,  774, 3358, 1530,    1, 1130,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 1629, 1236,  314,  551, 1692,    1,  523,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2656,    1, 1479,    6,   32,    1,    1,  673,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 3160,    1, 3343, 2572,   32,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  606,  365, 1173,    1, 1690,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2768,  460,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  884, 1003,  176, 1117, 1525,  923,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,    1, 3154,   32,    1, 2162,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,   35,  267,   69,  102,  190,   92,  134,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  352,    1,    1, 1622,  379,   37,  726, 1495,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2558, 1976,   32, 1778,  279,  535, 2308,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777, 2549,   51,    1, 2961, 1898,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  107,    1,   69, 1021,  220, 2135,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1277,  267,  204,   12,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,  187,  218, 1489,    4,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3062, 1858,    1, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1361,   15,    1, 1396, 1718,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 2572,   32, 3101,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  766,  140, 1876,    9, 3016, 1935,  384, 1662, 1701,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  542,    1,  176,  439,   45,  593, 2522, 2769,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1210, 2349,   32,    1, 3380,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  720,  249,    1,    1,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,  593,   61,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2744, 1021,  279, 2168,  220, 1718,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  624,    1,  460, 1360,  612,   52, 2613,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12, 2617,  804,   39,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  152,   94, 1962,  109,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2787,   37,  698,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  251, 1442,  158,   37,    1,  170,  220,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1186,   12,  232,    1,    1,  680,  365,    1,   45,\n",
      "          414,  100,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1662,   13,  665,   28,    9,  333,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1414, 2497, 3391,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2618,  571,    1,  667,    1,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1,  464, 1009,  580, 1463,  297, 1633,    1,  469,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  948,    1,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2767,  365,  103,  439,    1, 2168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2800,  208, 2565,  939,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2879,  938,    1,    1, 1281, 1946,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  311, 2936,  140,  453,  449,  427,   32,    1,   32,  166, 1050,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98, 2820,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2919,  487,    1, 2664,    1,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2007,   37, 1747, 1114,  892,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  204,    1,  204, 1924,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1716,  387,  276,   32, 2480,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  887, 1668,  183,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,   37, 1174, 1107, 2610, 1108,   32,  455,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   45, 1327,  475,  108, 1300,    1,   32, 1328, 1134,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  971,   34,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1, 1250, 1489,  683,  202,  247, 2494,   61, 1387,  759,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3344,  437,    1, 1147,  129,    1, 2606,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777, 1635, 1361, 1213,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  162,  257,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359, 1268, 3339,  736,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1090,   79, 1648, 3000,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1326,  197,  407,  187,   15, 1192,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3319, 1421,  683,  361,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006,  798,  104,  232,    1, 1428, 3102,  132,  232,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  954,    1,   28,  128,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106, 1086,    1,   12, 1211,  157,  412,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2065, 2064, 1648,   37,  860, 1429,  651,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1748,   16, 2468, 2960,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2018,  221, 1159,    1,  631,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1763, 2844,   32,    1,  114,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3006, 2856,    1,   32, 1815, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584, 2629, 1046,  567,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1034,   32,  231,  183,  978, 1077,    1,   37, 2261,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314, 1692,   37,  508,   79,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  102,  245,  187,  104,  957,  716, 1239, 1588,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1, 1220,   45, 2390, 1063,  639,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  200, 1021,  279, 2933, 2232,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2755, 3010,    1, 2177,    9, 3193,  361, 2788,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,  138,   59,   37,  878, 1576,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2, 305, 670, 548,  14, 420,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,  61, 786,  37,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  200,  105,    1,   45, 2687,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1634,   37,  223,  762,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 3160,    1,  597, 3343, 3357,  650, 2572,   32, 1388,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3177,   98, 3302,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101, 3057, 1512,   51,   23,  411,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359, 1268,  105,  365, 1015,   45, 2024,   32, 1811,  404,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  990, 1236, 1791, 2650,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1,  548, 1887,  176,  177,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  198, 2164,    1,    1,  686, 1850,  455,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,    1, 1232,  864, 2390,  315,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  487,  681,  664,   39,   37,  363,  342, 1495,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1281,  640, 1023, 1204, 2633, 2177,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  740,    1,  794,  777, 1085,  700,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1100,    1, 2071, 1331,  769,    1, 1998,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1260,   32,  531, 2414,  357, 2766,  388,  763, 3361,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1366, 2233,  619,  460,  917,    1,  396, 3317,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 2710,  437,  267, 2072, 3379, 2596,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1755,  418,  187, 1187, 1950,   32,    1, 1537,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  202,  321,  460,    1,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1796,  458,  708,  192,    9,    1,  861,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,  670,    1,  615, 1343,  166, 2320,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2700, 2562, 3036,  168,  115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1215, 1042,    1, 2581,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  256, 1479, 1410,   37,  453, 2079,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 3118, 2751,  815, 2500,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  507, 2177,    1,   98, 1964,  569,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1982,  750,  924,    9, 3378,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,   98,  627,    9,    1, 3178,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043,  526,   32,    1,  442,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2817,  361,    1, 2856,  388,  763,   32, 3349,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,    1,  190, 1403,    4,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 1484,   39,  166,    1,   98, 2275,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 2130, 2952,   32,  166,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   32,  854,    1,  284, 2830,    1,  384,  105, 2501, 2423,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2256, 1143, 1454,    1,  176,  654,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2266,  404,    1, 2699,  894, 1348,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  613,    1,   37, 1003,  176,    1, 2169,  218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  195,  441,    1, 2466,    1,  176,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 2700, 1835,  365,  165, 1017,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3343,    1, 2253, 1002,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790,  267, 1812,  229,  565, 2440,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  405,    1,   37,  319,  424, 1034,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  151,  460,  176, 1658,  258,  848,  525,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3171,    1, 2615,   88,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,  942,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 150,  37, 151,   1,  32, 987, 132,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2755, 2170,    1,  863,  437, 1874,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  446,  952,   37,   62,    1,  220,    1, 3114,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  296, 1830,  413,   37,   20,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707,    1,  469,    9,    1,   37, 1752,  105, 2502,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  947,    1, 2607,   45, 1674,  195, 1463,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708,    1,   37, 2237,    1, 3358,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2257,    1, 2050,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  920, 1366, 2233, 1937, 1232,  224,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  256,  547,  538,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9, 2900,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2163, 1215,    6,  197, 1396,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3370, 2253,   37, 1260, 3363,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,   37, 1978,   69, 1482,   37,   92, 1069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1076,    9,  671, 1443,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  632,  681,  582, 1638,   45,   69,    1,  384, 2343,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1713,  777, 2995,  443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1971,    1, 1751,  680,    1,  810,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374, 3384,  650, 2572,   32, 3339,  787,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1117, 2208,  321,  460,   52,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1,   98,    1,   12, 1228, 1085,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  636,    1,    9,  104,    1,  427, 1343,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  677, 1292,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  581,    1,    9,  105,    1,   45, 1228, 1167, 2141,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3289,    1,  801,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1773, 1009,    1,   79, 2371,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  802,  220,    1,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  654,  300,   39,  547,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  188,  419,  187,   68,   25, 1155,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  580,  365, 2834,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  954, 1258,  198,   93,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2957, 2850,   37,    1, 2334, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1069,   28,  176, 1796,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   28,   98,  509,   45,  568, 1073,  191,  510,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  132,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  744,  365, 1821, 2978, 1539,  330,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3218, 1285,    1,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 1774,   39,    1,  340,    1,  327,   32,  395,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1354,    1,    1,  680, 1665,    1,  284,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2091,  104, 1588,   92,   69,  636,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  315,   37,  665, 2048,   45, 1772,  111,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3190,    1,   32,  959,    1,  274,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  160,  636, 1279,   28,    1,   32, 1893,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1,    1,   32,  147,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  447,  580,  443,   32,  709, 2170,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  408,   71,    1,   15,   37,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1355,  240,  597,  391, 3401,  187, 1081,   12, 2674, 1009,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1, 1272,   32,  451,    9,  166, 2249,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  190,  193, 2035,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  614,  384,    1,   37,  105,  671,\n",
      "         3126,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  433,  991, 1797,  112,    5,    1,   37,  439,  442,  443,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3248,  949,    1,  361,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  365, 1788,   98,    1,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   37,    1,    1,    1,  125,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1361, 1362,  572,  354, 1052,  187, 2254, 2089,  288,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  456,   39,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  191,  590, 2638, 1827, 2072,  100,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1,  829,   37,    1,    1, 1411,  339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2822,    1,  565,    1,  658,  763, 2085,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1, 2430,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   26, 1039, 1872,  700,  251,    1, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,    1,  730, 2614,    1,   28,   98, 2114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3115, 3130,   61, 1176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  213,   37,  151,  849,    9, 1270,  131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3227,  103, 2551,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2184,  978, 3138,   37,  151,    1,    9,   59,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1544,    1,  187,    1, 2857, 1173,   37, 2199,  832,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  612,  584,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2685,    1, 3237,  943,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1459, 2694,  480, 1918,    1,  798,  133,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1312, 3111, 2572,   32, 1656, 2596, 1260,   27, 3155,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,  361,  104,   37, 1598,  864,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2004,  647,  148,  776, 1961,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226, 2867,   37, 1540, 1176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  602,  476,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3309,    1, 3328,   32,    1, 2027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 2555,  547,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   69, 1190,  267,  107, 2567,   37,   77,  102,   32,   33,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2862,  729,    1,  187, 1033,    1,   91, 2405,  907,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523, 2192,   28, 2101,  786,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  104,  358,   37,  588,    1, 1232,  587, 1575,  527,   95,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  105,   44,    9, 1477, 1990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2741,    1,  365, 1292,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  615,   51, 1937,  388,  665,   98,  776,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  777,   96,    1,  202,  729, 1604,   32, 1647,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1107, 2610,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2315,    1,    1,    1, 1236,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3342,  776, 2052, 2191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  732,  156,   28,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,   82, 2855,    1,  275,  736,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018, 1463,  546,    1, 1461,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  729,    1,   37,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  305,  417,   98, 1290,  720,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424,  356,    1,  166, 2910,  321,   52,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2841, 3046,  190,   77,    1,   98, 1737,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  839,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1864,  657, 2403, 2340,   37,    1,   37, 2071,    1,   32,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  293,  420,    1,    1, 1519,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2868,  307, 3126,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2140,   51, 1046,    1, 2304, 1512,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3232,  581,    1,    1, 2347,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978,  769,   85,    1,  583,  191,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3144,  446,   98,    1,   45, 1918,    1,  413,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3018,   12, 2320,    1,    9,    1,  846,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   51,    1,  572,    1,  572,  207,  174,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  297, 1503, 2001,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  433,    1,  233,  498,   37,  125,  962,    1,  439,  970,  271,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2511,  288,   37,  698, 1090,    9, 3209,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2298,   18, 1159,  289,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  691,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2049,  774,    1,   37, 2671,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  837,  124, 1399, 1925, 1583,   37, 2338,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2909, 2856, 1763,   32, 2597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  442,  517,    9,  105,    1, 3151,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2254, 1412,    1, 1239,  658,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2327,    1, 3138,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  356, 1691, 1667,    1,  548,  455, 2164,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2142,  171, 1293, 3158,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  711,    1,  193,  957,    1,   37, 1543,  365,  475,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   61,   32,  105,   11,    1,    1,  453, 1009,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,    1, 1463, 1894,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  267,  321,  350,    1,    1, 2320, 3162,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1128,   37,  480,    1, 2400, 1021, 1129,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  642,  643,   57,  670,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  386,  884, 1684,    1, 2753, 1056,  569,    9, 2016,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096, 2313, 1408, 1018, 1691, 2494, 2793,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  555,  556,  557,  540,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403, 1447,  267,    1,    1,    9, 2673,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,  111, 1090,  293,  167, 1192, 1312,    1,   32, 1056,\n",
      "          537,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  677,  529,  408,    1,  157,    1,  793,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  649, 1943,  232,  267,  971,  967,  590,    1,    9, 2086,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 1994, 2095,  625,    1, 2189,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2386,  455,   45,    1,  750, 1563, 2029,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1058,   98,    1, 2019,  190,  764,   17,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  189,  108,  460,  920,   21,  983,   93,  190, 2290,  453,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  477, 1396,   32, 3155,  361,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  447,   12,    1,    1,   65, 1990,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2136,  967,    1,  505,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   69,    1,  954,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  880, 1625,   37,  271,  846,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018, 1240,    1, 1537,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  225,  407,   37,  356,  845,   98, 1230,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3178, 1258, 2315, 1045,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,    1,  162,  611,  199,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,    6,  255,  962,   37, 1865,  365,    4,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1, 1407, 1190,    1,   69,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1499,    1,   51,    1,  115,    9, 1099, 1453,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2227,  387,  395,  187,  105,  365,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  964, 2770,  778,   45,   36, 3102, 1512,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,   37,  907,   10,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 196, 958, 389,   6,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 104, 616, 720,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3188, 2037,    1,   37,    1, 2807,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1542,   37, 1575, 2017,  384,  647,    1,  387,  693, 2443,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1373,   45,    1,   12,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2217,   66,  187, 2252, 2095,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  590, 1211, 2424,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  694,   32, 3278,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  828,  720, 2154,   20,    1,  630,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  802,  220,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  681,  548,    1,   56,  339,  340,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,    1,  150,   32,  590, 1882,   37, 1000, 1411,  887,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  204, 1360,  612,  865,   37,  166, 3296,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  892,   12,    1, 2748,  176,    1,  171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1494,  384, 2072,   37,  726,    1,    1,  628,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  627,   45,  342,  768,    1,   32, 1820,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,   37,  123,    1,  111,  589, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1366,  543,    1,   37,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   45, 1184,   32,   11, 1233,  872,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,   37,  245,  191,  105,   72,  107,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1327,    1,  191, 3102, 1887,    1,  202, 1360,  612,    1,   37,\n",
      "          531,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3348,    1,   79,   37, 2597,   32,  142,   37, 1211,  487, 3102,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  121, 1821, 2640,    1,    9, 3024,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3226,  405, 3291, 1240,  582,   37, 2347, 1638,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  219, 3397,    1, 2707,   37,    1,    1,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1290,  396,   28,    1,    1,  102,  504,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1688, 1874,    1,  220,  365,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1461, 2414, 3374, 2375,   13,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101,  845,  147,    1,  484,  297, 3359,    1,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3010,   12,    1,  967,  119,    1, 1194,    1, 1090,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  963,  650,    1,   37, 3349,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1935,    1,  162,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  171,  237,  574,  921,  367,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2850,    1,   37,  103, 1569,   32,  447,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1632,  810,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1918,   32,  691,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  632,  104, 2640, 1445,    1, 3029, 2981,  176, 2875,  548, 1023,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  488, 1914,   45, 2102, 3017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1024,  884,  166, 2107,    1, 2337, 1130,    1,  166, 1990,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2022,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3309,   37,  231,    1,  966,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  385,   15,   28,    1,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3076,   37, 2545,  105, 2965,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 2864, 1194,    1,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2111, 1398,  612, 1403,  166, 2924,   37, 2597,    1,    1, 2111,\n",
      "          949,  166,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,   75,  146, 1842,  858,  484,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1066,  297,  647, 1523,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2531, 2909, 2764, 3394,    1,    1, 2572,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2708, 3352,    1, 1072, 1235,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  500,  225, 1042,  118,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  325, 1645, 1101,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,   12,    1,  919, 1596, 1665,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3103,   51, 1594,   37,   72,    1, 3229,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  258, 1013,  729,  105, 1183,  454,   37,  168,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,  213,   37,    1,    1,  778,    9, 3358,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2628,  315,  111, 1074,   37,    1, 1507,  229,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  636,    1, 2582,    1, 1601,   65,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1558, 2074,  548,  354,   37,  602,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  420, 2827,   32, 1791, 2147,  722,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  889,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1585,  640, 2504,    1, 1097,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545,    1,    1, 2049,   12,  427, 3158,  119,  220,  105,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3141, 1684,   61,  612,    1, 1411,  837,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962,    1, 1520,  187, 1110, 1334,   32, 1131,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437, 1082,    1, 2978,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  224, 2976,  786,  861, 2454,    1,  202,  885,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  356,  560,  347,    1,  452,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3013,   12, 3305,  958,  204,   12, 1036,   37,  584,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1412,    1,   61,  365,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,  845,  275,    1, 1083,    1,  122,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  140, 1194, 1267,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  744,    9,  225, 1066,    1,   37,  752,  159,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3340, 1527,  232,    1, 1861,   37, 1154, 1922,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  554,   37,  810,  199,  119,    1,    1,  365,    1,\n",
      "           37,  104,  954,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  619, 1542,   37, 1343,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2843,    1,   32, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1061,  191, 3101,  947,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  818,    1, 2893,    1, 1861,    1, 2471,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  384,    1, 1343,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2587, 2043,   61,    1,  112,   32,  968,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1309, 1523,   98,  301,    1,   51, 1851,  415,   52,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1181,    1, 1183, 2218,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  835,  419,   45,    1, 1273,  669,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2746,   97,    1,   37, 1910, 1371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 3383,    1,    1, 3357,  696,   77, 1250,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  645,   70,  550,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  393,  142,   37, 1031,  734, 1145,   61, 2443,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1104, 2209,    1,   32,    1,    1, 1543,  357,  125, 1658,  248,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3308, 1990,  810,   56, 1050, 2954,   18, 1632,  449, 1385,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  284,  575, 1284, 1167,    1, 2067,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1,   32, 3228, 1971,  856,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2984,   12, 2820, 2945,    1, 2700,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  707,  220,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1465, 1466,   82,  190,   52, 1467,    1,   59,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2264,  420, 2205,  220, 3068,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  654,   43,  919,    1,   98,  311, 1204, 1092,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  220, 3288, 1987,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,  226,   45,    1,  105,  855,    1,    8,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181, 1074,  313,   37,   77, 2826,   98, 1171,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1037,  275,  952,    1,  444, 3190,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  615,  894,  713,    9,  105,    1,  881,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3256,    9,    1,    1,    1,  693,    1,  548,    1,  245,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   45, 1423,  353,   71,   32,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2746,   37,    1,  711,  333,  187, 1013,  891,    9,  105,  365,\n",
      "           82,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  631, 2024, 2699,   37,    1,  531,  787,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2102,  707,    1,    1,  202,  590, 1107,    9,  255,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398, 2794, 1834,   12,    1,   37, 1343,   32, 3220,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  433,  636,   93, 1258,   37, 1121,   85,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1, 1563,  162,  105,    1,  548,  537,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2050,  855,   45, 1989, 1990,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481,   12, 1994, 2095, 2954, 2443,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,   37, 1876, 3093,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2331,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  667, 1292,    1,   81,   37, 1046,    1,   32,    1, 2069,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2614,   23, 1090,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1889,   92,    9,  528,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2340, 2344,  138,   79,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2319,  176,  166,  973,   45,  105, 2533,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523, 1401,  191,   98,  105,    1, 1434,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1333,    1,  865,   37, 1019,  778,   45,  449, 1675,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 2871,  220,    1,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,  957,   37, 2035,  356,   24,  220,  829,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310,   25,  670,  187,   69,  765,  530,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,   98, 2237,   37,  447,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1676, 1740,  240,    1, 1623,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  695,  267,    1,    1, 1432, 3207,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  114, 2094,    1, 2775,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  765,   37,    1, 2212,  861,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2709,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  297, 2347,  104, 2548,    1,   37,  602,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1107,  293, 1236,  207, 2441, 2852,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  190,  335,  453, 2813,   81,   37,  147,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3248,  442,    1,    1,   37, 3183,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273, 1729,    1,    1,   98,  166,  168,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2231, 1485,  446,    1, 1038,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275, 1164,  332,  617, 2403, 1243,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  996, 2860,    1,   98,  734,  591,    9,    1, 2064,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187,   36, 1950,  921,    1,  964, 1877,  856,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1973,  566,  193,    1,  548, 3305,   12,  484,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  747,  353,  417,  737,  156,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3244,    1, 1542,    9,  449,  522,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2539,    1,    1,    1, 1668,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2004,    1,  459,   28, 1718, 2860,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  931, 3130, 2239, 1159, 2287,  460,  719,   37,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  491,  469,    1,  615,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2197,   61,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  422,  261, 1636,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  396, 1465,  846, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1187,  460, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   37, 1075, 1282,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2527,  276, 1115,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3172,  140,  917,   37, 2010,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1794,  420, 1458, 2275,  808,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  770,   45, 2729, 3102, 1976,   32,  531,  947,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  476, 2266,   37, 1540,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1972,   69,    1,   28,  915, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3172, 1090, 1829,    1,  171,  176,  316,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 3316,  361,  311, 1348, 1762,  698,   37,  914,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  294,    1,    1,   12,  671,    1,   98, 1377,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3314,   12,    1,   61, 2315,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3364, 2726, 3040,   32, 3339,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2308,   64,   79, 1330,  187,  649, 2800,  509,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  449,  104, 2161,   12,    1, 3126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,    1,    1,    1, 2268,    1, 1095,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  249,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3339,    1, 1787, 2129,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1108,  300, 1225, 1748,   37,  617,  259, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613,  936,  166,    1,  612,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    9, 1476,  977,    1,  449,  166,    1,    1,  920, 1494,  166,\n",
      "            1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3270,   21,    1,  384, 1955,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 180, 325, 159, 384, 982,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  60, 176, 365, 810, 199, 340, 951,   1,  94,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  107,    1,   69,  568,  191,   59,    1,  105,   74,  191, 1332,\n",
      "            1,   37,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,  848,  744,  636,    1, 2306,    9, 2371,   12,  455,  714,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3282, 2871,  104,  872, 1625,   37,   52,  388,  763,    1,    1,\n",
      "           32, 2468,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,    1,  854,  619, 1778, 2580,    1, 2581,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  251, 1270,  131,    9,  989,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2024, 1002, 2052,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  475, 1443,   37,    1, 3363,    1,  863, 2712,   32,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   52, 2745,    1,  665, 1888,  997,   37, 1694,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12,    1,   37, 1734,   85,  202, 1334,   32,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1, 1827, 3265,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  705,    1,  704,    1,    1,  197,   28,  118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1405,  213,   37,   47,    1,   32,  182,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3095,  119, 3282, 3272,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 1792,    1,  220, 1050,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  299,  300,   10,  301,    5,  302,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  829, 1416, 1604, 1121,  707,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1869,  279,    1,   32,  132,  220,   20,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843, 2523,    1,    1,    1,   32,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  647,  721, 1707,  142,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1933,   61,  645,  793,   37,  912,    9, 1942,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  700,  325,    1,   32,    1,  182,  132,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129,    1, 2885,  140, 1548,  628,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2031,  777,  778,    1,   61,   55, 2098,   32,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  135, 1735,  459,   45,  411,  238,   98, 1965,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3032,  406,   32,  403, 1447,  155,  104,  122,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3250,    1, 2563,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  446,  267,  247,  649, 2237,   37,    1,  123, 2471,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1008,    1,  365,   82,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  777,  819,  818, 1278,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26, 1039, 1243,  429,   28, 2366,  949,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  633,    1,  798,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766,   37, 1539, 3016, 1935, 2871, 2261,   32,  572,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2227,   81,   37, 1212,  979,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  515, 2967, 2213,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  732,    1,    1,   37,    1,    1,    1,  134,   76,   32, 1890,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1,  453,  844, 1896,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  816,  548,  595,   37,  686,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1022,    1, 2296,  228,  754, 2202,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3232,  565, 1827,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275, 1398,  612,    1,  445,   98,  111,  378,  506,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2, 420,  49,  50,  37,  52,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,  39,   1, 631,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1306,  316, 1959, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1591,   76,   37,  619,  183,    1,   98,  236,  237,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2868, 1949, 2890, 2237, 1010, 2357,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  613,  696,  529, 1449,    1,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2396,   76,   37,  289,   98, 2891,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  150, 1353, 1140,  656, 1876,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1,   12, 2633,    1,    1, 1159,  124,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  159,  554,   98,  214, 1801,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2971, 1958,   51, 1598, 2189,  557,  442,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  633,   12,  421,    1,    1,   12,  199,   61, 2175,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3126,    1,  942, 1586,   28,  671,    1, 2505,  361, 3077,   98,\n",
      "          166,  238,  176,  166, 1675,  963, 2122,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018, 1405,  776,  220,  183, 2326,    9,    1,  115,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  964, 2369,    1,   98,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  511,  275,    1,  483,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  191,    1,   69,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1220,    1, 1128,   12,  197,   28,   32, 1913,  401,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  103, 3354, 2764, 2765, 3060, 2572,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  974,  191, 1935,   45,  166,  627,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   98, 1262,   37,  138, 1879,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1125,  365, 2741,    1, 1664,   37,  881,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  387,  365,  845,   32, 1033,  442,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  577,  548,    1, 2195,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3014,  779,    1,    1,    1,  192,  221,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,   12, 2439,  166, 1512,   61, 1533,  384,  297,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  858,   93, 1071,  586,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585,    1,    1, 1324,  898,   32,  903,    1, 1447,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  647,  721, 1707,  214,  142,  191,  148,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 2565,   61, 2270,   37, 1664,  166, 1576, 1090,  315,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  267, 3370,  315,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3128, 2770, 2597,  187, 2137, 2856,   28,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  447,    1,  142,    9,  531, 3365,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  336, 2864, 1194,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3343,  863,  770,  267,  190,  193, 2199,  741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885,  140, 2941,  361,  552,    1,  517,    1,  105,    1, 1684,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1718,  437,    1, 2146,  659,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548, 3358,    1, 2024,  967,  916,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  659,   45, 3029, 2328, 1781,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2304, 1705,  110,  444,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1474, 1458,   79,  352,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   97,  762,    1, 1316, 3369,  828,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2898, 1114,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,   37, 2122,    9,    1,  469,    9, 2170,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1603,  357,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,   98,  531,  863, 2462,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2460,   32,  166,    1,    9, 2583,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  792,    1,  792, 2389,   45, 1815, 1816,  193, 1610, 2018,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2801, 2914, 1718,    1, 2894,    1, 1228, 2639,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,   46,   51, 1527,   69,  636,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788, 1215,  624,    1,    6,  156,  157,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,   37,   77,  388,  987,   98,   38,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2899, 2790,    1,  365,  912, 2285, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1491,    1,  550,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  190, 1306, 1645,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  475,    1,    1,   97,   37,  943,  220,  148,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2246,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1577,   12,  572,   15, 1121,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 162,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 162, 168, 115,  98,   1, 149, 444, 224,   1,   1,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1027,  247, 1509, 1724,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   10,   98,  596, 1793,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   74, 2222, 1921, 3151,   37,    1, 1756,  906,  176,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,   12,    1,    9, 2321, 3164,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1409,    1,    1,    1,  531,  443,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2206, 2207, 3183,  835, 1849,   39,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  348,  733,  854,   81,  756,   50,   48,    9,  152,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2483, 1928,   45, 2658, 2269,   12,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3356,  787, 3279, 2856, 3361,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3198, 3090,  449, 1385, 2716,   32, 2445,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1166,   12,    1, 1846,  297,  608,  537,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1769,   37,    1,  810,  619,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  345,   37,    1,    1,  590,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458, 1278,   98,    1, 1137,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  191,    1,  408, 1110, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548, 1523,   45,  166,    1,    1, 1443, 1542,    9,  581,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3253,  548, 1194, 3329, 1684,  220, 1918,   32, 2936,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26,    1,   37,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  107,  475,   21,   69,  102,   37,  470,  384,    1,  845,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1772, 2069, 2240,   61, 2675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,  213,   37,  875,  144,  145, 1350,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2744,    1,    1, 3004,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1412, 2521,    1,  861,  441,    1,  384, 2047,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1013,    9,  365,  758,    1, 2524,  685, 1790,  132,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1390,  630,  220,  359,  474,  338, 1632,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,  593,   96,   28, 1245,   98,  587,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  691,  104, 1211,  442,  630,  884, 1601,  365,  356,   12,   74,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,  670,    1,  615, 1343,  166, 2320,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  449,  854, 1463, 2052,   37, 1282,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1425, 1033,   12,  616,    1,  267, 1119,   32,    1,   61,  972,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,    1, 2454,    1, 3034, 1525,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311,  688, 3313,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1487,    1,   28, 1107,  361,    1,    1,   32,  453,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  896,    1,    1,   12, 2225,   51,   52, 1176, 1183,    1,\n",
      "          202,  204,   12,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  460,  190,    1, 3162,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1933,  936,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  391, 1329,   37,   47,   48,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1111,    1,  187, 1081,   12, 1411, 1009,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307,  162,  105,    1,   45,   40,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3001, 1249,    1,  176, 1022,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  247,  454,   37, 1333,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  794,  331,    1, 1705,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 2924,  856,  454, 1159,    1, 2827,    1,\n",
      "            1,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2357,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  559, 2617, 1822,  132,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  627,   45, 2227,   12,  487, 1938, 3197,   61,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1888, 2789,  205,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1261, 2958,    1,  202, 1458,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2784,   37, 2826,  357, 2370,  227,  943,    1,  166, 2259, 1924,\n",
      "          105, 2050,   37, 1744,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  836,  149,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087,  952, 1285,  384, 1049,   32,  645,    1,  973,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3043,    1,    1,    1,   32, 2592,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3183, 1421, 3252, 3284,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  119, 1194,   73,    1, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2620, 2951,   74,   32, 2592,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2529,  195,    1,    1,   37,  104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,   46,  600, 2128,    1,   32,  531,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  879, 1018,    1,    1,   37, 3370,   12,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  219,  864, 2673,  132,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2768,  166, 1246, 1719,  388,   37, 2321,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2615,    1,    1,  384,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  327, 1074,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,   37,    1,  573, 1197,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   81,  548,    1,  546,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1990, 2315,  785, 2319,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1658,    1,   12,    1,  606,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3214,   12,  365,  686,  119,    1, 1796,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230, 1426,   72, 1385,  176, 2197, 3329,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  766,    1, 1159, 2157,  626,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 2870,   27, 1147,  947,    1, 2190,   32, 2597,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  315,  680,  454,    9,    1, 3361,   37,  741,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  365, 3058,    1,  166,  593,   12, 1411, 2141,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  403, 1447,  733, 1011, 1527,   98,  258,  218,  463,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1479, 1665,   37, 2048,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1930, 1140,   32,  104,  793,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3096, 3328, 2192, 3309, 1480,    1,  698,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,   32,    1,   12,  754, 1223,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  560, 1110,  565,   27,  103,   32,    1, 1251,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,   12,    1, 1539, 2052,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1166,  565, 1444,  920,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1739, 3186,  872,  420,  385,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  731,  166,    1,   45,  166,  104,  961, 1482,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,    1,   45,  365, 1708,  518,  261,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1118,    1, 2580, 2851, 2568,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,   39, 1517,    1,   61,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  903, 3165,   64, 2592, 2699,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1629, 1229,   37,    1,  119,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  102, 1253,    1,  118,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800, 1090,  166, 1497,    1,    1,    1,    1,  992,   28,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  328, 1429,  700,    1, 1536,    9,  152, 1126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  334, 2233,    1,    1,  334, 2233,    1,    1,  202,  424,  170,\n",
      "           51,  193,   52,  105,  686,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1369,   37,  119,    1,  131,   32,  134,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187, 3181,  688,    1,   32, 2445,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  386,  295,  972,   37,    1,  573,  315,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1405,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2648, 2801,    1,  982,  477,  259,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  877, 1718,    1,  232,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,   81,   32,    1,  361,   98,  105, 2699,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296, 1321,  829, 1322, 1039,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1257,    1,   32,  467,    9,  581,  199,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,   66,    1,  573,  408,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  500,    1, 1191,  872,   28,   98,  858,  668, 2568,  327,  593,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3076,  267,  170, 1360,  612,  583,  180, 1990,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  575,   66,  187, 2711,   45, 1400, 2113, 1286,   93,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2067,  917,  176,  754,   32,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  267,   60,  832,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1380,    1,    1,   98,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  590, 2041,  533, 1724,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  213,   37,   52,   53,    9,  152,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  810, 3297,    1,  810, 2539,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,    1, 1765, 2102,  413,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1273, 2515,  677,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2919, 2409,  140, 2198, 1708,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2745,   37,   52,   81,   32, 2142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  369,    1, 1118,  737,  932,  187,  927, 1258,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2483,    1, 2355,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,    1,  829, 2274,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1480,  191, 2895,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870,  354, 1052,   98,  327, 1220,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1920,  765,   32,  220,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1139,  202,  363,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1815,  220,  105, 3380, 2876,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2475,  729, 1555,    9, 1125,   37,  168,   98,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3175,  563,  105,   12,    1, 1188,  786,  388,   37, 2935,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37, 2123,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  914,  167,   52,  901,  548,  645,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  267, 2534,    1,   51,  606, 2095, 2471,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   66,  187,  366,    1, 2409,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  232,  939,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1033,  580, 2301,    1,  384,  651, 1031,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  822, 1918,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  296,   13,  621,  155,  739,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2801, 1867,  517,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1117,    1,   37,  665,  365, 1046,   98, 1691, 2417,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  857,    1, 1567, 2660,    1,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1354, 2556, 3384, 2644, 1159,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3391, 2924,  680, 1884,  114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  506, 1898, 1273,  618,    1,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1631,    1,  119,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2095, 2985, 2945,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3251,    1,   37,  439,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3147, 1428, 2067,  514,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  694,    1,   45, 2177,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1870,  571,   37,  455,  548,  547,  537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1122,  853,  538,   37,    1,   98,  777,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,  166,    1,  222,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1844,   79,  741,    1, 1056,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  215, 1107,  293, 1236, 2441, 2852,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3110,  476,   37,  726,    9,    1,  424,  914,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3140, 2386, 1094,   45, 2596, 1260,   98, 3374,  232,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  119,  333,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  259,  681, 1882,   37,  619,  844,   98, 1273,  618,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2181,  361, 1675, 1897, 2038,  922, 3279,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1162,   37,  123, 1771,  250,    1,  125,    4,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  255,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2459, 1566,  613,  116,    9,  810,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1670, 1018, 1405,  776, 1533,  384, 2110,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  813, 3342,  147, 1727,   76,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1443, 1844,  105, 3163, 2107,    9, 1009, 1160,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  233,   12,    1, 1734,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1, 2615,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  178,  132,    1,   37,  720,   44,  444, 3310,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2321,  590,    1,    1,  202,  833,  612, 2898, 3138, 1532,\n",
      "         1328,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,  302,   37, 1814,  442, 1559,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  200, 1013, 1626,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 2527,  164,    1,   32, 2573,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2080, 2771,    1,  729,   32,  166, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  723,    1,  884,   48,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1360,  612,  815, 1527,    1,    1, 1377,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1608,    1, 1917,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2836,    1,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  398, 1297,  104,  358,  125, 1149,  138,  191,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,  190,  907,    1,  680,    1, 2915,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1479,    1,  335,  631,   32,  455,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  927,  396,  381, 1164,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,   25,  123,  417,   98,  410,  578,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2759,    1, 2168, 2094,   85, 1087,  932,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  342,  387,  121,    1,   98, 3093,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,    1,   37,    1, 1674,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,  220,    1,    1,   98,   15,   32,  104,    1,\n",
      "          455,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2102,   15,  759,   59,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1178,  386, 2331,   45,    1,   28,   98, 3181,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  665,  626, 1159, 1997,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  633,  603,   37, 1155,  632,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1183,  227,  151,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  476,  981,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  852,  760,  183, 2247, 1495,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2171, 3134,  511,  275,    1,    1,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 1190,    1, 1057,  297,  104,   60,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  835, 1928, 1027,   13,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1774,   39, 1718, 2355, 1499, 2706, 3004,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  430,  933,  529, 1859,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2944,    1, 1464, 2007,   37,  340,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  952, 1560,  220,  455,    9,  365,  903,    1, 1447,   46,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   12, 2557,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  129,  922, 2941, 1090, 1829, 1834,  176, 2110,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2137,    1,  297, 2408,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  198, 2498, 1542,    9,  593, 3154,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1334,   32,  756,  547,  388,  537,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1850,  430,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  980,   98,  430, 2024, 1259,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1662,    1,    1, 1031,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3336, 2489,  257,  548,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  146, 1842,  858,  695,   37, 1818,  147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98, 1928,    1, 2658,  267,  204,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  848,   37, 1539,  645,    1,    1, 1228,   32, 1837,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 2107,    1, 2783, 1569,   32,  103,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2670, 1521,  200,  340, 1251, 2759,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  572,  156,  720,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  590,  427,    9, 2737,   12, 1762,   64,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1, 1984,    8,  105,    1,   37,  949, 1645, 3073,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  317, 2674,   73,    1,   15, 1124,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1251,  672,   37,    1,  388,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1707,  443,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1029,   69,  232,  536,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  108,  342,   37,  652,  954,  357,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,  947,   84,   28, 2884,    9, 3035,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1190, 1310,   37,  439,  502,    1, 1559,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2990,   51, 1427,  166,  629,   45, 1245,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  393,  361,  359, 1769,   37, 1598,  805,   45,  411,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 1957, 1558,   32, 3343, 1633,    1,  176,  177,  786, 2347,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  709,    1,  710,  513,  514,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2536,  187,    1,  512,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  726, 1669,   98, 1943, 1638,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,    1, 1307,  872,   28,    9,    1, 1273, 1228,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  671, 1078,  721,  476,    1,   45,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2869,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3352, 1333, 1530,    1, 1688,    1,   32,  531,   12, 3383,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2513,    1, 2297, 1255,   12,  103, 1185, 1409,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1821,    1, 1821, 2190, 2640, 2145,   37,  125,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2137,  326,   12,  822, 2465,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,    1,  142,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1268,  105,  365, 2240,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 163,   1,  12,   1, 684, 734, 102, 670,  88,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 213,  37, 130,   1,   1,   1, 328,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1100,    1,  466,  116,    1, 1781,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  872,  839,  453,  248,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  375, 1236,    1, 1359,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162, 1950,  384, 1094,   12, 3339, 2731,  418,   37,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2018,   98,  845, 2393,  548, 1656, 2596, 2891,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 3375, 2844,   32, 3339, 3279,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1856, 1539,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,    1,  829,    1, 2432, 1499, 2515,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1671, 2794, 2617,   37, 2760,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708, 2153,   37,  791, 3358, 2005,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  994,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403, 1447, 2673,   46,  729,  205,    1,  104,  957,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  978, 3138,  759,    1,  630,   98,   59,  132,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652, 2593,  365, 1499,  353,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3129,    1, 2594,   45, 2741, 3062,  219, 3329,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  459, 1159,  625,  734,    1, 1124,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056,  365,    1,  845,   36, 2800, 2308, 1988,   45,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3263,  429,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1622,  650,    1,  393,  379,    1, 3006,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,    1,    1,    1,  940,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1484,    9,  163,    1,   12,    1, 2841, 1984,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,   12,  440,    1, 1512,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1123,  273, 2472, 1337,    1,  179,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  796,    1,  662,  220,  657,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1229,   37,  817, 2183,  317,    9,    1, 1292,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  721, 2540,  142,   37,    1,  425,  426,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1110,  634, 2747,    1,   12,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  886,   37,  151,    1,    1,    9,  600,   59,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  982,   72,  401,  156,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962,  375, 1401, 3209, 1415,   37, 1131, 1684,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3378,   12,  365,  750,   51, 1598,  247, 3130,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  142,  167,    1,    1,  654,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2,  25, 245,  98,   1,  69, 102,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  12, 714, 105,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  282, 2367, 2695,    1,   45,  166, 1034,    1,  220, 2001,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  593,    1, 1831,  566,  651,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1, 1140,    9, 2300, 2265,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  617,  259,    1,   12, 2263,    1,    1,  736,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1307,   12, 2522,    1,   37,    1,   40, 1228,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1554, 3236, 3186, 1090,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   75,    1, 1159,  538,    1, 1355,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1312, 2512, 2227,  872, 2677,    1, 1485, 1938, 3197,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1537,  668,   37,  714,   98,  617,  618,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   53,    9,  331,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2592, 1988,   45,    1,   32, 1802,  890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  552,  552,  719,  105, 2324,    1,  202,  579,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1840,    1,    1,    1,  187,  103, 1132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32,    1, 2003, 2960,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  305,   28,    1, 1183,  439, 1401,  166,  454,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947, 1616, 2375,    1,  384, 2313,   12,  754,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12, 1429, 1446,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2383,    1,  150,  619,   37, 1847,  388,  763,  786, 2995,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  342, 2153,  697,   37,  693, 2927,   46,   37, 2707,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  750, 2153,    1,  191, 2104,   32, 1038,  966,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  179,    1,  180,  498,   37,  170,   45,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2069, 1046,   79,   61, 1890,   63, 2911,  582,   37,  806,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  195, 1463,    1, 3306,    9, 1312,  257,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  686,  191,  777,  861, 2716,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2213,    1, 2578,  332,  631,  176, 2335,    1,  628,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  267, 1360,  612,    1,   37, 3345,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   61,    1,    1,   28, 1737,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1046, 2607,   44,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 1130,  912,  388, 1994, 2819, 2039,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2026, 1450,   51,   52, 2175,  384, 1658, 1465,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  818,   14,  157,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  295,  498,   37,  125,  541,  176, 2295,   12,  405,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3173,    1,    1,    1,    1, 1411,  176,  104,   26,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479, 1761,  333,   45, 1233, 2227,  872,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2164,  406,  418,  176, 1687, 1022,    1, 3008,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2335,    1, 1083,  344, 1057, 2104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  793,  852,   37,  211,  453,  573,  589,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1527, 1332,    1,   15,  245,    1,    1,  570,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2396, 1082,  388, 1647,   37, 1281, 1054,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   99,  288,   37, 1140,   79, 2579,   37, 3184,  297,  535, 1281,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2313, 1988,   45, 1809, 2429,  600,   36,    1,    1, 2375,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3167, 2307,    1, 1739,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1684,  176,    1, 2826,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  326,   12,  327,  112, 1025,    9,  333,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  491,   32,  492,  493, 1222,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826,    1,   37, 1377,   37,    1,    9, 1449,   37,  619, 1674,\n",
      "         3292,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  105,  183,    1,    1, 2357, 1676,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,   32,   46,  220, 1431,   98,  844,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2505,    9,  104, 2161,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3072, 2137,   79,   98,    1, 1292, 2699,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  433, 2362, 1380, 2051, 1021,   32,  365, 2968,  317,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2414, 1056,  176,    1,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2327,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106, 1013, 2677,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3282,  208,   12,    1, 3267,  140,   32, 2410,   74, 1343,   45,\n",
      "          136,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1528, 1713,    1,    1,  166,    1,   32,    1,  628,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  415,  786,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  609, 1070,   37, 2449, 1211,    1, 1377,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   75,   37,  771,  613,  412,   98, 1202,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  292,  822,    1,    1,  552,  552, 1107,  332, 1294,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  617,  259,   13,  108,   45,    1, 1080,  327,  593,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2669, 2080,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  686,  220,    1,    1,    1,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  760,  166,    1,   45,  617, 2948,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   37, 3016, 1935,  357,  193,   37, 3016, 1935,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32,  645,  531, 3389,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  288,    9,  700,  698,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1366, 2518, 2588,    1, 1366,    1, 2588,    1, 1366,  335, 2588,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3262, 1761,    1,   39,    9,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   37, 1539,  453,  449, 1234, 2177,  988, 1107, 1863,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  622,    1, 2690,  162,  275, 1901,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1121,    1, 1121,    1, 2149,    1, 2149,    1, 1121,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3132,  221, 1415,   37, 2585,   50,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2494, 1293, 2793,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3308, 1990, 2962, 3186,  298,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3310,    1, 2245,  384,   74,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  517,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,   45, 3123, 1832,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,    1,   25,   71, 2311,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2573, 2774,    1, 3398, 1211,    1, 1082,  652,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  424, 1034,   32, 1128,  550,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 2527,   12,  661, 1463,    9,  244,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1705,   37,    1, 2764, 2765,  193, 2567,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790, 1419,  365,  659,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 3152, 2565,  833,  612, 2898, 2967,  190,   52,  105,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  468, 1362,  515, 2017, 1273,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275,  943, 1133,   63,  915,  736,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 3002,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  654, 1009,  267,  132,  220,    1, 1372,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,    1,   98,    1,   12,   81,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,  159,  686,  365,  845,    1, 1721,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  251,  365,  825, 1013, 2560,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3330,   51,  335,  247,    1,    1,  361,  168,  754,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1648,   37, 1048,  454,    9, 2708,  741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1924,  105,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1981, 3331,   32, 1463,   45,    1,  361,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1375,   22,   37,  125,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3108,  103, 3132,  220,    1,  750,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1414, 1000, 3102,  792,    1,  792,   32, 3155,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  287, 1251,  897,    9, 2302,  624,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1042,  149,  444,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2838, 2712, 3108,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2902, 1660,  453, 1001,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 1260,   51,   52,  105, 1421,   45, 2258,   37,   18,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  874,  875,   32,  768,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 2950, 2414, 1312, 3111,   32,  531, 1983, 1867, 1761,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977,  794,    1,  880,  851,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1, 1100, 2035,  956,   37,    1, 1017,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2, 224,   1, 758, 875, 768, 361, 332,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  12,  37, 168,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1084,    1,   37,  221,   37,  786, 1589, 2225,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1447,   12, 2244,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1234, 1484,    9,  949,   45, 1691,   36,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1380,  166,  765,   98,    1,   17,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   61, 2333,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1033, 2211,  996, 2532, 1319, 2396, 1966,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  716,   45,  365, 2997, 2454,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1173,    1,    1,   12,    1,  659,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  292, 2927, 1722, 1718, 2168,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  704,    1,    1,  361,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2084, 1090,   45,  356, 1178,  386,  951,    1, 1545,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  294,    1, 2844,   32, 3360, 1585,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  691, 2172,  453,    1,   32, 1811,  404,    1,  475,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3318, 1844,  726, 1045,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  519,  103, 2807,   32, 3246,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1214,  835, 2922,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   39,    9,  914,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1542,    9,    1,  522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  245,  187,  395,  155,  347,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,   71, 1750,  105,  106,    1,  288,  885,  119,  845,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,  251,    1,    9,    1,  111, 2931,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2452,  517,  105,  449, 1173,  176, 1158,   12,  365,  810,\n",
      "           32,  786,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1478, 3224,   32,  611,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087, 2614,  132, 1417,    1, 1854,   37, 3234,    9,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  982,   37,  125,    1,    4,  481,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 3374, 3384, 2572,   32, 3101, 1461,  477,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  828, 2099, 3104,   12,  420, 2295, 2302,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2946,   45,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158,  167,  138,  388,   37, 1158,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  449,  197,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612, 1749,  220, 1509,  151,   37,  973,   80,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1304,  213,   37,  138,  152,   37,  875, 2089,  400,  220,  422,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  880,    1,   28,    1,    1, 1159,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779, 1321,  384,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  200,    1,  659,   45,    1,   32, 1033,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107, 1579,  672,   69, 1069,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  733,  613,   48, 2552,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1419, 1961,  861, 2976,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1581,  104,    1,   32,    1, 1299,  927,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12, 1384, 2188,  543,   37, 1403, 2924,  754,  384,  531,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  632,    1,    1,  476,   37,  576,    1,   37, 1821,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111, 1107,  778,   42, 2730,  149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  421,    1,    1,  361, 1110,    1,  166, 1639,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707,    1, 1489,  501, 1125,  384,    1,   98,  342,   46,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3257, 3205,    1,   37,   77, 3329, 1625, 2793,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  238, 1588,    1,  680,  903,    1,  395,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1191, 1561,   28,  378, 1083,  160,  122,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1266,  159,  720,   37,  365,  687,  548,   72, 1266,  880,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3363, 1398,  612,    1,  255,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2262, 3343,    1,   32,  163,    1,  903,\n",
      "            1, 3102, 1013,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1477, 1990,    1,   32, 1383, 2027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1227,    1,  657,    1,  365,  777, 1085,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 2231,  267, 1405,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2833, 2375,  384,  754,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  197, 1137,   98,  119,   69,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  392,   93,  570,  361, 1484, 1247, 1862,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  191,   69,  636, 2401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 1645, 3073, 2249,   32,  531,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  129,  975, 2073, 1023,  207,  418,   98,    1,   15,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1293,   98, 1434,    9,  581, 3023,  726,   32, 1559,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  709,  978, 3138, 3224,    1, 1976, 1530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  191,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,   62,    1,  202,    1,    1,  449,   74,   45,   36,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504, 1178,  928,   45, 2527,  164,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2804,  387, 2059,   12, 1529,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1438,    1,    1, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   29,  656,    1,    1,  675, 1499, 2175,  384, 1051,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  176,  105,  199,    1, 1366, 1151, 2017,  176, 1183,    1,\n",
      "          681,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32, 1013,   45,   54,  607,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2104,  267,   77,    1,    1,   79, 2879, 1638,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1611,    9,  159,   32,  224,   12, 1126,   51,  439,  892, 2928,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175,    1, 2087, 2614,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2868,  267,  864,    1, 2673, 2596,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,    1,  284,   45,    1,   12, 1639,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1718,    1,    1,    1,   82,  943,   28,   26, 1039,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3385,  475, 1484,   98,  864,   37,    1,  899, 3107, 3366,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,   22,   98,  487,  844, 2013,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   33,   28,   98, 1658,   33,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   98,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  794, 2948,  853,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  857,   44,  919,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1845,  895, 2011,   32, 2646,   37,  439, 1345,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,  991,    1, 1502,   12,  214,  142,    9, 1503,  129,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   45,  507,   37,  125,    1,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  204,   51, 1343,   98, 1517,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3242, 1458,    1,    1,  108, 3215,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  398,   57,  863,  639,   37,    1,  261,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 2469,    1,    1,    1,  361,  928,  176,  439,   45, 2701,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1658,  499,  275,  550, 1108,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  188,   32,   63,  166,  862,  442,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1961, 1487, 1107,  124, 2222,  714,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3035,  193,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1390,  449, 1023,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3249, 3041,    1,  686,   32,    1, 1987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1527,  541, 1195,   32, 1081,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 2259,    1,  810,  166, 1130,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  550, 1028,  596,  741,   45, 1161,    9,   94,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  803,  851, 2421,   32, 1739,    1, 1887,  810,  228,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  547,  163,    1,   12,    1,    1, 1248,  163,    1,   12,    1,\n",
      "          591, 1527,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2396, 1268,   32, 3099,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1976,   32,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   93,   51,  664,  128,    1,  774,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  626,  721,   37,  907,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   37,  693,  449, 1140, 1876,    9,    1, 2706, 2232,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,   85,  202,   66,   32,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228, 2844,  187,  344, 3403, 1450, 2018, 3392,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  804, 1999,  548,  121,  919,  650, 1650,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  562,  548, 1997,  686,   32,    1,   32, 2615,  726,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  633,    1,    1, 2378,  823,    1,  506,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  935,  794, 1808, 1412,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3095, 1210, 2024,  267,    1, 1190,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1224, 1025,  459,  356,  132,  220, 3247,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1164,  598,   37, 1343,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1494,    1,   37, 3024,  452, 1194, 2350,    1, 2977,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,  295,    1,   81,   32,   95,  116,  315,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1602, 2539, 2800,  748,   85,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2144, 2095, 2985, 1231,   32,  215,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106,    1, 1626,    1, 1013,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  936,  142,   37,   52,  903,    1, 1256,    1, 2696,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1583, 3400,  820,  384,  611,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  856,    9, 3362, 1258,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,   12, 3237,    1,  140, 1674, 1940,   12,    1,    1,  671,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  872, 2034,  415,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  994,    1,  150,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 361, 375,  37,   1,  32, 885,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 191,   1,   1, 396, 428,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1278,  831,    1,  227,  550,    9,   93,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1530,  357, 2249,    1, 1060,  583,   32,  455,   12,    1,\n",
      "            1,   32,    1,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  156,  176, 2447,  565, 1698,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,  640,  996,   93,  837, 1247,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1310,   37,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   13,    1, 1536,   37,  168, 1300,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3151, 2308,  920,   32,   91,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   66,  526,  176,   26,   69,    1,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1100,  251, 1998, 1243,   45,  365, 2071, 1331,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3333, 2770, 2611,  202,  590,    1, 2961,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3014,  251, 1211, 1718, 2079,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  499, 1173,  176,  163,    1,   12,    1,  531,  622, 2705,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  276,  528,  832,   32,   69,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  105,  559, 2198,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,   12,  142,    9,  647,   37,  619,  342,    1,    1,  249,\n",
      "          774,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2751, 2856, 1270, 1583,    1,    1,  163,    1,   12,    1,\n",
      "         3397,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  25, 410, 115,  45, 303,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2466,  863, 1918,    1,  673, 1879,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1, 1353,  531,    1,  760, 2597,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 3388,  652, 1010, 1891,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235,  501, 3299, 1198, 2722, 3074,  608, 1834,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  342, 2153,  429,   46,   32, 3369,  548,  365,  909, 1665,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843,  719,  289,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  963, 2328, 1539, 1961, 2191, 2020,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  921, 2002, 3222, 2760, 1215,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101, 3030, 1484, 2024, 1929,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,  294, 1983,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,  167, 1838, 1839,  432,  191,  356,  439,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,   71,    9,  581,   74,   32,  105, 1559,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3151,  914,    1,  402,   45,  590,  865,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1348,   37,    1,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  321,  104,    1,  105, 3077,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,    1,    1,  420,   98,  403, 1447,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3343,  650,  267,  863,  264,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481, 3390,   32,    9, 1194, 2113,  187,  667,  446,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2078,   16, 3350,    1,   37,   10,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1797, 1641,    9,    1, 2800, 1218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3260, 3224, 1588,  166, 1561,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3036,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1573,  220,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2662,   12, 2918, 2820, 3022,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  720,   32,   68,   70,  105,  468,    1,  774, 1721,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401, 2882,    1,   44,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  854,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  104,  233, 2107,    1, 2141,    1,    1,    1,    1,    9,\n",
      "            1, 2059,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 1620,   45,    1,   32,  105,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947,    1,  320, 1744, 1878,  487,    1,  298,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3264,    1,  175,  190,  688,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2072,   32, 1948,    1,    1,   28, 1030,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3279,    1,   32, 2646,  528, 2024,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  156,  242,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  861, 2221,  108, 1465, 2964, 1472,   28,  220, 1017,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,    1,  705,    1,  182,    1,    1, 1689,    1,    1,    1,\n",
      "          928,  176,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  993, 3160,  513,  514,   32,  104, 3402, 3408,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  991,  654,    1,  487, 1597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3369,  267, 1557, 1924,    1, 2282, 1450,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  627, 1046,   45, 2608,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   30,    1,   32,   72,  401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,    1,  156, 1396,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2950,    1,   37, 2844,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 2430,   32,    1,  977,    9, 3374,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2863,   37,    1,   28,  570,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2413,   37,  631,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1932,   22, 1225,  407,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1745, 2093,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3363, 1288,  365, 1015,    9, 3360,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2357,  548, 3101, 1497,   23,    1, 1159,   95,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1458, 3257,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1191,  500,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2877,    1,    1,   32,  299,  202, 2746,   22, 1931,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3003, 1353,  552,   37,  552, 2039,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  726,    9, 3241,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129, 3210,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 1668,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  613,    1,    1,    1,  384, 1307,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  485, 1949,  326, 1259,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  451,   95, 1781,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   14,  124, 2370,  166,    1,   45,    1, 2632,   32,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2815, 2208, 1294,   51,    1, 2298,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  717,    1, 1037,  921, 1117,    1, 2926,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 2347,   32, 2328, 1260,   98,  715, 1967,   32, 3360,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160, 1278, 1924,  526,   32,  367,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2232,  361, 1465,  254,    1,   37, 2888,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 1000,  377,  112,    5,    1,    1,   29,   16,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  535,  391,   21,  601,    1, 1698,  356, 2034,   37,  103,  689,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713,  166, 2723, 2724, 2636,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  518, 2153, 1664, 2095,  394,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  921,  449, 1412, 1107,   15, 2577,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1340,  640,  754, 1844,  590,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777,  162,  365, 1644,    1,  190,    1,  932,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  169,  891,  840,    1,    1,  754,    1,  111,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  195, 1463,    1, 3306,    9, 1312,  257,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2471, 2318,  845,  220,   56,  640,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1378,    1, 2250,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  199,  421,  387,  755,  117,  983,  176,   27,  131,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273,  259,  815, 1634,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1913,  401,  156,   71,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  590,  454, 3207, 1042,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  663,  437, 1060, 2249,   32, 3367,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3339, 2831, 1700, 3375, 2572,  187, 1094, 1258, 1479,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2087,  433,  536,    1,   93,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 1034,   12, 2462,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  190,    1,   52, 1922,  248, 2491,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 3143,   32, 1313,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1386,   57,    1, 1302,   32,  166,  403,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3297,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1009, 1310,   37,    1, 2024,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100, 2384,  784, 1273, 2403,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2942,    1, 1139, 1434,    1, 2498,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1627, 1727,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  647, 2549,    1,    1, 2973, 1764,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3286,    1,    9,  166,    1, 1463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1652,   37,   26, 2798,   37,    1,  361, 1718,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2806, 1787,    1, 1876,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  302, 1712,   61, 1354,    1,    1,   32,  166,  593,  829,   82,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2160, 2049,  361, 2142,  759, 2069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  420,   45,  590, 2375,   32,  531,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,  267,    1,  913,  176, 2673,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 638,   1,  37, 619, 310,   1,   1, 428,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  12,   1,   1, 902,  39,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2801,   12, 2226, 2969,   37, 1636, 1159, 1186,    1, 1423,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3290,  726,   32, 1602, 2539,  865,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  267, 2289, 1924,    1,  451, 2180,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510,  488,    1,    1,  404,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  501,   12,  221,  967,  104,    1,    9, 2383,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1,    1,  187,  365, 3225,  512,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1721,    1, 1232,  107,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118, 2751, 1988,   45, 1887, 1056,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3207,  321,   77, 1674,  671,    1,  147,  261,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,    1,  180,  167,  877,  132,  424, 1034, 1160,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2471,    1,    9, 1548,  631,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 1959,    1, 3322, 1937,  183, 1178, 1444, 2556,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1363,  952,  365,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1536,  467,    1,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2162,    1, 1564, 2049,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  952,  479,    1,  971,  573,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,  647, 1523,   61,  227,    9, 1643,    1,  710,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 2446,   98,  166,  201,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  215, 1874,    1,   12, 2457,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,    1,  365,  617, 2165,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2004,    1,  325,    1,    1,  207,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994, 2834,  378, 1961,  191, 1384,  446,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37, 1343,    9, 1110,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1968,  321,  729,  726,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018,  113, 2764, 2765, 2985,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564, 3268,  714,   32,  726,  297, 3322,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  982,    1, 2801,  872,    9,  517,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1159, 1108,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  294,    1,   28, 1959,    1, 1960, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422, 1554,  224, 1555,   98, 1126,  168,  115,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 1285,  417,   32,  310,  605,    1,  729,   27,  119,\n",
      "         1653,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  612,  353,    1,  131,  354,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 3046,  288,    1,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   12, 2646,    1,  548, 3382,    1, 2024,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1069,    1,    1,  102, 1556,   32,  871,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129,  104, 3164,    1,  726,    1, 2843,  600, 1477, 1990, 1141,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3227, 1542,   37,  943,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275,    1,   37,  442,    1,   98,  531,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  111, 2655,   30,  629,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  852,   37, 1151, 1998,   37, 1403,    1, 1890,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   69, 1086,  530,   98,  430,  997,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,  362,  384,  377,  405,    1,  541,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1688,   45, 2388, 1478,  183, 1055,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,    1,  140,  111, 1090,  149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2275, 1288,  105,  388,    1, 2977, 1821,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299, 2591,   37, 1281,   78,  384,    1,  116, 1108,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  200, 1211,    1, 1499, 2549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3342,   12, 2059, 1231,   32, 2282,  722,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2313,   34, 2161,   12, 3096, 3273,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  952,   37,    1, 3107, 3366,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  709,    1, 1213, 1061,    9,    1, 2098, 1368, 2915,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1, 3397, 3118,    1, 1750,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,   12,    1, 1082,  863,    1,    1, 3359,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1554, 3236, 3186, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1756, 1552,  187, 3151,    1, 2308,  474,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  476,   37, 1978,   69, 1482,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  581, 1674,  671,    9,  649,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3381, 1287,    1,   32,  365, 1928,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2236, 2520, 2792, 1135,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2222,  113,  260,   98,    1,  504,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  303,  267,  104,  321,  341,   69,  636,  641,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  459,   98, 1106,   37,  815,  453,  252,  535,  378,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1988, 3403, 1532,    1,   39,   45, 1142,  204,    1,    1,  384,\n",
      "            1,    1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   63,  166,  862,  657,  338,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1194, 2132,  403, 2926,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 2659,   81,  548,    1, 2350,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,  614, 1300,    1,  159,  120, 1270,  118,   98,  449,   74,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,    1,  908, 2119,  881,    9,  395,  945,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1509,  151,   12,  572,   15, 1124,  118,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1022, 2719, 1946,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  228,  104, 2548, 2572,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,    1, 1251,   45,    1,  439,   37,   36, 3071,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  939,  187,    1,  171, 2565,  548,  914,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  737,  197,  953,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  942, 1313,    1, 1065, 1190,  176,  181,   45,    1,  299,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 1009,    1,  186,   98, 2069,   74,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2991, 1396, 1095, 2264,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,  253,   81, 1499,  297,    1, 1816,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  207,  418,    1,    1, 2051,  763,  570,    1,   98,  408,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,    1,  532,   51,  686,  105,  131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2302,  156,   37, 2290,  308,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885, 2865, 2523,  384,  103, 1569,   32, 3129,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  159,   45,  340, 1251,    1, 1933, 1253,   98,  170,  943,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2737,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  942,   79, 2681,  220,    1, 1461, 1462,  469,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1625,    9,    1, 2389,   37, 3343, 3102, 1512,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  845,  147,   37, 2303, 1232, 1443,   51,  815, 1842,    9,  777,\n",
      "          412,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,   37, 1289,    1,    1, 2549,   37, 2255,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158,    1, 1128,  686,  191, 1395,  768,  149,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1414,  774,  837,    1, 2172,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2246,  730, 2614, 2935, 1569,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2695, 2223,  744, 2364,   98, 2948,    1, 1017,  361, 2212,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1521, 1240,   52,  449,  173,   45,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2226,  331,  380,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1485,    1,   13,    6,  157,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169,   81,   32,  103, 1505,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3109, 1532,   32, 2140,    1, 2950,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,   12,    1, 2633,  123,   37,  442,    9,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 2628,    1, 2295, 1022,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220, 3240,    1,  105, 2500,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3260,  631, 3209,  548, 2799,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302,  256,    1, 1661,  182,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   26, 2250, 2483, 2252,    9, 3173,  951,    1, 3064,   32, 2069,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273, 1830,    9,  730, 2614,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2405,  463,    1,  361, 2258, 1245,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,    1,  777, 2995,  593,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  696,  443, 2502,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  750,   98,  776,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  921,    1,   37,  726,  176,  395,   26,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  645, 3278,  105, 2370,  227,    9, 3010,    1, 2963,    1,    9,\n",
      "         3013,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  176, 1658, 1108,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  147, 1392, 2096,  297, 2388,    1, 1393,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3021,   51,  664,  671, 3126,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  347, 1360,  612,  686,  754,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3229,    1,    9,  931,  361, 2321,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1522, 1021,    6,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  403, 1447,  476,   46,    1,  590, 2306, 1724, 1186,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  342,  475,  884,  225,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  306,   37,  349,  649, 1885,    1,    1,  150,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   98, 2393,  187, 3043,  649, 2949, 1976,   32,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2358,    1,  251,    1, 1799,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    6,  197,   93,  739,  187, 2599,    1,  297, 2054,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1652,  936,   26, 2798, 2232,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,  288,   37,   26,   85,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  147, 2591,   37, 2831, 1899,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12, 1069, 1464,   37, 1192,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1,    1,    1,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1042, 2256,   44,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3157, 2263, 3370,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2851, 2489,    1,  220,  111, 1446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  369,    1,    1,   37,  222, 1077,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  755,    1,  744,   28,   59, 1482,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189, 1586,   28,  331, 1127, 1140, 2363,   24,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2835,   12,  695, 2789,  288,   37, 1761,   71,   45,    1,   12,\n",
      "         2059,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504,  927, 2758,   32, 2705,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  181,   32,   98,   50,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,    1,    1,   45, 1056,  487, 1527, 1900,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1752,  657,   12,   82,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,   37,  877,  433, 1484,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   24,  162,  474,   12,  562,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 2593,  116,    1, 2567,  437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2048,   32,    1, 1075, 3048, 2923,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1234, 1061,   32, 3184,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3149,  947, 2833, 2751,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 2149,  312,    1, 2111,    1, 1366, 1445,  487,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  447,    1,  386,   78,  361,  440,  497,    1, 2703,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,   37,  151,    1, 1499,  700,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1367,  361, 2321,    1,    1, 2310,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1234, 1156,    9,  105,  356,  548,    1, 1190,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1228,  920, 2812,    9,  166,  365,  772,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2171, 1031, 2198,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,  912,    1,  917,  384,  166,    1, 1656,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2448,  386,  159,   71,   98,  420, 2422,   51,   47,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  429, 1425,  105,  106,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  832,   45,  166, 2615,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2162,    1, 1564, 2049,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267, 1662,  967,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2748,   12,    1,  162,  247, 1333,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  636,  720, 2134,   69,    1, 1140,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1629,  614,  548,  286,  293,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1532,   32,  301,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1076,  190, 2286,   37,  222,  671, 1078,    1,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2752, 1633,  176,    1,   45,    1,    1,   32,  166,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1821,    1,   51,    1, 3033, 2725, 2727,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087,  433,    1,    1,   45,  302,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  442,  437, 1009, 2137, 1093,  977,  808,   32,  287,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,   82, 2182,   39, 2232, 1560,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1808,   37, 1539, 1972, 1821,  541,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204, 3205, 3169,  361,  744,  365,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1009,   12, 2162, 1564, 1298,  805,   98,   69,  102,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  809,    1,    9, 1107, 1089, 1343,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  841, 1284,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181,   12, 1762,  914, 1494,   37, 1018,  439,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  931, 2236,    1,    1,    1,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3147,  488,   37, 1260, 3114,  279, 2751,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   13, 1118,  420,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,  267, 1585, 1924,    9,    1,    1,  934,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1854,    1,    1,  764,    1,  114,   39, 3211,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,    1, 2162, 1175,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3117, 2370,  888,  187,  166, 1110,  504,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,   37,   47,  176,  612,   12,  207,  259, 1108,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  848, 2065, 2105, 1167,    1,   32,   98, 2186, 1521,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2339,  804,    1,  161,    9,  541,  176,  656,   45,  147, 1523,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  105,    1,   32,   12,    1, 2170,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,   37,    1, 1821, 2699,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1829, 1510,  601,    1,   98,  119,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545, 1482,    1,    1,    1, 1231,  220, 2930,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  621,  197, 1137,    1,  156,  570,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123,  232, 1484, 3283,  741,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2266,  680,  114,  187, 1428, 1566,  652,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  700,  200,  593,   12,    1, 1480, 1362, 2873,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3207,  614,    9,  388,  671, 1010, 2795,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096, 1218,   37,   52, 1231,  220, 2772,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1214, 1484,   28,   56,  384,    1,   98,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  711,    1, 1074,    1,  778,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2689, 1717,    1,  700,  256,  284, 1136,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596,  616,   69, 1276,  548,  107,  423,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2847,  726,   32,    1, 3135, 2034,  356,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,   39, 2084,    1,  328,   32,  537,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2, 814, 986, 599,  37, 875,   1,  45,   1,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 674,  45, 505, 229, 384, 761,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3342, 2059, 1924,  330,   37, 2816,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,  868,  449,    1, 2781,   32,  726,  297, 2090,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1431,  835,  803,  215, 1228,  669,   32,  987,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280,    1,    1,  187, 2289,  140,  365, 1788, 2472,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2535, 3349,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 2096,  297,    1,  951,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3115, 2935,  903,    1, 2227,    1, 1417,    1,  404, 1684,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61, 1170,  105,  804,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1090,  162,  754,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  451,    1,    1,   37, 2275,   12,  750,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  479, 2414,    1,    1, 1228, 1294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  268,    6,  111,  636,    1, 1355,  500,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2888,  868, 1688, 1465, 1294,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  753,    1,   98,    1, 2249, 2703,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  299,  300,   10,    5,  125,  302,    1, 1918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390,  132,  729,   98,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1636,  613,  858,   32,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1, 2454,   32, 3034,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  912,    1,  726,  147,  400,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 2801,    1,  196,   37,  345,   98,  517, 1017,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  935, 1288,   37,  576,    1, 1159, 1821,  191,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  796,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  395, 1760, 1163,  117,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1, 1014,  646,   67,  972,   37,   52,    1,   28,   98,\n",
      "          198,  301,   29,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,  361, 2275,  289,    1,   98,    7,   78,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548, 1628,    1,    1,  204,    1,   81,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1443,    1, 1923,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  193, 2697,    1, 2226,    1,  416, 1018,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3066,  744, 2457, 2306,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  354,   45,    1,  853,  488,    1,  372,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962,  405, 3291,    1,   32,  187, 1245,    1, 3206,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2466,    1,    1,    1,  140,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1362,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1257,    1, 2303,   98,  734,  132, 1371,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2158, 1380,  463, 2170,   32, 2886,   12, 1311,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1722,   37,  151,  179,   12,    1,   28,  112,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1620,  166,  810, 1048,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  365,  720,   32,   69,  102,    1,  236, 1022,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  625,  361, 2802,  176,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,    1,    1,    1, 2726,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  146,    9,    1,   45,  487, 3102,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   33,   39,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  215,   12, 1247,  476,   37,  652,  342,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  765, 1836,  220, 2723, 2724, 1935, 2146,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3375, 1210,  166, 2476,   37,    1,    1,  890,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  879,  186,   45, 1327,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  403, 1447,    1,   61,   10,    1,  193, 3203,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2980,    1,    9, 1307,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  510, 1360,  612,  877,  450,  686,   98, 1817,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  799,  396, 2853,   32, 3349,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3194, 3195, 2308,   37,  741,   98,    1,   37,  335, 2771, 2784,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089, 1229,   37,   16,    1,   45, 3365,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1614,    1, 2549,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,   72,    1,   98,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1131,    1, 1002,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1949, 1090,   32,  121,    1,    1, 2834,  629,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  403, 2926,    1, 2451,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129,   91,  168,   98,    1, 2731,  187, 3325,  884,  105,   74,\n",
      "           79,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  455, 3102,  580, 3026,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,    1, 1580,   61, 1509,  454,   37,  856, 2650,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2087,  433,  884,  838, 1058, 1750, 2266,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006, 1594,  297,    1,   37, 2646, 3346,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1433,  179,  361,  180,  416,    1,    1,  111,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1414, 2497, 3155,  187, 1186,    1, 2835,  588,   37, 1211,\n",
      "         3365,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  588,  922,  726,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,    1,  191, 1338,   45, 3118, 1647,   98, 1737,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  398,   57,  863,  639,   37,    1,  261,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2002, 2471, 1237,  365, 1015,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2963,  354,  408, 3301,  247,  389,  176,  584,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3315,    1,    1,    1,    1,   39,  220, 3265, 1987,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  117,  275, 2864,  293,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,  147, 2322,  288,   32, 1047,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   82,   12, 2667, 2668,  593,   45,  275,    1,  148,  837,  647,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3108, 1421, 2469,    1,   37,    1,  922,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  217,    1,  625,    1,  872,   28,   37,  856, 2026,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1,  921, 1238,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1204,    9, 1344,   45,  507,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3058,    1, 2426, 1086,  187, 2548, 1421,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  730,    1,  304,    1,    9, 1717,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187,    1,    1, 2789, 1924,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 2980,  210,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  765,   37, 1030,  756,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 3165,  271, 1159, 1796,   36,   32,  395,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  500,    1,    1,    9,  225,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2470,   25,  680,   97,    1, 1802,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  667, 3258, 3154,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1236,    1,   32,  722,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,   52,    1,   39,  176,  754,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  251,    1,   37, 3177,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2414, 2196, 2261,   32, 1778, 2580, 1901,    1,   28,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1425,  166,  593,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  882,  733,   48,   32, 1486,    9,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  942,    1,  119,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  870,    1,    1,  220,    1,   37,   92, 1117, 1943,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3214,  765, 1387,  786,  686,   45,  119,  187,  105,   12,  726,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2500, 2955,  640,    1,  813,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3234,  872,  420,  385,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  506, 1380,    1, 2705,   32,  531,  176,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1403,   98,  166,  183, 1305,    1,  267, 3315,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861, 1901,  176,    1,    1, 3000,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1876,  778, 1810,  103,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  790,   32,   46,  600,  164,  165,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  440,    1, 1531,    1,    1, 3141,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1704, 2767,  784,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1725,    1,  395,  187,  218,  954,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1075,    1,    1,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  716,   16, 1253,   32,    1,    1,    1,  679,   69,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,   12,    1, 1871,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3033,    1,  193,    1,  894, 1901, 3015, 2104,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,    1,  242,  187,   69,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  219, 2610, 1085,  168, 1273,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497, 1421,    1, 2967,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2837, 1710,  741,    1,    9, 2275,   32,  104,  863, 1002,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  478,   45, 2819,  490,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  350,    1,    1,   32,    1, 3114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481, 1268,  863, 1708,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  872,  476,   37,    1, 2500,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  754,  434,  490,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2964,  815, 3066,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3250, 1240,   52, 2198,    1, 1751,  444, 3276,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2222, 2405,   79,   37, 2028,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,    1,    1,    1,  187,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2862,  446,    1,    1,  680,  433, 2263, 2504, 1386,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   37, 1463,    1,  644,    9,    1,  453,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2523,    1, 1385,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1841,    1,  792,    1,  792, 1919,   32, 2235,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  103,  232, 1458,  964,   98, 1064,    9,  121,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942, 1484,    9,  592,   37,  335, 2177, 1173,  176,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3358,   12,    1, 1484, 1983,  912,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,  875, 1417,   43,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2650,  951,    1, 2650,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  515, 2018,  166, 1285,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   45,    1, 2931,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3067,    1,   45,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  270,  190,    1,   98,    1, 1031,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1,    1,    1,    1, 3269, 3237,    1,    1, 3238,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2528,  565,    1,  769, 1284, 2691, 1159, 2205,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   92, 1896,   32,  617,  259,  772,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  444,  547,  868,  652,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1920,    1,    1,    1,  384,    1,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2648, 2801,  166, 2084, 1796,  617,  259,    1,  267,  183,  590,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  853, 1781,    1,  384,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2701, 3009, 1083, 1001,    9,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  778, 1976,   27, 1019,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2104, 1458, 3359,   12,  469,    9, 3057,  957,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1771,  171,  176, 1923, 1028,    1,  167,  815,  284, 2153,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  575,    1,   32, 1411, 2273, 1935, 1523,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1318,   37,    1, 3349,   61,   32,  968,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1104, 2209,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 1020,   12,  365,    1,    1,  166, 1674,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1720,  105,    1, 1572, 1533,   39,   45, 1223,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1046, 3148,  776,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  388, 2510, 1501,    9,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3009,  361,    1,  565, 2626,    1,  202, 1221,   61,    1,   37,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2765, 2072, 3376, 2950,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1966,  315,  611,    9, 1899, 1940,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  274,   12, 3375,    1,  354,   45,  105,  874,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3124,  361,    1,    1, 2602,  365, 2036,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3258,  416,  460,  917,    1, 1528, 1477, 1990, 3164,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1079, 3063,   72,  401,  197,   28,    1,  202,  225,  338,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  531, 2596, 1585, 2414, 2335,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2147, 2596,  475,    1,  220,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2258,  603,   28,    9, 3300,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790,   37,    1,   32,    1, 1028,   45,  453,  195,  230,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  393,   82,    1,    1,    1, 1243,  138,    6,  359,  562, 1888,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340,  167,  606,    1, 2644, 2901,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2429, 2290, 1178,    1, 3339, 2129,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,  947,  379, 2572,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  176,  612,  613,  733,    1, 2665, 1671,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3131,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2349,    1,  267,  425,  426,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1547,  640, 1034,  845,    1,   60,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 108,  98, 244,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 437, 224,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  433, 1579,  131,  750,  302,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  417,   69, 1464,   37, 1198,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3211,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181, 1314,   98,  187,  386,    1,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   20,  296, 2096,    1,    1,   45,    1,  397,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  926,   98,  166,   71,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  459,   45,    1, 1976,   32,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1419,    1,    1, 2436,    9,  517,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  650,  852,  288,   37,  726,  581, 2113,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   12,    1,  472,   39,   32, 3155,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1006,  716,  244, 1124,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  437,  108,   45,  365, 1450,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,    1, 1270,  647,    1, 1322,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  149,  952,  949,   45,    1,    1,    1, 2945,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 2851,  949, 1961,  191,  861, 2429, 1387, 1779,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1749,   28,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 1762,    1,    9, 1763, 1492,   55,   37,  821,  220, 1001,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,  936,    1,  389,    6,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  109,  509, 1198,   69,   27,  104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267, 2131,    1,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3241,  750,   61, 2175, 2793,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  251, 1520,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3364,  738, 3374,   37, 1248, 1945, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,    1,    1,  439,  844,  883,  630,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  148, 1445,  879,  647,  142,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1698, 1202,    1, 1608, 1698,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1081,   12,    1,    1, 2095,  134,   32,  147,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2605,  907,   98, 2673,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3406,    1,   37, 3349,   37, 2199,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1380, 3304,   32,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1411, 1821, 2190, 1539,  288,    9, 1893,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  415, 1398,  612,  544,  460,  395, 1760, 1163,   12, 3134,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   37, 1075,   98,  367,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504,    1, 3043,   45, 1939, 2837,    1,  947,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 1408, 1528,  176,  827,   32,    1,  628,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3187, 1832,   28,    1, 2191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3262,    1,   37, 3116,  922,    1,    1, 2828, 1758,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1538,  477,    1,  102,   37,  554,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,   82,  267, 1360,  612,  211,  971,  665, 1144, 1114,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3052, 1882,   32,   37, 2069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  580,  391,  863,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  123,    1, 2175,  906,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3276,  877,  166, 1879,  138,  361,  726, 1515, 1194, 1090,   32,\n",
      "          105, 1559,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  105,   72,  401,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390,  213,   37,  365, 1495,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1, 220,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 328, 492,   1,  11,   1,  32,   1, 182, 132,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3229,    1,   37, 1306, 1056, 1675,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75, 1579,  365,  858,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2, 758,   1,   1, 361, 203,  37, 322,   9, 460,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 193,  32,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3324, 1287,    9,  593, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647, 1086,  856,    1, 2352,  148,   12,    1,  372,  142,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1747,  424,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2419,  218, 1258,  453,    1, 1716,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  460,  833,  612,  619, 2330, 1488,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  924, 2384,    1,    1,   32, 1143,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  774, 3339, 1953,  220, 3359,  105,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  668,    1, 1107, 1091, 2086,  396,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  589,   66,    1,  531,   12, 3102, 1512,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  458,  475,  972,   37, 1910,   32,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  761,  353,  242,  156,   98,  195,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32,    1, 3392, 2950,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1668,  331,  191,  840,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  210,    1,    1,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3251,  221,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  106,    1,    1,  767,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 2767, 1468, 1416, 2232,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  117,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  424, 1034,   12, 2462,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358, 1631,    1, 2056,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  636,    1,  832,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 2306,   32, 1123,    9,   86,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  629,    1,    9,  754,    1,  160,  209,   37, 1911,    1,    1,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  535,    1,  187,  593,   96,  460,    1, 1821,  361,  199,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1703,    1,  167,   52,   98,  454,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1231,  297,  116,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2614, 1334,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   12,   49,   69,  633,  729,  580,    5,  533,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  224, 1900,  619,  707,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 1185, 3009,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1487,  958,  636, 1124,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   34,    1,   37,   82,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3103,    1,    1,   32, 3089,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  171,    1, 1090,   98, 2929,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1273, 1182,  588,  242, 1620,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  919,  976,  442,  909,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  289, 2344,   37,   60,  361,  347,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2819,    1,  365, 2043,  856, 2026, 2574,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2821,    1,  220,    1,   32,  105,    1,   45,  166,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2047,  361,    1,   98,  166, 1708, 2290,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,   12,  119,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,   84, 2029, 2150, 1211, 1975,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1796,  845,  275,    1,    1,  242,  244,  202,  157,  410,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2569,  195,    1,    1,   37,  163,    1,   12,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1158, 1822, 2234,  357,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1172,   12, 1173,  115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  801,   37, 3295,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  202,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3051, 2224, 1874, 1428, 3146,   98, 3369,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1258, 2365,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2993, 2996, 2995,    1,  327,  593,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2924, 1523, 3006,   32,  531, 1530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  968,  105,  366,  593,    1,    1,  420,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1207,   37,    1, 1529,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158, 2659,   81,  444, 2546,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2170, 1458,  557,  540, 3368,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3157,    1,    1, 1260,   98, 2755,  787,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2820, 2599,   66,   37,   18,  361,  168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 1269,   81, 1315, 1714,  187,    1,  470,   32,  430,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2396, 1082, 1663, 2532,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  968,  926,  134, 1648,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  794,  885,  853,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  386,   51,  125,    1, 1612,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   14,   15,  245,    1,   32,  367, 2337,  442,  910, 1353,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2832,   64,  487, 3372,    1,  202, 2114, 2884, 1281,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2828, 1908, 1114,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,  437,  267, 2414, 1056, 1485, 2161, 3365,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,  506,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2171, 2547, 2370,    1,   45, 3003, 2039,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  640,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2776,    1,  644,   37, 2286,   37,  271,\n",
      "         3356,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783,  686,  191,  104,  358, 2240,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,   37, 2728, 2071, 1331,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3167,  273,    1, 2916,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  786,   39,  548,    1,  786,   39,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3095, 2856, 3374, 2328, 2221,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  365,  454,   37,    1,  888,  591,  331, 2226,  903,  612,\n",
      "          904, 2227,  704, 1117,   12, 1661,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1204, 1604, 1822,   52,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  523,   12,  244,  418,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1786, 2358, 1268, 1099, 1453,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  321,  612,  489,   79, 1427,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1312,   37,   52, 1231,  220, 2834,  297, 1887,   45,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2663,    1, 1247, 2321,    1,  463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2563,  265,    1,  131,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  203,  193,   37,  619,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  121,  140, 1940,   12,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  986,    1,   37,  166,  857,    1, 1009,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,  704,    9,  395,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,  762,   32, 3088, 2646,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2622, 3178,  176,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2734,  304,    1,   37,  619, 1632, 2504, 2221,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2733, 1914,    1,  912,    1,  484,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1089, 1090, 1110, 2365,   39,  280,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3356, 2431, 1683,  187,  531,  952, 1378,  863,   62,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3127,    1,   37, 2192, 1851,    1, 1470,   45, 1926, 1927,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2325,   69,    1, 2108,    1, 1428, 1896,   98, 3369,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  275,  633, 1303,  716, 1735,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1, 1230,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,   45,    1,    1, 2058,   32,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,    1, 1443,   32, 1521, 1151, 2107,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2352,   56,  356, 2836,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  735,  633, 2447,  572,  932,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,   76,   37,    1,   80,  384,  171,  261,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  258,  550, 1013,   37, 1079, 3063,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,  392, 1090, 1667, 1758,  636,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2826,    1,  890,   92,  104,  117,   15,  506,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1168, 1554,    1, 1676,  336,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1087,  190, 1021,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 1890,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 1034,   32, 2171, 2800,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  680,  166, 3180,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3105,   37,  166, 1746,   45,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1283, 1299,  700,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 1009,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  647,  744,    1,  528,  148,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2438, 1114,  600, 1128,  435, 1100,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  754,  434,  490,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1,  566, 2710, 1446,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3198,   37,   52,    1,   45, 3304,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2114,  546, 1212,  787,  947,  475,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,  764, 2264,    1,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  947,  114,    1,  493,  176, 2891, 1313,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  632, 1409, 1156,    9,    1,    9,  395,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  676,  420, 1924, 1514,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  782,  365, 1204,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053, 1458, 2592,   98, 1789,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,    1,   12,  227,  223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  838,  187, 1147,   68,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  693,   59,  159,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2882, 1995,   98, 1330,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  203,  183,   61, 2692,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994, 2995,  884,   98,  829,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1024,  361, 1024,  852,   37,  151, 1026,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422, 1360,  612,  335,  522,  951,    1, 1341,   32,    1,  400,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1900, 1604,   98, 1262,   37, 2446,  585,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2573,    1,  453,    1,  202,  590, 2149,  571,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  912, 2285,  496,  515,  105, 1067,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,  245,  548,   69,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  449, 1482,   37,  151,    1,    1,   50,    9,    1,  372,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3168, 1632,   37, 2069,  548, 2779, 1321,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  221,    4,   37, 1033,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2664,    1,   37, 1251,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1629,  387,  365,    1,   32,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,    1,  855,    1,    1, 1159,  388,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,  69, 155,   1, 122,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   7,   8, 176, 592,   1, 907,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1963,  597, 1009,    1,  395,    1,  116, 1013,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  306,  335,  105, 2026, 2784,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2708,  446,  653,    9,  439,   37,  792, 3344, 1803,  792,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  277,  191,  278,  279,  280,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3253, 2489, 3198,   32, 2936, 1286, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 1759,  309,  741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  381, 1654,  547, 1682,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405, 3291,   61,    1,   28,  166, 1245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1087,  335,  103, 1669,    9,   32, 2076,  420,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3175,  872,  420,  385,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3100, 1360,  612,  606, 1902,  951,    1,  903, 2433,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 2870,   32, 3383,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1591,    1,    1,   37,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,   37,  877,  438, 2509,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  166, 1497, 3276,  798,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409, 1285,  388, 1089,  809,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1562, 3128,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,    1, 1542,   37,    9,  885,    1,  220, 2121,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  214,  142,    9,  487,    1, 1256,  635,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,    1, 1297,    1,   52, 1018,    1, 2968,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   26,  914,   98, 1130,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3237,    1,   37, 1000,   39, 2615, 1722,   45, 1184,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  671, 3126, 2096,  288,   37,  439, 2283,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  951, 1158,    1,    1,  138,   39, 1954,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  388, 1428,  764,  110,    1, 1147,  957,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  297,  754,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1485, 1407, 1190, 2770,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2618,   12,    1, 2783,  449,    1, 2579, 1684,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2701,    1,    1,  191,    1,  602,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  365,   46,   37, 1154, 1938, 3197,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2247,  226,  891,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2107,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  773, 1003,   37,    1,  818,  819,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  753,  388, 2898,  531,  522, 2189,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  320,    1, 1167,   12,  166,  402,   45,  424,  669,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994, 2819, 3050,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  647,  648, 1924, 2051,  763,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2474,    1, 2474,  507,    1,  140,  528,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401, 2494,  872,  608, 2468,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2175,  361,  707,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,  879,  486,  132,  220, 1087,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  244, 1124,  187,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  485,    1,  197,  188,    1,  159,  720,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087, 2614,  512, 2317, 1056, 1675,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2275, 2386,   10,   45,    1,  531,  443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,   19,  220, 2181,  361, 1675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3385,  967, 1574,  600,  864,   12, 2673,  210,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 3375, 1333, 1530,   32, 3339, 2831,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3144,   12,  446, 2644,   37, 2611,  548,    1, 1260,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2333,    1,    1,    1, 1103,  176,    1,    1,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2170,   12,  223, 2664,    1, 1492,   12,  176,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2479,  786, 2847,  631,   32,  667, 3258,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3151,   61,   98, 2088, 2378,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  633,   84,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  314,  551, 1692,   37,    1,    1,    1, 1469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  666, 1564,  805,   98, 3103,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,    1, 1998,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1, 1085,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1631, 1674,    1,  220,    1,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  186,   98,  417,   69,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2136,    1,    1,  612,    1, 2911,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  868,  132,  220, 1652,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  777, 2165,  498,   37,   52,    1,   37,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,    1,  412,   32, 3118, 2056,  383, 1979,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1167,    1, 1173,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1312, 2572,    1, 1941,   32, 2597,  344, 1260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2730, 1523,    1,  297,   26, 1039,    1, 2690, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1353, 2177, 1027,  260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  799, 2321,   85,   98, 1817,    1, 1711, 2816,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  850,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  746,    1,  758,    1, 1636,    1, 1085,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1303,  162,  395,    1,  463, 2170,  802,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1046,  341, 1118,   98,  818,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1,   59, 3049,   45, 2255, 2324, 3004,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2597,   12,  198, 1178, 1141,   37,   77,  247,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,    1, 1159, 1718,    1, 1713,  730, 1777, 2274, 1659,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3333,    1,  105, 1103,    1, 1523,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2620, 1414, 2741,    1, 1364, 1365, 1159,  105,  581,   74,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1442, 1158, 1107, 2630,  205,    9, 1893,    1, 3011,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359, 1877,   37,    1, 3339, 2625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  467,  283,  852,  388,   55, 1018, 1611,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1169,  389,   93,    1, 2127,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  691,   37,    1,    1,    1, 2095,    1, 2060,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2397,  321,   77,  564,  680,  487,  132,    1,  798,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  396,    1,  671,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  927,   45, 1465, 1466,    1,  597,  475,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  503, 1351,    1, 2219,  763,  749,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   37,    1,  651, 3037,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1230,  919, 1158,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1249,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  155,  365, 1788,  171,  604,  731,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2620, 1118,  698,   32,  365, 1788,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3261, 1082, 2592,   37,  619, 1542,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  342,  943,  644, 1859,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  535,   12,    1,  105,  590,   16,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  640,  547, 1844, 2907,    9, 3232,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,   12,  365,  893,  193, 1542,    9,  166,   94,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1186,    1,    1,    1,    1,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1249,  691,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 1001, 1178,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2026,   61,  105, 2537,    9,  810,  116,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1458,   85,   98,  342,  741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1082, 2149,  698,    9, 3118,   23,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2741,   12, 3215,   98,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390,    1,  587,  498,   98,  389,    6, 1746,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3206, 1668,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  853, 2945,   51,   16,  365,  864, 2673,  778,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  863, 1984,   32, 3144,    1,  411,  932,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  831,  187,  679, 1588,  245,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3113,   37,  582,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  773,    1,   98,    1,   12,  677,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  420, 2056,  116,  815, 1660,   32,  163,    1,   12,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2932,  661,    1, 1928, 1027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3173,  166,    1,  140,  176,  163,    1,   12,    1,   26,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,    1, 1429,  458,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3006,  798,    1,    9, 2596, 1585,   32, 2018,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1, 1725,   98,  342, 1437,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  367,  160,  102,   28,    1,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  852,   37, 2002,    1,   32,  365, 1662,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1848,  494, 1335,  514,   37,  636, 1336,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1554, 2009,   26,    9, 1854, 2457,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1485, 2153,    1,  493,  965,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,   37, 2243,    1,    1,  660,    1,    1,  424, 1034,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1537,  947, 2856, 1255,   12, 1354, 2556,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3317, 2328,  300, 3262, 1632,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1932,  295,  572,  197,  641,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  490,   37,  726,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  413,    1, 2155,   28,  220,  224,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  835,  663,   37,    1,  195,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  267,   32,    1, 1167,  204, 1924,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,  546,  453,    1, 3030,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1363,  307,   39,   98,    1,  517,  259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,  275,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  449,   32, 2819,    1, 2111,    1,  193, 1167,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3140,   37,  693, 1147,    1,    1, 2165,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2959,  489, 3226,   79,  404,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,   32,    1,   37,    1, 1135,    9, 2170,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2494,  872,   39,   45,  671, 2107,  548,  354,   37,  208,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2802,   39,    1,    1, 1401,  633,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1601,    1,  191, 2977,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186, 1321,  531, 2375,  396,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  198, 2164,  640, 1850,  455,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325, 1023,   45,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  236,  237,  580,  890,    1,  193,  415,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2300,  674,  446,    1,  166,  233,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  863,  297,    1,  566, 1594,   37,  347,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2036,  518, 1190,    1,    9, 1184,   67,  423,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  795,    1,  359,  759, 1845,  895,   98,  138,  125,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  482, 1947,  179,  180,  170,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1623,   45, 1428, 3365, 2619,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  542, 2562,    1,  825, 2677,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   61,  227,  550,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 3240,    1,  590, 2537,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1960,  388,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2192,    1,    1,  388, 1343,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   12,  552,  376,  503,  734,  731, 1010,  749, 1057,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2820,  105,  227, 2919,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,  388,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947, 2856,  854,   12, 1354, 2556,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,   26, 1039,   32,  854,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,  794,    1,  279, 1067,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3253,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3308, 1990, 2283, 2677,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  437,  108,   45, 1665,   37,  215, 2715,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  686,    1, 1722,   32, 2119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   56, 2095, 2985, 2827,   32, 2235, 1010,    1, 2596,  420,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584, 2484, 1069,   76,   37, 1374,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3308, 1990,    1, 1242, 3186,   37, 1758,    1,    1, 3159,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,   12,   32,  166, 1510,    1,  538,    1, 1847, 1167,    1,\n",
      "          361,  388,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1166,   12, 2310,    1,  265,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  313,   37,  168,    1,  786, 1488,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1486,  361,  453,  709, 1831, 1041,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974,    1, 2977,  719,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1,    1, 1504, 2588,  220, 1658, 1768,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  793,    1,   61,   28,    1,    1,  565,  288, 1211,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3157, 3396, 1937,  753,   32, 1515,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  758,   37,  151,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1188,   37,  125, 1645,  646,   93,  570,  297,   69,  636,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  515, 1094,  449, 2085,  671, 3126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  862,    1,  288,    9,  818,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  120,   98,  550,  600,   69,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1458,    1,   12, 1940,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2971,  586, 1558,    9,    1,    1,   29,   32,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  431,  949,   45,  784, 1778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  199,   39,   37,    1,    1, 1330,  176, 2615,  730,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2910,   77, 3161,  590,    1,   32,  166, 3278,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  183, 2195,    9,  503,    1,  195,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    5,  625, 1064,  190,  805,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3379,  947,  123,   37,    1, 2147, 3403,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  256,    1, 2969,    1,  105,    1,  182,    1,  517,  613,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2006,  583,   32, 3343, 1633, 1585, 3133,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503,  162,  105,    1,    9,  920,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  232,   37, 1910,   65,    9, 2171,  317,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  985, 1260,    1,  229,    1, 1902, 2162,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3250,    1,  972,   37, 1642,  257,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2227,    1,  612,    1, 1417,    1, 1536,  449,   43,  444, 2650,\n",
      "          122,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  366,  996,    1, 1279,  948,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1718,  528,  342,  736,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2800,  311,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  613,  170,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1359,   37,  698, 1107, 2610, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2463,   12,    1,    1,  384, 2347, 1638,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3380,  267,  163,    1,   12,    1, 1822, 2653, 2708, 2096,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1149, 1539,  304,  868,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  867, 1396, 1331,    1,    1,    1, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325, 1056,  217,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2246,  460,   12,    1,  199,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  325, 1117, 1525,    1,   37, 1523,  224,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  424, 1034,   32, 1128,  550,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043,   28,    1,  419,    1,  356,  439,  186,  343,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1530,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2067, 1245,  384,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  981,    1, 2798, 2492,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  197,  490,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2406, 2040,   45,    1,    8,  220, 2531, 1632, 1903,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2867,  331, 1907,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,    1,  529,    1,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1,  172,   17,   98,  236,  237,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  485, 1458, 3304, 1159,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  696,  973,   28,    1,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   75,  475, 1702,  844, 1704,  845,  846,  116,  847,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,    1, 1011,   37, 3118, 1223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1249,    1,   37,  759,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12, 1429,   32, 1165,  953,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1830,   37,    1,   32,  166,    1,  176,  311, 2936,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2297,  187, 1430,   12, 2038,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1509,  151,  353,  737,  197, 1124,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2991, 1774,  365,    1,    1, 2549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1,   85,  730, 1777,  220, 2366,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,   37,  151,   48,   32, 1081,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  236,  237,   66,  526,    1,  752,   37,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,  231,  365, 1938, 2607,  382,  190,  489,  334,   32,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  342, 1937, 1378, 1104, 1350,  695,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  493,  102,  720,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3113,   12,    1,  531,  193, 1542,    9,  740,    1,  863,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275, 1804,    1,   32, 2138,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2384, 2823, 2362,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2775,  357,  193,    1, 3322, 1140,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1284,   98,  166,  389,    1, 2172,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 1562,  792, 1427, 2461,  792,   32,    1, 2834,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  126,    1,    1,   12,  127,   61,    1,  128,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,   96,  501,  827,  978,  187, 2807,    1, 3227,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  698,    1,    1,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1610,  333,  300,  159,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   69, 1315,    1,  997,   45,  163,    1,   12,    1,  984, 2368,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  162,  105,   92,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2080, 2341,    1, 1074,  108,   45,   29, 2124,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,    1,  500,  686,  220,  768,  149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  403, 1447,  267,  104,  992,   28,    1,  541,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   89,  590, 1188,   37,  125,  443, 1278,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2803, 2380,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   28,    1,   29,   30,   31,   32,   33,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  307, 1918,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,   98,    1,   37,   71,   37, 1787,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 2128,   92,    9, 3343,  741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,    1,  387,    1,  176,  105,  227,  199,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  393, 1478,  331,   32,  394,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  111,  162,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  116, 1110,  912,  767,    1,  176,    1, 2819,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   37, 1343,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1185, 2887, 2850,   85, 1545,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885,  613,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3282, 3204, 1774, 1159,  601, 1385,  176,  104,   26,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1742,   12,  504, 1240,   52,    1,   12,  354,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,   28,  118,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485, 3365,  949,  515,  753,   37, 3025, 1841,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,   22,   23,   12,  861,   37,    1,   98,  829,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1283,  365,   26, 1039, 2234,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1303, 1086,    1,    1, 2657,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   12, 1429,   50, 1008, 1213,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2673,   46, 2312,    1,  864,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1072, 2603,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2137,  176, 2835,    1, 2856,  176,  177,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1, 2547,  726,  129,  872, 2948, 2015,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,   28,  387, 1194, 1843,   32,  260,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  930,  548,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,   37,   92, 1942,   45, 2879, 2527, 2946,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162, 1597, 1799,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 235, 661,  98,  25,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 235, 661,  98,  25,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2099,   37,  576,    1,    1,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  267,    1,    1, 3103,    1, 1753,   10,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2615, 1285,  730, 2614,   37,  335,    1,   45, 2522,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3185,    1, 2849,  297, 2826, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   32,   16,   45,    1,    1, 1250,  365,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  754,   15,  245,   32,  871,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1853, 1557, 1484,    9, 1602,  477,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,   45,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  479,    1,    1,  132,  220, 1170,  853,  538,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,  136,  475, 2430,  669, 1426,  895,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  361, 1057,    1,    9,  365,  651, 1259,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  400,  105,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  837,  124, 1281, 1925, 1583,  862,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3102,   32,  227,  223,    1, 1928,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  149,  444,  735, 1091,  614,   37,  776,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  694,    1,  661, 1973,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2144, 2572,   32,  649,  845,   36,    1, 1260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  361, 1167,   12,  105, 2962,    9,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3151,   37,  360, 2308,  645,  693,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  171,    1,   51,  693,  116, 1704, 1021,  847,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3096,    1, 2331,   45, 1472,    1,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3271,  877,  221,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,  365,  845,  187, 2046,  477,  640,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428,  437,  782,    1, 1634,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,    1,  544,  193,  946,   37, 2095,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1173,   37, 1910,    1,   39,   32,  166,  984,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  186,  300,   25,  995,  417,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1116, 1278,   66,    1,    1,  372,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1574,    9, 2171, 2800,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   62,  187,    1,    1, 1946,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   98,  166, 1844,  994,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1090, 1829, 2213,  171,  176, 1959,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,   77,    1,   98,  105,   12,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1830,   37, 2728,  365,  301, 2492, 2232,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3183, 2331,  707, 1159, 1497,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777, 2355,  765, 1083,  861,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3168, 2257,   39,   45,    1, 1787,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2528,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,    1,    1,  686,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2452, 2085, 1564, 2197,  714,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1631, 3265,   32, 1300,  245,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2890, 1675,    1,  754, 1211,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  963, 2102, 1107,  525,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  308,  125,   98,    1,    1,  533,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,  515,  613,   92,   37,  649,    1, 1116,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  159,  245,   98,  594,  156,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2925,    1,    1,  907,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  198,    1,  576,   68,   69,  102,  417,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2939, 1240, 1306,  519, 1411, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2801,  361,  982,  943,  618,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  288,   37,   26, 1298, 1382,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,  512,  176, 1099,   37,    1, 2322,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,   37,  720,  647,  149, 1232,    1, 1464,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115,  138,    9,    1,   37, 2446, 1844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1902, 2753,   32, 3300,  726,  297,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1076, 1380,    1, 1046,   98,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1238,   69,    1,    1, 2833,   98,    1,  341,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,   81,  176, 1652,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2007,   37, 1515,    1,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1685, 1428,    1,    1,  104, 1042, 1140,    9,   69, 3368,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1524, 1090,  270,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  719,  228,    1,    9, 2872,   45, 1463, 3192, 1443,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  614,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492,    1, 1333, 1530,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  777, 1085,    1, 2123,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1, 1315,   37, 1034,  340,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  678,    1,    1,    1,  872,   98,  622,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2143,   37, 1505, 1651, 1597,   32,  395,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  578,  388,  596, 1793,    1,    1,  341, 1428,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3403, 2414,  176,  177,   32, 2018,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2696,  859,   37, 1281, 2970, 1089, 1675,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,   12,    1,  218,  884,  105,  686,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  215, 2132,    1,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  936,  645, 1273, 1151,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2699,  729,  193,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1082, 1527,    9, 2734,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2934,    9,  105, 2268,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  251,  340, 1251, 3044,    1,    1,    1,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3110, 3194, 3195,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2753,    1,   37, 1021,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  729,    1,  105,    1,    9,  166, 2826,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,    1,    1,    1,  839,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2018,  140,  104,    1,  297, 3343,  741,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  218,  183, 1463,    9, 1212,   12,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  421,   12,  157,  166,  869,    1,   98,    1,   12,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  585,   51,  606, 2963, 2977,   12,  865,   37,   95, 2462,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  199,  920,    9,    1, 1545,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178, 2827,  297,  395,   36, 2705,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1292,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  884,   85, 2851,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 2565,  361,  105, 1863, 2394,  334,  321,  168,  754, 1114,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1629,  267,  314,  167, 1046, 1780, 1533,  242,  763,  331,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1762,    1,   98,  166,  260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  896,    1,  513,  514,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3115,  664,    1,    9,  166,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  794, 2692,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  159, 1150,   98,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1306,    1,    1,  460,   12,    1, 2226, 1188,   37, 1173,\n",
      "          176,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3225, 2709,   98,    1,    9,  512,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  267, 1099, 2768,  193,  907, 2089, 2461,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  593, 1212, 1557,  967,  411,  631,   32,  171, 2208,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790, 1579,  365,    1, 1294,   37,  764,    1, 2847,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,  155,  647,  142,  191,   37,    1,  131,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  221,   37,    1, 1430, 1009,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,  794,  365, 1117, 1525, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  460, 1360,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1789,  520,  365, 1563,   37,    1,  384,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162,   45, 1007,    1,  105,    1,    1,    1,    1,    1,  736,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  524,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1298,    1,  994,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2597, 3389, 2856, 1763,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,   25, 1150,  187,  657,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  352,   50,  162,  105, 1894,  231,  384, 1474,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2038,  986,  331,    9, 2527,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  796,  548,  312,  287,  676,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1592,  506,    1, 2126,   32, 3013,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  615,  565, 1044, 1737,  187,  286,    1, 1636,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  342, 1523,  297, 1350, 1250,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  942,    6, 1113,    1,  191,    1,    1,  452,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  682,   98,   94, 1452,  187,  104,  954,  953,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,  908,  148,   12,  142,    9,  647,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1887, 2060,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  848,  794, 1234,    1,   37,    1, 1230,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1, 1007,    1,  105,    1, 1535,  794,  581,  647,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  567,  300,   69,  102,  242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2982, 1000,  388,  459,   45,    1,  238,   98, 1965,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,  134, 3160,   32,  356, 1691,   12, 2162,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51, 1046,    1, 2559,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1021,  847,  565,    1,  105,    1, 2082,   32,  584,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,   34, 2823,    1,   32,  863,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1645,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613, 3007,    1,    1,  612, 2419,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2, 848, 105,   1, 173,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 524, 884,   1,  79,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2004,  433,  884,   98, 2086,    1, 1089,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  519,  582, 2565,    1, 2908,    9,    1,  600,  472,   81,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2407,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3200, 1664,  459, 1700,  356,  881,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  492, 2292, 1086,  220,  166, 2263,   45, 1056,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1778, 2232,  704,  614,   37,    1, 1626,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2800,  424,   61,    9,  334,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  281,    1, 1099,   51,  619, 2015, 1371,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 422, 134, 938, 220, 133,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 409,  25,  26, 417,  32, 411, 605,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  517,  518, 1726,  907,   32,  316,  395,  213,   37, 1604,   98,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2995,  884, 1003,  176,    1,  282,  218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2999, 1994, 2819, 1260,  388, 2529,  763,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  119, 2098,  730, 2614, 2935,  593, 2522,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1414,  275,  389,    1,   37, 1119, 1560,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,    1,  187, 3365,  820,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3370,  108,   45,  388, 1450,  187, 3376, 1950,  418,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,   74, 2677, 1090,  199,  446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3230,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159,   28,   98, 1610,  333,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,  921,    1,    1,    1,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3296,    1,    1,    1,  967,    1, 1857,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3056, 1103, 1960,  105, 1463,   95,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1421,  132,   37, 2123,  350,  218,  844,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2105,   37, 1787,  526,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2797,    9, 3012,  298,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,    1, 1861,  187, 2789, 1929, 2055,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1685, 1405, 2251,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  539,  744, 1757,    9,  864,   37, 1806, 3107, 3366,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  167, 1158, 1641,  453, 1230,  631,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1043,  640,  786,  339,  181,  340,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,   42, 2255,  149,  220, 2254, 3004,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  567,    1,   69,  509,   97,   25,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3352,  335,  547, 3102,  176,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 1542,   37,  690, 2466,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2650, 1879,  726,  433,  432,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612,    1, 1167,  754,  259,    9,   80, 1108,  415, 1724,\n",
      "            1, 1592,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 1428,  952,   37,  846,    1,   45, 3406,   32, 3349,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3104, 2582, 2339,    1,  274,  176, 3127,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  850,  166,    1,   98,  375,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   25,  245,   98,   31,  997,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  528,  997,   45, 1450,  176,  806,    1,    1, 3157, 1542,   37,\n",
      "          741,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2959, 1285, 2920,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  777,   37,  844, 1089, 1108,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  880,    1,    1,    1,   32,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1, 1353,   37,    1, 2131, 1501,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  242,  615,  240,   65,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403,  464, 2404,  267, 2960, 1924,    1, 1585,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1390,  431,  388,  474,  802,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2135, 1337, 1604,   32,  531,  548,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  417,   98,   69,  361,  197,  937,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885,   98,  103,   45,    1, 1114,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   22,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   39,    9, 3250,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2097,   45,    1, 3338,   79, 2883,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2136, 2137,   10,   98,  531,    1,  166,  954,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3215, 2753, 1114,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363, 2598,  403,   98, 2333, 2784, 2747, 3360,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3232,    1,  361,    1, 1515,  454, 1159,  166, 2522,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159, 1374,  548,  304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2499,  716, 1994, 3348,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,    1,  157,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2557,  894,  804,  484,   98, 1076,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,   93,   32,  167,   52, 1315,    1,  592,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2149,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   58,  197,  407,    1,  157,   61,  969,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2823, 2855,  686,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523,  140,    1,    1,  707, 2017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3356, 1414,   37, 1594,   32, 2375,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  369,  353,  198,  932,  115,   45,  104,  221,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1447, 1564, 1479,    1,   32,  414, 1017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,   72,  401,  197,  526,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1292,    1, 1139,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447, 1458, 1855,  342,   46,    9,  857,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1764,  162,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12, 2881,  108, 1033,   45, 1718, 2039,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  957, 2776,    1, 2686,    1, 1017,   37, 1171, 2417,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   42,  573,  396,    1,  440,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  241, 2292, 2897,   32, 3349,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 2884,    9,  104,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  654,   37, 2192, 2017,  453,  124,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1658, 1039, 2690,    1,    9,  333,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056,    1, 3340,   32,  531,    1,  629, 3026,  844,  420,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98, 1107, 2633,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3096,  166,  914,   37,    1, 2954,  361,    1, 3009,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2583,    1,  220, 2741,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1116,  399,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1937, 1632,    1,    1,  162,    1,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  321,  612, 1154, 3211,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,  166, 1090,    1, 1608,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1658,    1,    1, 1228, 2432,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   51,  606,   37,  211, 2875, 2640, 1539,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3214, 1631,    1,   12,  914,  640,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2236, 2493,  204,  967, 1280,   37,    1,  810,  386,  719,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2163, 2405,    9,  526,  698,   69,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   32,   46,   37,   47,  280,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2665, 1994,  966, 2567,  437,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885, 1260, 3060, 1061,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,  697,   37, 1066,   49,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  242,   15, 1198,    1,    1,  159,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  590, 1400,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2751, 1114,  774, 3147, 2924, 1237, 3114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  874,  275,   37,  211,  932,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1291,    1, 1229,   37,  817,  840,   50,   32,  507,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  249, 1289, 2025,    1,   37,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   61, 1530,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1433,  321,  612, 1766, 1767,   52,  388,   55, 1292,    1,    1,\n",
      "         2973, 1764,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  606, 1018, 1285,  297,  116, 2542,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 1419,  861, 2976,    9, 1778,    1,    1,    1,  361, 2997,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  884,   98, 1230,  220, 1234,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2162, 1950,  418,   37,   32,  455,   12, 3121,  477,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  213,   37,  151,    1,  700,    1,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3230,   32,   46,  297,  365, 2565,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1,    1,  166,  104, 1114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3191, 2013,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,  794,  365, 1412, 1107, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  455, 2262,  119,    1,    1,  297,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2887, 1523, 2897,   32, 3339, 2831,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1000,  579, 1444, 1445,  603,    9, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3264,   21, 1918,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,   12, 1407,  442,    1,  176,    1,  372,  104,    1,   32,\n",
      "          166, 1022,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  884,  453,    1, 2973, 1764,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2087, 2614,  498,   37, 1056,  356,  132,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  837,  829, 2987, 2762,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  615,    1,    1,  193,    1,  191,  395,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2570,  787, 3266,  872,  420,  385,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,    1, 3260, 2884,    9, 1515,  449,  140,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2805,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1741,    1,  233,  650,    1, 1123,  469,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1065, 1190,  936,  957,   61,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1676, 2422, 1046, 2281,  134,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,   12,  365, 1009,  200, 2399,  361,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  192,  460,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,    1,  854,   37, 1413,  637,   32,  460,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  232,  397,  893,  894,  759,  895,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  569,  191,    1,  187, 3315, 1249,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1013,    9, 1204,   98, 1965,  220,  166,    1, 2550,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2407, 2162,   45,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   26, 3169,  640,  103, 2287,    1, 3168, 1177,   98,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284,  249,    1,   37, 1334, 2088,   32,  105,    1,  593,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  156, 2393,  291,  983,  418, 1010,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1436, 2908,    9,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2206,    1,  902,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425,   37,  130, 1883,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  550, 1121, 1782, 2039,  297, 1107, 3049,    1,  147,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,  193, 1724,   28,   37,  846,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,  566,  777,    1,  187,   93, 1522,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1721,    1,  487, 1109,   12,    1,   45,    1, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1091,    1,  773, 2360,    1,    1,  289,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  458,  475,   37,   84,   85,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1558,   95,    1,  782, 2780,  321,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1271,  115,   45,    1, 1347,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  547, 1443,   37,  949,    1,   41, 1167,  837,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  182, 1463, 2493, 1894,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,  361,    1, 2943,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 2161,   12, 2472,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2526,  187, 2957,    1, 2565,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  475, 1454,  829, 1197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1486,    5, 1084,  132,    1,   37,    4,   32,  447,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,    1, 1260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   39,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3405,  132,  113,   39,  365,  753,    9,  557,  540,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  341,    1,  142,   37, 1746,    1,  963,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  868,  132,  220,  461,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  189, 1118, 2092,  932, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3005,    1,   37,   52, 1104,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2802,  884, 2080,  517, 2630,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 3102, 2399,    1,   63, 2162,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2999,  251,  210,   37, 1260,  923,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,  245,   98,  420,  395,    6,   81,   98,  104,  734,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2476,  610,   32, 3343,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1147,    1, 2644, 3102,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2742,    1,    1,    1,  787,  957, 1584, 3251,   85,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  868,  386,  295,  869,  870,  384,  119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  548,  247, 1292, 1594,    1,    1,    1, 1267, 1827,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  420, 1861,   51, 1140,  863,    1,  763,   76,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3359,  267,  864,    1,  810,   37,  619, 2673, 2375,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2954,  603,    9, 1018, 1285,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1341, 1867, 1894,    9,  229,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,   37,  151,  180,   32,  131,  132,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   10, 2275,   12,  451, 2579,  388,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,  244,  304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  880,  190, 2564,  846,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1281,   98,  116,  412,  962,  697,    9,  432,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,  10, 459, 182,   5, 591, 302,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 954, 321,   1, 845,  69,  65,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3153,    1,   12,  105,    1,    9,    1,  600, 1123,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2292,    1,   32,  557,  540,  115,   45, 2823, 2237,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  182,  704,   12,  629, 1924, 1960,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  624, 1713,  142,   37, 1539,  853, 2699,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,  775, 1427,    1, 1935,    1,    9,  282,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1766, 1767,    1,   51,  631,   37, 1507,  725,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,  91, 184, 449,  74,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 759,  39, 361,   1,   1,   1,   1,  37, 166, 730,  78,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1435, 1087, 1310,    1,   37, 1250, 2261,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  715,  112, 1161, 1276,   32,  367,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  225,  298,    1, 1372,  892,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,  987, 1159, 2992,  700,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1127, 1426,  365,  858,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1834, 2776,  601,  401,    1,   37,  720, 3326,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1075,   39, 1938, 2607,  382,   81,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  872, 1118, 1539,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3363, 1918,  959,    1,    1, 1557, 1489,  290,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,   85,    1,    1,   28,   32,   86,    1,  163,    1,   12,\n",
      "            1,   15,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,    1,  176,    1, 3129,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2676,    4, 1509, 2389,    9,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1126, 1470,  547,  257, 2248,    1,  729,    1,  224,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2801,  315,  529,  617,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1235,  102,   28,    1,  419,    1,  626, 1042,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2733,  251,    1, 1211,  116,  259, 1484,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2414,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  794,  365, 2262,   98, 3391,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  233, 2104,  246,   32,   98,  613,    1, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,  223,  198,    1,    1,  528,  737,  720,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 1462, 1627,   74, 1056,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    7,    1,   32, 3360,   32,    1,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  451,  232,   98, 2930,   44,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2164,    1, 1850,  455,    1,    1,   32,  409,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  220,    1, 1228,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3056, 1554,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  729,  105, 1533,    1,  384, 2476,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1104, 1278,  288,   37,   71,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  542, 1472,    1,  661,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  393, 1426,  132,  220,  359,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  136, 1441,   26, 1039,    1,    9, 1718,  361, 1778,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2006, 2527, 2946,    1,   85,  995,    1,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1105,  787,   93,  307,  308,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1, 1363, 1413, 1414,   37,    1, 1273,  259, 1228,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1110,    1,  421,  187,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1310,   37,    1,  310,  957, 2017,  384, 1718,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  460,   12, 1100, 2747,    1,  111,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,   79, 1628,  806,   98,  531,  157,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,   37,    1,  220,  854,   32,  460,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 2741,  726,    1,    1,    1,   37, 2498, 1917,  854,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,    1,  691,    1,  697,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2528,  341,   29,   37, 1658, 2355,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1149,  619,    1,  953,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790,    1, 1070,    1,   37,  489,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  346,   29,   37,   16,   31,    1,    1,  715,   93,  157,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2272,   85,   98, 2975, 1064,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  370,  716,  417, 1022, 1023,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1271,  528, 1633,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2897,   32,  581, 1023,    1,    1,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  517,  518,  519,    1,   69,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,   37,    1, 3233,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151,  315,   37,  360,  166, 2308,  645, 2362,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  105, 1146, 1703, 2389,   37,  166, 3151, 1756,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  166,  923,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2957,    1,  766,  798, 1102, 2666,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  990, 1236, 1791, 2650,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   56, 2572,   32, 2597,   12,  501, 2060,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  644,  529, 1149,  477,  176, 2235,   12,    1, 1325,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  388,  972,   37,   84, 1483,  920,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2873,   61,    1, 1098,   45,  166,   23,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  633, 1373,   37,  138,   54,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  300, 1746,  872,   37,  531, 1010,    1,  297, 3102,  396,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1631,   39,   45,  701,   37,  764,  931,  726,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 3314,  726,  593, 1218, 1990,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  284,  137,  905,  749,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118, 2024,   46, 1961,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  405,   12, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175, 1421, 1695,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1585,  193, 2398,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,   51,  771,    1,   45, 1273,  618,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1674, 2962,    1,  140,  166,  331, 1010,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  320,  320,  714,    9,  829,   12, 2603, 1108,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  476, 2966,   98, 2412,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2673,    1,  865,   37, 2470,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2266, 1648,   37,  489,  163,    1,  903,    1, 1346,  384,  531,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3134,  210,    1,  191, 3172,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1090, 1372,    9, 2975,  424,  356,  161,   82,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  787, 2644,   79,    1,   12, 1075, 1638,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  219, 2579,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2104,   77,    1,    1,   79, 2879, 1638,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,  902,   98, 1973,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9, 1476,  977,    1,  449,  166,    1,    1,  920, 1494,  166,\n",
      "            1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1465, 1466,   37,  125,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  200, 2528, 1230,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1, 2919, 2234,   37,   26, 1039,  437,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3147, 1877,   37, 1260, 2751,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1573,  460, 2474,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  246, 1393,    1,  261,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  460, 1149,    1,  600,  389,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340,  913,   32, 2218,   61,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  968,    1,  927,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,   37, 1260, 2846,  220, 1178,  477,   23,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,  132,    9, 2274,   12,  517, 1089,  776,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   51,  606,  915,    1,   32,  667,  863,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1178,  162,  611, 2113,    9, 2587,  207,  912, 2285, 1228,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,   73, 2540,    1,    1,    1, 2070,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,   37, 1911,    1,    1,  176,    4,   29,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 3165,  588,    1,  176,  455,   36,   32,  395,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  224, 1355,  306,  220,  825, 1013,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510, 2682, 1549,  540, 1530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  547, 1147,  129,    1, 2572,   32,  365, 1450,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2313,  449,   32, 2490,   37, 2844,   45,    1,  164,  452, 2130,\n",
      "         1445,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,   69,  980,   32,  317,  104,  863,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 1133,    1,    1,  863,  856,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  680,  114,  314,    6,    1,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1370,   45, 2895, 1167,    1,  997, 1976,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  780, 1749,  220,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,  794, 1056,  784,  769,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  967,  590,    1,   37,    1,    1, 2673,   46, 2191,  548,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  793,   37, 1083, 2101,   45,  541,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2548, 1941,   32, 2708,  344, 2950,   32,  539,  458,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  685,  388,  763,    1,   45, 1714,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  433,    1,    1,  193, 1762,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  390,  470,   98,  531,  965, 1260,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1128,  884, 1003,  176, 3044, 2232,  218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3202,    1,  361, 1957, 2684,   32, 1742,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3219,    1, 1144,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2902, 1484,   98,    1,    9,   80,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  420, 3132,  130,  183,   50,   32,  547,  872,  442,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  227, 1678, 2083,  166, 1551,    1,    1,  361,    1,  907,    9,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3056,   61,  168,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1454, 2279,  444, 1574,   98,  247,    1,   37,  223, 2135,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,  640,  339,  340,  951, 1547,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1707, 1622, 1624,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1713, 3262,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  575,    1,  600, 1338,   45,  495,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1938, 1723,  839,  105,    1, 2226,    1,  517,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 1386, 1988,   45,    1,  104,  776,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1359,    1,   82,  992,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2528,   45, 1729,    1,   32, 1691,  409,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  121,   12,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  429,   28, 2882, 1918,  973,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3114,  267,  453, 2924,  565, 1345, 3086, 1414,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965,    1,    1,    1,    1, 1534,   45,    1,  238,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  255, 1003, 1924,   37,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   63,  166,  862,  657,  159,  245,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3021, 1464, 3185, 1463,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,   12, 2695,  105,   37, 2564,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  231, 1292, 1681, 1090,  515, 1523, 2579,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,  726,    1, 2777, 1624,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1720,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,    1, 3380, 1296,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1432, 3207,   12,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  948,   37, 1377,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2094,  105,    1,   37,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1763,  619,    1,    1,  384, 3177,  791,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3058,  476,   37,    1, 3342,   32,   12,    1, 2170,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984,  546, 1522,   37, 1083, 2818,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,   32,  299, 1807,  105,  673,  856,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  422,  972,   37, 1079, 1093,  977,    9,  388,   29,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  176, 1114,    1,  430,  509,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2140,    1,  591,   37,    1,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1206,    1,    1, 1458, 1117, 1525,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   32, 2050,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,   37,  647,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 2192,  973, 1117, 1525,    1,    9,  340, 1251,  618,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,    1,   32, 3117,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,  222, 2492,    9, 1211,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3059,    1,    1, 3265,   32, 2760,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  457, 1527, 1900,    1,  365,    1,    9,  412,   37,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,  835, 1151,    1,  384, 1087,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  539,    1, 1343,   85,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2018,  251,    1,   37, 2095, 2985,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,  482, 1046,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  504,  187,   69,  102,  470,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   37, 1198,    1,   98,  104,  532,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2395,    1, 1277,  431,  439,   45, 1183, 2179, 2318,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,    1,  958, 1992,  384,  885, 2789,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2708, 2572,   98,    1, 1856,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550, 1465,  298, 1634,   37,    1, 1245,    1,  122,  600,  620,\n",
      "         2208,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 105,   1,  12,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 963, 217, 837, 104, 187,   1,  37, 270,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1883,  325,    1, 1228,   32,  331,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1013, 1491, 2351,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3150,   45, 3363,   12,  472,    1,   61,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   66,   98, 2662,   12, 2820,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1065, 1190,  939,   32, 1430,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1176,  123,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1537,    1,  712, 1056, 3252, 2056,    1,    9, 1853, 2579,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1398,  612,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,  590,    1, 1739,  297, 2922,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1204,  166, 2955,   45, 1018, 1019,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614, 1370, 1262,  220,    1,  872,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1,  140,  176, 1298,  922,  593, 2522,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1521,   45, 1808,    1,   98,    1,    1,    1,   53,   37,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37, 2341, 2997,    9, 2580, 1851,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   27,  526,  187,   69,  636,  640,  119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  348, 1542,   37,   47,  854,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2850,   85, 3151, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614, 2035,  914,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2732,    1,    9,  567,  510,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  398, 1800,    1,  400,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   58, 2145,   37,    1,  163,    1,   12,    1,   59,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,    1, 2072, 1694,   45,  593,   98,  460,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3381,  396,    1, 2891,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390,  459,  630,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,  948, 1969,  303,    1,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282, 3329, 2110, 2090,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361, 1051,    1,   98,  853,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3152, 2967,    1,   98, 2347, 1638,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    9,    1,  210,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1570,  884,  166,    1,   79, 2473, 2367,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  484,  191,    1,   98, 1604,  261,  686,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,   69,  408,  686,  388,  295,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3059,    1,    1,    1,   81,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1512, 1120, 2167,  281,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  616, 1413, 1918,  186,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3025, 3026,    1,   98,  116,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3140, 1542,   37,    1, 2024,   46,  220, 1094,    1, 3397,  267,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1140,   45,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1790,  566, 1718, 2355, 1560,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3228, 2199, 2631, 1045,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3058, 2282,    1,    1, 2667, 3273, 1009,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  716,   45,  365,  116, 2542, 2454,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2510, 1530,    1, 1816,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  315,    1, 1219,  220,  163,    1,   12,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  856,  297, 2275,   12,  443,  119,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3176,    1,    1,  631,   37, 1312,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  111,    1,  967, 2176,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676,    1, 1464, 1463,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2163,    1,    1, 1870, 1268,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  951,    1, 1591,    1,    1,  191,  236,  237,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  667,    1,    1,  856,   37, 1154,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3263, 2446, 3152,   32, 1600,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2949,    1, 1750,  230,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3108,    1,   79,    1,  951,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2231,   12,    1,   98, 2811,  134,   37,   18,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1429,    1, 1998, 2153,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1520,  245,   32,  560,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3152,   38, 3013,  449,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,   22,  587,    1,   37,  469,    9,    6,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,  379, 1937,  388,   67, 1500,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1773,   37, 1403, 1107,    1, 1089,   37, 2510, 1090, 2402,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1360,  612,    1, 1437,   65,  379,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3176,  721, 1822,  877,  484,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  650, 1707, 1861,  581, 2842,  798,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,   12,    1,  920,  593,   12, 1254, 1465,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671,  338,  384,  339,  845,  548,  104, 1290,  396,  276,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2800, 1366,  415,    1,  612,  774,  590,   37,  331,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2159,  572,   15,    1,  174, 2328,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  531,   98, 1171,    9, 2020, 1002,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2142,  862,    1, 1936,    1,  424,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2333, 1428, 1953,   98, 3369,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,  980,  259, 1074,    1,  261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,  859,   37,    1,   98,  856,  444, 2834,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  438,   32,  103,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3322,   81, 2017,  384, 1367,    1,    9,  920,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1990, 2469, 2518,    1,   37,   52,  627,  104, 3164,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  111, 1107,  176,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  288,    9,  417,   26,    1,  156,  817,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1702,   26, 1039,   29,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545,    1, 2741,   12, 2127,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  991,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374,  267,   37, 1860, 2708, 2823,  741,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 2750,   45,  192, 1085,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2505,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3183,   38, 3326, 1194,  354,   32, 1559,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2950,  640,  104,    1,   32, 2597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1753,   37,  222, 1649,  625,   32,  878,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,  954,   51, 1192,  191,  528,  845,   69,  102,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  220,  758,  124,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3124,  744,  411, 1224,  220,   72, 1385,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2885, 1293,   98, 1171,    9, 1524,  726,   32, 1700, 2055,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  262,  263,  197, 1042,    1,  225,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1186,  267,  861, 1906,  894,   52,    1,   37,  497,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  681,    1,   28,  112,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2958,  631,   37, 2743,  245,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,  361, 2648, 2801, 1776,  630,    9, 2226, 2969,   32,  166,\n",
      "          215,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 2085,  502,    1,  928,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192, 2741,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,   12,  964, 1454, 2179, 1511,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  315, 1821, 1681,    1,  593,   12, 1821,    1,  162,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  691,  520,  711,    1,  333,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,  549,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   32, 2140,    1,  105,    1,  142,   37, 1027,   39, 2095,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  324,  983,  897,    1,  202, 2298,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1394, 2107,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3399,   81, 2266,  548, 1596, 1484,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2275,  489, 2924,  384,  531,   32,  537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  140,  147, 1918,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087,  343, 2098,   28, 1215, 2021,  199,    1,  721,    1,  444,\n",
      "          460,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,  700,   37,  130,  993,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  179, 1458, 1158,  275,    9, 1089,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  255, 2332, 1044, 1737,   32,    1,    1, 2948,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2693, 1396,  282, 2367, 2695, 2264,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  361,  920,    9,  166, 2039,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  479,    1,    1, 1046, 1280,  522,  149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2144, 3111, 2572,   32, 1345,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,   28,    1,   94,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  806,  402,   37, 1481, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  204,   61,  166, 2534,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1, 1307,    1, 2894, 1027,   37,  517,  627,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2391,   61,  166, 2010,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1033,    1,   37, 1289,   37,    1,  845,  951, 2882,   98,\n",
      "           67,  910,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2642,    1,    1,  384, 1499,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1403,  116,   37, 1537,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  982,   37, 1835,    1, 1732,    9, 2801,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203, 1444,    1,    1, 2954, 1066, 1675,  424,  356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3303, 2257,  115,   32, 1423,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189, 1118, 2092,    1, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   64,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  581,  916,    1,  361,  166,    1,   45, 1741, 1741,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  565, 1366,    1,  357, 1211, 2878,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967,    1,    1,  688, 2070,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,  499, 1173,  176,  163,    1,   12,    1,  531,  622, 2705,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2279,    1,    1,  759,  131,    1,  132,  683, 1177,   39,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  727,  590, 1954,  469,    9,  179,  142,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1, 1594,    1, 1443, 1159,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  487,    1,   45,    1, 2130,  590, 1400,    1,  337,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   22,  847,  387,  354,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2224,  908, 1197,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3200, 1594,   37,  356, 1691,    9,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1739,  275,  730, 2672,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,   46,   37,  151,    1,    9,   54,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1585,  176,  632, 2003, 2414,   32,  293,   12,  645,  139,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  986,  104,  331,    9,  491,    1,  493,    1,   32, 1549,\n",
      "           45,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  301,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2056,    1,    1, 3005,   28,   32,   91,    1, 2861,   37,  104,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  208,   12, 2161,    1, 1159, 2701, 1286, 3179,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  212,  697,   37,  142,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1955,  326,  860, 1819,    1, 1294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,   37,  168,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158,    1,  218,    1,  193,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447, 1550, 3203,    1,    1,   61, 1044, 1021,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1221,   12,  590, 2089,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 3198,  759, 2936, 2069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051,    1, 1451,    1, 1046,  365,  861,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548, 2095,  361, 2874,    1, 3157,  741,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2888,    1,  457,   29,  176,    1, 1465, 2827,  466, 1536,   98,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2570,    1,    1, 1022,    1,    1,   12,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  513,  193,  514,   37,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  597, 1405,  710,  513,  514,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388, 1451,    1,   29, 2713,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2594,  765,   32, 1030,  176,    1, 1898, 3154,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  983,    1,  197, 1253,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,    1, 1900,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3276,  354,   61, 3194, 3195,   12,  504,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  387,   72,  401,  244,   71,  419,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  666,    1, 1159, 1817,    1,    1,    6, 1021,   37,  331,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3141,  365,    1,    1, 2184,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 3006,    1,  193,    1,    1,  686,   32,\n",
      "         3343, 2625,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2902,   46,  600,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  272,   37, 1021, 2910,  220,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   56, 1880, 3188, 3329, 2307,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  991,  786, 2234,    9, 1744,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 1262,   37,  271, 1147,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1844,    9, 2708, 1009,  232,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 1639,  384, 1896,   37, 1155,  105, 3057,   45,  166,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2967,    1,   98, 2347, 1638,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1628,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3379, 2147, 1585, 2414,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1647,   98, 1280,  522,  767, 1121,  361,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  859,  365,    1,  444, 2638,    1,  361, 2638,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3185, 2322,  288,    9,  411, 1169,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   63,  166,  862,  425,  426, 1993,  417,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3375,   37,    1, 3358,   12, 1351,   98,  740,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1,  716, 3086, 2924,   32, 3114,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1252, 1292,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  742,   48,   32, 2448,  386,    1,   37,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1821, 2190,   51,  245, 1159,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3302,  313,   37,  764, 2308, 2905,    9,  593, 1990,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1808,    1,    1,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 1670,   37,    1,  716,   45, 3025,   12, 2162,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,   31,    1,  995,   32, 1169,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 2962,    1,  571,   37, 2925,  187, 2563, 1285,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3359,   61,  105,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  159,  686,  365,  845,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,   65, 1470,   98, 2127, 2432,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  130,    1,  279, 1606,  437,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  743,   12, 1261,  365,    1,    1,  187,  460,  716, 1275,    1,\n",
      "           15,  682,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  305,  125,  390,   98,  389,  533,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,    1,    1,  742,   12, 1689,  142,    9,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  831,  548,  531,  965, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1234, 2308,  176,  166,  917, 2293,  361,  636,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  166, 2717,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  811, 2579,  338,  526,    9, 1645,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  297,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1, 2018,  420, 1647,   98, 1815,    1,  440,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   47,    1, 2041,  187,    1,  132,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  134,  597,    1,  494,  220,  133,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1936, 1003,  176, 1230,  203, 2015,    9,  166,  218,    1,   28,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  108,  864,  444,    1,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2200,  342, 1559,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 3162, 2856,  361,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  183,  140,    9,  103,   56,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 2962, 2920,  186,   37,  688, 1957,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  463, 2926,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1631, 3265,   32,    1, 1300,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1670,  808,   32,  465,  404,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2475, 1403,   81,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3226, 1822, 1604, 2138,   37,  439, 1044, 1045,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713, 1715, 1651,  142,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453,  267, 1852,  782, 2089,    1,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,  361,  359,   37, 1195,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1479,  104,  295,  420,  390,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1021,    6,    7,    9,  657,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  150,   37,  130,    1,    9,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3110,    1, 2451, 3110,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3115,  664,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1963,    1,    1,  220, 3265, 1987,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3308,   37,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  515,  807,  808,   32,  247,  574,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  449,   32,    1, 1437, 2824,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1818,  147,   37, 2303,    1,  400,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  297,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  843, 2943,    9,  207,  844,  669,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1574, 1099, 1453, 2089,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1723,  782,  590,  133,   32,  183,    1,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2396, 1953,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,  105, 1940,   12,  855,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   37,  619,  357,  193,   37,  619, 1778, 2580, 1108, 1779,    1,\n",
      "         1167,   61,  166,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,  146, 2322,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  990, 1625,   37, 1073,   85, 2650, 2790,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2628, 2540, 2295, 1022,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,   25,  288,    9,  417,   26,    1,   69,  246,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,    1,   37, 2808, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  795,   12,  207,  221,  640,  388,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1705,   37,  439,    1,   32,  854,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  463, 1447, 2652,    1,   45,    1, 2924,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 1923,    1, 1923, 1022,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3359,   12, 3339, 2271,  193,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1529, 3215,   98,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1086,    1, 1844,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 1756,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  441,  619, 1495,   37, 1496, 1497,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  729, 1762,  726, 1045, 1426,    9, 3276,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   37,   26,  242,  528,  800,   60,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1290,  396,   28,    1,    1,  102,  504,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1186,   12, 3355,   37,   77,  593,   97,   98, 3369,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1443,  774,  829,  111, 1107,  525,  338, 1139,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  123,   37,  331,  987,  132,  220,  104,  633,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200, 1718, 2355, 1499, 2232, 2706,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  982,   37, 1706,   59,   32,  395,  704,  705,  656,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,    1,    1,    1, 1530,  176,   45,    1,  985, 1260,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  592,  108,   45,  433,  636,  720,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3306, 2226,    1,  229,  202,  193,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  793,  529,  302,   28,    1,  131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1034,    1,  267,    1,   12,  105,  227, 2565,    1,  202,  105,\n",
      "          792,    1,  971,  792,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1142,  267,  204, 2768,  193, 1937, 1988,  176,    1, 2772,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2966, 2595,   61,  363,    1,  506,   30,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  982,    1,  572,  244,   37,  331,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  535,  656,  190,    1,    1,  415,  193, 1724,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1229,    1, 1687,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1090,    1, 3039, 3040,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  632, 1409, 1156,    9,    1,    9,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  700,  315, 1607, 1901,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051,  108,   45,    1, 2762,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1, 1231,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1420, 1579,    1,    1, 2003,    1,  368,    1, 1437,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3253,    1,    1, 1021,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  550, 2680,    1,    1, 2310, 2544,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1493,  449, 1918,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3238,  288,    9, 2456,   76,   81,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2008,  597,    1,  609,    9, 1204,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    7, 1184,   67,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  856,   81,  176, 1477, 1990,  202,\n",
      "          729,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  104,  951, 1227,    1,    1,   12, 1442, 1350,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  935,    1,   37, 1155, 1606,   32, 1821,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  213,   37,  151,    1, 2203,    9,    1,  372,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1810, 2410, 1385, 2525,   32,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884, 1411,   84,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3247,  979,    1,    1, 1631,  886,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  853,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   37, 1075, 1282,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2597, 2137,  135,    1,  187, 1656, 2909, 2856,   56,  104, 2924,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3337, 1114,    1,   32, 1990,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2747,  166,    1,    1, 3346,    1,  187,  104, 1518,   32,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   91,    1,  267,    1,  321,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  398, 1579,  381,  399,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 986, 152,  37, 875, 220, 422,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 180, 361, 727, 875, 822,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2388, 2313, 2827,   98,  134,  204,  205,    1, 1260,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1170,  338,  548,  586,  267,  225,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  344, 3403, 2414,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  165,  205,    9,    1,    1, 2624, 1649,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2962,    1, 2951,  187, 2615,    1,  730, 2614,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2822,    1,   61,   98,  166,    1,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3280,  958,  142,    9,    1,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2547,    1,   98,  187, 2700,    1,  323,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  335,   98,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1791, 2397,    1, 1061,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  975,    6, 1952,  197,  570,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2193, 1459,  828,  973,    9, 1029,  535, 2109,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1181,   37, 1539,  259,  220, 2543, 2177, 1027,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,    1,    1,   39,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   50, 3350,   32,  531,    1,  384,  317,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  877,    1, 2494,  105, 2276, 2266,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2045,    1,    1,  197, 1308,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1396,    1,  220,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1680,   37,  130,    1,  481,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1771,  171,    1, 1918,    1,  202, 2388,  682, 1672, 2771,  142,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3284,   12,  701,  833,  612,    1, 3228,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1636, 1766, 1767,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   61,  786,  726,  384, 2069, 1385,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2753, 1056,    1,  187,    1, 2963, 2551,   32,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3198,  744,   28,  810,  632, 2069,   32, 2592,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1994,   10, 2832, 1523,  947,  176, 1966, 2396,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  133,  488,  777,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,  170,  315,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,    1, 3169, 1542,    9,  104,   26,    1,   32, 2110,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2313, 1231,  297,    1, 2693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3087,  640, 3097,    1,  590,  716,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  268,   37, 2446,    1,  857, 1469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230,    1,  220, 2565,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,  712, 2349,   28,  176, 3229,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1330, 1228, 2568,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2685,  907,    1,    9,    1,  176,  754,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   65,    1,  997,   45,  845,  160,  734,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,    1,    9,  449,  199,   32,  531, 1656, 2596,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,    1,  811,  588,    1, 1737,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  693,  384,  199,  421, 1200,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  778,    1,  182,    1,    1,    1,    1,  584,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1273, 1090,  218,   37, 2401,    1,  506,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1818,  147, 2411,   37,  804,   98, 1842,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  503,  197,  338,  118,   98,  749,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510, 1702,   69,  242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2254,  672,    4, 2311,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  896,    1,  288,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2556, 1485,    1,   98,  166, 1844,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1712,  829,   37, 1664,  166, 2650, 2537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  853,  538,    1,    1,   32,  105, 1292, 1013,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226,  190, 1334, 1583,  475, 2191, 3380,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 1245,   61,   98,    1,    1,  150,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  476, 1428, 1906,   37,  907,  176, 3369, 2024,   46,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2122,  231,  105,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,  858,    1,   98,  166,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  190,    1,    1,  967,    1,   37, 1824,  220,  166,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32,  344, 3389,   32, 1094,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428, 3397,  267,  443, 2938,  972,   32, 3118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,  200,  734,  125, 1553,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1222,  934, 1380,    1, 2261,   37, 1604,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683, 1888,    1, 1258,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,   39,   12,    1, 1447, 2128,  125,\n",
      "         2191,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 2352,    1,   45,  388, 2117, 3406,  232,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1052,  737,  207,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1304,  353,  354,   45,   59,   32,   72,  401,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2871, 1700,    1, 2632, 2587, 2901,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1140,    9, 2109,   98,    1, 3001,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3356,   57,    1,   37,    1,  114, 1316,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1202,  489,  104,  642,   57,  417,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  395, 2369,   28,  844,  117,  261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  274, 2629,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 328, 458,   1,  49,  50, 530,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 190,  52,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  742,  155, 2448,  386,   48,   37,    1,  419,  178,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1, 1119,  680,  166,  433,   45, 1099, 1453,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   32,  922,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  331,    1,  251,    1,  105, 2948,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1419,  469,    9, 2978,   12,  865,   37,   95,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1818,  147,  948,   37, 1709, 1211, 1819, 1787,   37,  544,  193,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2087,  433,   98, 2125,  548,    1,  943,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1,  908,  593,   12,    1,    1,  261,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,   37,    1,  112,  993,    1, 2943, 1499,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713,  146,    9,  487, 3102,   12,  949,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1604,  272,    9, 2161,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   37,  665, 2641, 1772,  111,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1366,  565,  105,  872,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273,  730, 2614,  872,  420,  385,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,  651, 1512,  365,  506, 1261, 1328,    1,   32,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 3066,    1,  297,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3260,    1, 1472,  809,   26,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2528,   45,  829,   12,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2954,    1,   32,  430,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  753,   32,  166,  856,  444,    1,  505,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2596, 2414,   32, 1815,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  315,   37, 1121,  207,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 1821,  639,  267, 2978,    1,  509, 2449,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2331,  602,  429,  968,   32, 1912, 2250,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  856,  707,   37, 2911,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,  391, 2540, 1081,   12,    1,    1, 1463, 1489,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  558, 1564,  453,  221,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296, 1321, 1876,    9,  829,   32,  342,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  610,   37,  537,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 1601,  384,  104,  358,  533,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2059,   32,  625,   32,    1, 2291,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12,    1, 1279,  682,  773, 1572,  191,    1, 1201,    1,\n",
      "         1758,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,  848,  714,  617,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1726, 1876,    1,  721,   12,  808,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  251,  575,  105,  365, 1013, 1522, 2294,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1476,  977,  321,  606,    5,    1,   32, 1657,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  288,   28, 1972,    1,   32,  395,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649,  947,    1, 1178,   32,    1,    1, 1260,  176,   36,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3066,    1, 1924,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 2080, 2341,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3069,    1,   98,  531,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585,   32, 2597, 2774,    1, 2414,  176,  177,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 642, 643,  57, 670,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 166,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3178, 2126,   98, 1684, 1045,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,  292,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2408,    1,   12,    1, 2115,   37,   52,    1,    9,    1,  182,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  238,  418,   32,  638,    1,  548,   27,  119,  340,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,  828, 2000, 2212,  861,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3296,  449,  221,   45,  889,    1,  979, 3224,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1985, 1178,    1,  429,   98,   37,   77,  103, 1569,   32,  447,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1396,    1,  777, 2264,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   61,  968,    1,  434,   28,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3012, 2699, 1323,  420,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1101, 1102,    1,   32, 1613,   12,    1,  612,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,    8,  469,   37,    1,    1,  261,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1759,  309,  947, 1173, 1159,    1, 1117, 1525, 1108,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  785,  786, 2514,   12,  340,  275, 2339,  105, 2745,  872,   61,\n",
      "          105, 2315,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1537, 1407, 1190,  267, 1815,  193,  105, 2673,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1,  121, 1980,   37,  759,  895,  176, 2396,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 353, 197,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 735,   1,   1, 384, 301,   5, 302,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  386,  295,  431,  132,   98,  388, 1251,    6,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1316,  166, 1255,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,  831,  187,   69,  102,  470,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  165,  967,    1, 1463,  932,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1128,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1827,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,  113,   98,   37,  504,  384,  119,  340,  517,   51, 1067,\n",
      "         1057,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2752, 2924, 1046,  966,   44,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,   37,    1,    1, 2396,    1,  202, 2862, 2126, 1324,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1557,  582, 2753, 2963, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2254,   12, 1412,  289,  408,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   92,  607,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1444,    1,  460,    1,  202,  590,  786, 1494,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  776, 2306,  288,    9,  597,    1,   82,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  441, 2562,  388,  199,  907,  365,  261,   98,  225,  809,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1141,   63,  163,    1,   12,    1,    4,  420,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  856,  845,   71,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  354,   37, 3010,  166,  590,    1,    1,    9, 3190,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  306,  572,  197,  418,    1,  307,  308,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275,    1,   28,    9, 1708, 1046,   79,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  616,   71, 1010,  383,   69,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1158,  517,  769,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  159, 1253,   98,  225,  151,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1794,  475, 1454,    1,  384, 1186,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  236,  237,   66,  526,    1,  752,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2753,   32,    1,  726,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3151, 2308,  729,    1,    1, 1291,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3105,    1, 1853,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  549,  640, 1215,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2318, 1509,  794, 3141,    1,  608, 1957,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3360, 2162, 1950,   32,   28,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  361,    1,  429,  890, 1517,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,    1,  123,   37,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,  879, 2320,   45,  453,    1, 3162,    1,  709,  650,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1168, 1450,  359,  465,   22,   32, 2046,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,  104, 2525,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1230, 2528,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  108,   45, 2454,   32, 1718,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,  655, 1231,   32, 2162,   45, 2708, 3065,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  992,   85,  187, 3097, 2565,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,    1,  693,    1,  613,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1693, 2038,  922,  427,  716,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523, 1321,  384,    1,  628,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  765,  115,  220, 2972,  704,  705, 1896,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2500, 3036,  736, 1445,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3272,    1,    1, 2779,  801,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1268,  342, 2102,    1,  200, 1230, 2528,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3151, 1756, 1953,   30, 1945, 1810,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,    1,   37,  454, 2673,   46,  395,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,  105,    1,  384,  306,   12,  825, 1013,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1419,  861, 1614,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094, 1086, 3038, 3339, 2731,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2089,  721,  261,  809,   52,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2278,  325, 2815, 1228, 1873,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,  103,  389,    1,    1,   12, 1535,  525,  475, 1554,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  715, 1818,  147,  261,   32,    1,   45,    1, 3017,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2213,  171,   45, 2387,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3186, 2491,  997,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2117,    1, 3118, 2024,   46, 2052,   37, 2675,   32,  430,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  359,   37,    1,    1,    9, 2977,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2144,  388, 2496, 1976,   32, 3383,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,  121,   37,  562, 1839,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  686,  455,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  105, 1427,   28, 1090,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 2003, 1585, 1746,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  294,  172,   50, 1581,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1076,    1,  191,    1,  265,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  799, 1564,    1,   27,    1,    1, 1817,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  724,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359,  952, 1876,    9,  205, 3057, 3339, 2292, 2414,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035,    1,    1,  176,    1, 1224,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3285,    1,    1,  844, 1074,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  732,  170,  220,    1,  992, 1415,  548,  331,   35,  333,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    4,  173,  246,   98,  160, 1161,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  938, 1075, 1173,   37, 1104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  176,  460, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,    1, 2731, 1530,    1, 1941,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977,    1,    1,  405,    1,   37, 1540,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3349,  555,  488, 1011, 1527,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1525, 1250,  229, 1526, 1159,    1, 1527,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652, 1236,  829,  297,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2494,  872,    1,  191,  208,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 3289,    1,  566,  105,  865,   37,  166, 1551,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,   12,    1, 2405,    9, 3118,    1,   51,  693, 2117, 1799,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,  243,  390,  548,   29,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2862,    1,  342, 2250,  847,   32,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   68,   69,  636,  490,  608,   32, 1033,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  938,    1,   37,    1, 1919, 3091, 2572,   32,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2137,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2862,    1,    1,    1, 2206, 3351,    1,   12,  223,  176,  629,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1535,  124,  565,  193,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  548,  166,  862,    1,    1,  418,  548,  156,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   27, 2644, 3102,  176,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  163,    1,   12,    1,  632, 2875, 2640,    1,    1,   45,\n",
      "         3024,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2161, 2911, 1237, 2206, 2207,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1931,  600,   36, 2910,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  977,  506,   98,  207,    1, 2012,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,  567, 1080,   32,  584,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129, 2523,   79,   37, 1480,  698,   32,  142,    9,  449,  455,\n",
      "         2579,  726,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   10, 1702,    9, 2212,  861,  788,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3089, 2161, 2365,  608,  403, 1739,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  861,  127,   37,    1, 3155,   12,    1, 2629,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3032, 1021, 2190,    1,   32,  121,    1,  590,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3401, 1765, 1009,   45, 1081,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  528, 1647,    1, 1592,  774,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1095,   37,  720, 1876,    9,  829,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  267, 3107, 1281, 2189,    1, 1800,  909,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2042,   12,    1, 2070, 1313,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32,    1,   45, 1450,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  594, 1983,  351, 2414, 1711, 2021,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  361,    1,    1, 2472,  614,   37, 1796, 1920,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 1514,    1, 1360,  166, 3193, 3217,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  176, 2009,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  199,    9,  183,  547,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  547,   74, 1981,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  864, 1800, 1428, 1063,   12, 1004,  187, 2189,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  381, 2120,  547,  548, 1446,  287,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3363, 1082,    1,   37, 2446, 3006,    1,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3219,  688, 1668,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,    1,  548,  105, 1031,   45,    1,  176,  915,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1011, 1139,   98, 1821, 2190,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2868, 2055,  365, 1811,  404, 2024, 1896,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   37,    1,   56,  647,  482,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  438, 1109,  444, 1273,  259,  278,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492, 2625,    1, 2172,    1,    1, 2263,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3033, 1504,    1,   39,    1,   45,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  575,  529,   93,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,  356,  548, 2555,    1, 2343,   12,  776, 2306, 2353,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   42, 2039,  444,  475, 1213,   12, 2059,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3086, 2924, 1731, 1159,    1, 3114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968,  952,  388, 3349, 1428, 2924,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1043,  490,   37, 1637,  123,   32, 2119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  220, 1658, 1465,    1,  361,    1,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  733, 1050,  112,   37,    1,    9,   59,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1472,   28,  220,  375,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2821,  852,   55,  599, 1429,    9,  977,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228,  275,  681, 1046,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  195,    1,    9,  985,  629,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  657,    1,   32,  829,   12,    1, 2232,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,  317,    9,    1, 1525, 2664,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   95,  473,  474,  488,  477,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1089, 1090,    1,   28, 2795,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  572,  197, 1249,  157,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1090,   74, 2677, 1090,  199,  446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  650, 1288, 1647,   98, 1511,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2826,  455,    1, 1632,   37,  726, 1940,   12,  872,  671,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   94,  640,  119,  845,  444,  163,    1,   12,    1,   60,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3226,   37,   52, 1231,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,   12,  166,    1,  815,   45,  105,    1,  259,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2754,  446,  140, 1161,  741,   32, 3372,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1851,  786, 1366,    1,  416,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2,  69,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 148, 695,  51,   1,   1,  88,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  447,    1, 1325,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193,  972,   37, 1343, 2191, 1981,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1536,  365, 2819, 2039,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310,   25,   71,   32, 1034,    1, 1572,  191, 1181,  623,    1,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1273,  618,  565, 2440,  774,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 1794,    1,  548, 2949,   66,   32,  455,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   26, 1039, 1228,  614,   37, 1604,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  616,    1,    1,   45,  462, 1551,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2632,   39,  191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1084,    1,   37,    1, 1501,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1867, 1106,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3092,   16, 1349,   38,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1043,   28,    1,  118,  191,   98,  236, 1022, 1253,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  950,  986,  103, 1001, 1132,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2518, 1822, 1734,  776,    9, 1995,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2464, 2298,    1,    9, 1524,   74,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2292,   32, 1850, 3339, 2414,   56, 3375,    1,    1, 1185,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   47,    1,   48,    9,   59,    1,  249,  774,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 3354,  446,  476,   37,  439,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  166,  917,  913,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  204,   51,  429,    1,   98, 3207,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 3164,  220,    1, 1827,   39,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1230,   61,  166, 1851, 1048,  855,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 2933, 2545,  384, 2957,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 2589,  176,    1,  628,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2134,    1,   37,    1,   28,  105,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796, 2227, 1938, 3197, 3275, 2052,  191, 3121,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1100,  872,   98,  365,    1, 2670,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,  874,    1,  166,  627,   61,  176,   38,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  404,  310, 1659,    1,  548,  342, 1494,  786,   84,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  939,  187,   82,    1, 1009,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  170,  162,  963, 2015,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585,   32, 1785,  787, 1965, 1856,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  590,    1,    9, 2974,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,  164, 1655, 2536,   32, 2490,    1, 2500,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  136,   37, 2225,  326,  710,    1,  187,   82,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 3222, 2917,  384,    1, 1638,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  647,  597,   82,   37,  619,    1,  331,    1,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510, 2097,  104,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  667,  458,  437,  716,  119,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,   64,    1, 2140,    1, 1018,    1, 1727,    9, 1011,    1,\n",
      "          643,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  709,  978, 3138,  512,    1,  928,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 1749,  220,  517, 2287,   13,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504, 2734, 2986,    1,    9, 1530,    1, 1173,  115,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3092,   37, 1463,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2692,  596,   15, 2709,  228,   59, 1501,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  597, 3104,  475, 1712,  108,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1721,    1,  600, 1400,  763,   76,  517, 1118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 2188,  758,    1,  117,   24,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  572,  354,  983,   28,  419,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  673,    1, 2887,    1, 1810,    1,   28,    9,  741,\n",
      "          857, 2283,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  945,   69,  669, 2189,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3164,   12,    1, 1348,  187, 3211,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1079, 3063, 2934,   37,    1,  224,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3300,    1, 2565,  928,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2887, 1523, 2897,  187, 2868, 2770, 3349,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,    1,   59,  693,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1423,    8,    1,   37, 3025,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  418,   98,    1,    1,  430, 1450,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2757,  952,    1,   79,    1,   32, 1606,   24, 2096,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2279,   12,    1,    1, 1497,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3186,  720,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3242, 1203,  730,    1, 1164,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  212,    1, 1151, 2436,   37,  326,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,  905, 1064,   37, 1984,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  315, 2184,   14,  525,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  947, 2856,  854,   12, 1354, 2556,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  889, 1177, 1039,   45, 3024,   12,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2925, 3276,  565,  166,  712,   45,  166, 1762,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777,  686,  191,  861,  328, 2215,  126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  256,    1,   37,    1,  834,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2688,   61,  495,    1, 1149,  920,    1, 1366,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1433,    1, 2582,   37,  168,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,  853,  618,    1,  166,  454,    9, 3343,  890,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,  562,  786, 2234,    9,    1,  769,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1442,  420,    1, 1158,   12, 1230,  631,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2677,   74, 1700,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810,  566,   98,    1,   12, 2022, 2552,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  698, 1408, 1717, 2793,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  961,  230,  639, 1070,    9,  480,   45,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,    1,    1, 1864,  170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2751,    1,   32, 3383,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  498,   98, 2825, 2690,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   12,   26, 1039,    1, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  299,  765, 1415, 1750,    1, 1281,   98,  116,  962,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,    1, 2712,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,  159,    1, 1728,    1,    1,  415,   51,   52, 2525,  548,\n",
      "          810,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  957, 1360,  612,    1,  890,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  166, 2891,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  538, 1860,   45,    1,    1,   12,  365,    1, 1648,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  367,  465, 1895, 1097,  568, 1071,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   37, 2186, 2288,    1,  384,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  148, 2167,  142,    9,  647,   61, 2069,  187, 1757,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  629, 1541,    1,  238,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1950,   28,  419,   98,  570,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  200,  365, 2452,  176, 2197,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  792, 2503,  593,    1,  288,  365,  119,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  560, 1274,   71,  187,  347,  470,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  534,  190,  606,   37, 1343,  191,  667,  261,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1105,  787,  572, 1690,  525,   15,  276,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  103, 2635,    1,    1,    1,  202, 3174,  361,    1, 1758,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1759,  309,  663,  437,    1,  487,  232,  297, 1211, 1819, 1559,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2926, 3326,  872,  420,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,    1, 1377,    9, 3365,  949,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3355,   37, 2122, 3369,   98, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,    1,    1,  988,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1678,    1,  294, 1919,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  176, 1428,  297,  632, 2095,    1,  469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 1178, 1492,  167,  606, 1846,  302, 1712,    1,  111,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2028,    1,  104, 1104, 2749,  220, 1994,  443,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2504,  446,  246, 1140,    9,    1,  770,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1024,  477, 2034, 3143,  726,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  196, 1996,  166,  848, 1303,    1,  105,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2252, 3358, 1351,  682,  432, 1010,  943,   45,  105,  413,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1116,   32,    1, 1086,    1, 1034,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,    1,  155,    1,   45, 2987,   45, 2162,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  190,  790,  771, 1196,   45,  963,  361,  219,  164,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1117, 1525,  852,   55, 2819,   37,  284,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1228, 2633, 1061,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 1141,   37,    1,  770, 1976,   32,  531,  187,    1, 3102,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  203,    1, 1360,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 2128,  221,  193, 2179,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  187,   91,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1061,  297, 2147, 2950,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2898,    1, 1937,  590,  346,   67, 1031,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  947, 2263, 1051,    1, 3060,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  199,  421,  353,  197,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  223, 2420,   86,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  709, 1065, 1190,    1, 2934,    1, 1445,  863,  190,   52,   26,\n",
      "            1,    1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1068,   93,    1,  570,   32,  367,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2160, 2049, 1268,  914,  220,  845,  689,    1,    1, 2719,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1497,    1,    1,  686, 3155,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1579,   69,    1,   98, 3369,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3142,  872,   28,   98, 1245,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2131,   17,  619,  166,  917, 1263,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   25,   76,   37,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056,    1, 1976, 1530,  176, 1038,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314,   82,  387, 1629,  399,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  503,    1,    1,    1,    9, 1682,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1331,   31,    1,  763,   76,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  835,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144,   12, 3372,   37,  736,  863, 1512,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1432, 3207,    1,   32, 1472, 3126,    1,  307, 1516,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2881,   12, 1718,  559,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1652,  831,   32,    1,   98, 1718,  983,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  857,  477,    1, 1104, 2789,    9, 3262,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1613,  765,   37,  470, 1615, 1102,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962,    1,   12, 2907, 1408, 3117,   32, 3235,    1,  631,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  105, 2265, 1463,  400,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,  717,    1,    1,  140, 3116, 3217,  297, 2741,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  884, 2791,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,  774,  163,    1,   12,    1,    1,  753,  297,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  812, 2018,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746,  967,  786, 2446, 1263, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  491,  952,   37,    1,  615,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1042,  449,  548, 1044, 3132,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1212,  787,    1, 1988,   32,    1, 1887,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1831,    1, 3269,  943,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2175, 1371, 1273,  844,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711, 3156,  191,  395, 2817,  187, 2162, 1950,  640,    1,  388,\n",
      "         2249,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,  115,   45,  163,    1,   12,    1,   29,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1376,    1,  187,   29, 1463, 1552,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2872,   32,  166,  931, 1022,    1, 2296,  140, 2513,   32,  105,\n",
      "         1559,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,  861, 1665,   45,  224,   12, 2355, 1013,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2179, 3080, 1810,  645, 1683,   32, 2862,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,   37,  489, 1414,  384, 3339, 2649, 2791,  716,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3128,  531,  861,   37,   52,    1,  115,   45, 1002,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  361,    1,  753,   77,  105, 2214,   12,  985,\n",
      "         2148,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2565,   12, 2027,   61, 1048,    1, 2385,  612,  460,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2442, 1117,  741,  162,    1,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  198, 2164, 2414,  176,  177,   32, 1850,  455,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  952,   37,  439, 1611, 1970,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1, 1361,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  835, 1412,    1,  700,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2279,  738,  220, 2224, 1726,    1, 3399,  297, 2734, 1527,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1707,  651, 1563, 1450,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612,  619,    1,    1,    9,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  216,  135,  557,  540,   12,    1,  787,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  462,    1,  132,  640,    1, 2432,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  114, 2151, 1069,  176,    1,   12, 2084,    1,  250,   32,  455,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3188,    1, 2321,  220, 1880,   12,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,    1,  215,    1,  774,  190,  193, 2192,   32,   37, 3345,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,   66,  417,   31,   29,   98, 1978,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2114,  967, 2315,  785,    9, 3326,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3035,   16,  730, 2614, 1433, 1444, 2449,  166,  872,   37,  688,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  387, 1332,    1,  163,    1,   12,    1,   15,   28,\n",
      "          419,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  709, 2265, 2224, 1190, 1941,   32,    1, 1656, 2950,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,    1,  140,   72,   32,  105, 1559,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  170, 2362,  220,   59,  158,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2899,  251, 1108,   37,  176,  612,  613, 2264,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  566,    1,  187,   60,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  920,    1,  166, 1796,   18,   28,  220,  166, 1762,    1,   28,\n",
      "          260,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  458,  958,  170,   46,    1,  700,   66, 1670, 2274,   37, 1527,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1312,  199,  810, 1292,    1,    1, 1484,  460,  796,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  154,  166,    1, 2151, 1120,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 2539,    1, 2210,    1,    9, 1427, 2113,   86,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 2036,  614,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 2565,  463, 2170,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1029,  146, 2282,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  829,   12,    1, 2341,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1345, 2897, 1425, 2774, 2827, 1147, 3346,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  977,  554,    1,  202,  565, 1444,   69,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  657, 1119,  297, 1188,    9,  846,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 1090, 1829, 2163, 1110,  176, 2459,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,  696,  310,  327, 1749, 2728,  220, 1718,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,    1,   37, 1752,  449,   37,  815, 2589, 2186, 2208, 1167,\n",
      "            1,  105, 1603, 2290,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3235, 3210,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  150, 1015,   12,  915,    1, 1943,  786,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2612,    1,  384, 2245, 1541,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  267,   93,   61, 1115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3255,  365, 2036,   21,   37,  877, 2048,   39,   45, 2551, 2579,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 2410, 1989, 1990, 2107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  159, 1374,  572,   98,   15, 1470,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  952,    1,   45, 2031,  396,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1983, 2078,   51,  168,  111,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    9, 1340,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  449, 1972, 2981,  288,    9,  142,   37, 2935,  183, 2223,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3054, 1310,   37,  271,  846,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1100,    1,  365,    1,  469,    9, 1151,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3054,  640,  959,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1212,    1,    1,  845,  275,  443,   98,  617,  618,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2962,    1, 1825,   32,  228, 2202,  187, 3079, 2651, 3266,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2883,    1,    1,    1, 1634,  124,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  627,    1,    1, 1836,    9,  466,  644, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,  958, 2527,  164, 1976,   32,    1,  915,  356,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1629, 1414,    1,   37,    1,  195, 1916,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1764,  865,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,  978,   12,    1,   28, 2232,  846, 2326,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1070, 3302,   37,    1, 3306, 2027,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1122,  853,   32,  152, 1123,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1237, 1658, 1117, 1525,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  741,   32,    1, 1285, 2823,  863,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  777, 3017, 1008,  619,    1, 1217,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,   37,    1, 1273,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2968,  851, 2421,   27, 1967,   32, 2018,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75, 1566,  617,  259,  815,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  864,   12, 3372,    1, 1190,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  267,  581, 1774,    1,   82,  939,  424,  356,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 1215,  733,  453,    1,   37,  105, 2683,   45,  756, 1821,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,  730, 2614,  288,   37,    1, 1246,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  104, 3361, 2572,   32,  547, 1450,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  200, 2501, 1333,  331, 2382,  220, 1568, 2533,    9, 1089,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  208,  209,  210,  211,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1487,   37, 1083,  453,  102,    1, 1893,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  398,    1,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  340,  174, 2053,  140,  105,    1,   32,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1270,  105,  339, 2248,    1, 1771,  856,  614,   98,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   25,  670,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3218,    1, 1957,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299, 1042,  735, 2109,   32,    5,  302,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1564,  388,   26, 1039,    1, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3124, 2361,    1,  389,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1652,   12, 1227, 2118, 1366,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  622, 2153,  429,   46,   32,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  459,    1,   37,  356,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   76,   37,   52, 2297,  582, 2565,  176, 3190,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,  418,   15,  606,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,  288,   37,  562,    1,  182,   32,  567, 1527,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2367, 2015,   61,  227,    9,  460, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1323,  729, 2353,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  793,  861, 1229, 2091,   32,  121,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2654, 2325,   37, 2911,    1,    1,  176,  105,  636,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,   37, 1706,   59,   32,  395,  704,  705,  656,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  632, 2224,  562,   12, 1839, 1259,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12, 1560,   52, 1158,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  915, 1734,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2345,    1,    1, 1555,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  487, 1300, 2054,  448,    1,   37,  119,    9,  385,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2500,  566,  321,  612,    1,    1, 2027,   32, 1283,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3349,   90,  463, 2170,   37,  674,    1, 3362,    1, 2656,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 1178, 2827,  297, 1051, 1039, 2690, 2607,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1808,   37,   47, 1412, 1863,   37,    1,  220, 1230,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1287,    1,  289,   98, 1184,  347,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  657, 2239,   79,  844, 1151,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    6,  102, 1316,  660, 2320,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1333,  176,  671,   61, 1018,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3349,    1,  220,   64,    1, 2705, 2709,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   94,  418,   37,  119,  845,  530,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3276, 1176,  445,    9,  519,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  506, 1770, 2436, 2558,    1,  612,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  665,  617,  725,   98, 2348,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1537,    1,   51,  686,  954,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  375,   30,    9, 2760,    1,  459,  786,  356,  132,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2529, 3121,  697,   37,  477, 2755,  455,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  877,  142,    9,    1,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1327,   12,  680,  114,  342, 2409, 1550, 2210,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1631,   39,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2431, 3339,  469,  313,   37,  222,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1107, 2415,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,  251, 1815,   46,    1, 2257, 2924,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1694,    9,    1,    1, 3260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  696,   32,    1,    1,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1268,  247, 1423,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1987, 1554, 3115, 2088,  176, 2761,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485, 3365,   32,  531,  820,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2875, 2640,   37,  764, 1013,    9, 2141,  165,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1, 2232,  315,    1,   37,  234, 3041,  235,  166,    1,\n",
      "          234, 3041,  235,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  249, 2572,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428, 3140,  387,  753,   32,   10, 1445,  863,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  580, 3231,   32, 3135,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1, 2329,  312,  966,  191, 3406,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,    1,   98, 1658, 1775,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739,  105,  551,  331,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428,  639,  108,   45, 2170,    1, 1512,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3302,  396, 1918,  297,  104,  700,    1,  116,  663,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2931,  207,    1, 2617,    1,  947,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2490, 1419,    1, 3348,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,   52,    1,   45,  183, 2883,  144, 2152,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593, 2522, 2361,  176,    1, 2578,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1423, 2272,   85,   98,  116, 2574,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  952,    1,  865,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2565,  156,  120,  118,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,   12,  275,    1,  920, 1809,  433, 1484,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   82,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1543,    1,   37, 1504, 2136,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  947,    1, 2144,  443, 2938, 2985,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,  942,  225,    1,   98,  231,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  978, 1602, 2058,   79,  111,  834,  914,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1026,  140,  365,  776,   32, 1022,    1,    1, 1983,  149,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2007,   37,    1, 1065, 3096,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1724, 1114,    1,    1,    1,  361,    1, 1370, 1262,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1327,    1,  447,    1,  297,  531, 3102,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123,  892,  428,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2868, 1450,  219, 3069, 2860,   98,  531,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  267,  460,    1,  955, 1461,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  978, 2953, 1007,    1,  593,    1, 1810, 2910,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 2962, 3188,  140, 3212, 1523,  187, 3244,    1, 2807,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  179, 2078,    1,  131,  354,   98,    1,   44,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116, 2264, 1827,    1,  548,    1,  853, 1464, 2928,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,   12,    1, 1447,  267,  163,    1,   12,    1,   37,  211,\n",
      "         2924,  428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,  567,    1, 2031,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2650,  400,  640,  104,  147,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878,  908,    1,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2494,  872,    1,  191,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  370,  371,   37,    1,   81, 2471,  220, 2077,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  939,  384,  721,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  224, 1900, 1781,   39,   45, 1626,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1840,  482, 1173,  176, 1715, 2187,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1796,  116,  624,    1,  835,    1, 2475,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  640,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1334, 2080, 2810, 2198,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,   12,    1,  835,    1,  129,    1,    9,   59,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  997, 1192,    9, 3391,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  163,    1,   12,    1, 2924,   37,  168,   37,  531,    9,\n",
      "          890,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,  378,  191, 2083, 1900,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,   37,  151,  111, 1107,    1,    9,   59,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,  200, 2528, 1616, 1230,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  861, 1999, 2072,    1, 2705,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962, 3218, 2651,    1,  191, 1394,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433, 2263, 1086,    9,  597, 1047,  475,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1865,  807,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2591,   37,    1,  365,  650,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1, 1228,   37, 2010, 2693, 1080,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1930,    1,    9, 1640, 2774,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1317,  704,  104,    1,   37,  572,  197,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  293,    1, 1343,    7, 1209,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1778, 2580,   37,  121,  220, 2518,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 3396,  420,  365, 1450,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2344,   37,  449, 1232,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1, 1004,  864, 2199, 3107, 3366,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2980,    1,  187, 2999,   91, 3050,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1303,  108,   98,   93,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  364,  315,   37,  714,    1,   28,    1,   32, 2564,   37,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380, 1070,  854,   37,  100,   98, 1815,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,   32,  573,  399,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2845,  726,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158,  251, 2324,    9,    1, 2087, 1669,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3123,   12,    1,  405,    1,   98,    1,  865,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3268,    1, 2445, 2784,  297,  122,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2333, 1994,    1,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  515, 1534,  176, 2322, 1159,    1, 2162,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  635,   12,  244,  288,   37, 1150,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  667,  845,  147, 1650,  587,  917,   37,  477,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  496,   30,  858, 2264,  920,  105, 2241,   32,  163,    1,\n",
      "           12,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1913, 1843,  197,   37,  354,   98,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  919,  909,   98,  104,    9,  920,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1095, 2479,  166,    1,   32, 1447,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 3375, 2572,   32, 3339,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2590, 3043, 3078,  271,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  191,  163,    1,   12,    1,   32,  463,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  629,    1, 2802,   32, 1013,   45,   94,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311,    1,  453, 1863,    1, 1107, 1085, 1501,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   68,   70, 1473, 1010,  107,  509,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 1386,    1,  213,   37,  807, 2117,   23,   32, 3118,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  619,  191,  220,  105, 1298,  764,  384, 1515,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  220,  105,    1,    9, 1437,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2634,    1,    1,    1,  766,   37,  288,   28, 1395, 2104, 1597,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1530,    1,  583,   32,  531,  344, 1656, 1585,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  147, 2037,   39,  386,   12,  573, 2092,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1897, 3151, 1756,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   67,   70,  245,  548,    1,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938, 1075, 2625,   98, 2343,    1,   12, 1559,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2104,  908,  881,   45,    5,    6,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,  548,  800,  163,    1,   12,    1,   29,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  225,    1,  191,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,    1,  649,    1, 1058,  176,  861, 1906,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1707, 3042,  161,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,  379,    1,   98, 1474,  927,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2700, 1083,  122,  600,    1,  195,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,   78,    1,    9,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1070,  845,  147,   37, 1709,  400,   98,  912, 2285,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,  391, 3401,  140, 1081, 1002,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  990, 1536, 2118,  444, 1791, 2650,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   12, 1895, 2043, 2639,  288,   37,    1, 3004,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  691,  123,  854,  912,  176,  915,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  539,    1,  429,   28, 2741, 1314,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2, 982, 387, 517, 259,  15,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 353, 417, 197,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2004,  837,   37,   47, 1191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  729,   98, 1324, 2335,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,  884, 1013,   37,  166,    1,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1118,  449,  844, 1151,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  191,    1,    1,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2266, 1261,    1,   37, 1636, 1428, 1527,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  170,  167,    1,  180, 1749,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1033, 1648,   37,    1, 1211,  442,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2963,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,    1,   32, 2410, 1989, 1990, 2107,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  384,    1, 1887,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1444, 1445,  998,  810,  166,    1,  920,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1433,  565, 1529,    1,  320, 1121,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 2384, 2177,  988,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  629,    1,    1, 1008,  365,   82,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,    1, 1974,   69,    1,   37,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  224, 1475,  837,  225, 1539,  265,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,  315,    9,    1,  660,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,    1, 1604,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962,    1,    1,    1,  631, 3117,   37, 1918,  297, 3251,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1333,    1, 2572,   32, 1785, 2044,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  474,  650, 2827,    1, 1538, 2253,   37,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2026, 1251,  575,   59,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503, 1351,    1, 2219,  763,  749,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3311, 3310, 1576, 1210,  247,    1,  608,   79, 1650,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537, 1660, 1740,  298,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2222, 1494,   37, 1145,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1766, 3164,   21,  388,  384, 2741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 2036,  105,    1,   12,    1,    9,    1,    1, 2715,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1251,   45,  594, 1393,  218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  156,  157,    9,  572,  338, 1315,  689,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1005,  124,  156,   71,    1,  159,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,   81,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3243,  901,  176, 1090,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1303, 1353,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  700,    1,   37, 1753,    1,  574,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1301, 3187,  542,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,   37, 2237,  968,    1,  943,  220, 2153,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1081,   12, 3401,  812, 1918,    1, 1877,   37, 1664,  926,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2104,  387, 2978,  541,    1, 1371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3260, 2561,    1,   37,  698,   98, 1139, 1694,  424, 1981,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1710,    1,    1,  606, 1846, 2526,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1674, 2962,    1, 1660,    9, 2379,    1,    1, 2939,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428, 1002,   10,  113,    1,  631,   98, 2275,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  352,  267, 1583, 1974,    1, 1665,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,  276,  809,   98,    1,    1, 1854,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3134, 2246,    1,  919,    1,   37, 1918,  297,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1011, 1196, 1124,    1,   51,  427,  532,  424,  356,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  667,  446,    1, 2266,  396,  531,  443, 2189,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1429,  700,  733,  810, 1369,  159,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1697,  681, 2116, 1251,   45,  510,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  183,  856, 1003,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2571,    1, 2830,  240,  363, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  391, 1329,  733,    1,    1,   91,   48,    9,   59,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,    1,    1,  937, 2809, 2054,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2620,  833,  612,  245,   98, 3297,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3075,    1,    9, 1147,  249,  548, 2596, 1450,   98,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  361, 2387,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1674, 2965,    1, 2222,  140,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1074,   37,  123,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  463, 1447,  267,  460,   51,  193,  907,  646,   93,  837,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,    1, 2266,    1,  808,    1,  191, 1428,   32,    1, 1663,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1092, 1489,    1,  384, 1739,  361, 1147, 2354,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  640,    1,  845,  951, 1547,   69,  343,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  721,    1, 1952,  863,   45,  482,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2672, 2871,    1, 1240,  619,  698,  444,  519,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  828,  289,   98,    1, 2673, 1816,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3215,  952,  365, 1787,  176,  311, 2936,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1576, 1599,    1,    1, 1854,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  597, 1304,  475,   51, 1046,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  493,  636,   28,   27,    1,  105,    1,  496,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2529, 3121,  640, 2755,  455,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3255,    1,  459,  220,    1, 1632,  593, 1990,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  835,  885, 1117, 1525,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2546,  733,  152,    1,    1, 1086, 2610,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2140,   37,  341,  845,   69,  102,    1,    1,    1,    1,  202,\n",
      "          193,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1264, 1265,    1, 2226, 2898, 2226, 2518,  334,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  803,    1, 1044,    1,  260,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1433, 1366, 1822, 1075, 1459,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  506,   30, 1048,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  575,    1,  600, 1338,   45,  495,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69, 1226, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1147,    1,  167,   52,    1,  763,  104,  396,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  715,  112,  783, 1042,   32, 1332,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  540,  387,  377,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1436,  550,  590,  134, 1954,  548, 3134, 2811,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2700,   37,    1,   39, 2719,  316,   12,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1478,  104,   22,   23,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3242,   51,   52,    9,  311,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2733,  776, 1360,  612, 2324, 1107,  293, 2453,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  515, 1412, 1107,  105,  559,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306, 1396,    1,   32, 2039,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  251,   26, 1039, 1013,  932,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  458,  288,   37,  489,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359,    1,   32,    1, 2789,  741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3310,   12,    1, 1822,   52,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  447,   98,  103,   32, 1764, 1990,\n",
      "         3295,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   32,  557,  540,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   65,   66,    1,  347,  242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,  580, 3169,   32, 3329, 1990, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1273, 1182,  588,  242, 1620,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 2962,    1,   18,   81,   37,  688, 2213,  171,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1924,  227,  361, 1628,    9,  460,  861,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1125, 3163,  894,   52, 2917,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3114,    1, 1388,   98, 3086, 2735,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967,  590,    1,    9, 2485,  444, 3108,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,  105,   92,   37,  453,  342,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,   32, 1815, 1313, 1791, 2930,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  506, 1898,  617,  618,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096, 3316, 2222,    1,    1,  202,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  299, 1579,    5,    6,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2957,  921,  326,  220,    1, 2334,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2731,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1663, 1821, 2190, 2640,  315,  365,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3237, 2770,  166,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  195,    1,    1,   98,  166,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,   12, 3359, 3358,  190,  619,  579,  204,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 2924, 2856,   56, 1891, 1730,   27, 3339,  622, 2791,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  384,    1,    1, 3064, 1505,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2061, 3140,   37,    1,    1, 2735,  220,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1405,   12,    1, 1670,   59,  278,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2907,  515,  273,  411,  631,   32, 1090,  786,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  487, 2924,  582,  403,    9, 2699,   27, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,  814, 1501,   87,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  388,  756, 1294, 2168,    1, 1085,   98,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006,    1, 1147,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1086,  649,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1025,   37, 1306, 1411,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  487, 1190, 2682, 1691,    1, 2658, 1040,  297,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  177,   56, 2572,   32, 1056,  216,   32, 2597,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3370, 2175,   32,  384,  166,  984,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1360,  612, 1330, 1114,   32,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,   12,  978, 2953, 1007,  614,   98,  333,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  383,   69,  102, 1198,  978,  769,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,  331,  313,   37,    1,  885, 3161, 2148,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1182, 1140,   45, 1034, 1183,  477,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2380,   32, 2009,   37,    1, 1033,   12,   71,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  678,    1,    1,    1,  872,   28,   37,  877, 2873,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,  247,  103,    1,    9, 1786,  317,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2464,    1,    1,  111,    1,  361, 1095,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1044, 1380,    1,    1,   32,  105,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967, 1846,  103,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   32,    1,   45, 1509, 1896,    1,    1,  167,    1, 1114,  361,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  555,    1,    1, 2785, 1527,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  162,  764,  384,    1,    1,  326,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1304,  353, 1913, 1843,  354,  641,  822, 1356,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69, 1993,  242,    1,    1,  341,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1194,   32, 2573,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,    1, 2342, 1317,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479, 1169,   15,  245,    1,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2087,  433,  267,  460,   61,  193, 2072, 1260,  378,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,    1,   37,   52,   53,   98, 1102,  841,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  727,   80,  132,    1, 3007,  280,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2527,  164,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3241,    1, 2908,   37, 2565,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 2461,    1,   90, 1227,   37,  720,    1, 1718,  378,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  405,  936, 1056,  365,    1,   41,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  871, 1952,  433,  102,   71, 1354,   32,  105,  356,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  459,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  391,  371, 1360,  612, 1012,    1,  187, 1018, 1213,    1,    1,\n",
      "          267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  474,  765,    4,   37, 1033,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1, 1181, 1421, 2019,  630,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  592,  782,    1,  220,    1,  297,  448,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1369,  251,  988,  279, 2815, 1085,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3277, 1494,   37, 3264,   12, 1527,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1536,  767,  444,    1,  923,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1545,    1,    1, 2226,    1, 2740, 1977, 1514,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1212,  288,   37, 2709,  942,   32,    1,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962, 1245, 1334, 3158,  220,  726,  297, 3206,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162,  361,    1,    1, 3051, 1316, 2735,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2494,  872,    1,  608,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  638,    1, 2024, 1259,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  667,  159,    1,  590,    1,   37, 1876,   12,  551,  552,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,  215,    1, 1935,    1, 1108,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1773,  361,  848,  494,  442,    1,  297, 2371, 2510, 1523,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800,  786,    1, 2107,    9, 3180,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1281,    1,   45,   20,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  365, 1015,    1,   32, 1821,   95,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  395, 2038,  476,    1,  954,    9,    1,  652,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 1466,   37,  125,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  606, 1658,  774,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  625,   32,    1,   32,    1,  446,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1763,   12,  913,   37,  151,  654,  124,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545,    1, 3158, 1844,   32, 2741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2314, 3358, 1713,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1151,   25,   71,   98,  293,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3394,    1,  146,   37,  531,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  624,    1,   37,   52,   53,    9,    1,  131,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3207, 1360, 3208,  671,   98, 2277, 2485,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228, 2249,  715,    1, 1976,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1537,    1, 1866,   37, 1038,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  952,  885, 2031,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  727,  613,   37,  151,    1,   12,  728,    9,   54,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  105,  914, 1698,   45,    1,    1,  166, 2107,  967,  415,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 1837,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  857,  868, 1198, 3119,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   65,  288,   37,    1, 1184,  347,   28,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3347,    1,  388, 1125,   98, 3127,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   88,  852,   37,  877,  854,  389, 1153,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2102,    1,    1,   79,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1530,   32, 2625,   98,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2321,  750,   96,  460,   28,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   61,  460,  105,    1,  357,  105,  259,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2843,  967,    1,   28,  247,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  461,   98,  103,   32, 2760,    9,  968, 3222,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3251,  221,  729,  580,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  638,   25,  176,  638,  102,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2875, 2640,    1,    1,  187, 1011,  109, 2202,  340, 1821,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3079,  688,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1536,    9, 1211,  639,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2004,    1,    1,  657, 1620,   79,    9,  911,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2405, 2498,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  896,    1, 2772, 3060,  967, 2095, 1898,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2415,  375,   32,  979, 2340,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1840, 2781,  176,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   63,  166,  862,  348,    1, 1170,  670,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2414, 1056,    1, 2803,   32, 1853,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994, 1645,    1,    1,  557,  540,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3322,  323, 1700,  925,   32, 2138,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585,   32, 3354, 1223,    1, 2006, 2548, 1941,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3102,    1, 2192,   28,  548,    1, 2426,   98,  336,   32, 1617,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2159,  781, 1194, 1843,  197, 1660,  187,   15,   71,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  220, 3051,  957,    1, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2658, 1040,    1,    9, 1691,    1, 1944,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  167,  588,  480,   45,   28,   37,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  744,  119,  187,  365, 2292,    1,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1517, 1215,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 2972,    1, 2690,    1, 2043,  110,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  171, 1360,  612,    1,  810,  901,    4,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2016, 2171, 2547,    1,   32, 2086,  149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2719,  316, 3272,  590,    1, 2998,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1427, 1631,  460,   26,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,  551, 1363,  764,    1, 2255,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 1641,  631,  202,  688, 3108,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   37, 1930,    1,    1,  612,    1,    1,  275,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  315,    1, 1219,    1,  220,  163,    1,   12,    1, 1217,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3256, 1285, 3236,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550, 2786,    1,    1, 2481,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   62,  187,    1,    1, 1946,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  455,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2650,    1,  293,    1, 1128,  997,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32, 2107,    9,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,    1,    1, 2047,    1,  776, 1232,    1,   37,  104,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    9,  104,  872,    1,  166, 2539,   45,  484,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2049, 1108,    1,   37,    1,  453,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,  326,   37,  559,   79,  327,   50,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 2368,   28, 1273, 2945,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   12, 2571,  844,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  528,  514, 1727,   32,    1,    1,    1, 1300,  290, 2156,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,   27,  526, 1256, 1256,    1,  374,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,  548,  245,   98,    4,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  915,    1,  105,  829, 1013, 2549,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2596, 1585, 2766,   32,  854,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  922, 2857,    1, 3316,    1, 1021, 1632,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  108,  417,  983,    1,    1,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  302,    1, 1038,  199,  297, 2650,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 2123,  220,  183,  487,  700,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,  103,  187,    1, 1242, 2857,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1521,    1,   45, 1537, 3365,   81,  754,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  449, 1674,  671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485, 3222, 3275,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  721,    1,  797, 1699,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1380,  861,  176, 1658,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  548,    1,  720,    1,  284,  183,  922,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1411,  302, 1712,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1044, 1844,   61,    1,  105,  792,    1,  792, 2236,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311, 1343,   85, 3066, 1987,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  424, 1981,   98,  844,    1,  538,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,  983, 1702,   28,  148,   12,  572,  156,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2523,    1,   32,    1,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1105,  787,  737,  354, 1052,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  921,    1,    9, 2941,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,  650,    1,  393,  379,    1, 3006,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3012, 1821, 3027,   37,   18,   37, 3013,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2645,   37,    1,  361,  501,    1, 3231, 2222,  606,  284, 1204,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2511,   37, 1876, 1411, 2273, 1935,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  295, 1366, 2233, 1565,    1,    1,  489,   81,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1034,   32,  231,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 2651,  730, 2614,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1221,  614,  166,    1,    1,    1,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  430,   12,   69, 2751,  529,  997,   45,  596,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3192,    1, 1910,  460,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,  537,   45,  443,    1,    1,  588, 2024,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  219,    1, 2230,  176, 1477, 1990,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  487, 2924, 2572,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2279, 1953,  220,    1,    1,  411, 1463,   32, 2821,   45, 1358,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 1875,    1,  815, 1994, 2650, 2043,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1431, 1268,    1, 2657, 2363,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671, 1078, 1707, 1076,  671,   12,    1,   54,  214,  693,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  476,  388,  977,    9, 1147,  861,   87,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,  418,    9,  449,    1,   32, 1700,   98,  531,  109,\n",
      "         1057,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1819,    1, 1228,   37,   26, 1039,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  360,  365,  342, 1786,  475,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  651, 1031,    1, 2500,   97,    1, 2738,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,    9,    1,  361,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  647,  721, 1707,  148,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  325, 1412,    1,  669,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,    1, 2683, 2043,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144, 1557,    1,    1,  548, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2451, 1635,    1,  597, 2565,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  188, 1315,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32,  531, 2292,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  229,  384,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2414, 3361,    1,  356,  548, 2343,   12, 2555,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2767, 2695,    1,  327,  593,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  849,  132, 2094,  848, 1415,   37,  453, 1135,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  702, 1690,  525,   15,  245,    1,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,   37,  576, 2924, 1159,  104,    1,  274,   45,  531,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 2835,   12,  449,  671,   32,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006, 3353,  547, 2703,   32, 3376,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  517,  972, 1360,  612, 2122,  395,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183, 2005, 1248,  864,   37,    1, 1428, 2390, 1806, 1220,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   72,   32,  451, 3329,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  150,    1,    1, 1490,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3005,    1,  191,    1,  378,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,    1,  571,  105,  103,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  550,    1,  801,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3182,  130, 2469,    1,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,    1,  121, 1003,   37,  860,  442,    1,  622, 2471,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1230,  384, 1087,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  288,   37, 2565, 3312,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  190, 2498,  453, 1509,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  138, 1146,    1, 1013, 2131, 1494,  449,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1797, 2960,   32,  403, 1447,  915, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 1292,  493, 1974,    1,    1,   51,  588,  467,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  171,  645,   37, 2286,   37, 1121,   10,    1, 3190,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1735,  104,  954,  680,   10,  357, 2275,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  197, 1784,  176,    1,  361,  789,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1024,    1,   37, 3318,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,   25,  243,  390, 2007,   37, 1307,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  908,  333,   45,    1,   12,  365, 1546,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2960,  176,  217, 2414,  786,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  579,   12, 2072, 3101, 1165,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  361, 1151, 1749,  335, 1003,  176,  657, 1379,   12,  112,\n",
      "          499,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  636,   45, 2213, 1241,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,  421, 1042,   39,   45,  849, 2107,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1054,   53,   32,  331,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994, 1554,  590,    1,   37,    1, 2997,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,  163,    1,   12,    1,  498,    1,   45,  284,    1,\n",
      "         1196,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3240,    1,  600, 3134, 2811,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  921,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192, 2427,    1,    1, 2838,    1, 2204,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3294,   81,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  603,   37, 1155,   32,  365, 1788,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1128,    1,    1, 1718,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  546, 2673, 1542, 1461,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37,  817,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  403, 1656,    1, 1022,    1,    1,    1,    1,    1,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,  195,    1,  764,  220,    1,  505,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  485,    1,  197, 1042,  191,  105,   72,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1056, 2308, 2709, 1590,   98, 2925, 1638,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,   37,   52,  583,  191,  585,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  176, 1099,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,    1,    1, 2800,    1,  171,   12,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1432,    1, 2715,    1,    1,  220,  873,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,  879, 1281,   98, 1088,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  232,    1,  384,    1,   98,  214,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1733,    1,    1,   32, 1940,   12,  331, 2639,   32, 2890,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   74,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  761,  159,  245,   98,  420,   45, 1646, 2705,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  444, 2506,  444,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1133, 1708,  115,    9,   10,   12,  667,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  176,    1,  960,    1, 1230,  105,  845,  275,    1,   98,  166,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 2177,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  647, 1707, 2069,  148,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,   52,    1,    1,   12,    1,  384,  903, 1447,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1778,   51,   52, 1211,   32,  864,    1,  202,  861,  997, 2200,\n",
      "         1718, 1027,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1928,   90,    1, 2905,    9, 2282,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  342, 2331,  297,    1,  934,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3259,  899,    1, 2523, 2198,  138,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   10, 1877,   37,  194, 1797,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,    1, 2367, 1876,    9, 2071, 1331,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1477,  207,  197,   28,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  878, 1383,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,  356, 2248,    1,    1,  810,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647, 1489,    1,  147,  695,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2266,    1,  247, 2059,    1,    1,  105,  356,  384,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1427, 1401, 3271,  608, 3231,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  193,    9,  333,    1,  774,  311, 2936,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  692,  365,   26, 1039, 2234,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  105,  227, 1020,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1684,  765,  463,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2922,   12, 1045, 1086,  202, 2672, 1285, 1879,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  565, 1691, 2171,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  708,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   25,   28,    1, 1017, 1401,  454,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  992, 1483,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1486,   37,    1,  365,    5, 1323,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  112, 1228,  681, 2346,  388,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  527,    1,    1,  498,   37,   74,  881,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2414,   56,    1, 2803, 1060,   32, 1619, 1853,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1542,   37,    1,    1,  132,    9, 1211, 2878,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  425,  426, 1519, 1521,  191,    1,  365, 1116,  656,   32,  395,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1660, 1102,  841,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32, 1450,   98,  531,  947,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2951,  342, 2396,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1266,  475, 1213, 1432,    1,  939,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121, 2414,    1, 1554, 2290,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1906, 2424, 3146,   98, 3118,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  544,    1, 1492, 1556,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   65,  155, 1114,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187,  208, 3096, 2565,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2448,  386, 2827,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1362,    1,    1,    1,    1,  872,   28,   98, 2334,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  116, 1297, 2313,    1,    1,    1,  384,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1822,  138,    1,   59,    1, 1723,  267,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1110, 1865,  365,  111, 1107, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2266, 1484,   98, 2862, 2153,   37, 2449,    1,   37,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 1731, 3067,  531,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1614, 2336,  260,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 185, 631, 409,  25,  28,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 169, 353,  59, 354,  32, 572, 428,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051,    1,  829,   84,   28,  803,  112,  973,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  980,  187,    1,  636,  338,   37,  105,  106,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  370,    1,   37, 2446, 1809, 2738, 1395,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  706,   45,    1,   98, 1285,  548, 2772,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  744, 2364,   98,  988,   37,  988, 2815,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,  879, 3343, 2699,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2862,    1, 1679, 2101, 1056, 2179, 3082,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384,    1,   32,  395,   37,  758,   32,  507,    1, 1013, 1522,\n",
      "           15,  554,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,   37,  619,    1,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3247,    1, 3248, 2260,  548,  449,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  597,    1,    1,  650, 2827,   32,  611,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  721,  261,  809,   52,    1,  187,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1994, 2834,    1,  861,    8,  972,   37,   52,    7, 2521,    1,\n",
      "           32,   10, 2237,  963, 2122,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106, 1013, 1626,  288,   37, 1539,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  202, 3254,  140,   98, 2304, 1394,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1680,   37,  151,   39,  258, 2274,   12,  332,   32,  395, 1651,\n",
      "         1597,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1154,  166,    1,    1, 1154,  166,    1,    1, 2221,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186, 1458, 1428,  861, 1906,    1,    9,  968,    1,  602,    1,\n",
      "          854,    1,  455,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2596, 1585,  640, 2147,   32, 2197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861,    1, 1152,   45, 2786, 2558,   32,    1,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  596, 1273,  259,   15,  554,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  208,  108,   45,  651, 1512,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1256, 1256,   37,  151, 1026,    9,    1,  131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676,    1, 3273,  336, 1585,  155,  861,  997,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1848,  494, 1335,   37,  636, 1336,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  162, 2072,    1, 2608, 2146,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2606, 1205,  297, 2189, 1662, 3049,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3268,  619,    1,   81,    1,  665, 1590,   32, 2340,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  565,  334, 2859,    1, 2955,  506,   30, 1366,  332, 1023, 1515,\n",
      "            1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,  913,    1,   98, 2347, 1482,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1717,    1,  716,  449, 1655,   45,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2967,    1,   37, 1668,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 590, 422, 134,   9, 596,   1, 597, 582,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 181, 574,  37, 365, 615,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3184, 1550,  716,   45, 1011,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  803, 2909,  168,   79,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3352, 2833,  547,  487,    1,   32, 2597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  476,   37, 1343, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  729, 3156,   32, 2003,   32,  395, 1585, 1530,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   64,  799, 2414,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3391, 3045,  774,  193,  998, 3377,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2962,    1,    1,  187, 3115, 2651, 2551,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181,   12, 1762,  698,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  535,    1,    1, 1167, 1089, 1675,  565, 2970,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  256, 2474,  841,    1,   37,    1, 1102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018,    1,  854, 2153,   37,  907,   86,    1,   32,  163,    1,\n",
      "           12,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  117,  267, 1688, 2768, 1977, 1514,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2077,    1,  971, 1413,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  382, 2054,  533,    1,  602,   12, 1188,    9,  996, 1031,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1033, 2211,    1,    1,  187, 2153, 1980,   37,    1,  220,    7,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652, 1288,    1, 1876,    9,    1, 1718, 2973, 1764,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 2439,  176,  163,    1,   12,    1, 2735,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,    1,  166,  855,   32, 1029, 1743,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3336, 1258,    1, 3076,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  705, 1458, 1285, 3234,   32, 2799,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3028, 1614, 2995,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  875, 2039,  297, 2862,  966,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056,  388, 3109,   32,  463, 2170, 2375,  927,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2895,    1,   32, 1185,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  427,    1,  384, 2857,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,   12,    1, 2120,    1,  176,    1, 2630,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  215, 1107,  293, 1236,  912,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   42,  149,  297,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3303, 1293, 2017,  187,    1, 1654,  453,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,  105, 1328, 1641,   37,  542,    1, 1468,  787,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1178, 1179, 1831,  920, 1075,    1,  168,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247, 1702, 2734,  734,  591,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2275,  884,  389,    1, 1263,   37,  903,    1, 1417,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2941, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2236,  415, 1408,   98,    1,   39,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3160,  162,  537,   32, 2162,   45, 1147,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3058,    1, 2426, 1086,  187, 2548, 1421,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1414, 1822, 1604,    1,   32,  463,  555, 2504,  446,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  384, 3113,   98,  531,  741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 2571, 1009, 3405,  113,  365,   46,   98,  557,  540,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,    1,  367,   15,  570,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2335,   39,   45,    1, 1046,    1, 1281,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  220,  786, 2482,    1,    1,    1, 3304,  361,  931,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  504,   98,  424,  865,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2602,    1,  729,   98,  166,  605,  222,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2145,   37,  194,    1, 1441,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2206, 2435,  153,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3322,  565, 1542,    1, 1452, 1232, 2110, 2385,  612,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3358,   12, 1983, 2078, 2562,   37, 2708,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,   39,   45,    1, 2630,  220,    1, 1987,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3333,    1, 1684,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2489,   85,  968,   12, 2712,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 2097, 3391,    1,    1, 2292,   32,  403,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2401,   32,  433,  102,   61, 1103,  361,    1,  297,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  104,  585, 1980,   37,    1,  691,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785, 2044, 1760,    1, 1656, 1778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 2576, 2410,   45, 1537,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1009,  146,    9, 1945,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3115,  619,    1,   98,   72, 2622,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2932, 1604,   98, 2984,  934,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1289,    1,  365,    4,   32, 1332,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2050,  187,  367, 2620, 1464,   37,    1,  845,  237, 1278,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1024,  140,    1,  364,  682,   32, 1684, 1948,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   93,   61, 1065,   98, 2521,    9,    1,  458,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1940, 1343,  208,    9, 1333,  176,  671,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,   12,    1, 2545,    1,  859,  411,  865,   37,  232,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1,  326,    1,  837,    1, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3264,   21, 1918,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,    1, 3154,  191,   56,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,  418,   32,   72,  401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  108, 3140,    1,  864,  444,    1,   32,  531,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,  166, 1009,  105,  410,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  942,   28,   98,  957,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  433, 2424, 1994, 2650,  302,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043,  640, 1034,  181,  340,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   42,  149,  361,  422,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2452,  517,    1, 1465,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3013, 3268,  872,  420, 1169,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   98, 3240,  204,   61,   79,    7,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  766,   37,  815,    1,    1,   32,  365, 1825,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,   37, 1343,    1,    1, 3177,  361, 3215,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  903,    1,  182,    1, 2611, 1149,  469,   37,  335,  477,   37,\n",
      "         2038,   12,    1,   98,  449,   74,  963, 2122,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2903,  166, 2615,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2948, 2593,  248,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3335, 1004, 3092, 1048,   28,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3284,   39,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2487, 2855,  815,    1,   32, 1708,  378,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 233, 476, 657, 475, 220, 673, 774, 428,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 199, 421, 133,  44,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  613,   37, 1027,  116,   93,    1,  275, 2153,  774,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994,  957,  477,    1, 1853,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 790,  57, 198,   1, 937,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 610,   9,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 212,  37, 151,   1,  32,   1, 182, 132,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 666, 697,  37,   1,   1,  32, 584,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  691,    1,   32,    1, 1559,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1461,  614,   28,    1,  202,    1, 1464,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087,  292, 1228,   37, 1121, 1465,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2828,  464,  996,   46,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1,  236,  237,  220, 1402,    1, 2524,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  848,  872,   28,   98, 2723, 2724, 2657,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,    1,  590,    1, 1252,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 1380,  636,   98, 3149, 2751,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1264,  341,    1,    1, 1746, 2699,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1138,    1,    1, 2017,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3118, 2751,  774, 1021,  132,  449,    1,    1, 2248,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3029, 2981,    1,  220, 1663, 1821, 2190,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  136,    1,   28,    1,  280,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785,    1,  776,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  575, 1195, 1862, 1278,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  335,   98, 1158,   12, 2102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  439,  526,  116,  159,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196,  176,  612,  613,  170, 1812,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  551,    1,  581, 1023, 1660,   37,  105,   59,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3039, 3040, 1089, 1090,  949,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,  376,  636,   98,  116,   19, 1108,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2077,    1,   59,   32, 1951,  250,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  548,  199,   32, 1821,    1,    1,   61,   98, 1324,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  297,    1, 2282,  798,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  709, 1304,  232,  190, 1335,  514,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  582,   45,  393,   12, 2441,  992,   85,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1023,   45,  111,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1340, 1194,  894,   52,  105, 1585,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 1977,   37,  544,  220, 2349, 2167,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2077,  571,   37,  197,    1,  716,  276,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  190,  422,    1,   79,   98, 3327,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2646, 1345,    1, 1010, 2024,  973,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  105,    7,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878, 2176, 2506,   45, 2608, 2607,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2388, 1022,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1744, 2265,    1, 1009,   12, 2113,  881,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1149, 2098,  756,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  315,   37, 1706,   32, 2103,  617,  506,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2953,    1,    1,    1, 1533,    1,  163,    1,   12,    1,  506,\n",
      "          782,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1452,  176, 2087,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3258,   45,  507, 1064, 1477, 1990, 3275, 2294,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   36, 3071, 2162, 1950, 1784,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178, 1231,   32, 1227, 1778,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  338,  384, 1653,  548, 2249,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707,    1,  531,   98, 2521,    9,    1,  811,    1, 2396,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,   37, 1343,    1,    1,   39,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  914,   12,    1,   45,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 2185,  453, 1560,   98, 3369,    1,  952, 1428, 1527, 1232,\n",
      "         2024,  132,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  267,  460,  190, 1155, 2439, 1167,  590,  786,    1,  967,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361,  744, 2364,   98, 1718, 2718,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390,    1, 1746,   46,  220, 1485,  587,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1013,   61,   98,    9,  593,   12, 2084,    1, 3001,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  365, 1996, 1713,   28,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 1976,   32, 1617,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,    1,   98,  800,  425,  426,  570,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3221,   61,  166,  449,   37,    1,   39, 2689, 1717,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  870,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,  449, 1023,  207,  354,   98,    1,   15,    1,  242,\n",
      "          408,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1180,    1,  517,    1,  269,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3306,  476,   37,  288, 1018,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  680,  166,    1,   45,    1, 1340,  571,  754,   37, 1198,  247,\n",
      "         1239, 2671,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2945,    1, 2293, 2261,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 2224, 1579,  797,  469,    9,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  183, 2247,   57,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1894,  297,  403, 1447,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2163,  700,  476,  810,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1883,   37,  151,   13,   45, 1117, 1525, 2759, 2043,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1802, 1603,  256,  529,   37, 1801,  395,   12,    1,   39,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,    1, 2094,  626,   37,  105, 2539,    1,   45,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   68, 1276, 1315,  104,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962,    1,  640, 1194, 2907,    1, 1426,    1,    9,  931,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  146,    9,   64,  591,  341, 1519,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  256,  365,    1,   37, 2209,   45, 2500, 3020,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  683,  272,   39,  220, 3287,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1674, 2965,    1, 2437,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3209,  130,    1,    1,  361, 3236,  498,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1829,    1,    7,   32,  863,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2966,   45,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1887, 2048,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  275,  681,    1, 2157,   37, 1994, 2086,  302,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715,  458,  733,    1,  998,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   81,   37,  627,    1, 1094, 2612,    1,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   59,   61,  415,  786,   95, 2017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3181,  606,    1, 2349,    1, 3306,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2159,    1, 2695,    1,    1, 2581,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  331,    1,    1,    9, 1585, 2372,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1061, 3394, 2416, 1018,  854, 1696,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3011, 1034,   32,  231,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  513,    9,  764,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  524,  525,   15,   71,   32,  645, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  952, 2649, 1527,  384,  592,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1537, 2924,  489,   39,   45, 1815,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169, 2094,   98,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  587, 2253,   37, 2035,  430,  477,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283, 2246, 2701, 1863,    1,    1,  928,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3337,    1, 2594,   32, 1477, 1990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3401,  288,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  742,  325,  388, 2448,  386,  225,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3140,    1, 1430,  360, 1407, 2081,   45, 2471,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  179, 2806,   80,   37,    1,  553, 1842,  669,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2985,  864,   61, 1809,  365, 3162,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1614,    1, 1228,    1,  459,   28,    1,  361,   20,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  102,  701,  187,   25,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1075,  844,    1,    1,   32,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  861, 1906,    1,   32, 2170,    1, 1702, 3369, 2024,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,   69,  102,    1,   98,  197, 1936,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  375, 2903,  166,  104,   32, 1987,  199,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1470,   45,    1,   29, 1308,   60,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115, 2125, 1664,    1, 2347,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  121,    1, 3071, 2372,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1205,    9,  912, 2285,   32,   91,    1,   32,  166,  215,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  241,    1,  142, 1702,  218,   37,  365,  119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  499,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1092, 1066,  187,  654, 1458, 2723, 2724,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1018,    1,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  668, 1701,  664,   32,  400,  444,  912, 2285, 2515,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3022,    1,   61, 2970,    1, 1121,  361,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2764,    1, 1877,   37,   77, 1345,  163,    1,   12,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1695, 2244, 2423,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1443,  260,   28,   37,  335,   98, 1230,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3309,   37, 3328,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  596,    1,   32, 1117, 2208,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3203,    1,  729,   32,  913,    1,  403, 1447,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  557,  540,    1,    1,  804,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,  321,  612,  804,   39,   69, 1069,    6,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1432,    1,    1,  187,  475, 1213,   45, 1266,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,   12, 1861, 2450,   37,    1,    9,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,   12, 3356,  948,   37,  907, 2646, 2024,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  292, 3042,  161,   37,  856, 2819,    1, 2574,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  447, 2450, 1147, 3345,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2310, 1596, 1509,  454,   45, 1148, 3312,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  476,  590, 1793, 2362,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2235, 2095,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1117,  442,  244,   71,    1,  528,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  539, 2838,  254,    1, 1231,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  609,   37, 1642,  257,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260, 2602,    9,    1,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3358,   12, 2162, 1268, 2009,    9, 2024,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1,    1,  293, 1511,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  477, 3391,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3241,    1,   81,   98,  166, 2347, 1638,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1245,   61,   98,    1,    1,    1,    1,  167,   71,  191,  105,\n",
      "            1,  191,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  760,  166, 1140,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  273, 1554, 3132,  220, 2087,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1345, 1316,  531, 2414,  388,  763,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1613,    1, 1615, 1775,  202, 1355, 2449,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2656,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  105, 1173,  176, 3194, 3195,    1, 1794,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,  580,   69, 1069, 2199,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,   32,    1,    1, 2392,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  572,  156,  245,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  531, 1044,  453, 1509,  361,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1215,  166, 3024,    1, 2085, 2025, 2604, 3022,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  420, 3117,  599,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65, 1500, 1184,  347,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3262, 1831,  792,    1,  792,  548,    1,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1326,    1,   32,  853,  538,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,   37,    1, 2759, 2340,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  169,    1,  702, 1210,   37, 1140,    1,  582, 2116, 1064,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2746, 2825,   28,  388,  365, 2911,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  200,    1,  361, 2686, 2687,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3199, 1103,    1, 1167,  204,  967,  590, 1333,  176, 1684,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  365, 2866,  220, 1778,  535, 1863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3342,    1,  297, 2282,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1914,    1,  344,    1, 1229,   37,    1,  126,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3132,  726,  744,   28, 2522,  220, 3216,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  719,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3118, 2696, 1898,    1,  722,  220, 2751,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,   12,   83,  387,    1,  187, 1351,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,  829,  132,  155,   26,  756, 1574,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  268,    1,   32, 1092,  524,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  335,   98, 2348,    1, 2351, 2973, 1764,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2880,    1,    1,   98,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1053,   37,    1,  611, 1145,    1,    1,    9, 1228,  361,  116,\n",
      "         2086,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1914,   45, 1739, 3186,    8,  516,  548,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  187,  163,    1,   12,    1,  801,   32, 3391,    1,  365, 1345,\n",
      "         2897,   32, 1850,  531,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437, 1396, 1983,  293,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  294, 3370,  952,    1, 1175,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2836,  686, 3226, 1421, 1056, 2308,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  455, 1518,  381,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  192,    1,    1, 1188,   37,    1, 1607,  414,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1034,  115,   25,   51,  186, 1232,   69,  980,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  475, 2326,   39,  365,    1,   32, 1013,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2122,  231,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2893, 2237,   37,  976,   37,    1,  528,    1, 2429,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3327, 1321,  384,  584,    1, 1013,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2114,    1, 1281,   61,  600, 1280,  443, 1016, 1234,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2504, 2292,  115,   45,    7,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  208,    1, 1327,   37, 2341, 2613,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2006,  274,    1, 2007,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,    1,  152,  734,  269,  693,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  387,   26, 1039, 1665,    1, 2085,    1, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1290,  396, 1269,    1,    1,   93, 1071,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3292,    1,  140,    1,    1,  548, 1056,  356, 3106,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187, 2529,    1, 2757,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3175,    1,  105,   12,   77,  166, 1224,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3402, 3408, 1988,   32, 1727,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1249,    1, 3257, 1141, 1632,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,  166,  862,  159,   45,    1, 1150,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  544,  334,    1,  388, 1084,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 1821,    1,    1,  666,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  424, 2306,   32, 1123,    9,   86,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597, 3127, 3082,  366, 3384,  437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  150,  200,  889,  176,    1, 1929,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2844,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  335,  105, 1318,  357,    1,   45, 2588,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  199,   45,    1,    1,    1,  251,    1, 1886,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2158,   45, 2121, 3134, 1863,    1,    1, 2356,   45,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3225,  114,    1,  548,   56, 1890,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  115,   32,    1,   12,  258,  890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1733,    1,    1, 1568, 1669,    1,   37,  907,  220, 2169,  649,\n",
      "            1,   98,  968,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,  759,  401, 3179,   45,    1, 3282,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2353,    1,  115,    9, 2730, 1942, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  636, 1226,  187, 1147,   68,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1,   32,    1,    1, 2800,  400,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  971,   91,   51, 1865,  365,  669,    1,  221,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 1009, 1921,   32, 2018,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2292, 1258,   32, 3155,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,   37, 1421,  365, 1545,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  919,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789, 1949,    1,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1918, 2903, 3115,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  547, 1530,    1, 2249,  548,  114,   32,  228,  649,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  388, 2572,   32,   98,  707, 3339, 2292,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162, 1950,  384,    1,   64,   61, 1270,   32, 3349,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1530,    1, 1941,   32,  557,  540,   22, 2262,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1159, 1089,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  466,    1,    9, 2048,  167,   52,   32,  637,   45, 2888,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1883, 1380,    1, 2589,   98,  365,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3144,   12,    1, 1484,    9,   62,   98,    1,   45, 1002,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  952,  131,   32,  567, 1527,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3230, 1454, 2347, 3009,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  884,    1,  191,   64,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,  147, 1297,  217, 2000,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3061, 3343, 2161,  590, 1488,   79, 2295, 2302,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094, 2414, 3006,   32, 2154, 3339, 2731,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3228, 3229, 1544,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  424,  889,   37,   52,    1,  763,  915,  356,   12,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 1466,  288,    9, 2281,    1,  328,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   33,   61,   32,  166, 1525,    1,  202, 2267,   98,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1,  395, 2153,  498,   37, 1953,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  812,  179,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3207,    1,    1, 1494,   81,  384, 1194,  913,   37,  726,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  497,    1,   32,    1,   45,  593,   12, 1568,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2576,  551,    1,  936,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  160, 1278,  831,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1654, 3001,    1,    1, 1758,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2046,  361,  104,  332, 2376, 2223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2967,   12,    1,    1,  408,  166, 1497,  105, 1090,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  458,   45,  507,  197,   28,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1918,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3386,  312,  966,    1, 2007,  424, 1034,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,   37,  151,  552,    1,    9,  600,   59,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3020,  776, 1576,  877, 2069,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428, 3053,  267, 1821, 2978, 2219,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  455, 1579,  788,   45,  622, 1563,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  511,  275,  140, 2613,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777,  108,   45,  861, 2432,    1,    9, 1718, 2264,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  267,  978, 2953, 1631,  846,  119,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  195,  278,  469, 1908,  114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1584,  166, 3101,  249, 2303,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  867,  292, 2039,    1,  365,  552,  552, 1345, 1228,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2573, 1958,  249,    9, 2527,  164,  267,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 565,   1, 658,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  60,   1,   1,  66, 383, 981,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  455,   16,    1,  460,   12,  810, 1729,  638,  361,  803,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32,  241,  531, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   38,  460,   37, 1185,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,    1,   12,    1,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3277, 2963,  176,  896,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  137,    1,   37,  365,    1,   32,    1,  625,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  107,   37,  125,  109,   32,  142,   37,  288,  636,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2832, 1173,  115,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  200,  105,    1,   45, 2687,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1417,    1,  717,    1,  317, 1807,   37,  606,    1,\n",
      "         2576,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2355, 1013,    1, 2381,    1,  219,  616,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1647,   98,  317, 1839,  187,  651,   46,  439,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   20,  190,  726,  104,   22,    1,  132,   32,  166,  439,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1191,  572,  354,  703,    1,  515,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051,  292, 1331,    1,   17,    1,  999, 2639,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1238, 2361,    1,    1,  674,  210,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  249,  190, 1188,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176, 1072,  104,    1,  885, 2149, 1031,   45,  767,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  108,    1, 2400, 2264,   45,    1,  629,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   37, 1876, 3014,    9, 1718,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  574, 1132, 1083,  987,    1, 1722,    1,  267,  496,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3194, 3195,  140,  129, 3154,   98, 1780, 2058,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  146,  147,  695,    1,  912, 2285,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1687, 1022,    1, 3008,    1,   85,    1, 2700,  417, 2393,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2954,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1751,  361,    1, 1018,    1,   32,  453,  248,  917,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1090,   74, 2677, 1090,  199,  446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3211, 1493, 2250,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2279,   61,    1,   37, 2449,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1873,  437,    1,  365,  777, 1085, 1499,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  228, 2572,    1, 2753,  583,  187, 2751, 2596,    1,   32,  854,\n",
      "           12,    1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401, 1528,  191,  187, 2885,    1,  176,  654,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  199,  421,  361, 1200, 2000,  142,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1861, 1648,   37,  100,   98, 3025,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  259,  967,    1, 2382,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1159, 1411, 1385,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,    1,    4, 1908,  388,  763,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2673, 1806,   46, 1822,  193,  915, 1176, 1183,  864,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2680,  313,  176,  803,  681,  220, 1117, 1525, 1108,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  463, 1447,   34,  403,  861,  548,    1,  125,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1725,  738,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094, 1086, 3339, 2831, 2731,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  108,   45, 2416, 1665,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,    1,   45,    1, 1435,  719,   37,   52,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1844, 1264,   32, 2603, 2734,  736,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  166, 1981,  406,   45, 2309,    9, 1744, 1185,\n",
      "         2837,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  764, 2715,    1,    1,  506,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,   12,  442, 3224,    1,    1,   37, 3209,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260, 2497, 3209,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2932,  774,    1, 1080,    1,    1,   45,    1, 2620,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,    1, 2511,  172,   50,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  882,   37, 1270, 1427,  395,  704,  705, 1346,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1191,  200, 2869,  791, 1108,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1695,    1,   32,    1, 2596,  722,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299, 2424, 2507, 2968,    1,  302,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1554,  105, 2840, 2072,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,  136,   82, 1231,  220,  133,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2700, 1937,  753, 1010,    1,    1,  361,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  729,   32,   46,  220,  148,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1110,   37,   77,    1,  528,  307,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1090, 1829, 2206,    1,  176, 2295,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2658, 1040,    1,    9, 1691,    1, 1944,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  361, 3354, 1634,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3186, 2565, 1484,   98,  542,   37,   81,    1,  667,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1024,    1, 1415,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2562, 2316, 1204, 1175,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,  183, 3001,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  403, 3165,    1,  297,    1, 1159,  963, 2147,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1433,  864,  476,  453,  248, 2673,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1296,   28,    1,    1, 1159,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 3263,   85, 3241,    1, 3206,  688, 2475,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   35,  353,  119,  197,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  776, 1086,  220,    1, 2552,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3221, 2689, 1717,    1,  166, 2069,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,   28, 1658, 1545, 2373,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  296, 1867,   32,   95, 1273,  618,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089,   30,    1,   45, 1855, 3102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  396, 1994, 2693,  449,  220,  365, 2403,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  334, 2556,  166, 1509,    1,  334,  416,  166, 1509,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 2640, 2405,   37, 1821, 2190,  424, 1034,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1710,   52,    1,   37, 3115,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   83,  992,   79,  654,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596, 1793, 3037,  162,  121,   12,  562,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3383,   12, 3006,  856,    1,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275, 1070,    1,    9,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3152,    1, 3263,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  295,  353,  183,  390,   32,  572,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 3072,    1, 2724,    1, 2699,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2872,  608, 2807,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2490, 1042, 2048,   45, 1603,    1,   98, 3348,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2137,  135, 2936,  493,    1,  548,  304,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3175, 2935, 2764,  539, 1684,  220,  726,  297, 2916,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,   69,  408,  686,  388,  295,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1380, 1412,  844,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3233, 1421,    1,   37,  547,  356,    1,   59,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1796, 2730,    1,   61,  610,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3219, 1589, 2317,  786, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,  531,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  846,  116,    1,  612,   52, 1961,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2374,    1,    1,  724,   98,  531,  443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189, 1118, 2092,  932, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3209,    1, 2805,    1,  307,  698,  444,    1,  220,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1550, 2330, 1841, 1559,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   28,  187,   69, 1042,  995,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  375,  162,   37, 2192,    1, 1028,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3076,  501,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,   37,   26,  409, 1116,  656,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1933,  972,   37,  690, 1932,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1065, 1190,  796,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  221,  417,  187,   69,  102,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  753,    9,  365, 1015,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  534,   37,  335,    1,   39,   45,    1,   32,  331,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219, 1619,  458,   37,    1,  347,  187,  408,  120,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  490,   37,    1,  105,  106,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1403,  116,   37, 1537,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3103, 1421,    1, 3310,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   73,  943,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  311,  162,    1,  297, 1230, 1708,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398, 1360,  612,    1, 2862,  149,  444,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1661,  551,  331,  353,    1,  572,  244,    1,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1497,  565, 1284,   37, 1847,  590,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  193,    1,    1, 2845,  166,  873,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3364,  267,  204, 1360,  612,    1, 2708, 3006,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1189,  210,  193, 1018, 1954, 1665,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118,   32, 1803,    1,  267, 1428,  420,    1,   59, 1229,   32,\n",
      "         1188,   45, 1527,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  228, 3141, 2308, 1810, 1231,  220, 1995,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1180,   28,    1,   69,  720,    1,  191,  395,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   69, 1276, 1315,  187,  531, 2014,  418,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2212,  861,   37,   71,    1,  419,    1,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1927, 2431,  267,  104, 1414,    1, 1159,    1,   32, 3360,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2357,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  602,    1,  191,  163,    1,   12,    1,  315,   37, 1418, 2924,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  359,   51,   52,   27,  138, 1259,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  726,  105,  916,   37, 2346,   59, 1405,  302,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2310, 2012,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1227,    1, 1377, 2058,   79,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,  686,  191,  800, 1220,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  449, 1405, 2281,  400,  288,    9,  776,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  561,  221,   98,  613,  777,    1,  617,  618,   32,   95,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  806,   16, 2091,    1,   32,  691,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1786,  951,    1,  735, 1542,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   39,   37, 1814,  342, 1512,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144,   12,    1,   37, 1844, 1114,   32,    1,  741,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2175, 1371,   37, 1658,    1,  845,    1,  844,  618,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,    1,  697,    9,   93, 1232,  535, 1506,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1663,  716,  449,  401,  174,  720,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942, 2188,  469,   37,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2703, 2572,   32, 1260,   32,  531,   12, 3383,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1417,  675,  140,   24,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1181,   30,  617,  259,  220, 2177,  988, 1027,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  744, 2915,    9,    1,  384,  166,  863, 2107,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,    1,    1,  220,  349,   45,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  335,    1,  441, 2274,   98, 1412,  754,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  415,  416,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2157,    1,  953, 1159,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  449, 3081,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974,   12,  270,  967,  166,  293, 1769,   37, 2833,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2807,    1, 3103,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3166, 2682,  166, 2009,   98,  182,    1, 1417,    1,   12,  183,\n",
      "          404, 3135,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  758, 1774,   39, 1867,   45,    1,  698,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,  166,  593, 3154,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158,   12,    1, 2334,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 3365,  729, 2793,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3377,  513,    9, 1922, 1204,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,   12,  197,   85,   98,  417,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,  361, 1678,   37, 1604,   98,   29,  656,  469,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  892,   12,  112,  550,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  224, 2937,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2911,   16, 1444, 1210,  388,  774,   32,   93,    8, 1160,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2142,   12, 1024, 1765,  810,  199,    1,    1, 1277,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1740,  774, 2831,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1170,  159,  670,   98,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,    1,    9,  333,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  247, 3077,  361, 2437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2396, 1082, 1663, 2532,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2087, 2614, 2372,   45, 2935,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1934,  622,    1, 1156,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  422,    1,    1,  388,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2384,    1, 2186, 1230,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,    1, 1690,  525,   15,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  166,  931,    9, 1307,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  990, 1536,  149,  444, 1791, 2650,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409, 1285,  365,    1,   32, 1412, 2913,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   71,   32,   69,   25, 1825,  102,   85,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1002, 2275,    1,   10,   98,  129,  861,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  885, 3323,    1,  583,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 1741,    1,  275,    1, 2998,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1, 1237, 2701, 2158,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2957, 2744,   56,  454,    1,    1, 1778, 2232,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1203,  167,  686,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129,  458,  162,  607, 1184,   32, 1973,  217,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  447, 1111, 1010,  753, 3365,  190,   52, 1683,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1415,   37, 2093, 1183,  521,  443,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  845, 1625,    9, 2984,   12, 2820,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796,   25,   71,    9,  105, 1913,   74,    1,    1,    1,    1,\n",
      "         1758,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2476,   32, 3376, 2506,  548, 2950,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2628, 2696, 1281, 2970,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2448,  386, 2800, 1218, 1542,    9, 1684,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   12, 2877, 1625,   37, 1911, 3391, 1995, 2431,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  179,  361,  780, 1421,  517, 1074,  630,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  381,   12,  597, 1429,  582,   51, 1046,  422,  522,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3324,  884,  878, 1684,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3064,  162,   79,   37, 1894,  698,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   12,  844,  315,  335, 1134,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2881,  387,    1,   98, 3018, 1757,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1, 1713,  620, 2208,   43,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  716,  244,   28,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116,    1,    1,  105,    1,   37,    1,  356, 1856,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  251,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  903,    1, 1101, 1234, 1863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2192, 1658,  754,  105, 2895,    9, 2695,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786, 1178,   12, 3078,  167,   52,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  794, 1995,   98, 2774, 2827, 1147, 1223,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 3168, 1713,    1,   32,    1,  401, 3179,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  602,  361, 1186, 1152,  864,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1430,   12,    1,  191,    1,  166, 3341,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3056,    1,  884,   98,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129, 2523, 2483, 1990,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  112,   37,  112,  111,  117, 1074,  794,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  751,    1, 2308,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  219,   25,   71,  187,   69,  953,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3404, 1670, 3358,    1,   32,  539,  458,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2960,   32,  531, 2414,    1, 2803,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492, 3392,    1,    1,  191,  114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  786,   95,  384,  331, 2223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115, 2935,    1,  404,    1, 1003,  242,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1773, 1542,   37,  335,   98,  848,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,   37, 2579,  854,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1285, 1823,   37,  759,    1, 3179,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  744,   28, 3204, 1286,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3327,   37,  335,  297,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3287,  688,    1, 3116, 3263,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  321,    9,  197, 2176, 2709, 1018,    1, 1463,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273,    1, 2175, 1371,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1340, 1713,    1,    1,    1,   32, 1218,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  274, 2629,    1,    1,    1,    1,    1,   12,  354,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  409, 1285,  166,  645,   32,  754,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  171,  681,  321,  142,    9,   49, 1541,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2226,  331,  707,   37,  184,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  947, 1260, 3118, 2649, 2791,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1,  394,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2978, 2798,  884,  656, 1267,    1,  176,  915,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1011,  293,  696, 2476,    1,  658,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1117,    1, 2165,  686,  220,    1, 1450,    1,    1, 2429,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2347,   32,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2497,  967,    1,  504,  385,   14,   15,    1, 1672,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  580,    1, 1757,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1043,  338,  191,    1,    1,  185,   85,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  374,  375,   37,  138,   59,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  531,   37, 1079,  864,    1, 2707,    9, 2735,  764,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485, 1178,   51,  606, 1846, 2644, 3102,    1, 2572,   32,  531,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1228, 1669,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  183, 1429,  217,  420, 1042,   32,  737,  197,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  310,   25,  455, 1784,    1, 1572,  191,    1,  395, 1273,  801,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1,  166, 1411, 2273,   32, 2943, 2568,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  224, 2355,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1306, 1640,  140,  593,    1, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   12, 1447,    1, 1377,   32, 3207, 3126, 1559,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102, 1348,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  185,    1,  217,  817,   98, 1043,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1044, 1933,   37,  467,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2438,   98, 3190, 1408,    1, 2800,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 2587, 2634, 1825,   32, 2168,    1, 2759,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   81,   37,   36,    1, 2325,    1, 2819,   37,  365,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 1994,    1, 2292,  407,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3369,    1,  716,  105, 2282,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,    1, 1081, 1982,  750, 1259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2749,   39,    1, 1086,    1, 1844,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  729,  765,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,  484,  548, 3208, 2322,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3233,    1, 1844,  448,   32,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  200, 1663,  517,  617,  259,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   82,    1, 1183,    1,  469,   37,  721,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   98, 1018,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  920,    1, 2763,    1, 1167, 2654,  229,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1408,    1,  707,  528,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1, 1022,    1,    1,  365, 1546,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3140,  967,  590,  469,   37,  489, 2924,  384, 1430, 1428,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2817, 2856,  388,  763,  249,   32, 3349,    1, 1060, 1827,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  487, 1109,   37,  151,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718, 2146,  682,  183, 2225,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2492,   34,  223, 2135,  669,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   76,   37,    1,  148,  647,  151,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  108,   45,  417,  156,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  305,    1,  417,    1,   29,   32, 1881,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 2543,   14,  525, 2436,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,   12, 1412,   15,  157,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3143,  726,  914,   12,  449,  922,  427,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   32, 2786, 3137,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  352,   51,    1,    1,   50,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  115,   45,  129, 1002,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962,    1,   12, 2907, 1408, 3117,   32, 3235,    1,  631,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171,   45,    1, 1340,   47, 1103,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1592, 2714,    1,  202, 1820,    1,   10,  651,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2997,    1,    1,  191,  166, 2114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2960,    1,  176,    1, 2244,  669,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  851,    1,   32, 2527,  164, 2716,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  147,   51, 1048,  166,  454,    9, 1507, 1508,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3267,    1,    1,   37,  726, 1742,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1933,  467,  167, 1737,    1,    1, 2547,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12,  618,  565,  166,    1,  361,  606,  166,    1,  244,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3264,  939,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374, 1260, 2414, 3101, 3160,    1, 1086,    1,   32, 3339, 2292,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2180,    1,    1,  664, 1818,  147, 1377,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  621,  721,  729,    1,  365,  296,  880,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1963,    1,  548,  985,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  744,    1,  142,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3247,  429,  885,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,    1, 2244,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3152,  971,   21,    1, 2967,   37, 1334,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  220,  730, 1571,  214,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  573,  574,  387,    1,  131,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1050,  458, 1360,  612,   52,  665,   79,  191,  413, 1503,  142,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  160, 1161, 1276, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  756,  757,    1,  929,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1443,    1, 1548,   96,  197,   32,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,  647,   82,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2442, 2911,    1, 1650,   98, 2103,  617, 1116,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465,   13,   32, 1018,    1,  593,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2868,    1, 1750, 3148, 2669,   32, 3118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  517,    1,  792,    1, 1064,  792,   32,    1,    1,   69,  387,\n",
      "         1424,   32,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1178,  782,    1, 2924, 2496,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  557,  540, 1583,  475, 2526,  187, 2703, 2816,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2692, 2975, 1090,    1,  297,  166,  207,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,   37,  123,  896, 1097,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2745,    1,  115,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3378,  776, 1337, 3133,    1,   37,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  733,  331,   48,   32, 1440,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   28,   32, 1125,    1,  115,   45, 1209,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2028, 2188, 2763,  220,  219,  497,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,   32,  166,    1,  297,    1,  625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  236,  237, 1268,  242,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  936,    1, 1892,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  479,   37,  693, 1170,   98,  388,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967,    1, 1857,    1,  894,   52, 1542,    9,    1, 2172,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  141,   48,   32, 2507, 1611,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3097,  140, 2161,   12, 3208,  671,    1,  163,    1,   12,    1,\n",
      "          884, 2505,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 1571,  361,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596,  616,   91,  159,  245,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  539,    1, 2013,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  721,    1, 2098,   28,  166,  669,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  306,  353,  197,    1,  159,  245,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,   39,   37,   26,  885,    1, 2009,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  176, 1604,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066,   12,   81,  187,  311,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1537, 1228, 2401,   98, 1171,    1,  293,  582,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   56,  403, 3165,   64,  963, 2147,   32, 2592,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  273,   12,  183, 1272,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1, 2117,   12,    1,   32,    1,    9,   46,\n",
      "           98,  557,  540, 1512,  101,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 105,   1, 458,  42, 927,  45,  15, 378,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  60,   1, 444,  94, 202,  79, 687,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2700, 1835, 1805,    1, 1294,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  124, 1103,    1,    9, 1104,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1409,  967,  122,  600, 2776,   45, 2971,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,    1,    1,  667,    1,    1,  176,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  773, 2866,   32,   37,    1,  688,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  609,    1,  384,  236,  237,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  915,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1384,    1,    1,  231, 1600,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2751,    1, 1056, 2909,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2589,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2604, 1656, 2514, 2015, 1618,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 3006,    1,  294,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 678, 182,   1,   1,  12, 197,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  81,   9, 388,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3173,    1, 2779,  221, 1159, 2592, 2033,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  218, 1121,   37,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  678, 2158,  571,  187, 2563,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2754, 2548, 2572,   32,  531,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   96,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  890, 1822,  168,  115,  187,  205,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  698,   28,  251,  340, 1021,  466,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2781,  187, 2427,  184,  449,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1405,    1,  373,   32,  132,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  837,  862,    1, 1281,  190, 1251, 1925, 1583, 2048,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 829,  37, 138,   1, 830,  59,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1,   1,  79,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2053, 2055,  120,    1,  419,    1,   32, 1352,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   71,  187,   69,  338,  384,  119,  845,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1081, 1057,   98, 1461,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1028,  638,    1,    1, 2795,    1,   85,   37, 2948,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2931,  625, 1908,    1, 2165,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1, 2176, 2506,   45, 2608, 2607,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035,  513,    9,  822, 1527,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1177, 1910,  388,  763, 1530,   32, 2140,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 1530,    1, 2192, 2645,    9, 1515, 2853,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 1216,  487, 2924,   51, 1334,   32,  104,  274,    9,  257,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  437,  182,  311,    1, 1632, 2072,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  186,  444,  900,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 1622,  474, 1974,    1,  477,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,  967,    1,  453, 1557,   37,  621,    1,  170,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2495,    1,   81,   37,  754,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 1090,  933, 2015,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2883, 1458,   79,  798,   10, 1924,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1675,  700,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1301,  501,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280,    1,   66,  191,    1,  331,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428,  288,   37,  741,   98, 3339, 3146,  187, 2868, 1484,    9,\n",
      "          439,   37, 2262,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1427, 2094,  754,  855,   32, 1194,  187, 3251,   85, 3209,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1663,    1, 2286,   37,  439, 3144, 1512,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3310,  398,    1,    1, 2530,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   60, 1308,   37,  365,    1,  340,  951,    1,   94,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,  207,  490,   37,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2569, 1533,  917,  650,    1,   85,  947,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  405,    1,  337,    1, 1090, 1961,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1841,    1,  384,  455, 2164,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,  542,    1, 2102, 1539,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1054,    1, 2449,  105, 2124,   37,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  957, 1713,  756, 1039, 2690,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2733,  251,    1, 1211,  116,  259, 1484,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  170,  408,  686,    1,  485, 1948,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2162,    1,    9, 3343, 3365,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  430, 1583,  267,    1,    1,    1,   32,  393,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 132, 729,  32, 272,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 328,   1, 267, 213,  37,  52,  53,   9, 152,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  695, 1391,  552,  552, 1523,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3303,  361,    1, 1155,    1,    1, 1343, 1401,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,   32,  132,   37,   28, 1633,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1022, 1023,  207,  418,   98,    1,   91,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228, 3226, 1231,   32, 3134, 2811,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1769,   37,  429,   79,    1,   32, 3308, 1990,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2942, 1360,  612,  103,    1,    1,  202,  204,   61,    1,   98,\n",
      "          166,  640,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3269,  288,   37, 1421,  220, 2685,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  908,    1,   98, 1972,  541,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3094,    1,   32, 2835, 2950,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3303,    1,  365,    1,   45, 1204,  220, 1687,    1,  726,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  328,   25,   25, 1473, 1114,  187,   69,  102,  670,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  430,  947, 2856,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1380, 3304,   32, 2792,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1005, 3113,    1,   92,    9,  163,    1,   12,    1, 1477, 1990,\n",
      "          872,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  458,   45,    1,  267, 1126,  193,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  952, 1001,    9,    1, 1580,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  626,  494,  736,  627,   45,  858,  297, 1021,  847,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,  551,  105,    1,    1,  361, 1678,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1030,    1,    1,    1,  449,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3089, 1292, 1401,    1,  810,  507,  872,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3140, 1542,   37, 1195, 3101,   46, 2198, 2915, 1428, 3397,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,  581,  726, 2922,  967,  139,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  187, 2374,    1,   32,    1,  221,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,   79,  420,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1985, 3101,    1,   32, 3339,  622,  178,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,   78,   37, 2122,    9,   69,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 2635,    1,  801,  176,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  755,  744,    1, 1159, 1697, 1013,  218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,   51,   52, 1044,  453,    1,  150,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2984,  782, 1056,  388, 2662,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  205,  170,    1,    1,    1,  765, 1836,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  848,  437,  213,   37,  151,  849,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  288,   37,   26,  417,   98, 2204,  156,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,    1,  764,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3385,  839,   12,    1,  464, 2673,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2868,  952, 2470,  764,   98,  903,    1, 1447,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,    1,  148,  647,  474,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1126,  190,   52, 2213,    9, 2830,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  661,    1,  613, 1017, 3000,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  335,  460,  187,  730,    1, 2226, 2233,   52,  105,    1,  444,\n",
      "         1179,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  547,    1,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1414,  837, 3356,  787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  858,  719,  105,    1,   75,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1319, 2153,  543,   37,   92, 1211,  442,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 2618,   12,    1,  113,  700,   37,  726,    1, 1684,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1547,  418,   98,  301,  783, 1002,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2341,  412,  614, 2229,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,    1,  190,  875,    9, 1977, 2051,  763,    1, 1411,\n",
      "          957,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  954,   57,   16,    1,    1,   93,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2535,   98,    1, 2427,  631,  854,  191, 2202,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  727,   12,    1,    1,  117,    9,    1,    1,  105, 1313,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  711,   82,   37, 1910,  411,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1148,    1,    1,    1,    1,    9,    1,    1,  111,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  750,   66,  187,    7,   32, 3297,    1, 1090,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  978,  769,   79,    1,   12,  552,   28,   98,   69, 2338,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468, 2095, 3060,  205,    1, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2026,    1,  116,  938,  616, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,    1,  220,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1307,  267,  636,    6,  606,  277,   92,  218,  332,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  338,  981,  384,  531,   69,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  597,  391,  288,    9, 1081,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3400,   12, 2322, 1373,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 2982,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110, 1445, 1421,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  583, 1114,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 3382,  213,   37,  439,    1,    1, 1004, 1302,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3176,    1, 1427,   92,  220,    1,   32,  361,    1,   39,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  355,    1,   81,  569,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1659,    1, 1137,   32, 1126,  714,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870,    1,    1, 1658, 2177, 1027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,  506, 1898, 1273,  618,  220,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1855, 3365, 2572,  420,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 442,   1, 190,   1,  10,  32, 942,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 386, 952, 573,   6,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3094, 2572,   32,  531, 2292,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,  162,  105, 2195,   32, 3372,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3052, 1000, 3373,   98, 2073,  851,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3356,  213,   37,  508,   85, 2108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   25,    1, 1340,   71,    1,   69,    1,\n",
      "           60,  245,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2565,    1,  155, 2412,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3311, 2963,  191,    1,   12, 1791,   18,   98,   37, 1404,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,    1, 1841, 2143,   34,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  416,  579,  204,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2082,   23,    1, 3160,  928,   45, 2766,    1,   32, 1656, 2950,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,  716, 1647,   98,  223,    1, 1964,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299, 2424,  131, 1278,  302,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2691,    1, 1044, 1515,  454,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3317,    1, 2741,  565,  680,   97,    1,    1, 1748,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1831, 1454,  425,  426,   12,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  316, 1638,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  331,   37, 2199,  312, 2130, 1512,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,   12, 3054,  167,  759,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2255, 2351,  792, 1228,  361, 2351, 1398,  612,    1, 2444,  792,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1855, 2038, 2682,  715, 1557,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3118, 2024,   46,  288,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2137, 2265, 3372,   12,  881,   45, 2823, 2113,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1622,  477,  288,   37,    1, 1159,  601,   74,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035, 1070,  669,   37, 1330,   32,   98,  822, 1879,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3358, 1229,   37,   52,   98,    1,   45, 2162,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   49,   50,    1,    9,  333,   37,  138,  302,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  437,  267,  998,  365, 3365,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123, 2415,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3209, 2561,    1,   74,   37,   74,  220,    1, 3288,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343,  650, 2055,  105, 2107,  191,    1,    7, 2696,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  288,   37,  439,  176,  915,  220,   71,   45,  166,\n",
      "         2873,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,   20,  710,  610,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  590,  241, 1401,   98, 3393, 3035,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1257,   12,    1,  912,    9,  467,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 2488,    1,   32,    1,    1,  233,  856,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  877,    1,  762,  565,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1117, 2208,   78,    1,    9, 2298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1737, 2475,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2919, 1988,   37, 1413,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826, 1423,   12,  405,    1,  396, 1674,   16,    1,  671,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1447, 1550,    1,   45,  650, 3203,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2076,  387, 1735, 2232,   15,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   26,  756,    1,   51,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   76,  176, 3358,   12,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056, 3375, 1941, 1094,    1,  384, 2708,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  592,  739,   93,   32, 2949,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3298,  571,   37,  247,    1, 1267,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  155,  347,   37,  838,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1550, 2013,  420,   98,    1,   12,  214,  142,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,   46,  439,   32,    1,   98,    1,    8,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,    1,    1, 1277,   61, 1530, 1183, 1824,    1, 1277,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9, 3336,  361, 1130,    1,  242, 2326,  763,  105, 3217,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   45, 1096,    9, 2476,  533,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,    1,  546, 1461,   32, 3339, 3133,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2018, 3109, 3060,   32,  163,    1,   12,    1,    1, 1585,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  361,  359,  474,  759, 1845,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2246, 2041,   37,    1,    1,  590,  454,    1, 2843,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  451,   12,    1,    1,   37,  341,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  667,    1,  640, 1684,    1,   32,    1, 1869,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  121,   37,    1,  861,    1,  588, 2532,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  878, 2142,  171,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1107,  293,   61, 1769,   39, 1412, 1851, 1419,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2161,   12,  593, 1990,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3134,  395,   12, 3202,  884, 1755,   39,   98,  365, 2036,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   71,  187,    4, 1347,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 3343, 1708,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  132,  786,  356, 1851,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1911,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  868, 2723, 1318,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2570,    1, 2709,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  121, 2384, 2095, 3146,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  535,    1,  938,    1,  247,    1,    1,   74,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   37, 1075,  906,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   34, 2895,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  393, 1426,  132,  220,  359,    1,    1, 2240, 2092,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 2170, 1082,   37,    1, 3086, 2548,   12,    1,   32,\n",
      "         3114,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3257,   32, 2033,  187,    1, 2437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3116,  922, 1545, 1426,  915,  220, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3342,   12, 2059, 1231,   32, 2282,  722,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1412,    1, 1421, 1479,  132,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2406, 1874,  342, 2362,    9,  955,  956,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   85,  548,  156,    1,  983, 1306,  236,  237, 1944,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 989,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 267, 590,  37,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3290,  634,   37, 2446,    1, 1458,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  457,    1,    1, 2562,  331,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1489,  864, 2673,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129, 2501,  861,  662, 1008, 1352,  187,  129, 2501,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  447,   12, 2543,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2337, 2936,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2993,  794, 2994,    1, 2995,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2871,    1,    1,   39,  548, 3288,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,  61, 388, 763, 105,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 325,   1, 469,   1, 225, 418, 419,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1095, 2034,   92,  275,   25,  374,  953,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403, 1696,    1, 1478,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1853,  957,  251,    1,   37, 2155,    1,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2384, 2529, 2168,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,   61, 1542,   37,    1,  535, 1863,    9,  342,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  863,  190,  764, 1811,  404, 2024, 1861,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1808,   37, 2243, 2869, 1107, 1863,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1384, 1900,  912,  395,    1, 2118,    1, 1248,  909,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  474,  140, 2069,  432, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2310,  758,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  506, 2990,  254, 1696,   37, 1844,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  986,   59,   32, 1350,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  794, 3155, 2731,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3339, 3006, 2856, 3095,    1,    1, 1321,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 166,   1, 987,  32,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  449,    1, 2800,  581,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  375, 1236,    1,    9,   59,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3253, 1249,    1,  176, 2936, 3329,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1542,   37,  843, 2390,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3298,    1,  187,  461, 2783, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,  952,    1, 1197,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  103, 3370, 3350, 2572,   32, 3360,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  325,    1,    9,   59,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1105,  787,  353,    1,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   89,  952,   37, 1119,  289, 2017,  384,   60,  701,    1,  104,\n",
      "            1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2862,   37,  949,  105,  981,    1, 3080,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3238,    1,  204,   12,   10,  922,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  684, 2541,   21, 2388,   37, 2449,  105,  883,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 3279, 2856,    1,    1,   46,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564, 2179, 2457,   32,  316,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3094,   45, 3043, 3006,    1,   32, 1378,    1, 2625,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,   61,  816,  548,    1,  119,    1,   98,  109, 1057,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,   45,  443,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1911,  861, 2043,  334, 1398,  612, 1188,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1056, 1048,  220, 2335,   37, 1343,  176, 3258,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  176,    1,  288,   37,   26, 1970,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,    1,   37,    1, 2611,    9,  985, 2456,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2504, 1414, 2797,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190,  964,   12, 1021, 1343,  877,  121, 2219,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1110, 2967,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  974,    1,    1,    1,    1, 1444, 1445,    9,  311,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   69, 2405,   28,  115,   45,  529,   25,   29,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129,  922, 2941, 1090, 3210,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  616, 2360, 1720,   65,  190,    1,   98,   67, 1500,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,  504,    1,   45,    1,    1,   32,  105,    1, 1292,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1087,   37,  631,  160, 1539,  220,    1, 1230,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3147, 1877,   37, 1599,  444, 2751,  279,   32, 3114,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1596,   32, 1300,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  526, 2186,  102,  583,    1,    1,  882,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  652,  110,   32, 1891,  593,   37, 2712, 2095,  104,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1244,  469, 1260,   98, 2136,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1498,  506, 1055, 1059,  681,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1993,    1,   32, 1759,  309,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3061, 1000,  388, 1117,  741, 2558,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1786,  908,  196,  176,  612,  613,  132,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  691,  634,  444,  365, 2036,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  647,  951,    1,  148, 1388,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,   28, 1102,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2415,    1, 2489, 1056,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2462,   98,  454,    9, 2615,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1857,    1, 3141,    1,    1,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1094,  108, 3140,  297, 2834,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3052, 1174,    1, 2372,   45, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2964,  837,  829, 2987, 2454,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159,   85, 1010, 1057,  600, 1645, 2054,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,   12, 1117, 2678,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  140, 1604,   98,  553,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3357,  251,   37,    1,  674,   45, 3346,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3271, 2712, 3231,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1423, 2008,  463, 2211,   32,    1,    1, 2678,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066,    1,    9, 2836,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    9,  166,  119,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2217,   12, 1277,    1,    1,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 1821,  639,  475,  939,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 3365, 1683,   32, 3376,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,  574,    1,  321,  764, 1598,  734,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2699,    1,   37, 1965, 1370,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3316,  168, 1048,  187,  311, 2936, 2827,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1345, 2897,   32,  531,   12, 2646, 3133,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1759,  309,    1,   32,  365,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  824,  943,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3204,  361, 3257, 1758,  176,  163,    1,   12,    1,   26,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428, 1094,  300, 1592,   37,  764,  121,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3363, 2694, 3360,  361, 2018,  792,    1,   32, 1345,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  258,  535, 1594,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  640,  119,   98,  679,  122,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1044,  537,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,  794,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1, 1211,    1,  220,    1,    1, 3078, 1821,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3390,   32,  187, 1081,   12, 2674, 1009,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,    1, 3377,    1,    1, 1186,   37,  319,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1019, 2288,    1,    1, 1183,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1079,    1,  600,    1,   12, 1442,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  183,  681, 1822, 2394,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226,    1,  182,    1,  331,    1, 1131, 1036,   37,  395,  967,\n",
      "         1532,  590,  197,   32,  537,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 1313,  686, 3343,  787,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310,  159,  417,  187,   69,  245, 1271,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 3160,  162,  537,    9, 1147,   12, 2772,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3237,    1, 3238,  288,    9, 1136,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3043,   32, 1771,  114,    1, 1887,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   98,  105,    1,    1,    1, 1297,    1, 2230,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  455, 1326,   37, 1155,  649,    1,  250,  220,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  140,    1,   59,   32,   81,  138,    9,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  973,  848,  244,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  719,  105,    1, 1292,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2999, 2194, 3050, 1908,  114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2967,    1, 1459,  726,   32, 1029,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  920,   61,  166,  199,   37, 2303,   98,    1,    5, 2092,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,   61,  297,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1091,  856,    9, 1650,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,    1,   37,   47,  176,  119,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  361, 1181,   32,  768,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2167,  698, 1822,  792, 2160,   28,  361,    1,  166,    1,\n",
      "          792,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  933, 1628, 2702, 1108,  191,  979,  248,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 3373, 2626, 2249,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 1583, 1707,    1, 2081,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  982,  162,  395,    1,   24,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1818,  147,   37, 1709,    1,    1, 1842, 2096,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  342, 1984,   37,    1, 1855,    1,  142,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1436,  550, 3141,  892, 3141,  892,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  583,    1,  202, 3247,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,   37,  151,  294, 1983,    9,  152,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,  613, 1632,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,    1, 1791,  966,  191, 1346,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  288,   37,  168,   37,  806,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545,  856,   81,   37,  427,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  130,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1449,  613,   37,  349,    1,    9, 1417,    1,  372,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1433,  284, 1937,  105, 2773,   32,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  852,   37, 2022, 2240,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1759,  309, 2179,  651,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2038,  796,   32, 2169, 1559,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1693,  922, 1990, 1545,    1, 3187,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  883,  406, 1586,   28,    1, 1165,  490,   37,  119,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1563,  738, 2276,   32,  539,  187,    1,    1,   61,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 1586,    1, 1539,  778,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3125,    1,  487, 3102,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  430,  365,  529,  477,  456,   85,    7, 2458,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  211,   32,  740,    1,  741, 2156,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2448,    1,  967, 1754,    1,    9,  386,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,  879,  647,  693,    9, 1194,  199,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3248,  920,  619,   37, 1937,  440,  175,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2964,   37, 2988,  645, 1778, 2762,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3014, 1419, 1211, 1456, 2079,    9, 1718,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   10,    1, 2275,  389,  315,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  436,  256,   28,   37,  270,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2407,  861,   32,  903,    1,  904,    1,    1,    1, 1366,\n",
      "          565,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1086, 1183,  713,    9,  633,    1,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1001,    1,  100, 2149, 1720,    1,   61,  901,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  547, 1530,   32,  645,  395, 2003, 1585,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  720,   32,   69,  636, 2749,  114,  680,  218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1509, 1317, 1398,  612,   18,   32,  105,  183, 1510,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  463, 1447,  267, 2924,    1,    1,   37, 1850,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1212,  952,   37, 1805,   28,    1,  663,  119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1090,  297,    9,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1013,  640,  166, 2355,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1128, 2489,  636,  841,  220, 1652, 1718,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2161, 1159, 2069,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  848, 2371, 1908,    1,  361,  847,   98,  449,   74,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,  105,  807,    1,   32,  786,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  794,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066, 1542,   37,  865,    9,  311, 2936,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  470,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1532,   32,  395,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,  821,    1,    9, 2332,   45,  810,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1288,  365,    1,  190,  335, 1488, 2135,   45,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  693,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  387,  395,    1,    1,    9, 2149,    1,   45, 2673,   46,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3309,  162,  786,  427, 1281,    9,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652, 2460, 2055, 2355, 1718,  973,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,  475,  176,  702,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974, 1830,    9,  581,   95,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3321, 1554, 1090,  548,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1105,  787,  162,  111,    1,    1,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2068, 2384,  365,    1, 2687,  680,  104,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2226,  933,  777, 1085,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  121,  782,    1, 3373,   98, 2073,  851,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  693,  340,  275, 2208,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2925,   12,  198,  886, 2465,    1,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,  712, 1481,    1,  460,  810,   32,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2722, 3074, 3231,  872,  420, 1352,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,  200,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,   12, 2679, 1851, 1671,  775,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1211, 2119,   45,  166,  236,  237,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  512,   45,  166,  339,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,    1, 2280, 2430,    9,   29, 2607,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   61, 3305,  166, 1178,   37,  619, 1973,   28,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2366, 1905,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1386,  476,   37, 1121,  596, 1793,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3147,   51,  729,  576, 2924, 1159, 3114,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3094, 2572,   32,    1, 3389,   32, 2597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343,  741, 2116,  288,   37, 2962,   28,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2707, 1822, 1124,    1,  663,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  218,   32, 1186,  162,  105,   92,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 328, 183,   1, 387,   1,  72, 401, 354,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1, 361, 105, 227,   1,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  215,    1, 1594,   37,  531,   32,  142,   37,  583, 1861,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1284,   81,   98, 1171,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  415,  885, 1604,    1,   98, 1965,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3180,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  744, 1126,  636, 2320,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  613, 1074,    1,  593,  846,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,   81,   17,   32,    1, 1655,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994, 2995,  884,  218,  332,  384,  829,   12, 2997,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612,  877,  166,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,  313,  845,  220,  340, 1251,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1300,    1, 2526,    9,    1,  116, 2931,  176, 1604,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3184,  861,  665,   98, 2393,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1411, 2273,  844,    1,  297,  259,  847,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1839,  537,    1, 1793,  593,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1423,    1, 2637,  332,  593, 1990,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  571,  187,    1,    1,  190, 1046,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  428, 1002,  861,  103, 1816,    9, 2476,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  939,  187,  463, 2170, 2565,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 1484,    9,  342,    1,   23,    9, 2170, 3279,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2468,   12,    1,  140,  487,  458,    9,  372,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,   12, 2981, 1627, 3048, 2818,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2993,  794, 2994,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1428,   37,  100, 1720,  460, 1822,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1463,  958,  581,  942, 2623, 2624,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2512,   98, 1383, 2027,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2162,    1, 1801,   98,    1, 1351,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  474,  744,   28, 2079,   37, 1171,  389,  486,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3151,  288,   37, 1306, 2410, 2539,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  590,  516,    1,  590, 2338,   98,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 1361,  798, 1647,   98,    1,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1002,  267,   10,  729,  967, 1285,  297, 2275,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3290,    1, 1554, 2760,  220,   81,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   12, 2290,   32,    1,    1,    1,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  147,    1,  288,   32, 1939,   45, 1147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 2800,    1,    1,  187,    1,  361,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1123,   32, 2016,    1,    1,  972,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2059,   37, 1734,   85,  176,  314,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  215, 1063,  744,   39,   80, 1563,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,  877,  166, 1354,   45, 1515,  754, 2498,    1,  361, 1834,\n",
      "           61,  166, 2566,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1060,   76,  176,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614, 2428, 1451,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1518,   32,   98, 1698, 1108, 1872,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  262,  263, 1042,   63,  862,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  433, 2272,   85,   98,  116,  823,    1,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  794,  365,  260,   45, 2168,  176,  250,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3276,  913,    1,   98, 2347, 1482,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   12,    1, 1287,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  405, 3291,   39,  220, 2091,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112, 2153, 1937,  863,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  379,   16, 1444,  190,    1, 2763,  804,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1, 1821,  656,    9, 1610,  477,  191,  510,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   72, 2197, 2545,    9, 3198,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1955,    1, 1069,   32,  395,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2298,  220, 1117, 2208,    1, 1096,  166, 2990,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1489, 2306,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1290,  396,   28,    1,    1,  102,  504,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2483,  453,    1,   37,  166, 1300,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  550,  651, 1031,  167,    1, 1238,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  113,   27, 1034,  687,   98,  163,    1,   12,    1,  341,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1290,    1, 1097, 1279,    1,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,  390,  202,    1,   32, 2320,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3093,  884,  105,   81, 1311,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  706,  774,  560, 1110,    1, 1176,  183,  361, 1176, 2056,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2321,    1,    1,  220, 3078, 1987,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  150, 1658, 2495,   37,  310,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1546, 3182,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   37,  184, 1016, 1929,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  794,  365,  535,  841,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282, 2246,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1087,   37,    1,  460,    9,    1,  626,  633,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  364,  197,  407,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  187,  220,  440, 1151, 1091,    1,   15, 1174,   37,    1,  176,\n",
      "          882,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  526,  548,  720,    1,  388,  390,   66,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,   32, 2866,  220, 1412, 1107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422, 2954,  753,   37,  688,  510,   37, 1136,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  754,    1,   88,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2604,  617,    1,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2413,  361, 1086,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777,  325, 3028, 1017,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  914,   79,   37, 1121,  698,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422, 1268,  290, 1159,  224,  225, 1816,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1444, 2233,  335,  105,  713,  361, 1937, 1992,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  193,    1, 1018,    1, 2825,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2004, 1361, 1908, 2238,    1, 1159, 2366,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1154,  166,    1,    1, 1154,  166,    1,    1, 2221,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  980,    1,   37, 2255,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   47, 1440,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  305, 2589,    1,   63,   29,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1809,   45, 1018, 2695, 1510,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 1533,    1,  384,    1,    1,    1,    1,   45,  608,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  582, 2565, 1048,   98,  569,    9, 2751,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  232, 3133, 3369, 1260,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,   12, 1133,  484, 1494,   32, 1657,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2236,  376,  572,    1,  356,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1436, 1283,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1850, 1327,    1,  191,    1,    1, 3087,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  260,   28,   98, 1600,  138,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  691,   37,   92,  861, 1553,  176, 2311,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 1717,    1, 3311, 2424,   98,    1, 3332,    1,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2613, 2022,    1, 1112,  176,  550,  369, 1178,   12,  654,\n",
      "          221,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2318,    1,  619, 2747,  166, 1831,  582,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,   76,   32,  179,  180,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2786, 1780,  408, 2672,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2275,    1, 1817,    1,    1,    9,  411, 2591,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  164,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2308, 1587,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  369,    1,    1,  674, 1107,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3056, 1525,  614,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  297, 3358,    1, 3375, 2905,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  567,  510,    1, 1750, 1549,  540,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   12,   69,    1,  686,  191,  216,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2932, 1152, 2400, 2264,   45,    1,  629,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043,  879, 1044, 1045,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  430,  587,  211,  477,  484, 2191, 1517,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,  251,    1,  279, 1402,    9,    1, 2043,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  299,  933,    1,    8,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2512,   12,    1,   94, 1656,   37,  168,   98,  333,   32, 2433,\n",
      "           91,    9,    1,    1,  101,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  409, 1285,  388, 1273, 1107,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  275,  755,    1,  829,   12, 2819,    1, 2146,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1420,   37,   47,    1,   32,    1,  361,    1,   69, 1078,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425,   37,  130,  861,    1,   48,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  140, 2683, 1876,   37, 1155,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510,    1,    1,    1, 1887,  361,    1, 1146,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  715, 1113,  418, 1114,    1,  673,  448,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 2748,   12,    1,  319,   37, 1911, 1997,    1,  402,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,   37,    1,  327,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1833,  403,  464, 2673,   46,   32, 1820,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,   37, 2763, 3345,   37,    1,    1,    1,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  642,  643,   57, 1269,   32,  367,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3276,  193, 1472,    1,   98, 1045,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,    1, 1423, 1539, 2069,  903,    1, 1973, 2024,  973,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  251,    1,  131,    9,  989,    1,  195,   13,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  919, 2108, 3368,   98,  976,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   84,    9, 2691,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2562,  916,    1,  539,  105,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 2127,    1,   45, 1228,  802,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1877,   37, 2449,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1234, 1863,   15,   37,  686,  131,  191,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2171, 1675,   98,  844,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32, 1958,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613, 3007,    1,  612, 2419,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3369, 1830,    1,   45,  134,  444, 3118, 2751,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37, 2341, 2997,    1, 1901,   37, 2580,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1010,  555,  176,    1,    1,    1,    1,   37, 1540,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  458,    1,   37,  138,  331, 1780,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,  384, 1294,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018,  293,  191,  293, 1173,  176,  166,    1,   45,  166,  863,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2843,    1,  654,    9,  449,  199,  187, 2193,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  346,  954,    1,  220,    1,    1,  331, 1001,  109,   29,   16,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1733, 1707,  395, 2179,  652,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1950,    1,    1,  921,  837,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  103,    1,    1,  801,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1539,  162, 1479, 1107,    1, 1876,  384,  421,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  268,    1,  857, 1469,    1, 1408, 2007,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280,   81,   98, 1171,    9,  593, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   60,  640,  365,  340,  444,   94,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3263,  750, 1380,    1,   98, 3218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1419,  282, 2367, 2695,  861, 2976, 2973, 1764,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,  361,  112,    1, 1425,  261,  361,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3257, 2421,   39,   45, 2197, 3329,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1649,    9,    1,  600,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1312, 2572,    1,  583,   32, 1619,  395,    1, 2292,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2236, 2903,  386,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2570,  787,    1,    1, 1245,  384, 2073,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  493,  921,    1,    1,    1,    1,  384,  119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1220,  264, 3144, 1002,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1629, 1396,  286,    1,  293,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   37, 1418,   28,   37,    1, 2924,  384,   91,  361, 1033,\n",
      "           10,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,  886,   45,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  515,  449,  171,   45,  166,  787, 2653,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1853, 1557,    1,   37,    1,    1,  957,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,  162, 2322,  187,  460, 1310, 2446,  333,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2229,  327, 1268,    1,   98,  282,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  104,    1,    1,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3170,   37, 1343,   32,  449, 1463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785,  947,    1, 3006, 1388,   32, 1633,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  147, 1342,  750, 1576,    9, 3378,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,  551,  552,  418,   98,  550,   45,  388, 1097,   57,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2932, 1148,   37,  506, 1089, 1090, 2292,  345,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1073,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  633,    1,    1,  487,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  650,    1,   98,    1, 1634,   44,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  166,    1,    1,    1, 1821,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   12, 1913,  401,  197, 1249, 1721,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1921,   32,  166,  215,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,    1, 1529,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3115,  792,  183,  792, 2489,    1,   32,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2325,  297, 1563,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  124,   26,    1,   37,   15,    1,  120,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  649, 1461,    1,  176,   22,   16,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1027, 2917,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2479,  103, 1569,  176, 1548,  628,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3075, 3067,    1, 2948,    1, 3036,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2152,  166, 2808, 3133,   37, 2502,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 1128,  183, 2525,   45,   22,   23,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1746,    9, 1390,  108, 1327,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,  879, 2381, 2639, 1085, 2575,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75, 1579,  196,   12,  176,  551,  612,  613,  142,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  424, 2955,   61,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1149, 2898, 1894,    1,    1,  600, 2492,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,  315,   37,  442,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3321,    1, 1114,    1,  162, 1217,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  389,  504,   45,    1,    9, 1275,    1,  980, 2047,  954,   61,\n",
      "         1115, 1379,   12,  112,  499,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2850,   37,  726,  191,   56,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  531, 3045,  686,    1,    1, 2856,   56,  294, 2924,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1407, 3399,   32,  403, 1447,    1,    1,   37,  778,   45,    1,\n",
      "         1585,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1022, 2719,  197,  331,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1114,  879,  647,  693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  386,    1,  325,  152, 1219,    1,  159,  245,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,   37,    1,  947,    9,    1,  195,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3118, 2024,   46,   32,    1,    1,  297,  861,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1550,   19,  104,  443,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  845,  861,    9, 3343,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12,  861,  475, 2726, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3244, 1101, 2375,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,  418,  669,    1,  142,    9,    1,  596,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  442, 2583,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1000,    1,    1,  176,    1,    1, 1176,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3352, 1260,    1,  861,  475,   12,  754,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1, 2753,   45, 1691, 1089, 1675,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  411,    1, 2785,   32, 1316,  104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3261, 1581, 1077,    9, 1675,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1,  784,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  588, 1281,   98, 2476,  195,  834,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  848, 2055,  350,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3330,  515,  166, 3260,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,   12,    1, 2918, 2699,  707,    1,  232,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3236,  114,    1,  548, 1056,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2444,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   25,  526,  548,  646,   29,   32,  260,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1142,   37, 3051, 2292,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1022, 2350,    1,    1, 1294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1087, 2232,  437,  387,  197,   32,  572,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  176, 2957,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1583,    1,  193,  166, 2259,   37,    1,    1,    1,   37,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2477,  944,    1, 2977,    1, 2896,    1,  928,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2902, 2287,   28,    9,   80,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  352,  138,  894,   52,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2883,  850,   28,    1, 1054,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  418,   37,  119,   27,  187,  585,    1,  104,  568,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  593,   12, 3105,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  922, 3175, 1832,  105,   12, 3214,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  596, 1793,    1,   32, 2822,  506,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3060, 1216,    1,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2018,   37, 1982, 1537,    1,  970,  693,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   37,  927,   45,  829,  199,  421,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1796,  458,   37,  674,  627, 2247,   15,  361,  535,  663,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  466,    1,  384,  727,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  111, 1107,  614,   81,   37,   36, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12,    1,  535,  656,  729,  338, 1139,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  379,    1,   98, 1565,   45,  864, 2390,  798,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141,  435, 1936, 1675,   37,  395,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 1610, 1090,  698,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2237,  991,  454,    9,  455, 2924,   37, 1334,   98,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2512,  267,   51,  877,    1, 1283, 1656,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3239,  750, 2222, 1518,  786,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  611, 1175,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,    6,    4,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  255, 1815,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   62,    9,  166,   64,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   32, 1651,  215,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3332,   51, 1343,   32, 1245, 3201,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   28,    1,  163,    1,   12,    1,   64,  914, 1391,  509,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  519, 3130,   98,  105, 2365, 1114,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 3006,    1,    1,    1, 1147,    1,  844,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  617,  618, 1604,  187, 2579,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962, 3117, 1493, 1194,    1,  726,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  597,    1, 2650,   13, 1991,    1, 1218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1913,  401,  197,  338,   98,    1, 2187,  408,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1448,  700,   32,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  931,    1,  580, 1691,  872,   32, 1090,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  989,    1,  721,    1,    1, 1330,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  565, 2342,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1312, 2512, 2227,  872, 2677,    1,  649, 1938, 3197,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302,    1, 1038,  199,  297, 2650,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  729,  590, 2324,    9,  163,    1,   12,    1, 1821, 2978,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868, 2940,   45,  395,    1, 1789,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  441,    1, 1469,    9,  207,  259,  315,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  324,    1,  326,   51, 1371, 2704,  327,   50,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  108,   98, 2650,   12,  805,   98,  328,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  297,    1, 2844,    1,   74,  384, 3114,  443,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  386,  972,   37,  439,  869,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1039,  342, 1498, 1048,  148,  142,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  140,  856,  444,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32,  455,  191, 3121,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1233,   37,   52,    1,  361,   53,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  876,  612,    1,  220,  597, 2548,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  952, 1259,   32, 1559,  220,  971,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,    1,    1,    1, 2949,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  475, 2827,  297,  331,  605,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   30,  105,    1,  166, 2615,  190, 1188,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101, 2534,   39,   45,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1647, 1532,   32, 1123,    1,   46,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  176, 2362, 1167, 3207,  865,  247,\n",
      "          671,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2732,   37,  843,  116,  412,   37,  594,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  755, 1360,  612,  815,  829, 1994, 2819, 2146,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107, 1680,    1,  176,    1, 2396,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  228, 2844,   32,    1,    9, 2702,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  844, 1074, 1086,    1,   37,  447,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 2080,  252,  951,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,    1,   98, 2759, 1499,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,  446,   12, 1815, 2784,  113,   39,  105,    1,   45,  753,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,    9, 2095,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  393,    1,  474,   32, 1845,  132,  297,  411,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1002, 2275,  113,  631,  297,   10,   32,    1,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2680, 2329, 2650,  220, 2798, 1289,   98,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1398,  612,  168,    1,  446,   90,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1811, 1280,    1, 2087,    1,    4,  380,    1, 1176,    1,  193,\n",
      "          415,    1, 1604,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  959,  319, 2468, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2713,  917,  384,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  743,   12,    1,   28, 1662,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1066, 1244, 1680,    1,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006, 2253,   37,    1, 1855, 1178,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   50, 1727,    1,   32,  636, 1336,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3252, 2737,  884,  449, 1385,  631,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   12,  792,    1,  792, 1013, 1560,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1542,   37, 2075,   81, 1159,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3217,   12,    1,  866, 2198,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  889,  529,  109,  509, 1348,   98,   29,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  335, 1056,  744,    1,    1,    1,    1,    9, 2206, 2989,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  192,  414,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 3175,  726,  183,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  647,    1,  148,   55,  730, 2614,  951,    1, 2615,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2384,  365,  526,   67, 1402,  315,    9,  104, 1766, 1767,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 104,  22,  23,   1,  37, 312, 396,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 242,  15,  92,   1,   1, 244,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2647,    1, 1877, 1064,  424,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 2347,  963,    1,    1,   37, 1423,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  971,    1, 2077,   37, 1835, 1736,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   98,   65,    1,    1, 2964,  588,   37, 1154,  507,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3349, 2785, 1950,  921,  384,  799,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  434,  105, 1718,    1,    1, 1370,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1411, 1009,  167,  619,   37,    1,  845,  147,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  355,  197,  583,  191,    1,  596,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  315, 1736,  659,   45,    1,    1, 2587,  479, 1017,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1353, 1228,    1,  210,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3016, 1935,   32,  766,    1, 1411,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    9, 2250,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  121,    1,    1,   49,  333,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3277,    8, 2453,  304,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  343,   32, 1821, 1697,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2960,   32, 2752,   12, 1633, 2766,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2885,  140, 3258, 3154,   32, 2941,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,    1,  854,    1,    1, 1054,   45,    1,  921, 1344,   45,\n",
      "           69,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 132,   1,  20,   1, 420, 267,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,  37,   1,   9, 786, 339,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1920,  928, 1890,  548, 2059,   12, 2162,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1550,    1,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1266, 1340,    1,  548,    1,   12,    1,  731,   37,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  172,  682,   98,    1,  754,  399,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1711,    1,    9,  238,   32,    1,    1, 1527,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2570,  787,  519,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1711, 2816, 3114, 3279, 1428,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  756,  757,  572,  197,  948,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,  387,  121,    1,   98, 3093,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,  787,   32,  593,   12,  553, 1766, 1767, 1222,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,  401,   45, 2527, 2946,   32, 2124,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2565, 1408, 2925, 2009,   26,    1,    1,   45, 1698,  199,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1896,    1,   37,  429,  464, 1512,   46,  104,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  580,  629,   45,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  755, 2065,  912, 2815, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  315,    1, 1281,    1,  952,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 105,   1, 270,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 196,   1, 176, 551, 612, 613, 317, 932,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  451,   37, 1865,  388,    1, 2915,    9, 1407,  615,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800,    1,   98,    1,   44,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  561, 2962,   28,  111, 2502,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  688,    1,   32,  364, 1523,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  949,    1,    1,   37, 2862,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2883,    1,    1,   37,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  361, 3314,  619,  460, 2740,  857,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  307,    1,   15,  837,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  440, 1944,  905,  652, 2521,   32,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468, 1454,  453,  531, 2128, 2129,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1273, 1090,  218,   37, 2401,    1,  506,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3333,  967, 1183, 1473,   37,  103,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3079,    1, 3171,    1,  548, 2237,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2222,    1,  501,    1,   37, 1839,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1481,   32,  863,    1, 1559,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   15,    1,    1,   71,    9,  196,  613,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 3389, 2856,    1,    1,  583, 2753,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 447, 105, 356, 548, 166,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  25,  26, 242,  32, 409,  98,   7, 496, 428,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  951,    1,  105,  182,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2331,   45,    1,  581,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 2140,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465,  861,  496,  782,    1,  910,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1545,   94, 1463,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1461, 2414, 2710,    1,  475,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1789,    1,  315,  129,   74, 1819,   98,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1380,    1, 1046,   98,  617,  618,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2893,    1,  610,   37,  537,   32,    1,  776,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1925, 1583, 1542,   37, 1551,   32,  987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018,  267,  998,    1, 2765,  650,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3045, 2856, 1147,  861, 1414,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2569,   90,   45,    1,  722,  444,   10,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1498, 1048,  148,  142,    9,  647,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3310,  400,  167,    1, 2930,  716,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,   12, 1230,  884,  166,  631,   98,  848,   12,  754,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  705,   32,  581, 2138,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283, 1676,    1,    1,   45, 3126,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  338,  548, 1819,    1,  202,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  469,    1, 2024, 2909,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  484,   37, 1154, 3015,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   86,    1,    1, 2149,  884,   98,  284,   45, 1034,   12,\n",
      "          388,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  197,  418, 1011,    1,  493,   15,  198,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299, 1118, 2591,   98, 2138,    1,  195,    8,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1716, 2480,   15, 1348,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766, 2721,   45, 1092,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  393,   12,  142,   37, 1031,  734,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1768, 2735,  161, 1294,  653,    1, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,  617,  259,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    1, 2460,    1,    9,    1,   12,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1585,    1,   32,  531,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2499, 1249,    1,   32,  593, 1990,    1,  548,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  208, 1707,  592,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1122,  853,   32,   59, 1123,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1906, 1579,  963,  195,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1680,  267,  876,  612, 1579,  395,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 2205,    9, 2805,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  395,    1,  947,    1, 1178, 1988,   45, 1887,   28,   37,\n",
      "         1305,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  386,   37, 1377,   37,  214,  770,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2376,  855,    1,    1,    1,  297, 3022,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  854, 2058,   79, 1194,    1,   45,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390, 1036,    9,  467, 1387,  105,  339,  721,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2137,  135,    1,  501, 2060,    1, 2572,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  700,   98,  531, 2924,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2786,  187,  963, 2949,  729,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  290, 1159,  841, 1184,  347,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  103,  996,    1,   37,   10,   61,  380,  317,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1139, 2113,  612,  302,  347,  410,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3188,    1,    1, 2567,   98, 2925,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1766, 1767,    1,  187, 1193,    1, 2157,   32, 1817,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2646,  947,  105, 2088,  978,  260, 1813,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,  726,  105,    1,  187,  915, 3343, 2591,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2994,  682,    1, 2995, 1681,   51, 1245,   28,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  107,  190,  125,  568,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  587,   51,  477,  297, 1233,    6,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  297,  340,    1, 2116,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  166, 1110,   45,  104, 2841,  872,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 3372, 2794, 1009, 3380,   37, 2449, 1583,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3230,    1,    9,   81,   37,   81, 1268,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1030,    1,   45, 1412,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1024,    1,  387,  983,    1, 2034,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460, 1924, 1590,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3358, 1801,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1, 2196,    1,    1,  163,    1,   12,    1,   37,  332,\n",
      "         1994, 2095, 1017,  428,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1787,  297, 1405, 2251,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  921,  121,  176, 2701,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   61,  460,  105,  135, 1292,    1,  590,    1,  415, 1158,   12,\n",
      "           72, 2273, 2452, 1465,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  645,    1,   37,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    1,   12,   98,    1, 2941,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994, 2693,  280, 1306,    1,   32,    1,    1, 1536,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  476, 2971,  384, 2638,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,   12,  186,   32, 2513,   37, 1334,   98,  103,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1084,  729,  105, 2919,   37, 1354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,    1,  647,  693,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1159, 3293,  176,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1228,  980, 1085, 2568,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  442,  321, 1814, 1815, 1816,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3323,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,  159, 1285,   85,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654, 2621,  220,  166, 2723, 2724, 2636,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  176,  612,  613,  200, 2665, 1851, 2480,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1646,   37, 1334,  166,  218,    1,    9,  920,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3118, 2024,   46, 2139,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204, 1249, 3253,   37,  759,   26, 3295,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  374,  375,   37,  151,    1,    9,  152,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2016, 1906, 1579, 3283,    1,    1,    1,    1,   45,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1087, 1518, 1151,   50,    1,  221,   37,  657,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,  669,   37, 1865,    4,  176,    1,    1,  250,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1791, 2282,  650,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1710,    1,  264,  531,  863,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  386,    1,   12, 2647, 1114,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 2872, 2720, 2796,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,    1,   37, 2436,    1,   12, 2585, 2948,  656,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  375,    1,   37,  151,    1,    9,  152,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1018,  411, 2022,  384,  531,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,  452,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2514,    1, 1292,    1,    1,    9,    1,  721,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   37,  125, 1213,  138,  191,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1592, 1152,   45,  207,  164,  165,  126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  267,  118,   45,  647,  225,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1629,   21,   37, 1753,    1, 1204,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2918,  927,    1, 1159, 3048, 2818,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,   12,  299,  140,  806,   32,    7, 1068,  171,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  792,    1,    1,    1,    1,  792,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2899, 2790, 1544,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 1685,  531,  516, 1484,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1821,    1,    1,  384,    1, 3027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2529, 3121, 2414,   32,  455,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1554, 1090,  220,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106, 1107, 1539,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  303,  387,  996,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  288,   37, 1776,  365, 2232,    1, 2759,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  894,    1, 1128,  132,    1,  202, 1366, 1822,  817,    1,\n",
      "           45,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,    1,  580,  972,   32,    1,   10,    1, 2275, 2224,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1423,  794,  259,  133, 2678,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2528,  129,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1035,   12, 2013,  798, 1464,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  710,   21, 1121, 1314, 1069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2250, 1554,  311,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  327,    1, 1696,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,   12, 2071, 1331,  769,  714,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1985, 1215, 1056,    1,  786, 3076, 3289,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  746,   37, 1539,  258,  116,  279,   19,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  874,   45, 1945,  361, 2024, 1532,  384,  166, 3024,   45,\n",
      "         1094,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  812,  632,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2095,  617, 3109,   71,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035, 2301, 1008,  597, 1436,  232,  187,   82,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,    1,  484,   32,  148,  214,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,    1,  548, 1133,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  476,   37, 2495,  105,  855,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1178,  787, 1710, 1982,    1,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2350,  919,  854, 2029,  230,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  567,  799, 2682, 1159,  584,   12,  404,  540,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2308,  254,   32, 1242,  297,    1,    1,  267,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1056,  440,  104, 2161, 1758,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  386,   78,   61,    1,   37,  726,  166, 1477, 1990,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1056, 2844,   32,  463,    1, 1345,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  261,   98, 3207, 3126,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2753, 1394,  187, 2290, 3259,   85,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2466,  162,  433,   37,    1, 2824,  302,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3144, 1002,    1,  191,  133,  361,  555,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1411,   37, 1412,    1,    1,    1, 1173,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3369,    1,   37, 2024,   32,  463,  361,    1, 2389,   37, 3118,\n",
      "         1512,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   63,  166,  862,    1,    1,  338,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2974, 1564,  581, 2784,   37, 1821,    1,  140, 2695, 2223,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  345, 2574,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  782,  247, 1567, 2589,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388, 3349, 3406,  191,  439, 1332,    1, 1428, 3397,  267,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2960,    1, 1632, 2729, 1606,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  204, 1360,  612, 2565,    1,    1,   46,   37, 3103,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2414,    1,   32,    1,  129, 2578,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2151,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  188,   32,    1, 2069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,  242,    1,   60,   28,  951,    1, 1547,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,    1,  419,    1,   48,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,   12, 1127, 1064, 1273, 2274,    1,    1, 2457,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1648,    9, 2389, 3380,  267, 2018,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  590,    1,    9, 2974,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1277, 1914,    1,  315,   37,  125,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283,   32,  870,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,  190,  693,   80, 1108,   32,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   21, 2707,   37,    1,  132,   98,    1, 1282,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    9,  405,    1,  705,    1,  182,    1,    1, 2181, 1924, 1176,\n",
      "          445,  357,  193,  176,  810,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   45,    1,  921,    1,   12, 1688, 2788,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   91,   12,    1, 2137,  340,   60,    1,    1,   98,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  225,   12,    1,  714,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2883,  952,  764,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 2924, 2856,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  954,  883, 1279,  338,    1,    1,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2823,  736,    1,  160,   29,  343,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  121, 1475,  131,  384,  531,  734,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1688,   90,    1,   37,    1, 2997,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1011,  472,  320,  340,    1, 2190, 1167, 2640, 2145,   37,  125,\n",
      "           81,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,  403, 2926,  921, 2451,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1423, 2024,  132, 1827,    1,    1, 1861,  361,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  565,  193,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,  486,  802, 1960,  182,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,    1,    1,   85, 1651, 1597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2749,   98,    1,  220, 3303,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1567, 2032,  865,   37, 3176,  187, 3316,  726,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  105, 1412,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   63,  166,   16,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,   37, 1155,  593,   12, 2084, 2229, 2641,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 1178, 1654, 2886,   12, 2234,    9,    1,    1,   98,  105,\n",
      "            1,    1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2751,  498, 2597, 1302,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713,  342, 2699,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3352, 2856,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  681, 1937,  410,  932,   32,  486,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  216,  686, 2936,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2876,  873,    1, 1389,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3359,   37,    1, 3339,    1,   37,    1, 2789,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403,  951,    1,  463, 1123, 1681,    1,  878, 2304,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  696, 3228,  726, 1312,   32,  105, 1559,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2808,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2800,    1, 1792,    1, 1812,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2942,    1,   39,  220,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2659, 2571,    1,  220,    1, 2455,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1008,  356, 2469,   82,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1359,    1,    1,  928,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1,    1, 1511,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   91,    1,  104,  498, 2824, 3146,   98,  864, 2673,  210,  104,\n",
      "          232,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,  776, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2999,   91,  792,  877, 2518,  193, 2819,  792,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  475,  387,    1,    9,   10, 1821,  210,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2546,  794, 1107, 2610,  636,  443,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  398,    1, 1899,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  447,  300, 2404,   37, 1211, 3365,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2037,  166,  825,  176, 2838,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1921,  528, 1313,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2633,    1, 3233,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1629,    1,  782, 3022,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1170,  361, 1349,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2162,    9,    1, 2231,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,  361,  829, 1519, 2432, 1499,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2163,  171,  996, 2657,  639, 1579, 2362,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  228,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  156, 2393, 1652,  387,    1,   32,  460, 1278,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  596,    1, 1278,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,   32,    1,  351, 1259,  220,  503,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3226, 1360,  612,    1,  220,  947, 2099,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1755,  176, 1340,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  190,  100,   98,  651,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  657, 1042,  315,    9,    1, 1151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1494,   28,  183,    9,  730, 2614,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  491, 2286,   37,  222,  430,   69,  477,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711, 1313,   10,   63, 1966, 2396,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 3400,  580,  247,  608,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  651, 1031,   61, 1120,    1,  920,    1,  774, 2700,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  794,    1, 1013,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  250, 1182,    1,  191,  230, 2104,    1, 1796, 2673,  250, 2960,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  845, 2725,   97,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   66,    9,  845,  275, 1244,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  547,  551,   39,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,   12,  811,  267,  215, 1360, 1977,  384,   10, 1876,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  171,  749, 2264,  260,   28,   37, 1753,  297,  985,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1097,   57,   28,    1, 1290,  396,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1178,    1, 1712,   45,    1,  237, 1061,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1591,    1, 1996, 2257,   32,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  637, 1211,    1,  167, 1719, 2587, 1658,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2593,  777, 2165,   37,    1, 2275,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,  476,  942,   37,   38,  297,  403, 3165, 1492,    1, 2147,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2153,   32,    1,    9,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  619, 3130,    1,   32,  581, 1023,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  928,  548,    1,  384,  963,    1,   79,  540,   45, 1423,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 1454,  531,    1,   32,  942,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56,  395,  945,  379,  946,    1,  328,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  424, 1876,    9, 2275,    1,  176,  105, 1628,  199,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  961, 1482,   12,    1,    1,  954,  410,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1360,  612,   81,  864, 2390,    1,  469,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,    1,  220,  104,   98,  864, 2390, 1757,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3191, 1293, 1762,    1,  311, 2936, 1654,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,  102,   16, 1520,  871,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  617,  618,   32,   95,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 2978, 1539,  753,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,   37, 1421,  220, 3236,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1917,    1,    1, 1917,  705,    1,  683,    1, 2413,    1, 2677,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2227, 1938, 3197, 1625,    1, 1159, 1204,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  261,   98, 1213,  138,  167, 1031,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  224, 2228,   79,   32, 1013,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   26,  242,  187,   69,  102,  832,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2967,  476,   39,   45,  942,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  197,   28,   32, 1022,  898,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  147,    1,   12,  312,    1,    1,  612, 1211, 1819,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2504,    1, 2862,  446, 2270,   37,  319,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 1976,   32, 1223,   27, 2893,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,  396,    1, 2666,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  453,  193, 2613, 1997,  501,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  709,    1,    1,   36, 2547,  321, 1753,  187,  105, 1280, 1377,\n",
      "          147,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  335,  572,  686,  384,  585,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  702,  353,  197,  548, 1251,    6,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1,    1, 1159,  872, 3346,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614, 1292, 1408,  784,   45,  247,  608,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3141, 3009,  688,    1,   37,  726, 1674, 1940,   12, 3134,\n",
      "         3077,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2596, 1976,   32, 1223,   27, 2893,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707,   21,   37,    1,   93,  837,    9,  439,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  398, 2682,    1,   12, 2227, 1021,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  231,  829, 1013,  338, 1533, 1139,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  550,   32,  870,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,  373,    1,    1, 1405, 1612, 1439,   45,  133,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   98, 1658,  813,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,  919,   69,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1928, 1082,    1,   37,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  619,   26, 1039,  809,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  160, 1161,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   25, 1285,   85,   98,  197, 1936,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  183,  268,  967,  183,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 2924, 2856, 1056, 3375,   32,  365, 2292,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1717, 1215,  148,   12,    1,  520, 2925,  872,  349,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1818,  147,    1, 1084,  841, 2096,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  410, 2244,   25,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1173,  176,   10, 2275,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  854,  794,  449, 1580,  853,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  171,   45,  166,  593,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3249,  866,    1,   98, 2069, 1343, 2460,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,    1, 1001,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,  108,  539,  444,    1,   32, 3367,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  973,    9,  388, 1021,  176,  531,  250,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190, 1303,   12,  627,  427,  453,  608,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3034,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973,    1,  220, 1822,  726, 3249,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  497, 1079,    9,  506,   45, 1601,   45,    1,  439,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  400,  444, 3311, 3310,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  632, 2640, 1445,    1,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1395,    1, 1768,    1,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32, 1450,   32, 2597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942, 3067, 3393,    1, 3389,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   37,    1, 1718,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    4,  817,   98,   60,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2437,  548,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,  787, 1606, 1149,  477, 1552,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  839, 1645,  458,   12,  808,   32,    1,  210,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 1260,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  708, 3229,  115,   45, 2462,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2939, 2479,  671,   32,    1,   45,  199,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  651, 2840,   45, 2701,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  954, 1353,  528,  677,   69,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  711,  936,    1,   45,   82,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2190,    1,    1,  105,  270,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  148, 1426,  214,  132,  220,  647,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  565, 2901,  187, 1628,  187, 1366, 2898, 1444,  565,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3359,  744, 2306,    9, 3339,  489,   39,  736,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,    1,  902,    1,    1, 1748,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 191,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 105,   1,  12,   1,   1,  81, 754,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1622,  477,   37,  837,   69,  532,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1105,  787,   12,   15, 1139, 1105,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,   32,    1,    1, 1176,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1774,   39,  365, 1718, 2232, 2587, 1021, 1151,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  487, 2404, 1554,    9, 3118, 2237,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  365,  509,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,   32,  166,  829, 2031,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994, 2819, 2146,  770,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  845,   69,  102, 1240,   52,  105,    1,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  835,  853, 2655,  669,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1949, 3379,   16,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  251,  311,  199, 1225,  716,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   25,  123,  242,  187,   68,  338,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1086,  284,    1, 1958,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  487, 3127,    1,    1,    1,    1, 2772,  191,  104,  622,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1712,   32, 2670,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,  200,  330,  361,    1, 2544,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,    1, 1315,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2953, 2297,  187,  461, 1463, 2886,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  441,    1,   37,  877,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2882, 2793,  548, 2555,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  338,  118,   63,  862,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3013, 3268,  121, 2784,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1, 1087,    1,    1, 1017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 1259,  220,   22,   23,  167,   52, 2876,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340, 1150,   98,   71,   32,   31,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1375,    6,  152,  388,   32,    1,    1, 1639,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  527,  744,    1,    6,  313,    9,  152,  745,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1628,    1,  357, 1211,    1,    1,  204,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1230,  884,  105, 1526,   45,    1, 2717,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1282, 2539, 2811,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1309,    1, 1380,  289,   98,  203,  977,    1, 1021,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2414,  104, 3160,   27, 3402, 3408,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121, 2414,   32,  455,    1,    1,   32,  105,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  267,   86,    1,   15,   28,    1,  118,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  326,  132,    9, 1766, 1767, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  115,  176, 3023,   45, 3116,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3084,  140,  917,   37,  588,  412,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  829,  875, 2039,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  144,  145,  387,  156, 1315,  308,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3192,  854, 2659,    1, 1281,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1338,   45,  861, 1408, 1011,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3132, 1173,    1, 1114,   37, 1694,   45,  922,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2369,    1,  548, 1633,    1,  187, 2108, 1757, 1552,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 2292,  868,  854,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1614, 2355, 1013, 2549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2365,   32,    1, 3201,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65, 1482, 1009,   21,    1,   71,   32, 1184,  347,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  614,   37,  806,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 2163,  700,   11, 1283,  361,    1,  639,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  302,   37, 1195, 2673,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,  186,  176,   26,   60,  418,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2772, 2884,  952,    1, 1898,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,    1,   12,   82,    9, 1943,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  947,    1, 1428, 2924, 2625, 3362,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9, 1933,    1,  460,  810,    1,   85,   37,  987,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  187, 1361, 2483, 2366,    1, 2264,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1323,  729,  105, 2919,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1720, 2518, 1494,   37,    1,    1, 2226,  331,    1, 2155, 1167,\n",
      "            1,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  500,    1,  220, 1191,  918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2834, 1186,  884, 1442,  992,   37, 1523, 2834,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3034, 2264, 1371,    1,   37,   33, 1117, 1525, 1704,  157,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 2995,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,    1,    1,   32,    1,   45,  117,    1, 2876,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1258,  453,    1, 1844,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,  773,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1764,    1,    1,   98,  227,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  519,  563, 3059,   32, 2651,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   28,   98, 1894,  160,  636,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  529,    1,  340,    1,    1,  295,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  849, 1293,   32,  166,  173,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1627,  215, 1107, 2610,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,  422,    1,  199,  421,   27,  399,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  449, 1663,  517, 1732,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,  913,   61, 2440,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   12,    1, 2695,  327, 2776,  365,  660,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  986,   79,    9, 3221,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294, 1456,  353,  118,  197,  504,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  160, 1161,  338,  187,  863, 2107,  614,   37,  166,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283,  361, 2325,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1051, 1636,  861,  662,    1, 2798,  725,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220,    1,    1,  163,    1,   12,    1,  921,    1, 2300,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1232,  193,    1,    1,  176, 1128,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  544,  227,    1,  726,  105, 2223,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3188,   12, 1998,  155, 1574,    9, 1110,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   25,  686,  687,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  193, 2643, 2321,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  695,  892,   98,    1,    1,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  197, 1784,    1,  307,  570,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1876,    9,    1,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2934,   37,   52,  105,  686,   32,  166, 2498,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  156, 2393, 2031,   37, 1291,  822,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1537,  777,   15,   45,    1,  735, 1046,  365,   97,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2804,   32,  625,   45, 1919,    1, 1061,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  602,  267,    1, 1260,   98,  531,  446,    1, 1061,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1187,    1,    1,    9,  691,   12, 1264,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1200,    1,    1, 2153,   32,    1, 1492,    1,  474,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  735,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  326, 2951,  103, 2334, 1638,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  963, 1184,   67,  423,   76, 1970,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  853,   34, 1674,  861,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  801,   37, 1858,    1, 2033,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  229,   32, 1020,  271,   32,    1,    1,  722,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,    1,  829,   12, 1994, 2819, 1017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3345, 1220, 1407, 2924,  319,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1530,  187, 2924,  335, 3155,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1312, 2844,   32,    1,   98, 1029, 2883, 2735,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  922, 1090, 1829,  365, 1788,  176, 2184,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  442,  910,  703,    1, 2087,  433, 2216,   69,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  631,  511,   37,    1,  103,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  625, 3177,  321,  335, 2310, 2545,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 3062, 1858,    1,    9, 1922,   72,    1, 1684,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,  794, 1626,   45,    1, 1013,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1920,  396,    1,    1,  444,    1, 1132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2162, 1220,    9, 2516,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  939,  384,  404, 2926,  317,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,  104,  396,   37, 2856, 2764, 3381, 2431,   32, 3155,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  872,    1,  810,  600,    1, 1343,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1492,   12, 2587, 2994,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1354,    1,   98,    1,  254, 2713,  829,   82,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,    1,  152,  422,  399,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2258, 1167, 2716, 1361,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  647,  546,   82,    1,    1,  454,    9,  142,  191,  148,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  443, 2938,    1,   37, 1174,    9, 3127, 3080,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3337,  162,  166, 1140,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  656, 2182,   79, 1023,   45,   15, 1346,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  657, 2384,  365, 1273, 1151,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2173,    1,   49,  924,   32,  645,  221,  444,  166,   69,  633,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  550, 2508,    1, 1791,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178,  163,  142,    9,    1, 1292, 3177,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2640, 2449,   98,  103,   45, 2258,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1855,    1,   37,    1,    1,  488,  342,   46,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2579,   37,    1,  163,    1,   12,    1, 2161,   12, 3096,  872,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  387,  244,   28,  528,  845,  408,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  255,  475, 3381,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,  631,  176,    1,  628,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1674, 2965, 3021, 2317,  191,    1,  872,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746,    1,  829,   32,   59,  132,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,    1, 1810,  433, 3145,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1536,    9,  147, 1942,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094,  251,  215,    7, 2024,  808,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,    1,    1,  837, 1796,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3171, 2352, 2615,   59,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  779, 1256,    1, 2639,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  208,   12,    1, 1713,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,  275,    1,   37,  759,  388,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  547, 2476,    1, 1056, 3157, 2572,   32, 3376, 1585,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2379,    1,   61,    1,  227,    1, 1277,    1,  638, 1186,   12,\n",
      "         2939,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  742,  641, 2448,  386,   48,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   45,    1,    1,  166, 1354, 2947, 2603,  724,\n",
      "           45,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1465, 1151,    1,    9,  846,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,    1,  315, 1022,  987,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,   65,   34,    7, 1184,   67,   37,    1,  118,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   12,    1,    1,  153,  154,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 187,   1, 865,  37,  69, 252, 787,   1, 105,   1,   1,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 427,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3079, 2844,   32, 2527,  164,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9, 2630,  891,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  398, 1707,  625,   37,  222, 2638, 2931,\n",
      "           98,  777,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 2697,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  304,  459,  176,  657,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  311, 2565, 2331,   45, 1876,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1293,   32,  968,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1524,    1,  921,    1,  252, 1638,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  236, 1022,    1,   96,   37,  166,  199,   39,  187,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1009, 1564, 2024,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  213,   37,   56,  356,  132,  220, 2142, 3225,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  259, 1091,  872,   98, 1273,  844,  315,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  762, 1529,    1,    9,  506,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  952,    1, 1656,  286,  125,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  732,  482, 1413,    1,   32,  142,   37, 1911,  388, 1803,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1,  187,  163,    1,   12,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 386, 295, 387, 388, 389, 390,  88,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  69, 102,  23, 575,  37, 913,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  780,  267,  156,  388,  763, 2316,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  476,   37,  544,  311, 1821,   95,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1038,    1, 2414,  176,  177,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  855,   32,  792,  166, 2107,   61,   98,  792,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1737,    1,   22, 1450, 2497, 3155,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   40,  768,  400,    1, 2017,  384, 1968,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3167, 2206, 2435,    1, 2142,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3039, 2431,    1,    1,  928,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1022,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1766, 1767,  861,  328,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1834, 1414, 1090,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  330,   37,    1,  625,  444,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  166, 1158,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1105,  787, 1052,  572,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  964,    1,  674,  548,   36, 3071,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,  356,   98,    1, 2892,    1, 2445,  147,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   46,  389,  861,  220, 2685, 1914,    1,  971,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1380,  453,  327,  112,   28,    9,  333,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2922,    1,   37,   16, 3323,  204,   12,  729, 1185, 2398,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3306,   12,    1,  396, 3281,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 1447,  839,    1,  202,  284, 1820,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  603, 1836,   37,  166,    1, 1787,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2275,    1,   28,    1,   32,  709,   10,    1,   32, 1771,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,   66,  424,  356,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,   59,  693,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1,  829,  335,  275,   98,  166, 2041,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  586,   34, 1885,   12,  731,   37,  151,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,  877,  105, 1736,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1051,  986,   59,    9, 1228, 2348, 2683,  552,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2688,   12, 2494,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  433,  233,    1,  213,   37, 1348,    5,    6,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,   12, 1016, 2660,  132,   37, 1413, 3359,   12, 3057,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  515, 1975,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1530,    1,  583,   32, 2178,  851,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2053, 1165, 1637,   32,  257,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2888,    1,    1,  457,  414,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  395,   12,    1,  159,   71,   98, 1759,  309,  714,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2069,    1,  338,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  590, 1694,    9, 2213, 3065, 2939,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,    1,  409,  256,   37,   97,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 2731,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325,    1,    1,  164,  165,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  750, 2177,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092, 2860, 1753, 1935,    1,   13,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1056,  675,    1,   32, 1759,  309,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  590,    1,  220,  316,  297, 1428,  389,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977,   37, 2564,    1,   95,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2850, 1530,  547, 3375,    1,    1, 2108,    1,   32,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  617,  259,    1,   37,  619, 1718, 1144,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,   12,  442, 3224,    1,    1,   37, 1834, 3209,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,   51,   26,  124,    1,    1,  773,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3290,  688, 1971,   32,  581, 1637,    1, 1090,   32, 2925, 2218,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,   45,    1,  220,  105, 1884,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1617, 2479,  449,  671,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2043, 2962,  777, 1085,    1, 1117, 1943,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 3192,  854, 1140,   28, 3170,    9,  691, 1867,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 3143,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  262,  263,   32,  365,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  197,  418,  419,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1454,    1,  934,  444,    1,  706,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 262, 263, 290,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 307, 125, 176, 166,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1,  614, 1092,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    1,    1,  905,  191,  103,  104,  147,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  947, 2562, 2025,  199,   37,  429,    1, 2596, 2985,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,  142,    1,  686,  220,  183,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3175,    1,   61,  181,   32,    1,    1,    1,  631,  105,    1,\n",
      "          437,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  522, 1662, 1292, 1492,  901, 2140, 2823,  863, 2590, 2847,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  485,  476,   56,    1,   98,  652, 2521,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1426,    1, 1422,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2741,  361,  854, 1003,   37,    1,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 1090, 1829,    1,  176,  316,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,   22, 2743,   37,  151,   28,   37,  296, 1497,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2192,  105, 2149, 2904,   37,    1, 2565,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564, 1286, 3179,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711, 1313,  531,  443,    1, 2868, 2237,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1427,   61, 2398,    9, 3176,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,    1,    1,    1, 2403,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1202,  477, 3391,    1, 3381, 2263,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773, 2510, 2493, 2947,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3202,  288,    9,  449, 3141,    1, 1090,   32,  395,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  954,    1, 2095,    1,   10, 2275,  736,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  224,  162, 1126,  501, 1125,  384,  422,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 3349,   23,  719, 2924,    1,  968,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  306, 1355, 1935,    1,  218,  220,  417,  347,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,    1,  484,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  190,    1,   38,    1,   12,    1, 1064, 1417,   12,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2137,  361, 1345,   32, 2597, 2856,  176,  177,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  422, 1236,  709,  702,  494,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3160,  952,  942,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2800, 3296,  565,    1,  191,  166,  862,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   37, 1075,  906,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,  332,  756, 2690,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1762, 1516,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,    1, 1204,  220,    1, 2982,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   74,   32, 2597,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2749,    1,    1,    1,  522,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,   32,  170,   46,  220,  440,  681,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1353, 1778, 2580,  328,  949,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  818,    1, 1798, 1698, 2122,   61,   98, 1160,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504, 3043, 2527,  164,  400,  542, 2500,  345, 2047,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  793,  321,  815,    1,  987,    1,  398,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2884,    9, 2018, 3006,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2871, 3231,  774,    1, 1360,  612,   52,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  140, 2376, 2024, 2223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  691,  603,    9,  183,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,    9,  166,    1, 3141,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2802,  580,  105, 1133, 1787,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,   98,  829,   12,  365, 1994, 2086,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  463, 1447,   12,    1,  483,  188,  548,  104,  354,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  580,  365,    1,   32,  105,  784,  593, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2404,    1,  738,  220,  715, 2404, 3139,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1701,   37, 1753,  668, 2633,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1239,   28,  220, 1298, 1117,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2991,    1,    1,    1, 2232,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  190, 1334,    1, 2191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2912,   37,  712, 3309, 2895,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   65,   67, 1500, 1284,   37,   52,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200,  103,  861,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2889,    9, 1956, 1463, 2522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  180,  650,  364,  614,   39,  411,  220,    1, 1522,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3353,  700,   37, 1910,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1235,   12,  225,  338,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,   61,    7,   37, 1222,  270,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2637,  640,   81,   37, 1832,    1, 2741,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2298,  211,  632, 1821, 1539,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3136,    1,  792, 2708,  792, 3080,  619,  590, 1442,  351,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3309,   37,  100,   98,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  288,   37, 1539,  645,  973, 1159,  160,  616,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1086,  166,  356,   98,  105,  198, 1318,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91, 2216,  104,  297,  800,   60,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2971, 2896,    1,    1,  928,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  437,  696,    1,   32,  133,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  715, 1178,    1,    1,   32,  247,   81,   32,    1, 2666,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,   28,  387, 1194, 1843,   32,  260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2934,    9,  183, 1838,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  336,    1, 1220,    1,  357, 1366, 2233, 1641,   28, 3365,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  332,  631, 2748,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  724,   61, 1176,  227,    9, 1886,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3066,   37,  319, 2741,  548, 3179,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 3125,    1, 3025, 2465,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  422,    1, 1099, 1453,   37,    1,  156,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2827,   32,  492, 1994, 2095, 2625,    1,  947,  583,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2468, 2047,    1,    1,   32, 1764, 1990, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  865,   37,    1, 2921,    1,    9,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  247,  454,   37,  593,  186, 1684,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3079,    1,   81,    1,    1, 1346,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1794, 2097, 1583,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1107,  293,  437,  794, 2086,  767,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,    1, 1159,    1, 1928,   26, 2498,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359, 1288, 2532,  220,  121,   37,    1, 2834,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303,   98,   69,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   62,  361,    1,    9, 1183,    1,    1,  865,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,    1,  310, 2153, 2962,   28, 2396,    1,    1, 2862, 1816,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2648, 2801,  200,  455,   12,  449,    1, 1362,  529,  617,    9,\n",
      "          517,    1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035,  716,   37, 1038,    1,    1, 2530,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,   86, 1656,   15,   71,    1,  419,  384, 1275, 1603,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2569, 2751,   38,  297,  564,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158, 2373,  861, 2432,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    1, 1157,    1,    1,    1,  928,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,   51,  875,    1,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1567,  515,  104, 2161,   12, 3096,  671, 3126,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1238,    1, 1421,  365,    1,    1, 2363,    1,    1,   37, 1018,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  135,  816, 2453,   77, 1684,   32, 1881,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 1571, 2704,  449,  872,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  844,    1,  395, 1662, 2243,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2962,    1,  547,    1,  696,  730, 2614,    1, 3079,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,    1, 2275,   32,  104, 2823,  741,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1375,  353,  737,  354,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2486, 3119,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  344, 2950,  176, 1147,  947, 2190, 2414,    1, 2803,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1076, 2386,  671, 1078,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,   14,   15,   85,    1,  118,   32,  367,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1926, 1927, 1928,  665,  111,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3119,  967,  590, 1890,   45,  845,   22, 2150,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2048,    1,    9,  350,    1, 2083,    1, 1633,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,   12, 3339, 3350,  939,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  199,   37,    1, 2095, 2985,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1797,  286,  126,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3385, 1187,  193,    1,   37,    1, 1133, 1992, 1750,  864,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1830,    9,  166, 2491,   32,   91,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1,    1,   98, 1033,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2117,    1,  907, 3369,  379,  115,   45,    7, 3118,  861,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  176, 1034,  340,  187,  109,  997,  470,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1304,   61, 1229,   37,  138,   59,   32,   12,    1, 1117,    1,\n",
      "         1417,    1,  399,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,   81,   37, 1604,    9, 3263, 3263,  865,  384,    1,\n",
      "          914,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3263,    1, 3287,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375, 1543, 2823, 2855,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2280,    1,  853, 2175,   37, 1204,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1178,    1,  297,    1, 2772,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 1810, 2644, 3102,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  176,    1,  460,   12, 1121, 1330,    1,  220,    1,   28,\n",
      "          542,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2840,   45,  105,    1,  650,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  492,    1, 2985,  205,   37, 2772,    1,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,   37, 1947, 1718,  528,  768,  509,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   20,   24,    1,  610,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2408, 2165, 2438,  220,  943,   45, 2528, 1542, 1230,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,  150,    1,    1, 1490,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   42,   32,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  786, 1333,  631,  176,    1, 3154,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1159, 1089, 1675,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  874,  936, 1610,    1,  159,  670,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,   12, 2813,    9, 2024,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3375, 1173,   37,  627, 2198, 3358,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2975, 2776, 2692,   37,    1, 2308,  111,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   77,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,  168,   79, 2041,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1916, 1594,   28, 1875,  365,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1130, 1505, 1033, 2211,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  189,  159, 1150,  548,   93,  570,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1550,  798,  460,    1, 2646, 3346,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2711,    1,    1, 1492, 1245,  220,   69,    1,   37, 2370,  166,\n",
      "         1354,  888,  384,   68,   69,  423,  963, 2122,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  612,  613,   37,   47,   48,   32, 1597,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1971,    1,  597, 1863, 2572,   32,  451,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3354, 3006,    1, 2764, 2765,   66,    1,  365, 3038,  662,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2103,  617, 1116,  105, 1523,   45,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   65,    1, 1184,  347,   28, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,    1,  166,  632,  633,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162, 1950,  418,   37,  384,  649, 2201, 2003, 2960,  187,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2249,   32,   89,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115,  176, 1971,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2779,    1,  187,  455,   26, 2965,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1027, 2069, 3145,    9, 2512,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,  843, 1545,  220, 2446,  910, 2389, 3213,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739,   12, 2435, 2889,    9, 1694,   45,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101,   22,  477, 2414,  786,   32, 3339, 2649, 2791,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3234,  132,    9,    1, 2802,   98,  429,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  433,  908,    1, 1527,    9,  903,    1, 3165,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3061, 1753,  297, 1206,    1, 2049,  469,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  105, 2177, 1027,  361,  415,    1,  105, 2895,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3168,  140, 1524, 3023,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1323, 1745,  680, 1665,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2646, 1302,  884,  429,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,    1,   37, 2447,   32,  581, 3192, 1463,  444,  854,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  315,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3064,  683, 1249, 3173,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,  324,  835,  326,   12,  327,  112,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1547,  418,  951,   60,  528,  455,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035,  891,    1, 1175,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  315,    1,  187,  390, 1687,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,  396, 2853,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   14,   15,   28,    1,  419,    1,    1,    1,  191,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  170,  220,  215,   12,    1,  437, 1801,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3108, 2365, 3186,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,   26,  242,    1,    1,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  422,  839,  458,   45,  365, 1788,    1,   50,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2301,  166,  845, 1204,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1249,   39,    1,   32,    1, 2041, 2107,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 1675,   98,  844,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2106, 2309, 1905,   37,  726,   32, 3367,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1550,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2677, 2925, 2677,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,    1,   98,  301,  739,  361,    1,  763,   76,  996,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   49, 2845,    1,   54,    5,  302,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12,    1,  738,  964,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1936,   98, 3356,  787,   32,  105,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1925, 1583,  952,   37,    1,  837, 1281,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  573,  686,  256,   37,  533,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1729, 1284,    1,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2680, 2806,  293,  449, 1273, 2693, 1942,    9, 2648,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2175, 1371,  166, 2144,    1, 2871,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  316, 2757,  267, 1123,  132, 1270, 1530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  710,  884, 1003,  176,   26, 1039,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3101, 3160,    1, 3384, 2572,   32, 3339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159,  504,   98,    1,  349,  420,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2980,    1, 1396, 1273,  618,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  624, 2436,    1,    1, 2542,    9, 2977,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2151,    1,   37,   71,   37,  103,   32,  404,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  396, 1918,  176,  186,   45, 1327,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2754, 1920, 3102,   32,  531,  820,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   61,  449,  680,  321, 2819,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,  365,    1, 1013,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233, 2409,    1,    1,    9, 1117, 1525,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  331,    1,  951,    1, 3184, 2789,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   28,  289,   98,   65,    1,    4,    1,   69,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  147,  879,    1, 1942,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  156,  689, 1865,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  364,  476,  726,  191,  388,  763, 1394,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  370,    1,   37, 2446,    1,  844,    1,    1,  289,   98,  999,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3033,   98,    1,    1,  548,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2921,   45,  166, 1298,  249,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  606,  183,  805,   98, 3001, 1397,  506,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,  138,   37,   71,   37, 1632,    1,  506,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  294, 2800,    1, 2578,    1,    1, 2578,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  770,    1, 2260,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  878, 2565,  162,  365,   24,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  775,  224,    9, 2953,  406,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2477,  967,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2065, 1110,  680,   97,   98,  651, 1031,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2117,    1,   37,  186,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1,  331,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3043, 3373, 1976,   63, 1789,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  729, 1555,  247, 1594,  220, 1879,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  491,   37, 1752,  786,  669,    1,    1, 2071,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,  288, 3184, 1918,  837,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   95,  473,  474,  908,    1,  477,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2127, 2432,  193,  320, 2127,    1,  187,  104,  996,   93,\n",
      "           61,    1,  242,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1,  399, 1027,  187, 3359, 1702,   98,  220, 3339,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2309,   61,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3359,  580, 2786, 3339,  741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1855, 2122,  566, 2041,   37,  342,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3380,  361, 3371,    1, 1560,    9,  365,    1,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755, 1627,  166,  111, 1697,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  923,  565,  411,    1,   45,    1, 2146,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1137,   98,  842,   12,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1224,   45,  104,  389,   93, 1071,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  560,  347, 1348,   37,  245,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3155,  477, 2098,    1,    1,  391,  267,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118,   12,  443,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  982,   37,  130,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3035, 2856,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,  443, 1675,   51,   52,   79,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,  155,    7,   67,   37,    1,  105,  356,  845,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1444,    1,  686,  105,    1, 2432,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,   68, 1120,   37, 1334,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1105,  787,  353,  800,   15,  159,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232,    1,  972,   37,   52,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3250,  335,    1,  680,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  958,  547, 3365, 1683,   32, 3360,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  539,    1, 1237, 3116, 3217, 1286, 3179,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  127,    1,    1, 1371,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,  147, 2424,    1,  400,   81,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2733,  154, 1539, 1462,   32,  912, 2434, 2730,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  864,   51, 2199, 2368, 2673,    1, 1232, 3372, 1579,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  919,  163,    1,   12,    1,  909,    1,    1,  962,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   61,  166,    1, 1176,  445,    9, 1739,   37,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2376, 2024, 2223,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3177,   12, 1542,    9, 2846, 3242,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,    1,  927,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3007,  593,   12,    1, 2627, 1107, 1863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  587,  726,  105, 1385,  951,    1,  386,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  105,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  529,  745,   45,   32, 2458,  220,    1,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  683,   37,  856,  593, 2965, 3333,   32,  365, 1788,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,  140, 1322,    9,  365,    1,   97,    1,  202, 1392, 1140,\n",
      "            9,    1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  25, 276,  98, 503,  12, 749, 533,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   98,  105, 1121,  147,    1, 2468,   61,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584, 1022,    1,    1, 2160,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3363,   12, 2342, 2041,  384,    1,   37, 3343,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1788, 1536, 2069,  142,    9, 2826,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3380, 2071,  808,    1,  191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2709, 2100, 1658, 1412, 1107,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2725,    1,    1,    1,    1,    1,  176,    1, 2295, 2302,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2652,    1, 2069, 1777, 2739,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  370,  371,   37,   47,  372,   45,    1,   37,  373,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3364, 2726,    1,    1, 3375,   37,  741,  740,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  963,    1,  928,   45,    1,  114, 3307,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1879,  619,  449,  726,  297,    1, 3103,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2954, 1670,  439,   37, 1477,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1629, 1851,    1,   45,  286,  287,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 1431,  207,   28,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3231,    1, 3225,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1430,  446,  939,    1,  267,  190,  193,  582,  365, 1386,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   25,  504,  187,   69,  980,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1932, 1564,    1,  103,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187,  102,  720,    1,  107,    1,   37,  568,    6,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3111,  240,   57,    9, 3155, 1995,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  191, 1338,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2193, 3362,    1, 2253,  446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   37, 1075,   98, 1275,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1932,  520, 2093,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1973,  132, 1271,  297, 2397, 2108, 2455,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,   12,  327,  132,   66,  187,  955, 2129,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3397, 1562, 1414,   45,  166,  608,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  602, 2682, 1327,  297, 1428,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2412,    1,    1,   12, 1463, 1605,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2940,   98, 2206, 2989, 2086,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 1656, 2596, 2414,  176, 2018,    1,  186,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  288,   37,  138,  453, 2308,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,   85,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3157,   37, 1211, 3354, 3080,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564,  865,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3053,   12, 1183, 2318, 1086,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,  616,    1, 1244,  123,    9, 3121,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,  805,   32, 1973,  714,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2854, 1360,  612,   52,   98, 2879, 1638,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  590, 2876, 1385,  384,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  200, 1778, 2580,    1, 2581,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,   24,   37,   92, 1718,  861,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3382,   32, 2646, 2450,   37,  907, 1147,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  305,    1,   69,   12, 1473,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  399,   32,  573,  149,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1079, 3063,  614,   37,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3337, 1401,  191, 1056,  548,  857,   44,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3171, 1392, 2615,   15, 1330, 1411,   84,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  669,  852,   37,  365,  229,   32, 1046,   45,  768,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  506,  414,  861, 2498,   37, 1192,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,  353,  197,    1,  387,   15,   93,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  691,   12,    1,    1, 1360,  612,    1,    1,    1,  142,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1431,   12,    1,  888,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3226,  379,   81,    1, 2308,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  239,    1,  395,  221,  109,  122,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2175, 1371,    1,    1,    1,    1,    1, 2885,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1086,  539,  458, 1165, 1806,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1547,  418,   98,  301,  783, 1002,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  515, 3103,  110, 2731,  764,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,  28, 219,  25,  88,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  45,   1,   1, 231,   1, 168,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   32,  354,   37, 1973,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  862, 1380,    1,   98, 1171,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1700, 1530,   32,  531, 2137,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2355, 1013, 2107, 1618,   28,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  897, 1813,  455,  361,  395,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  632, 1821, 2640,  877, 2127, 2585,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  403, 1447,   12,  798,  600,    1, 1585, 1240,   52, 2848, 2470,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1449,  613,    1,  413,  220,  182,    1,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1181,  378,    1,  384,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596, 2641,    1,  365,  414, 1015,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  698,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118, 2377, 1046, 1011,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  593, 1139,   45,  223, 1149,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3340,  487, 1920,    1,    9, 1204,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,    1,    1,    1,    1,  980, 1011,  997,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3194, 3195, 2667,    1,  833,  612,  429,  105,    1,   37,    1,\n",
      "           12,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  848, 2344, 1560,   37, 1876, 1234, 1536,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  141,    1,  132, 1268,  454,   37,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1811,  404, 3101,    1, 2766,  547, 3375,   32, 3339,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676,    1, 1231,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   68,   70, 2075, 1425, 1146,  106, 2320,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2334,  396,   37,   52, 1254,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2943,   98,  844,  902,    1, 1159,  522,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2204,    1, 2111,    1,    1,    1,  166,   12,    1, 1117,    1,\n",
      "         1417,    1,   61,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,    1, 2512, 1787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  539,    1, 1878,    1, 2716,   37,  825, 2069,  913,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1181, 2384,  259,  220, 2177, 1027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2160, 2049,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3354, 1497, 2596, 3006,   32,    1, 2517,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  845,  147, 1707, 1377,   45, 1940,   32, 2772,   45,    1,\n",
      "            1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  241, 2137,  135,    1,  854,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1509, 1470,   45,  810,   61,  255,    1, 3022,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1233, 1910,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2795, 1965,  342, 3341, 2825,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,    1,    1,    1,    1, 1936,    1,  131,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  686,    1,  187,  854, 2277,    9, 1056, 2539,\n",
      "          631,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1519,    1, 2126, 1090,  199,  484,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   51,   52,  638,    1,  202,  203,   12,  166,    1,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1554,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523,    1,   98, 2387,  548,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  236,   45,    1, 1271,  649, 1746,    1,  753,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  460,  389,   93,   37, 1121,    9, 1694,   45,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   81,   32, 1343,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  147,    1,   98, 1842,  207,  412,  804,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,  389,    6, 2300,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  614,   28,    9, 1611,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   71,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  550, 1586,    1,  297, 3188,  187, 2925,   12, 1509, 1863,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 3057,   46,  167,   52,    1,   32, 1890,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1068, 1069, 1270, 1271,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    7,  686, 2070,    1,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  891,   32,    1,    1, 2696,   12, 2107,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1900,  817,   32,   98,    1,   37, 1011,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3110, 1310,   37,  439, 1826,  444, 2388,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 229,   1,  69,   1,  25, 417,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 917,  37,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2676, 2137, 2275, 2095,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  743,   12,  267, 1913, 1843,  197, 1672,   37,    1,  105,  332,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275, 1542,  365,  378,    9,  245,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3183,  186,    9,  601,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 1473,  187,  997,  297,  531,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,    1, 2640,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  867, 1236, 1935,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 2261,   37,    1, 2723, 2724, 1825,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  913,    1,   98, 2347, 1638,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115,    1, 1509,  634, 2321,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2236,  884,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006, 2562,    1,    1,  498,   37,  439,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1450, 2856,    1,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  795, 2373,    1,   37, 1531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2039,    1,  163,    1,   12,    1,  863,   63,  460, 2055,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  443, 2938, 2231,    1,    1,  267, 2343,  894,   52, 2399, 2083,\n",
      "          531,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  872,  190,   16,   28,  444, 1194, 2132,  275,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1008, 3013,   12,    1,  187,  582, 2565,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   12,  170,  315,  220, 1327,   12,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 3230,  640,  119, 1642,  187,  104,  335,  674,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  460,   12, 1846, 2056, 1215,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1818,  147,   37, 1709,  912, 2285,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  845,  275,  787,   37,  168,   28,   32, 2755,  854,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2572,   32,  403,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 176, 612,  37, 125, 600,   1,   4,  88,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 982, 315,  37, 125,   1,   4,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1107,  519, 1171,   85, 2633,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3142,  712,   28,    1,   12, 1144,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1031,   32,  166,  649,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  453,  199,   37, 1910, 3187,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3391,  884,  388,  104,  640,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 1749,    1,   98,    1, 2168,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2548,    1, 3361,    1, 2596, 1091,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  366,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361, 2744, 2366,    1,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1, 1380,  691,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 2628,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  258,  819,  753,    9,    1,    1,  361, 1488,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2675,    1, 1352, 1194,  446,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1292,   45, 2994,   12,  365, 2995,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  179,    1,  746, 1776, 1766, 1767,    1, 1259,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 2297, 2764, 3212,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   68,   69, 1426,  119,   98,    1,   69,    1, 1384, 2096,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1581, 1451,    1,  297,    1, 2600,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2483,  469,   37,    1, 2638, 2135,  809,    9,    1, 2332,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  895,  288,   98,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  982, 1774,   39, 2079, 1499, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1562,   10,  115,   45,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  168,    1,    1,  202,    1, 2940,   28,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  348,   37,  151,  238,  351,  624,    9,    1,  372,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2611,  232, 3358,  967,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  359,   37,    1, 1821, 3027,  384,   22,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1199,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773, 2480,   37, 2560,  613,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1081,  947,   84,   28, 2884,    9, 3035,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  353,    1, 2073,  401,  354,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 579,   1,  45,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  50,   1,   1,  32, 531,   1, 622, 267,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12, 2327, 2764,   12, 1667, 1494,   45,  823,  361,\n",
      "         1564,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2717, 2489,  105,  808,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1089,    1, 1220,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,   61, 1156,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  597, 1486, 1831,   61, 1041,   59,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98, 2843, 2523,  204,   61,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2459,   61,  176,    1,   45,  613,    9,  810,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12,    1,    1,   37,    1, 1056, 3033,   98,  228,   74,\n",
      "         2699,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2, 517,  37, 736,  98, 593, 996,  93,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 284, 878,   1,   9, 694,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3303, 2034, 1684,  187, 2523,   61,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1536,    9,  467,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  365, 1030,    1,  361,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,  794, 1260,   98, 3043, 3006,   27, 3343, 2735, 2572,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1537,  446, 2770, 1815,    1, 2924,  698, 2271,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171, 1949, 1056, 1017, 1495,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  195,   61,    1,  191,  453,   13,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  420, 1407,  450, 1429,   98,   71,   32, 1430,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3186, 1831, 1454, 2308,  548,  405,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1899, 2430,    1, 1061,    9, 2772,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  640, 3315,  855,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299,  697,   37,  741,   98,  116,  962,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1523,   45,  166, 2937,  891,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2098,   85,  166, 3278,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1547,  526,  548,    1,  186,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885,  590,    1,    1,    1, 2457,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  795,   22,   82,  796,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   28,   37, 1330,  787,   37,  154,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3375,   37, 1468, 2433, 3399,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,    1,  546, 3162,  176, 3339, 2649, 2791,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  879,  832,  548,   68, 1155,  701,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3333,  105,  125,  530,  166, 1694,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1415,   37,   26, 1039, 2366,  220, 2824, 2234,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2620,  640,  115,   45,    1, 1990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3276,   56, 2622,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  443,  997,  548, 3147, 2874,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2416, 2985,  205, 1797, 1585,   32, 2936,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1802,   25,  439,  176,  339,  845,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  592,   37,  417, 1645,   93,  570,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1445, 1421,    1, 3108,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1178, 2827,  297,  395,   36, 2705,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,    1,  116, 2638, 2931,  625,   32,    1,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3308, 1990,    1, 2622,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,    1,  140,  104,    1, 2472,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  709,    1,    1, 1009, 2145, 2827,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,  387,   93,    1,    1,   67, 1500,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  996,  570,    1,  129,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2889,  384,   91,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  947, 2263, 1178,   98,    1,   45,    1, 1645, 2280,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  792,  356,   45, 1516,    1,  792, 3359,  251,  171,   37,\n",
      "         3375,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3059,  949,    1,    1,  877, 1312,  440,  765,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1842,  361,  613,    1, 1796,   50,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  433, 1042,  736,   98, 2028, 1697, 1281,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  321,    1,    1,  663,   32,  284, 1655,    1, 1818,  147,\n",
      "          261,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  220,    1,   12,  967, 2460,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 2751, 1910, 2646, 3346,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1127,   37,  693, 1507, 1766, 1767,   37,  453, 1273, 2264,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  411,  570,  164,  914,  167,   52,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32,  395, 2201, 2003, 1585,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1270,  249, 2572,  187,  581,   64,   32,  105, 1034, 2682,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1585, 1056, 2572,  176,    1,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1548, 1203,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  861,    1,   32, 2197, 1969, 2147, 2950,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2365,   98,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2, 845, 275, 293, 967, 901,   1,   4,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1, 361,   1,  37, 429, 890,  32,   1,  88,   1,   3,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   99,   12,    1, 1484,   98,  104,   37,  194,  673,  448,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2617, 2237, 3358,  187,  247,  223,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3192,  379, 1140,   79,  691, 2018,  427, 2007,   37, 1884,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3172, 1550,    1,    9,  683,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    4,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,    1, 1844,   39,   98,  915,  873,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  596,    1,    1,    1,  395,   12, 1239,  996,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  357,   10,  190,  193,  805,  104,   93,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3302,  100,   98, 2107,    1, 1559,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1353, 2647,    1,  210,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  395, 2171,    9,  116, 1090,  293,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    8, 2095,  304,   32, 1850,   91,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2584,    1,  427, 3300,  693,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,  267, 1428,   61,    1, 2398,    9,  531,  890,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  207,  418,  159,  245,  187,  983, 1042,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3245,    1,    9, 1517,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,   37, 1664,    1,  361,  861, 1563,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2144,  709,    1,  675,  494, 2430,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2770, 2920, 2172, 2791,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1484,    9,    1,  439,   37, 3114, 1345,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2504, 2700, 1174,  927,   32,  183,    1,  400,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  987,  507,  733,  219, 1501,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,  593,  565,  786,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3287,    1, 1668,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  667, 1557,  650,   37, 1910, 2611,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2146,    1,  140,  142,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  590, 2181,    9, 1090,  911,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   37, 2286, 2343, 3404,   32,  863, 1844,   28,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1820,  297,  403,  464, 1585,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  382,    1,  875,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  548, 1460,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,    1,  539,   32,  443,   45, 1886,  297, 3148,   44,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  879,    1,    1,   37,  301,    1, 2264,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739,    1,  353,  242,  572,  244,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,   49,   50,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,    1, 2838,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,    1,  547,  709,  494,  875,  134,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2486,    1, 1090, 2052, 2007,   37,  567,  510,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  870,    1,  459,  182,  486,  132,  220,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545, 1249, 2448,  787,   37,  103,    1,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1771,  171, 1550,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1280, 2456,  384,  698,   37, 1838,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  943,  176,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3286,   21,  166, 2491,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 1019,    1,    1,    1, 1976,   32,  215,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  625,   45,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  192, 2886,   12,  728,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129, 3210,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1529,    1,  321, 2446, 1117,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3381, 1082,  531,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  369,    1,  580,  822, 1787,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1260,   45,  166, 1529, 1469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  479,  794,  453,  810,  365,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2716, 1414, 1053,  851,   37,  215,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2793,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1050, 2428,    1,   32,    1,  443,    9, 1503,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1110,  729,  606,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 1627,  160,  623,  218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  178, 2708, 3384, 2572,   32, 3101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1763, 2572,   32, 1260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  398,  267, 1369,    1,  138,  804,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340, 2909,  590,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  220,  121,  548, 1657,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2133,    1,  991,  454,    9, 1056,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1002,    1,    1,    1, 1875, 2838,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1366,  321, 2155, 3181, 3177,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307, 1564,    1, 1159, 1054, 2550,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,   95,  220,   20,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2538,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   94,  654,  566,  152,    1,   45, 2095, 1039,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2420,    1, 2308,   45,  166, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2597,  686,   32, 1056, 1479, 1450,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 2862,  446,    1, 2072, 1260,   98,    1, 2206, 3351,    1,\n",
      "          104,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,   12,    1,  103, 2521,  176,   16,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37,  151,  215,    1,  421,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1009,  459,  294,    4,    1,  100,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3364, 1484,   98, 3375,   37,  720, 3344, 2139,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273, 1609,    1,   15,  288,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  572,  197,  418,  995,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  519,   85, 2807,   32,    1, 1838,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2792, 2565, 3264,  796,    1,    1,  542,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708,  178,  590, 1031,   32, 3358,   12, 3137,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2343,  738,  924,    9,  449,  199,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  592,  232, 1082,  497,   37,  544,  388,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2231, 1666,  932,   45,  927, 1159,    1, 1676,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   28,   32,  218,  714,  548,    1, 1126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,  315,    1,   45,    1,  787,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1029, 1457, 2483,  590,  133,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  395, 1518,    1,  792,  116, 2008,  792,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  267,  460,  321,  686, 3006,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1955,  872,   98, 1067,    1, 1656,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  213,   37, 1198,  810,  909,   98,  976,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   99, 1408,  166,  347,  176,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3194, 3195, 2352,    1, 2771,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2314,    1, 1079,  584,    1,   37,    1,  131, 1624,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,  903,    1, 1417,    1,    1, 1252,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  915, 2446,    9, 1778, 1018, 2851, 2051,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2828, 2857,  952,    1,  726,  444, 3191,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2862, 1065, 1190, 2072, 1260,   98, 3351,    1,    1,  104, 1386,\n",
      "          267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 2935, 1194,   73, 2764,  404, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1829, 1510,    1,  673,    1,    1,  734,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835, 1679,    1,    1,  548,  537,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  138,  599,    9,    1,  636, 1336,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  146,  147, 1360,  612,    1,    1,  400,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1487,  636,  423,   66, 1893,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  911,  912,  469,    9,    1,  913,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1712,    1,   12,    1,  302,    1,   37,    1,   12,  721,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 2037,  323,  805, 2981,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  548,  166, 1126,    1,  224,   51, 1188,   37, 1706,   32,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  702, 1008, 1751,  187, 1009,    1,   82,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  550, 1626,  193,  877, 1001,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,  698, 1411, 1090,    9, 3103,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1231,  297,    1, 1887,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2717, 2489,  105,  808,   32,    1,    1, 2700,  774,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1577, 2593, 1507,    1,    1, 1228,  659,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  526,  187,    4, 2101,    1,  657,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  647,  300,    1,   37,  148,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3168, 1564,    1,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  156, 2393,    1,  737,  983,  418,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1360,  612,  335,  460, 2613,  528,  631,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  944,    1,  802,   50,    9,    1,  182,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2778, 1413, 1414,   37,    1, 2712,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2972,  756,   51,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,    1,    1,    1,  176,  754,    1,  193,   32, 3151,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  547,  583,   32,  539,  458,  344, 1585,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  365, 2741,    1,  176,    1,  629,  384,   22, 2150,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2161, 3365, 1683,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 1713,  632,    1, 2227,  872,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1018,  836,    9, 2002,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2262, 2856, 1645, 2924,  361,  294,   32,  557,  540,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1465,  772,   12,  128,    1,  443,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  710, 1366,    1,   28,  156,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,   52,  220, 3232,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1258,  198,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2165,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2570,  787, 2755,   37,  151, 1951,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1338,   45,  105, 1351, 2599,  627,  548, 3358,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,    1,  939,  384,  721,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2523, 1542,   37,  619, 1159, 2482,   45,  365, 1090,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2723, 2724, 2636,    1, 1812,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  437, 1419, 2519, 2895, 2955,   29,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2817, 2856,  176,  177,   32, 3349,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2130,  629, 2151, 3391,  865,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861,   32, 3369,   12, 3118,  105,    1,  663,  437,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 1542,   37,    1,  397, 1288,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,  415,  321,  612,  619,  166, 3130, 1782,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  382,   15,   71,   32, 1352,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,  247,  916,   37, 2230,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2250,    1,  220,  878,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  188,  419,  187,  163,    1,   12,    1,   25, 1155,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 1333,    1,   28, 2494, 1684,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,    1,    1,  148,  361, 1087,    1,  593,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1343,  460, 1114,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  510,    1, 1549,  540,    1, 1554, 1530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1817,    1,  190,  360,    1,    1, 2023,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 2776,  632,    1, 1497,   37, 2324, 1104,  199, 2979,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1471, 2182,    1,  176,  715,  474,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1447,   12,    1,    1,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,   12,  245,  509, 1796,  379,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1191, 1901, 2344,  844,   30,   37, 1465, 2400,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  195, 1464,   37, 1604,   32,    1,   12, 2130,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779,    1,  176, 1447,   26,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  774, 1444, 2233,  221,   37, 1496,    1,    1,   45, 2220,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1118,  691,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  548, 1118,    1,  657, 1394,   37, 1151, 1809, 1758,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  640,  365,  340,  444,   94,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,    1,   37,    1, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2453,    1, 1159, 2069,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   49,  588,  104,  147, 1250,   37,  222, 2270,  333,   32,  121,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1809,  297,  982,  994,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,  132,    1,  202, 2226, 2233, 1604,    9, 1945, 3398,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  632,    1, 3272,    1, 2325,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,   34,  647,  142,   37,    1,  131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2950, 2032,    1, 1034,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1352,  190,   52,  590,  245,    1,    9,    1, 2800,  872,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1100,  353,  197,    1,  387,   15,   93,  159,   71,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   31,  980,   37,    1, 1146, 1703,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,  187,   65, 2509,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2076,    1, 1228, 2234,  802,  920,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103,    1, 1517, 1090,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  964,  590,   46,  220,    1, 2638,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,    1,    1,    1, 2030,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  252,    1, 2591,    1, 1002,    1,  191,  539,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,    1,    1,  191,    1, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  809,  420,  239,  335,  225,   47,   79,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2005,  608,  634,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3168,    1,    1,   37,  726,    1, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496,  575, 1111,   98,  163,    1,   12,    1,  954,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  358, 1070,  147,   37,  125, 1149,  138,   37,    1,   79,\n",
      "          467,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2944,   37,  576, 2924,   37,  531, 1411,  478, 1462, 1190,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 2800,  580,  652, 1484,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228,  497,  726,    1,   98, 1428,  861, 1906,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,   12,  565,   85, 3175,  335, 3201,    1,  631,   32,  166,\n",
      "          539,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1159, 3151, 2158,   45, 2121,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2980,    1,    1, 1994, 2819,  783,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683, 1373,   37,    1, 3103,    1,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1,    1,  880,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,  105, 2219,    1,    1,  207,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,   26,  242,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32,    1, 2774, 1260,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1663, 1821, 2190, 2640,  884,  105, 1747,   32, 3029,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  274, 2629,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3183, 2410,  566,  220,  698,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  542, 1734, 2072, 2317,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2275,   98,  531, 1514,  443,    1, 1514,  913,    1, 1514,  199,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 1579,  469,   37, 1066,   28,    1,   47,    1, 1085,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3374, 1098, 2726,    1, 1260,    1, 1094, 2797,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,   37,   47,    1,  279,  124,   37, 1763,   12,  913,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2871,    1,    1,   32,    1,    1,   91,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1479,  922, 1123,  550,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,  197,   28,   32, 1022,  898,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  580,  149,    9,  840,    1, 1090,  675,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056,  104, 2548, 2572,   32, 3383, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 2401, 2100, 1212,   12, 2735,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  400,  506,   29,    1,   32,  584,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  615,   32,  224, 1013,    9, 1560, 1160,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1484,    1,   32, 3369, 3148, 2928,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1632,   37, 1764, 2069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 1183,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3184,   96,   81,    1,  548,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1821,    1,   85,   37, 3024,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1221,   12, 1977,   37, 2047,  202,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,   51, 1911,    1, 1424,  187,  347,   71,    1,  496,   30,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640,  166, 1030,   32,    1,  628,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 2694, 3148,   32, 3369,   12, 3118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1685,    1, 1512,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3260,  688,  931,   37,  335,    1,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  465, 1895, 1097,  568,  897,   32, 1837,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   46,   98,    1, 1021, 2285,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1171, 2725,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2564,   37, 2446,  166, 2702, 1608,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 326, 200, 365,   1, 361,   1,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 521,   1,   1,   1, 592, 475,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2779, 1632,   37,    1,  915,   56,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3297,    1, 3089,  190, 1343, 2675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,  506, 1355,  111,   11,    1,    1,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  364,    1,  579,  460,  884,   37,   52,  105,  311,\n",
      "         2773,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1210,  105, 3278,    1,    1, 1173,  176, 3013,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3224,    1,    1, 1987,   98, 1056, 1844, 2210,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3013, 1437,  872,    1,  680, 2565,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,  668,    1,   45,  166,  356,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  282,  756,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942, 1822,  764, 1083, 2395,   45, 2657,    8,   32, 2170,    1,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  422,   51,  100,  444,  597,  780,   82,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708,  446, 2188, 1665,   37, 1540,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3374,  837,   45, 2596,   32, 3140,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2689,    1,    1, 2158,    1,  331,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  338,  384, 1653,  548, 2249,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790, 1574,  842,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   49, 1536,    9,  467, 1942,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1027, 1128,  244,   92,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  649, 2817, 1910, 3094, 1530,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,  361,  848,  877, 1702,   63, 2063,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  412,   37, 2733,  193,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  565,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1877,  590, 1427, 2461,  297,  463, 1447,   12, 2673,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 1898, 1273,  618,    1,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,  673,    1, 2198,  736,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,  674,  187, 1545, 1343,  460,  838,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2604,    1,    1,  162, 1539, 2306,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1405,  290, 1396,    1,  508,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   82,   45,  355,  376,  157,    9,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1029,  622,  851, 2421,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  848,  958,  469,   37,   47, 2738, 2186, 1395,    1, 2105,   32,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1236,    1,    1, 1089, 1090,  669,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2932, 1000,  365, 2946,   45, 2527,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  166,  627,   61,  920,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2821,   45, 1059,  162,  140,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2573,   37,  151,    1,   45, 1081,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   99,   12,  475,   60,   94,  765,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1,    1,   32,  453, 1525, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  936,  315,    9,  617,  259, 2105,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  977,  304,  459,    9,  574,  615,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1926, 1927,    1, 1081,   12,    1,    1,  147, 1373,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2563,    1,    1,  187, 3130,  475,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,    1,    9, 2643, 2614,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1728,    1,    1,  587,  686,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  297,  583,   98,  449,   74,   45, 1853,  477,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1380,   98,  166,   97,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2888,  884, 1526,   39,   45, 1158,   12, 2102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1408,  453, 3158,  119,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1350,  924,  884,    1,  176,  990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  581,  401,  646,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3144, 1557,  186, 1908, 1060,   45, 1711,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 2924,   32, 1619,  531, 1673,  365, 1450,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   22,    1,  393,  359,    1,   54,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    1, 1126,  895,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  437, 1261,  620, 2208, 2298,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 2117,    1,    1,    9, 1450,   32, 3118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,  991,  454,    9,  647,  214,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2206, 2207,   12, 1084,  731, 2317,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,  920, 1310,   37, 1344,  166, 2685,  384,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  446,  852,  404,   37, 1725,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1527,    1, 1116,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3012,    1,   37, 2346, 1125,   98,  255,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2442, 1445,    1,    1,    1, 1582,  408,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117,    1,  552,    1,  105,    1,    6, 2150,    1,  220,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1914,  190,  138,    9, 1080,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 3294, 1216,   37, 2587, 2901,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   56, 1476,  574,  441,    1,    9,    1,  442,    1, 1669,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2290,  191,  786,   32,    1, 1990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1628,   74,    9,  195,  441,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1361,  726,  593, 1023, 2472,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  320,  445,  388,  763,  138, 1146,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   98,  829,   12, 2229, 2232,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3380,   37,  907, 2885,  176,  166, 1428,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,  200,  453, 1013, 1522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  978,  769, 2155,  984,   98,  122,  297,  223,  137,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2036,    1,    1,    9,  166,  449, 1463,  361, 2522,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  609,   12, 1623,    1,   32,  700,  637,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1212,    1,    1,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2258, 1167,  168,    1,   98,  166,  207,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1627, 1092,  173,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   37, 1075, 1970,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   94,    1,  288,   28,   37,  947,  166,  593,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,   69,  102,  276,    9, 2073,   73,   74,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1479,  238,    1,  271, 2817,  237,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  365, 2702, 2162,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2343,  967,  449, 1953,  220,  247,  924,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1156, 3382, 2450,  949,    9, 3365,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  305,  245,  187,  883,  972,    1,  424,  339,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  411, 2202, 1380,    1,   98, 2613, 1022,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,  103,  176, 1739,   26,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503,  533,  817,   98,   25,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  531,  437,  267,  998, 1364,    1,    1,    1, 2711, 2764,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2128, 1397,   32,  531,   37,  686,  119,\n",
      "            1,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  613,    1,  103,  131,    1,  267,    1,    1,  918,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2278, 1564,    1,    1, 1049,    1,    1, 1343,  220,    1,  887,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3013, 2800,  872,    1,   28,    9, 1090,  176, 2206, 2207,  171,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  400,  506,    1,   39, 2124,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1717, 2920, 1292,  566,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564, 1343,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  552,  552, 2165, 1073,   85,    1,  867,    1, 2039,  481,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2160, 2049, 1993, 2142,   37,  726,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3149, 2751,    1,    1,  191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096, 3308, 1990,    1,   12,    1,    1, 3186,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035,  267, 2289,   12, 2861,   37, 1038,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878,   37,  741,   98,  131, 2103,  617,  934,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1060, 2827, 3102,  176,  632,   36,    1, 1428, 1004, 1515,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  709, 1688,   45, 1739, 2280, 2430,    9,    1,    1, 1159,\n",
      "         2910,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,    1, 1789, 1009,   12, 2024,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1769,   37,  877,  166,    1,  187,    1,  187,  166,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1917,    1,  683,    1,    1,  664,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3403, 2414,   32,    1,    1,   12,    1,  218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  741,  133,    1,    1,    1,  191, 2780,    1,  565,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1966,  782,    1,    1, 1991,   32, 2705,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1147, 1414, 2833,  674,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273, 2171, 3272,  717,    1, 1037,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1036,   37, 2110, 2771,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  966,  398,    1,  993,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3354, 3384,    1, 2582, 1898,  220,  103, 2764, 2765, 2153,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1355,   45, 2073, 2565,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  218, 2246,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1290,  396,  720,  915, 1034,    1, 2040, 1421,    9, 1016,\n",
      "          218,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  207, 1443,   71,  361,  245,   98,  224, 1126,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 1251,   45,  594, 1393,  218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,   24,  881, 2312,    1, 2312,  123,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  952,    1,  764,   32,    1,  220,  864,    1,  403, 1447,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1746,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  424,  199,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  235,  854,    1, 1421, 2251, 3037,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1087, 1419,  792,    1,  792,    1, 1718,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  806,   16,  105, 1133,  856,  446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,   14,  496, 1770, 1738,  818, 1278,  105,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3167,  810, 3009,    1, 1114,   32,  455,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1853,    1,  191,    1, 1777, 2739,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1948, 2711,   16, 1444, 1445, 1120,    9,  166, 2789,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118, 2751,   51,  319,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  123,  242,   63,  818,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2140,    1,  591,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,   32,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1832,    1,  332,  631,  548,    1,  921,    1,\n",
      "           32,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  105, 1172,  852,   81,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  705,    1,   51,    1,  612, 3375,  606,  105,  311,  863,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3192,  691,  123,   98, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1035,   85,    1,  202,  193,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1687, 1022,    1, 3008,    1,    1,    1,  128,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2578,   32,    1,  176, 1181, 3154,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1, 1765,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700, 2572,  176,  129, 2681,  317,   27, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  515, 3227,   92,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  354,    1, 3290,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1340, 1194, 3212,  415,  105, 1575,   32,  166, 2578,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  334, 2415,  528,  105,    1,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,  803, 1291,    9, 2330,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1417,    1, 2489, 1632,  166,    1,   37,\n",
      "         2449,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  178,  848,  566,  912, 2285, 1597,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2257, 1089, 1675,  384, 1038,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  187, 1420,    1, 1295,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   14,   15,   32,  163,    1,   12,    1,  524,  124,   71,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1079,    9,   10,   37,    1,  531,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  736,   51,   16,    1,   45, 1102,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  103, 1668,   32,    1, 1090,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,   32, 1815, 1313, 1791, 2930,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2807,  321,  221,  873,    1,  202,  321,  612, 2277,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1480,    1, 2593, 2438,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1254, 1178,   32,  593,  967,  638,  669,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2912, 1554,  105,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2286,   37, 1237,   12,    1, 1447,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  792, 2692,  792, 1542,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  449,   37,    1,  593, 2522,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56,    1,    1,   61,  166, 1690,  187,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  297, 2707,   12,  342,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,   25,  245,    1, 1572,  191, 2184,    1,  458,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,    1,   98, 3036, 1281,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  787, 1831,    1, 1231,  297,    1, 2081,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1, 928, 176,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3184, 2322,   98, 1791,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1658,    1,    1, 1232,  460, 1924, 2457,  357, 1686,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,    1,  854, 2303,   37,    1,  955,  956,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1542,   37, 1636,    1, 1085,  220,  131,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  640,  455,   12,  954,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1712,  829,   37,  837,    1,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,   12, 1818,  147, 2450,  797,   37,  463,  464,  443,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1050,  947, 2263,   32, 1994, 2834, 2872,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  776,   45,    1, 3382,    1, 2055,   32, 1081,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  810,    1,  447,   12,    1, 1456,    1,  447,   12, 1637,\n",
      "            1, 2702,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  593, 2522,    1,  582,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  831,   98,  889,  109,  509,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1, 2199,   37, 3343,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  765,  565,  112,  187,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962, 2463,  688,    1,    1, 2920, 2712, 3083,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1795, 2279,   37, 1012,  600,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2994,  659,    1,  820,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2546,    1, 1107,  102,  202,  221,   37,    1, 1158,  190, 1124,\n",
      "          669,   12,  354,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1682,   37, 1599, 2089,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1,    1,   85,   98, 1789,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  857,   16,    1, 3308, 1990,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,  854,  776, 1142, 1229,    1,  191, 2966,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  284,  379, 1670, 1119,  384,  869,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2164, 2478, 1687, 1022,    1, 3008,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,    1, 2217,   37,    1,   39,    1,    1,\n",
      "         1916,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2841,    1,   32,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1431,    1,  829,  872,   98,    1,  535,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,  267,  590, 3118, 2516,  804,    1, 1574, 2774,   46,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 671, 176, 915,   9, 163,   1,  12,   1,   1,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  60, 176,   1, 845, 951,  94,   1,  29,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,   27,  687,   63,  163,    1,   12,    1,   29,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  167, 1121,    1,    1, 1224,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  622, 2764, 3381, 2431, 2572,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187,   68,   69,  109,  897,    1,  493,  102,  720,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2730,  302,  928,   32,  233,  187, 1130, 1758,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178, 1697,  304,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,   12, 2877, 2489,   85,  342,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  137,  815,  853,   29,   37,  506,  629,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2331,    1,  321, 1376,  384,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,  163,    1,   12,    1,    1,    1,   98,  634,  295,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1414, 2856, 1056, 2708, 1763,   32, 3339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 3356,    1,    1,   32, 2375,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  477,  515, 2857, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  267,  531,  443,  155, 1574,   98,   10,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2004,  822, 2221, 1713,   26, 1039,    1,  700,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196,   37,   47,    1, 1541,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1125, 1017, 1288, 1400, 1204,  361,  417,  408,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  355,    6,  156,    1,    1, 1396,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2925,  908,  356,    1,  220, 2114,    1, 2374,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1913,  401,  244,  120,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  321,    1, 1878,  105,  139,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  927,    1, 1159, 2162,   45,  104, 2800, 1292,    1, 3160,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2689, 1717,    1, 2562,  166, 2904,   32, 2513,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2773,   12, 2714,    9,    1, 1292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   12, 1013,  338, 1533, 1139,   45,  224,   12,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  176,  356, 1691, 2408,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1869,    1, 1126,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,   26,  863,  226,   37,    1, 2409,   37, 1504,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  111,    6,  983,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,   32,  489,   39, 1665,  297,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  166, 1551,   45, 1204,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 2591,  891,   32,    1,  863,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  547,    1, 2827,   32, 2107, 1336,  927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3108,  439, 3175, 2335, 1090, 2315, 1045,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2968,    1,  639,    1, 2747,  163,    1,   12,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,   52, 1041,    9, 2089,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1691, 2910, 1018,  460, 1535,    1, 1167,   12,    1,  388,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  259,    1,  167,    1, 2322,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2, 422, 952,  37, 328, 225, 333, 261,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 386, 542, 856, 214, 142,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1059, 2017, 2366, 1455, 1294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,  361,  758,    1,   98,  777, 1085,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2684,    9,    1,   45,    1,   12, 2545, 2658,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   37,   52,  173, 1762,    1,  105, 2309,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,  315,    9,    1,  552,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  716,  119,  197,  202,  157,    1, 1160,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3385,    1,   37,  864,  767,  810, 2778,   37,  166, 1559,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1021,  249,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  105, 1280, 1979, 2530,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938, 1075, 1542,    9,  365, 2731,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  683,  272,   39,  220, 3287,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1452, 1232,  415,  105,    1,    1,    1,    1,    9, 2063,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 2924, 2572,   32, 3360,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1398,  612,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1419,    1,    9, 2366,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2774, 2782,    6,    1,   37,    1,    1,   88,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2827,   32, 2137,  176, 2729,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  301,    5,  302,  991, 1479,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  597, 2231, 1765,  475,  176,  700,   32, 1512,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   12, 1539, 1961,  176,  177, 1890,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  391,    1,  353,  242, 1913,  401,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2253,  593,  238,  109,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 2272,   85,   98, 2975, 1064,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  472, 2025,    1,  744, 2990, 1979,   32,    1,  593,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1082,  864,   37, 2199, 3366,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861,  437,  744,    1, 2146,    9,    1, 3004,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1717,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481, 1349,   37,    1,   98, 1170,  538,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   39,  932,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 2609,    1,  267,    1, 2977, 1831,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  191,  829,    1,   26, 1039,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  316, 2757,  267, 1906, 1380, 1123,   32, 1633,  176,  629,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2648, 2801,    1, 1718,    9, 1411,    1,  618,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 1848, 1682, 1036,   37, 1038,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2885,  697,    9, 2218,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1021,  744, 1126,  636, 2320,    1,   51, 1083,  152,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1835,    1,    1, 2759,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,   32,    1,  297,  247,  223,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  159,  245,  419,  548,  157,  304,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3228,  439, 3276, 2315, 1844,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2438, 2055,  176,    1,  187,  872,    1,    1, 2598,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  631,  176,  814, 1990, 3154,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3361,    1,   37, 1155, 2208, 3057,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3276, 2222,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,  550,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1579, 1021,    1, 1960, 1417,  152,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,    1,    1, 1717,    1,    1,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  206,   12,  197,   28,  419,    1,    1,  921,  308,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2695,  105,    1, 2699, 1961,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3317,  868,    1, 1641,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  251, 3139,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1425,  166, 1833,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3015, 1669,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235,  884,  656, 1267,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2476,   37,    1,  442,   46,   32, 2028,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  909,    1,   59,   71,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2227,    1,  705,    1,  105,    1, 2104,  267,  312, 2432,  719,\n",
      "          388, 1958,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1315,  187,    1,  102,  832,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  531, 2778, 1248,  211,   45,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081, 1679,    1,  379,   32, 2150,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1307,  936, 1273, 2943, 2568, 2639,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2692,  967,    1, 2969,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  615,    1,    1,    1,  131, 1159, 1597,  977,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1340,  640, 1194, 2318,  754, 1844,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,   12, 2877,  879, 2108,    9,  987,  469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  485,   37,  123,  965,    9, 2337,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187,  404, 2926, 2565,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  647,  387,  983,  530, 1944,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584,  741,   61,   62,    1,    9, 1728,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2500,  406, 2260,   37, 3038, 1245,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1249,    1, 3289, 2779,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  765,  167,    1, 3108, 3132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  700, 2416, 1967,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2757,    1, 1906, 2905,    9, 3283,  741,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302, 1712,   37, 1901, 2181,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  691,   12, 1481, 2864,  601, 1002,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1298, 1811,  404,    1,   32,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1204,    1,   32, 3125,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  539,    1,  835,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2615, 1758,   32, 1479,  922, 1123, 3220,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,    1, 1484,  199,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1861,   37,    1,    1,  985,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  119,    1,   32, 1759,  309,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1051,  361,  829,  837,  999,  681,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  142,   37,  207, 1107,  542,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   28,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,    1, 1239,   98, 1687, 1022,    1, 3008,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2925,  908,  356,    1,  220, 2114,    1, 2374,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2145,   37, 2446, 2587, 2523, 2225,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1384,   32,  845, 1220,    1,  340,  109,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  379, 2317,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   69, 1993,   28,   98,  531,    1,  671, 1518,  417,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,  105,  365,  119,  340,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2,  69, 636, 640, 295,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 236, 237,  25, 439, 242,  98, 702, 169, 170, 132,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,   27,   98,  109,  997,   32,  430,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1465,    1,  902,  961,  549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2700,    1,   28,    1,  389,   98, 3012, 2981, 1167,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  334,    1, 1220,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453,  494,    1, 1852, 2228,   79,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  356, 1691,    1, 1976,   32, 1617,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  517,   24,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1029,  936,   69,    5, 1124,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  116,    1,  163,    1,   12,    1, 2179,  736,    1,  496,  267,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1307,  801,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2275, 1562, 1009,   12, 2128,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  448,  246,   98,   60,  646,  640, 1547,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1168, 1554,    1, 1676,  336,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2423,    1, 1827,   26,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2, 236, 237,   1,  79, 365,  69, 119,   1,   1, 242,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 334,   1,   1,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  393,  269,  693,    1,    1,    1,  417,  763, 1567,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226,  331,    1,    1,  267, 1676, 1674, 2965,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3255,  474, 1745, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  919,  909,  548,  163,    1,   12,    1,  459,  302,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1809, 1211,    1,  138,   79,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1699,    1, 1344,   45, 1056,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  565, 1488, 2248,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  439,    1,  220, 2505,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   49, 1576,   37,    1,  400,    9,  104,  467, 2092,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3391,    1, 1800, 1665,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1312, 2572,   32, 2597,  344, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2137, 2747,  501, 2060, 2856,  176,  177,  228,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  670, 1315,  762,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1450, 2354,   32,  903,    1, 1256,    1,    1,    1, 2107,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2863,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275,    9, 2319,    1,   98,  531,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2331, 2861, 1159, 1741,    1, 1798,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785, 2044,  952,    1,   69,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3204,   12,    1, 3282,  744,  166, 2146,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3079, 1176,  445,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,    1,    9,   59,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  164, 1593,   37, 2684,  857,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  604,  102, 1285,  242,  176,  123,   45,   74,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963, 1409, 2384,  166,  792,    1,  187, 2519,  792,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  920, 1075,  861,    1,  486,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1364, 1365, 3079,  335,    1,  297,    1, 2638, 2548,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,  854,  190,    1,  596,  954,  528,  845,   69,  102,\n",
      "            1, 1420,  267,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 3030, 1484,    9, 3369, 1527,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  901,  220, 2961,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  940,   45, 1778, 1607, 1499,   46, 2994,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  729,  387,   15,   28,  419,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  915,    1, 1151,   37, 2684,   98, 1602,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  236, 1022,    1,  186, 1071,  528,  720,   32,   69,  102,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2292,  686,   32,    1,   32,  443,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1920,   90,  147,   45, 3386, 2921,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777,    1, 1001,    1,    1, 1564,  460, 1488,  763, 1361,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  354,   45,    1,  853,  167, 2253,  333,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  307,  813,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2094, 1766, 1767,   85,  384,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3191, 1249, 3312,    1,    1, 3158, 1045,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1542,   37,  619,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  920,    1, 3132,  565,   98, 1568, 1311,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1252,  230, 1024, 2317,    9, 2667, 2887,   27,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  577,    1,    1,  365,    1,   37, 3322,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3401, 3390,   32,  187, 1081, 1009,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  919,  570,    9,  449,  593,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   15,  914, 2055,  220, 1595,  689,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   73,    9,  105,  182,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,  777,  778,  696,    1,    1,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,    1,   81,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  388, 1001,    9,  529, 2727,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1270,  810,    1,  331,  551,  105, 1749,   81, 1126, 1039,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,  119, 1770, 1056,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  951,    1,    1,   32, 2442, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  650,   45, 2397,   12, 2179,    1,  792, 2609,  792,    1, 3389,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  534,  251,  119,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2900,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,  104,    1,  396,  531,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1013, 1522,  550,  424, 1034,    1,    1,  758,    1,  361, 1106,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1333,  683,   12,    1,    1,  147, 1392,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1528,    1, 3164,   45,  104, 1477, 1990,  872,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  578, 1128,  132,  220, 1100,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1173,  829,  803,  112, 2089,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,   85,  202,   66,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 3370, 1231,  176,  104,  622,    1,  548, 1953, 1841,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2968, 1683,  187, 1370,   45, 3082,  269,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3215,    1,   37, 1343,  166, 1555, 1090,  176,  311,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1247,    1,   37, 1046, 2672,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37,  698,    9, 3248,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1243,    1,    1, 1736,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3186,    1, 2317,    9, 2408,  856,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3258, 1938, 2809,   37,  865,   37,    1,  827,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 1091,  361,  587, 1822, 1046,   28,   37,  672,    4,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1,   37,   47,  327,  112,  548,  326,  132,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,   69,    1,  729,    1,   32,    4, 1559,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  636,  423,    9,  112,  858,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671, 1078, 1355,  695, 1167, 1584, 1076,  142,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   12,  551,  552, 1064,  453,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1679, 3343, 3080,  176, 3363,   12, 2099,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  590,  388,    1,  500,    1,    9, 1935,    1,  636,  443,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  354,  227,    9,  575,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   70,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,  219, 2699, 3062,    1,    1,   45, 3024,  361,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  742, 1284, 1328,  528,  542, 1557,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   12,    1, 2483, 1876,    9, 1502,   12, 1503,  142,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  709, 3141, 1292,    1,    1, 2356,   45,    1,  966,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2650, 2851,    1,  304,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3303,  953, 2072,    1,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1726, 1980,   37, 1814, 1816,   45,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1652,   96,  105,  572,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808, 1831,   32, 1821, 2057,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1090,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,  166,  858, 2401,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   66,  526,  565,   69, 1993,  242,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1, 3247,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  852, 1836,   37,  105,  241,  698,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  845,  237, 1421,   61, 1810, 1354, 2713,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2412, 1955, 1761,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61, 2222,   39,   45, 3116, 3217,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3260,    1,   28,  227,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1568,    1, 1608,  984,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1378,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2806,    1,  618,    9,  207,  279, 1484,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1586,  273,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974,  288,   37,  335, 2695, 2223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1789,    1,   12,  197,   85,  118,   32,   72,  401,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  765,   28,   37,  112,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158, 2102,  640,   59,   15,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  410,    1,   45,    1,  606, 1515,   74,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,    1, 2018,   37, 2000, 2128,    1,  384, 1815,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1867,    1, 2320, 2673, 3085, 1461,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  560, 1274, 1253,   32, 1275, 1034,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2855, 1343,   98,  997,   45, 1450,    1,  443,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  190,  771,  587,   32,  395,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2484,    1,    1, 2451,  729, 1542,    9, 1257, 1904,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  215, 3102,   32,  531,  513,    9, 1204,  548, 2476, 2572,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,  313,  340, 1251,  466,  116,    1,  176, 2065,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   38, 1684,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   72,  401,  156,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2139,   37, 1154,  864,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,    1,  193, 2040,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69, 2405, 1750,    1,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2987, 2988,  167,  688,    1, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  288,   37,   92,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1140,    9,  290, 1159, 1639, 1465,  298,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  837, 1137,    1,  202,  307,  308,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2883, 1360,  612,    1,  103,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3089,  707,    1,   37,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  159,   32,    1,  669, 1374,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2707,   45,  166, 1034,  166, 2925,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  197,   28,   32, 1022,  898,  401,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  479,    1,  971,  802,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1788,    1,  191,    1, 1674, 1323,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 2018, 1542,   37,  221, 2017,  384, 1428, 3146,   98,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596,  616,  163,    1,   12,    1,  305,    1,  682,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,  187, 1158, 1765,  388,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1465,  765,  384,    1,   37, 2301, 2012,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  415,  885,   74,   32,  166,    1,  187,   69,  921,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1138,  108,  197, 1139,   45,  739,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1643,    1, 1087,  872,   98,    1,    1, 1996,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1268, 1772,   37,  386,  781,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3213,    1,  176, 3281,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2620, 2150,   28,  118,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  294,    1,  884, 2161,   12,  810, 1425, 3208,  671,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1545, 1188,   37, 1296,   79,    1,  384, 1691,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1485,  518, 1190,  933,  673,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3094, 2572,  187,  104, 2924, 1523, 3006,   32, 3356,  787,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2018,  267,  460,  113, 2985,  330,  183, 1450,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1062,  458,    1,    1,    1,  875, 1116,  134,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3194, 3195,  879,    1, 1632,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2094,   26, 1039,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2246,    1,  103, 2184,   37,  726, 1194,   73,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   36, 3071,    1, 2169,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 1408,  183,    1,   98,    1,  384, 1033,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2453, 2827,  191, 3180,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  310,   25,  455,   12, 2648,  682,  691,   12, 1420,    1,  418,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 3121, 2861,    9, 2785,  686, 2140,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2002, 3222, 2107,  420,    1,  396,  449,  726,   45,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  542, 1403, 1816,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  761,  195,    1,  598,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1,  829,   37,    1,    1, 1411,  339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2981,  298,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1464,   98, 1821, 2190,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 1602, 2539,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  896,    1,    1, 3277,    1,    1,    1,    1,  631,  166,    1,\n",
      "            9, 1777,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,  302,   37,  619, 1133,   98,  195,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453,   12,  245,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1126,  102,  176,  332, 1039,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,  567,  488, 1817,    1, 1821,  656,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  569,  190,   52, 1460,    1,    1, 1748,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1962,  140,    1,  372,   94, 1085,   24,  384, 2656,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  200,  365,    1,  361,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2749,   28,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  232, 2047,    1,    1,   37,   69,  636,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2615,  477,   81,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  504,  297,  331, 1479,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3262, 2671, 2912,  928,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596,   32,    1,    1,  218, 2414,    1, 2766,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  187,   15,  245,    1,    1, 1091, 1278,  388,   98, 1299,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   64, 2134,  350,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1573,  166,    1, 1090,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3012, 3027,   37,   52, 1866,   37, 1440,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1079,    1,   37,    1, 3231,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190,   69, 1125,  105,  114,  680,   31,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   17,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1233, 1149,  469,  477,  297,  389,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1,  657, 1413, 1414,   37, 1835, 2894,  618,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1950,    1,  197, 1137,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2623,  548, 2275,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  829, 2587, 2692,   37,    1, 2975, 2964,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  398,  261,   32,    1,   45,    1,    1,   43,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  160, 1161,  338,   32, 1688,  496,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  726, 1924,  590,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1520,  256, 2177,  988,   37,  453, 1718, 2419,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3043, 3006, 2572,   32, 1785, 1388,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  694,    1,  405,    1,    1,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1654,    1,  631,  548,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1706,  331,   32,    1,  250,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  355,    1,  342,   27, 1350,  399,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  197,  388,  763, 1660,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1656, 3389, 1296, 2597,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,   28,   32,  317,   65,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  961,    5, 1346,  477,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1411, 1821, 2190, 2640,   37, 1539,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1, 3130, 1924,  105,  784, 1844,   85,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  159,   71,   37, 1637, 1722,   32,   56,  537,   98, 1230,\n",
      "         1220,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2466,    1, 1027, 1988,   45,    1,  931,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1168,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2161,  836,  166,  823,    1,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713,    1,  260,    1, 1877, 1860,   45,  960, 1628,  112,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  168,   32, 2924, 1296,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2295,   37,   47,  787, 1491,    1,   98, 1095,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2292,    1, 2708,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,  335,  297,  187,    1, 2565,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147,  863, 2306,    1, 1159,  241, 1820,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  103, 1569,  220,    1, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1299,    1,   12,   74,   32,  166, 1361,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   37, 1174,  350, 1069,   45, 1698,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  168,   98,  166,  335,  220, 1252, 2966, 1372,    9,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,    1,  680,   97,   37,  221,    4,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2095,   32, 3070,  193,    1,  191, 2330, 1389,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656,    1,   32, 2597,  361, 3383,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2965,    1, 2421,   39,   45,  593,   26,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  437,  315,   37,  698,  785,  786,  872,    9,  914,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2525,   45, 2376, 2223,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1936, 2135,   45,  112,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  147, 1250, 1086, 3101,  477,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   37,   77, 3127,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2414, 1312,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1023, 1204,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1497,  193,    1,    1,  202, 1173,    1, 2398,  176,  187, 2631,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  726,    1, 3207,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  597, 2548,  335,  297, 3362,   12,  754,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  153,    1,  162,  105, 1479,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2, 105,   1, 176,  38,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 215, 611,   1, 176, 119, 845,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3170, 1463, 1820,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1,  489,    1,   45, 2862, 2396,  548,    1, 1296,   28,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  680,   24,  220, 3271, 1632,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3111, 2572,   32,  531, 1345,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1962,  108,    1,  259, 2866,  167, 1080, 2322,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1423, 2272,   85,   98,  116,  133,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,   28,    1, 1228,  973,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1191,    1,  500,  872,   37, 2654,  116, 1089,   98, 1220,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1159,  111, 2218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,  147,   37,  804,   98,    1, 1305,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2922,    1, 2925,    1,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3360,   12,  863,  104,    1, 2860, 1822,    1, 1183, 2113,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  105,  686,   32,  572,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,  957, 1579, 1839,    1,  300,   37, 3372,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3371,    1, 2531,  446, 1010, 1860,  191,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  861,    1,   32,    1,  111, 1748,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  885,    1,   32,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1,    1, 2254,  875,  845, 2326, 2096,  297, 2255,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1181, 1660,    1, 1102,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  330,  191, 2751,   61,    1,   32,   36,   12, 2126,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 326,  72, 401, 207, 526, 548,  44,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 782, 160, 783,  28, 105, 784,  88,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   32,  166,  823,   45,  166,  613,  259,    1,  105,    1, 1223,\n",
      "         1489,  166,  311, 1265,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  776,   45, 2282,    1, 2317,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  613, 1256, 2146, 1268,  455,   37,  166, 1766, 1767,  593,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1390,  871,    1, 1315,  689,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  848, 1303,  551,  196,  613,    1,    1,  105, 1273,  259,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2877,  113,    1,  220, 3045,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2142,  162, 2761,    1,  361, 2689,    1,  384, 2672,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  207,  388,  763, 1660,   98,    1,   15,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3222,  105, 2107,  220,    1,  176,   48,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,  856,   45,  247, 1204,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2066,   68,   69,  102,  576,   25,  417,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1771,  171,    1, 2451,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  280,  832, 1159,  388,  844,   30,    1,  220,  764,  384,  365,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  863,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1732, 1581, 1412, 1089,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,   47,    1,   98,  912,  332, 1108,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1,   60,    1,  769,   37,  817,   98,  236, 1022,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  305,  417,  528,   32,  260,    1,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597, 2664, 1236,    1,    9,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2153, 1911, 3351,    1, 1816,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   61, 2869, 1089, 1542,    9, 1065,  199,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  852,   37,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   36,   37,   38,   39,   40,   41,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3166,    1,  590,    1, 3119,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3340,  384, 2597,  756,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  868, 3381, 1074,    1, 1887,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3213,    1,  191, 1545,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1743,  190, 1980,   98,  340,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  197, 1137,   98,  983,  120,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  803,  681,    1,    9,    1,   45,  861,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  590, 1023, 1553,  220, 1023, 1204,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   25,  700,  191,    1,  548,  657,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2960,   32,  395, 2201, 2003,    1, 3156,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  581, 2132, 3079, 2084, 1787,   45,  166,  356,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,  657,    1, 1087, 2336, 1651, 2657,   37,  439,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584, 1117,  741,  506,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  961,  957,  958,  673,    1,   45,    1,  131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963, 2102, 1107,  525, 2052, 3011,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1106,    1, 3005,   61,  590, 2181,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 3160, 2317,   32, 3065,   12, 2162,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,  387,  590,    1,   45,  395, 2108, 1281,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,  108,   45,  417,   15,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3301,    1,  260,  361,    1, 2747,  166,  484,   37,  114,    1,\n",
      "         3301,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   95,  473,   37,  429,  477,  741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,   32, 2340,    9, 2459,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1536,  149,  444, 1791,  792, 2650,  792,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 197, 304, 640, 159,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  58, 197, 407,   1, 157,  61, 969,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  593,   69,  102,  686,  106,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  780,  267,  156,  388,  763, 2316,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2733,  776, 1268,  220, 2154, 2086,  798,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3069,  190,    1,  531, 2172, 2699,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1564,  183,  805,   98, 3228,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1913,  199, 2493, 2213,    1,    9, 2379,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  961,    1,   37,   52,    1,  131,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1319, 2237,  193, 2323, 1211,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2221,    1, 1509,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2102,  942, 1781,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  187, 3194, 3195,  831,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1303, 1111,  528,   93,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 1674,    1, 2572,   32,  298,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1010,  166,    1,    1,  166,  730, 2614,  544,  193,  720,  166,\n",
      "          873,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  758, 1713,  468,   37,    1, 2937,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  892,   12, 1675,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1839,   32, 1881,    1,  163,    1,  903,    1,   46, 1174,   32,\n",
      "         1488,  651,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1408,  661,   98,  166, 2223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  951,    1, 2142,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1, 1151, 1660,    1,  846,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3261, 1082, 2592,  193,   37,    1, 2890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  410,  187,   65,  155,  347, 1051,    1,  275,  159,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2868,   37, 2237,   91,    1, 2170,   98,    1, 2699,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  316,    1, 3251, 1012, 2247,  639,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,   12, 1126,    1,  689,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  255, 1462,    1,  104,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  303,  300,   60,   37,    1,  340,  951, 1547,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,  361, 2608, 1085,    7,    9, 1652,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  212,    1,  620,  441,    9, 1791,  768,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  721,    1,  131, 1889,    1,  210,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  582,  267,  277,    1,  375,  815, 2901,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2615,    1, 3269,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  891,  187,    1,   37, 1194, 1856,   45,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  457,    1,  614,   37, 1821,  361,   81,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  677,   32, 1744, 2433,  616,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3253,   32,   72, 1385,   45, 2936, 3329,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3086, 1009,  108, 1414,  190,  132,  220, 2751,   32,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2558, 2253, 1778,    1, 1718, 2261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1607, 1784,   32, 2925,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  163,    1,  903,    1,  232,    1,    1,  674,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  177,  972,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1011,  639,  992,   28, 3369, 1527,  187,    1,  914,    1,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1484,   26, 1039, 2079, 2798, 1542, 3004,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090, 2697,  166,    1,  245,  628,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3184, 1557,  650, 2356,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2919, 1585,   32, 2597,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1492,  108,   45,  388, 2500, 2705,  548, 2527,  164,   12,  645,\n",
      "         2566,   32,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,    1,  167, 1371,  420,   37, 1604,  465,   95,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2,  69, 669,   1, 583, 575, 437,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  56, 388, 640,   1,  56, 388, 640,   1,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2722, 3074,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,  920,    1, 1139, 2845, 3226,  565,    1,    1, 1021,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3229, 2743,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1600,  261, 1031,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1481, 1349,   37,  221,   37, 1170,  538,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2034,  671,    1, 1624,    9,  166,  449,  199,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  294,    1,  353,  197,    1, 2055,  158,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1142,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3360,  288,   37,    1, 1054,  826,  808,    9, 1033,  104,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2146,    1,  458, 1802,  936, 1499, 1064,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141,  365,    1,    1, 2295, 2138,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2235,  891,   37,    1,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3228,  565,   98, 1324, 2335,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537,    1,    1,   37,    1,    1,   32,  786,  356,    9,   59,\n",
      "         1714,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 3144, 1002,  852,  972,  454,   39,   45, 1512,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  743,   12,  244,  120,   98,  163,    1,   12,    1,   15,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1019,    1, 2952,  915,    1, 2500,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  474, 1755,  176, 1956,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 2996,    7, 2851, 1816,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1153,    1,  176,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2578, 2850,   37,  726,  463, 1447,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 3006,  720, 3127, 3082, 1220,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1718,    1, 2652, 2225, 1031,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1269,  176,    1,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3101, 3372,  908,    1,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,  361,  864,   37,  907, 1114,   98, 2673, 1816,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1861,    1,   79, 1596, 1574,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,    1, 2017,   98, 3373,  187,   10, 2344,  289,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3297,  921, 1252,    9,  422, 1684,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2241,   45,  754, 2910,    1,  220, 2650,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  391,    1,  197,  407,    1, 1500, 1698,  356, 1470,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2137,   79,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2962,    1,  670,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   12,  365, 2480, 1089, 1090, 1294, 2371,   37, 1237,  218,\n",
      "           32, 1837,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2227,  221,   37, 1048, 1171,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187,  105, 1204,    1,    1,  166,    1, 1841,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3297,    1, 2337,  510, 1774, 1632,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2024,   98, 3024,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2942,  256,    1,   37,  247,    1,   45,  671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  557,  540,    1,  114, 1086,  220,    1,  444, 2774,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3221, 1408, 1684,  220, 1194, 1385,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1445, 1421,  917,    1, 2805, 1024,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  342, 1164,  640,  864,  220, 2673, 1757,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1231,  220, 1095, 1283,  841,  126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1230,    1,  315,  225, 1996,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  920, 3360,  719,  105, 2804,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  813, 1695,  155,    1,   45,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  244, 1980,   37,  973,   25,  242,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  902,    1,  191,    1,  501,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2573, 2590,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  691,  365, 2036,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 2303,  424, 1034,   98, 1503,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,   96,    1,   37, 1889,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187,  475,   45, 2708,  861, 1906,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 1708, 2606,    1,  384, 2083,  104,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3318, 1844, 1045,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,    1, 1867, 1089, 1013,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  327, 2264,  420, 2205,  220, 3068,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2893,  267,  204, 1360,  612,  619, 1439,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303,   37,    1,   67,  423, 1470,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  263,    1,  156,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1542,   37,  335, 1411,   84, 2100, 2041,   81,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1154, 3243, 2711,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 2151,    1,   32,  219, 2579,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2984,    1,  162,    1, 1593,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,  437, 1702,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  216,  135, 2597,    1, 2675,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,  967,  590, 2537,  472,  220,  375,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  702,   11,  169,   32,    1,  131,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403, 1447,    1,  350,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  775,  552,  552, 2706,  472,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1509,    1,  247, 1944,   98, 1545, 1246,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,   37,    1, 1147,  734,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,    1,   98,  365,   38, 2827, 2402,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  579,  321, 1257,  544,    9,  334,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12, 2252,    1, 2632,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2711, 1838,  914,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228, 3375, 2572, 3101, 1260, 1167,    1, 3374, 2042,   32, 3339,\n",
      "          787,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1366,  190,  335, 1161, 1159, 2069,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  476,   37,  125,    4,    1, 2035, 2567, 2074,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  859,   37, 1334,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2963,  726,   61,  943,   45, 1171,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,  187,  753,    1,    9, 2249, 1295,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1708,  778,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  344, 3035, 2856, 3361,   32,  120,   45, 2292,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1412,    1,    1,    1,   28,    1,   51, 2394,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  597,    1,  582, 1061,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    4,  420, 1702,   25,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  967, 1658,  858, 2582,  453,    1,    1,  327,  593,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  247,  454, 1836,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2957, 2850,   37,    1, 2334, 1684,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  134, 2917,  444,    1, 2547,   32, 2930,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  150, 1292,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,  506,    1,   93,   32,  903,    1, 1256,    1,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1485, 3102,  437,    1,    9,    1,  949,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1528,  159,  631,  176,  654,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2254,   43, 1251, 1361,    1, 2048,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   34, 2741,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  548,  166, 2785,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123,  730, 2614,  661,  439,   37,  593, 2522,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1762, 3168,    1,   32,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2005,   28,  845,  439,  988,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3072,   12,  365, 2382,    1, 1542,    9, 1821,  361,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2292,    1,  176,  116,  772,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1988,   22,  854, 3403,   61,  105, 2566,   45,    1,  750, 1576,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  595,    1, 3358,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2090,  162, 2505,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2934,    9,  885,  270,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  287,    1,    1,  361,  105,  784,   45, 2325,   98, 1802, 1708,\n",
      "         2290,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  327, 1167,    1,  311, 1021,    1,  361,  810,  415,    9,\n",
      "         2349,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  828, 2360,  503,    1,  790,  297,  749,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,  775,    9,  602,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  488,   37,  720, 2308,  384, 1990,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  836,    1,   32,    1, 1260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  437,  567,   51, 1251,  137,    1,  182,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1,  945,   69,   12, 1772,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1918,   30, 3343, 2169,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018,    1,    1, 1013,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2222, 1284, 1922, 1333,   32, 1567,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  204,   12, 2222,  686,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1164,   32,    1, 1381,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  397,  566,  163,    1,   12,    1,    1,  777,    1, 1281,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,   12, 2759, 1228,    1,  810,   45, 2278,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  879, 1965, 2550, 2699,  257,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  213,   37,  356,  132,  220, 2142,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  952,   37,    1, 1988,    1,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  439,    1, 1281,    1,  531, 3102,    1, 1152,  447,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2565,  476,  872,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3364, 1809, 1647,   98,  105, 1302,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  444, 1658, 1678,    1, 3122, 1592,  361,    1,   32,  424,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1492,  108, 2504, 2527,  164,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1230,  203, 1183,  190,  460,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   45,  507,   37,    1,    1, 2348,  618,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  543,    1,    1, 1146,   74,   45,  365,   69,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,   25,  698,   98, 1894, 1318,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 3118,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  941, 2104,  267,  453,  154,    1,  987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  971,    1,  387,  388, 2690,   98,  627, 1975,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3268,    1,    1,   12, 2101,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,  587, 1174,  105,  365, 1385,   45,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3349, 2785, 2162, 1950,  167,  759,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3096, 1693, 2038,  922,  590, 1031,  187,  103,   56,  726,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2572,   32, 1785, 1948,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2688, 2572,   32, 2433,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1,    1,   98,  365, 2366,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  156,   37,  245,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  499, 2610,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1947, 3343,  863,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  912, 2285, 1074,    1,    1,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  919, 3110,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,   37, 2192, 2868,  543,   98,  539,  458, 2128,    6,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2628, 2871,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  202,  321, 1658,   80, 1108,  544,  424,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3339,    1,    1,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,  147,   57,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  593,   12,  553,  161, 2607,    1,  580,  537,  611,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1470,  590,    1,   98, 2834,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2673,    1,    1,    1,   37,  447,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1,   57,  384,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1,    1,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   93,    1,    1,    1,   37,    1,    1, 2103, 2727,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1376,   32,  217,  696, 1043,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,  105,    1, 1223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  878, 1236,    1,  297, 2208,  675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2212,  861, 1639,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,   37, 1947,  148,  214,  716,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   74,   32, 3311, 3310, 1723,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  964,  267,  632,   69,  441,  565,    1, 1069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  431,  342,    1,  187,    1,    1,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  597,  391, 1401,    1,   32, 1081,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3300,    1,  191, 3263, 1462,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2768, 1965, 1728, 1468, 1204,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  586,  387,    1,  142,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2254,    1,  326, 1937,  661,   37,  661,   98,  365, 1521,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102, 1253,   37,  119,  845,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1494,  754, 2440,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  696, 1000,  365, 3022,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1631,  166, 2481,  176, 1687, 1022,    1, 3008,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,   37,  899, 3107, 3366,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,  388, 3229, 2795,   32, 2748,    1,  614,   98,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  761,  641,  304,   98,    1,    1,  629,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1092, 1536,  552,  552, 1377,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  267,  388,  600,  542,  763, 2308,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   45,  985,  595,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,  727,  613, 2257,  259,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,   34, 3019,   12,  846,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2695, 2223,    9,  593,   12, 3088,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  785,  786, 2107, 2524,  395,   12,  365,    1,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3183, 1421,    1,    1,   37,  786,  356,  132,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  796,  187, 2748, 2565,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,   63,   65,  738,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   25, 1473,   98,  198,  996,   29,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,  421, 1842,    1,  613,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1178, 1827,    1,    9, 1204, 2191,  166,  439,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,  166, 2391,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  515, 1244,  388,  199,   37, 1463, 2851,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  361,  920,    9,    1,  699, 2267,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  496,  958,  460, 2161,    1, 1940,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  267,    1,  190,  193,    1,  829,   43,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2177,  260,    1, 1454, 3378,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   70,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  393,    1,  104,   22,   25,  720,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1,   28,  453,  248, 2943,    1, 1294,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  205,    9,   10,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,  908,  302,    1, 2650,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3358, 2312,    1,    1, 2708, 2153,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3387, 2870, 2756, 1625,  220,  228, 2909,   32,  166, 1050,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,    1,    1,  105, 1717,    1, 1842,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2308, 2000,    1, 1958, 1563,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3242, 2226,  190,  193,    1,    1, 2226, 2143,  166, 2308,    1,\n",
      "         2226, 2898, 1366,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1033, 2211, 2153,   37,    1,  593,  442,    1,  856, 2095,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1340, 1924, 1514,  221,    9, 3271,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1, 1273, 1140, 2587,    1,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3340, 1072, 1235, 1683,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,   98, 1017,    1,  176,  245, 1721, 1953,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3272,    1,   32,    1,   26,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1852,    1,  183,   56, 2089,  681,  202,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1125,    1,   37, 1334,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  121,    1, 1839,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1082,  864,   37,  899, 3366,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  798,   37,  288,  365,  844,    1,  119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2748,    1,  105, 2237,   37,  166,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  318,   12, 1586,  166, 1509,   45,  255,  777, 1085,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,  361,  166,  443, 2083,  166, 2009,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2372,    1,    1,  379,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 2946, 1976,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2397, 1710,    1, 1232,  903,    1, 1973,  132,   61,    1,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1539,   45,  365, 1663, 1821, 2190, 2640,  288,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2700,   37,  506,  903,    1,  904,    1,    1, 2830,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  188,    1,  657,   28,   63,  862,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,  98, 575,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 793,   1, 453, 573, 315,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  199, 1411,   32,  525,    9, 3238,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  361, 2018,    1,  176,    1, 1815, 2024,  469,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3072,    1, 1921,   32, 2304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2976, 1389,    1,    9,  961, 1132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1186, 1670, 1876,   37, 2446, 2103,  617, 1281,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,   32, 1568, 1311,   98, 1610,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   60, 1141,   37, 2035,  471,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2139,    9,  166,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  303,  108, 1167,  104,    1,    1,  629,   37,   60,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1419, 2764, 3155,    1,  548, 1450,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  111, 1107,  151,  951,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,    1,   45,  121,    1, 1536,    9,  467,   32,  104,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  777, 1013,  220, 2368,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1822,  877,  704,  551,  705,    1,    1,  112, 2153, 1152,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1718, 2355,    1,  315,  224, 2304, 1013,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2755,  624,    1,  716,  803, 1253,   32,   72,  401,  197,  528,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1087,   12,    1, 2537,  920,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  528,  961, 1001,    1,  590,    1,   32, 1117, 2208,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1086,  537,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2146,  458,  313,   37,  860,  841,  629, 1499,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3262, 1798,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  773,  317,    1,  818,   15,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094, 2072, 2162,   45, 3374,  650,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228, 1530,    1,  547, 2347,   32, 1981,  433,  546,   32, 1531,\n",
      "          274,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  391, 1329,  353,  354,  202,  236, 1022,    1,  681,    1, 1103,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 1572,  437,  213,   37,  151,  849, 1662,    1,    9,    1,\n",
      "          131,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  715,   89, 2087, 2526,    9,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   29,  384,    1, 1361,  927, 1866,   37,  878,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  358, 1070,  467,  398,   37,    1,  547,  474, 1495,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089,   45, 3026,   45,  487, 3102, 1905,   98,  116,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  294,  922,  331,    1, 1917,    1,  552,    1, 1624,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  374,    1,  329,    1,   12,  552,  720,  118,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2700, 1000,  365, 2946,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   12,  964,    1, 3144,  446,   32,  844,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1087,  859,   37,    1, 1250,    1, 2298,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2802,  884,    1,    1,  220, 1524,    1, 2674,  140,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1, 1717,   32,    1,    1,  149,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2899, 2790, 2914,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  458,   45,  507,   37,  125,  388,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1584,  166, 2480, 1675, 1174,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  818,    1,  565, 1637,    9,  124, 1167,    1,   98, 1981,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  921,    1, 1463,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,  183, 1410,  872,   37,  693, 1772,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 2308,  693,  118,    1,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,  750,    1,  313,    9,    1,  675,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2823, 2107,  614, 1159,  581, 1385,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2982,    1, 2453, 2250,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,  190, 2122,  115,  220,    1,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,  146,   37,  903,    1, 1447,    9, 2390,   46,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,  251,    1, 1151,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018,  267,  460,  967,    1, 2095,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2844,   45,    1, 2693,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2966,  884,    1,   32,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2137, 2856,   98, 2835, 3101, 2735,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2171, 2800,    1,  163,  884,   98,  365,    1,  176, 2755, 3010,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115, 1508,    1, 1247,   37, 1700,  356,  881,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  148, 1445,  879,  647,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  192,  162,  105, 2276,   33,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,  671,    9, 2942,  187, 3163,  872,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3155,    1,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  354,  408,  968,  103, 1990, 3275, 1569,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1763,   12,  913,   61,   37,   52,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  750,  475, 1112, 1796, 2924,  167, 2449,   32,  531, 1632,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2834, 3343, 3006,  774,   37,  429,   46,   98, 1428, 3365,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3103,    1, 2136,   24,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189, 1702,   81,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1, 1559,  176, 1512,  402,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2107,    1,   98, 1001,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,   37,  907,   32,    1,    1, 1840,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 2216,    1,    9,  164, 1333,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1794, 2352,    1, 2771,  142,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1037, 3272,  590,    1, 2142,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1008,    1, 1644,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066, 1442,  980,  311,   97,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  132, 1679,  104,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707,   12, 1183, 2041,   37,  342,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  811,  413,  884,    1,   45, 1009,   12, 2789,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1414, 2856, 2751,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  284,  163,    1,   12,    1,    1,    1,    1,  157,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1187,  224, 2355, 1013,    1,  762,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    1, 1194, 2107,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,    9,    1,    1,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3194, 3195,  921, 3190,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826,    1,  744,  671, 2146,   32,    1, 2457,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  596, 1151,   15, 1672,    1,   32, 1352,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1840,   37,  335,   50,  457,   32,  987,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3247, 3229,  967, 3190,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  267,  306,    1, 1317,  704,  104, 1822, 1604, 2444,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 2467,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,   37,  125,    1,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,   25,  429,  803,  682,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  397,  958,  695,  444,  104,   32,    1, 2096,  220,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1546, 1082,  249,   37,  335,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596, 1151,   15,   93,    1,   32,  871,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  931,  186,  384, 1844,  448,   37, 1832, 1090,  786,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  129,   37,  151,    1,  772,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2823, 1708,   37, 1332,    1,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973, 1164,  606,    1, 2883,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  496,  495,    1, 1173,  227,  202, 1115,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  437,  213,   37,  151,  849,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   51,  606,    1, 3012,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   28,  548,  132,   37,   47,   50,   37,    1,    9,    1,\n",
      "          372,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1190,  577,   98,  651, 1031,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 1305,  384,    1, 2370,  166, 1188,   37,   52,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1317,  704,  104,    1,   37,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  721,  515,    1,  562,   37,    1,    1, 2234,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  166, 1510,  737,  156,   28,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1778, 2367,   34,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2506,   45,    1,  133,  191,  700,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  519,  243,    1,   37,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1380,  327,   50,   28,    9,  333, 2163, 1215,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3233, 2225,    1,  187, 1515,  365,  512,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1691,   36,    1, 1370,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,   37,   47,  391, 1329,  159,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  335,  105,  356,   79,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  773,  361, 1515,  385,   15,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  379,    1,   98, 1147,  890,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2225,   45,  316,  872,   37,   52,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1, 1125,   98, 2355, 1560,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1431,   37, 1155,  129,  613,  535, 1074,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2043, 2962,  777, 1085,    1, 1117, 1943,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  709,  266,  475,  190,    1, 1170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  932,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,  267,   37,    1, 2837,  384,  557,  540,  191,   88,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,   12, 2789, 2751,    1,    1, 3339, 2271,  469,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2499,  140, 2498, 2701, 3217,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1005,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  114,  220, 2708,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,   45,  818, 1059,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  284,   78, 1066,  220,   10,   98, 1649,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 1484,    9, 3361,   37,  764,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  398,   37,  804,   98,  511, 3020,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2502,  921, 2736,   12, 1819, 2521,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 3322,  877,  460,    1,   55, 1691, 1215,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2698,  284, 1089, 1675,  193,    9, 2332,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3014, 1419, 1211, 2079,    9, 1718,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,    1,    1,   45, 3118,    1, 3396, 1188,   37, 1847,  593,\n",
      "           61,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1297,    1, 1159,  756,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,    1,  148,  142,    1,    1,  326,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2561, 1800, 1682,   32,  751,   37,  290,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  351,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1465,    1, 1228, 1443,  224, 2549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2881, 1718,  321,  612,    1,   37, 1778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  523,  431,    1,  220, 1786,    1,  422,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233, 1579,    1,  187,  582,   45, 3104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  536, 3329,  120,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2858, 2665,   61, 1239,   28,    1,  707,   37, 1604, 2928,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2753, 1114,   37,  470, 3181,   12,    1,  533,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1977,   55,    1,  176,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1081,  719,   37,    1, 1255, 1563,    9,  397,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1285, 3083,    1, 1600,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2832, 1260, 2114,   12, 1656,   32, 1212, 2735,  787,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  856,    9,   48,   32,  517,  700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   42,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196,    1,    1,  983,   71,    1,  202, 1455,  197, 1269,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1645,    1,  973,   37, 1154, 2571, 2859, 2830,  384,   91,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  403, 2618,    1, 1223,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  647, 1707,  645,  148,  142,  187,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181,  877,  232, 2118,   37, 3308,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  777, 1359,    1,  627, 2532,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3053,   12, 1183, 2318, 1086,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2883, 3062, 2774, 3397,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3001, 1249,    1,  176, 1022,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   10,    1,  509, 2275,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  775,  365,    1,    1,    1,  280,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  251,  365, 2842,   45,    1, 2530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3102, 2772,   37,  583,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  844, 1825,   28,  550,  369,    1,  156,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3296,    1, 1141,  548,    1,   12,  198,  698,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  203, 1185, 2912,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2851,    1,  395,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  496,  387,    1, 1147, 2705,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 2153,    1,  297,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,  972,   37, 1048,  148,  132, 1039,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1569,    9,  950,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    9, 3070, 3071, 2372,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3335, 1670,  754,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1745, 1297,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   51, 1046,  885,   43,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2594, 2331, 2398,   37, 1343,  220, 2330,   45,  247, 1477, 1990,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 1756,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2994, 1765,  786,  892,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  996, 1511,    1,  187, 2835,   12,  695, 2789, 1929,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  225, 1279,   70,  276,  381,    1,  348,  670,   32,   91,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2953,   51,  764,  249,    1,  384,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2787,   51,   52,   39,    9,  105,  339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56,  388,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1808,  794,    1,  279, 1107, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,    1,    1,  176, 3026,   45, 3102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,    1,  297,    1,  663,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2565,   90, 2308,  204,   12,  193,  707,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2040,    1,    1,  140,    1,  384,    1,   98,    1,   45,\n",
      "          395, 1798,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  353,   59,  354,    9,  166,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2534,    1, 2070,  104, 2393,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1231,  220, 1995,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2087,    1,    1,    1, 3161,  297, 1739,  275,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 1188,   37,  726,    1, 1463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2466,    1,    1,  863,  140,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,  223,  198,    1,    1,  528,  737,  720,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  852,   37,  288,   28,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   85,    1, 1487,    1,  185,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  506,   30,    1,   22,  376,    1, 1208,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  313,  176,  228,   74, 1821, 1333,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 1419,    1,   37,  883,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187, 2819, 1468,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  785,  786,   12, 2412, 1955,  140,   24, 2096,  220,    1, 2533,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  159,  504, 1010,  275,  276,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,  60,   1, 115,  45,  65,  67, 221,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  37,  52,   1,   9, 131,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  657, 1042,  315,   37,  877,    1, 1151,  105, 1766, 1767,  412,\n",
      "          402,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1016,   12, 1994, 2095,  543,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  171,    1, 2547,   37,    1, 2997,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1645,  681,    1,    1,    1,  469,   37, 2123,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,  25,  26, 526,  97,  98,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 191,   1,   1,   1, 446,   1,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  458,   17,    1,    1,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2963,  922, 3116, 2857,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428,  420, 1915, 2873,  815, 1239,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2095, 1260,    1,  851,  121,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3358,    1,   37, 1694,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  698,   28, 1396, 1117, 1943,   98, 1220,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3330,  696, 3260,  335, 2522,  631,  297, 3209,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,    1,  388, 1608,    1,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2920,    1, 3142,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 3394,  396, 1887,   45,  487, 1178,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2266,  396,  443,   32,  531,   61, 2189,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,   24,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2776,    1,   37,    1,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  251,   29,  384,    1,   45, 2519, 2895, 2955,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1433, 1366,    1,    1,  249,   79,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1450,   32,  854, 2856,  388,  763,  249,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3167, 2110,    1, 1022,    1, 2296,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1504,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 2758,   32,  121,  880, 2421,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116,   96,    1,  729, 1604,   32, 1647,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  642,  643,  245,  187,  644,   57,   79,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  302,  313,   37,  611, 1662, 2633,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  200,    1,    1, 1153,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  940, 3104,  193,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2321, 1543,  193,   37, 1421, 3229,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,  533,    1,   28, 1114,    1,    1, 1029,  741,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453, 1512,  155,  122,   98, 1513,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 1477, 1990,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3076,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2756, 2094,   69,  636,  670,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  187,  105, 1204,   12, 1604,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  989,   12,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,    1,   45, 1855, 2774,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  612,   34,  389,    6,   37,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  882,   37,   47,    1,    1, 1370,   45,  526,  844,    1,   37,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004, 1718,    1, 2287,   28,    9,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428, 2216, 2751,   32, 3118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2745,  220, 1619,  808,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  103, 1985, 3002,  361,    1,  898,   37,    1,   32, 1352,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   45, 2162,  872,  726,    1, 2376,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  627,   61,  577,   32, 2610,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2994,  120,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  575,    1,   28,    1,  673,  448,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1902, 1401,  454,    9,    1,   12,    1,  750,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  590,    1, 1638,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1063,  488, 1084,  841,  293,  297,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2197, 1386,    1,    1,    1,    1,   37,   26, 1039, 1228,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  122,    1,   98,  651, 1031,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1280,   45,   51,    1,   37, 1211,  639,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3089,  188,    1, 3297,  418,   32,  428, 1002,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2819,   61, 2222,  105, 2502,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  363,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  193,    1,   32,  413, 2522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,  200, 1689, 3153, 2220,  625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  654, 1458,  848,   12, 2723, 2724, 1935, 2294,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1241,   28,  119,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  793,  315, 2462, 1064,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   71,  187,  374,    1,  354,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3121,    1,    1, 2755,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  183, 2525,  176,    1, 2577,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  968, 3067, 3101, 2731,   98, 3339, 2831,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2786, 2953,  105, 3060,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2658,    1, 1454, 2068,    1, 2742,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3303,  162,  105, 1938,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  614,   37,    1,  176,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  952,    1, 2362,   98, 1256,  551, 2196,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  734,    1,  167,   52,  686,  424,  339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,   12,    1, 1562,  828, 1338,   45, 1278,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1366, 2572, 1407, 3006,  176, 2172, 2791,    1,  267, 2018,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  550, 2215, 3005,    1,  187,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,  193, 1343,  581,    1,  176,  449,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1, 1007,    1, 2962,    1, 1401, 3175,   37, 2872,   45,\n",
      "         2615,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1840, 2023,    1,   37, 1982, 2187,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  203,   37,  619,  166, 1354,   39,   45,  829,   12, 2851,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,  978,  641,    1,  187,  529,  102,  554,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1401,   37,  104,   15, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2019,    1,    1, 3018, 1031,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,  580,  696, 2920,  866, 3120,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,  361,  166,    1,   45,   61,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3177, 1458,    1,    1,  101,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2335, 1061,  548,  667, 2921,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,   28,    9,  885, 1124,   32, 1184,  347,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777, 1021,   37,  166,  249,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1069,   85,    1,  202,    1,  190,  712,   28,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   35,    1,   22,  438,  661,  365,  662,  548,    1,  562,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1824,    1,  384,    1, 1821, 1481, 1349,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1236,    1,  297,  787,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  671,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  457,    1,  445, 1415,   37, 2276,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1804,  247, 1291,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1101, 2817, 2856,   32,  854,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  398, 1707, 1100, 1727,    9,    1,  657, 2417,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   34,    1,   37,   82,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1156, 2708, 1360,  612, 1844,    9, 1513,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  459,  220, 2206, 2435,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1220,    1,  549,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,    1, 1173, 2311,    9,  195,  109,    1, 1603,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1212, 1702,  163,    1,   12,    1,   98,    1, 2295, 2302,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  920,    1, 1232,  903,    1, 1447,   37, 1539,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2038,  922,  650, 3181,  140,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1825,    1, 2015,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2838,    1, 3108,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1853, 1149,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   44,    1,  279,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963, 3129, 1292,    1,    1,    1,    1,  928,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1663, 1821, 2190, 1323,  420,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,    1, 3021,  140,  199,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  917,  280,    9,    1,  616,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  315, 2834,  750, 2616,   32, 1741,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  316,   32,  870,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741, 2308,  686,   39,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1739,    1, 1052,  570,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 3006,   98,  166, 1844,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1, 1969,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  664, 3163,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2615,  998,   39,  753, 1167,    1,  321,  764,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2682,  247,  248,    1,  542,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2456,  777,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1861, 1921,   32, 3369,    9,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2696, 1408,    1, 1089, 1675, 2017,  384,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2693,  420, 1394,   37,  197,    1, 2964,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2523,   37, 1343,  176,    1,  628,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  518,  166,  402,   45,  590,  571,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1,   32, 3313,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1303,   37, 1155,  395, 1109,   12, 1411, 2273, 2348,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1013,   96,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   56, 1848, 1682, 1156,    9,    1,  636, 1336,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1283, 3260, 3296,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1,  904,    1, 2757,  967,  315,   37,    1,  164, 1593,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  105,    1,  220,    1,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1674,    1,   98,    1,   32, 2235,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1283, 3117,  276,  809,   98,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   12,    1,  267, 1935, 2294, 2096,   37, 1348,    9,  284,\n",
      "          199,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,  391, 1329, 1651, 1597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3114,  957,    1,  774, 2555, 2774, 1967,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  103,    1, 1167,  877,  105,  327,    1,   37,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  215,  858,  408,    1,  267, 1063,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  786,    1, 2489,    1,  440,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2385,  612,  166,    1,  460,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   25, 1285,  242,   98,   14,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3070,    1,  187,  964, 1877, 1133,  751,   37,  810,   39,  443,\n",
      "          191,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1306,    1,    1,   45,  608,    1, 1628,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1585,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3232,  335, 2522,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,  786,   84, 1415,   37,   72, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1640,   12,    1, 1438, 2153,   37, 1046,  776,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1579, 1024,  442,   37, 2615,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1774,   39, 1230, 2528,    1, 2668,  220,  163,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1, 2196,    1, 3102,  513,    9, 1204,   98,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  792, 2226,  321,  335,  247,    1,  792,  683,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  166, 3194, 3195,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1013, 1522,    1, 1381,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779,    1,  140, 1447,   26,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,   46,    9,  667, 1259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,  627,  315,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1778, 2580, 2851, 1463, 1658, 1274,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510, 1774, 2029, 2028,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  506, 1770,    1,   51,    1, 2500,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  542, 1210,    1, 3221,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   63,  166,  862,  657,  159,  245,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 1930,  606, 1931,   98,  735, 1780,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  552,    1, 1079, 1818,  147,   37,  360, 3003, 1281, 2099,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087,  433, 1769,   37, 1761, 2095,  437,   12,    1,   37, 1926,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962, 3319,  470,  608, 1110,  528, 1340, 2907,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1817,    1, 2715,   32, 1328,  276,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  777, 2515,  565,  166, 2840, 2515,   45,  166,  627,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  365,  823,  391,  512,  696,  439, 1018,  823, 1691, 2769,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2914,    1,    1, 1935,  579, 1411,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129,    1,  353,    1,  737,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  503,  338,  187, 1117,    1,    1,  749,    1, 2887,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1486,  156,  565, 1107,   37,  247,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,    1,  897, 2747, 1687, 1022,    1, 3008,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   55,  227,    1,    1,  105, 1339,   61,  105, 1822,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  386,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2201, 2003, 1585, 2414,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,   28,   98,    1,    1,  844, 1151,   15,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  389,  469, 2524,    5,    6,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1492,  232,  952,  388, 1001,    9, 2527,  164,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2217,   12,    1,  502,  972,  365, 1277,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1773,   21,  228,   59, 2510,  675,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  166, 1427,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1140,    9,    1,    1, 2789,   37,    1, 2072,\n",
      "          365,  650,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  572,  197,  338,    1,  197,  837,    1, 1564,  104,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 2610, 2363,    1, 2367,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  900, 1682, 1046,  134,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  345,    1, 1204,   98, 1965,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  187,    1, 1449,  140,  593, 3154,  199,  776,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1043, 1308, 2007,   37,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1792,  195,   15,    1,   32, 1212,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  631,  163,    1,   12,    1, 1159, 2069,    1, 2468, 1401,\n",
      "          447,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1894,    9, 2889,  229,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  192,    1, 1908,  183, 1008,   32,   14,    1,  845,  275,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 1009,    1, 2784,  548, 2328, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  542,    1,   37,  151,    1, 1767,    1, 2692,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  211,    1,   32,  776,   45,  709,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,  852,   37,  593,    9,  432,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2859, 2955,  894,   92, 2971, 1116,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  294,  922, 1090, 1829,  718,  176, 2570,  787,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  523,   37,  138,  152,   37,  875,  961,  839,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    6, 1126, 2293,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,   51,  245,  187,  568,  831,    1,  496,  267,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  616,    1,   79,  531,    1, 2834,  550,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2514,    1, 1554,  683,   98,  105,  845,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275, 1414,    1,  166,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  761,  580,  938,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  171, 2358,    1,  231,   45,  531, 1527,\n",
      "          469,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   37,  686,   94,   93, 1411,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  430,    1,   45,    1,    1, 1961, 1428,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  919,  166,    1,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  245,   69,    1,   60,  335, 1515, 1950,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 1454,  625,  444, 2834,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  773,  317,    1,   15,   32, 1332,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,   79,  340,  444,  166,   94,  548,   99,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1970,  705,   74,    9, 1850, 1423, 2024,  132,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 1117,    1, 1417,    1,  108,    1, 2153,  460,   51,\n",
      "          912,  521,  134,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  936, 2300, 1273, 2943, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  738,  220, 3103,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  552,  552,  725, 2277,  822, 1918,  444, 1701,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2347,   32,  885, 2748,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  506, 1484,    9,    1,  182, 2041,  361,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  116,  117,    1,   28,    1,  118,   37,  119,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843,   12, 2788,   98,  260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1963,  105, 1298,    1,   45,    1, 1857,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  361,  306, 1413, 1414,  444,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1971,    1,  719,  581, 2456,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,    1,   10, 1388,  297,  531,  361, 2877,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1665,   37, 1212,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1048,  855,    1,  863,   74,    1, 1232, 1608,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  455, 2386,  649, 2949,   45,    1,  453,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3333,   12,  125, 2537,  167,   52,    1,    9,  683,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3123, 1249,    1,    1, 1268, 2335,  402,  631,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018,    1,    1,  227, 2360,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1361,  744,   28,   26, 1039, 2366,  934,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1209,    1, 2208,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1095,   72,  401,  207,  490,  187,    1,   71,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 1554, 2611,  548,  985, 2456,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  539,  458, 1841,  513,    9,  949,   45,  531, 3102,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,    1,   98,  479,  361,  971,    1,  166, 2497,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1029,  851,  298, 2414,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  841,  133,    1,  986,   79,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  298, 2797,   98,  624, 1858,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,    1,    1,  361,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1089, 1675,  227,    9, 1763,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3233,   37,  907,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3354, 1414, 2856,  366, 2764, 3394, 3384,   32, 3246,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3113,  936, 1326,  132,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,    1,  365,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   78,  686,  191,  585, 1079, 1527,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1898,  565,  193,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1036,   37, 2142,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,   45,  591,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 2663,    1,   28,   37, 2192, 1470,   45, 2527,   55,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2305,  548,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1442, 2954,  515,  694,    1,   32,  183,  404,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 3382, 1082, 1314,   37, 2646,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   20, 1064, 1499,   32,    7, 1131,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,  218,  967, 2491,  339,  452,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1481,   37,    1, 3401,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,  587,  439,  477,  202, 2253,  388,  522,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   20,  140,  152, 1461,  750,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  626,   37,  693,   59, 2415,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  352,  330,   37,    1, 2245,    1,   50,    1,   51, 1173,   37,\n",
      "           47,  460,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1211, 2760, 2227,    1,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  639,  958, 2249, 3373,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2442, 1740,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3251,  664,   37, 3271,   32,  872,   12, 2069,  754, 1090,   32,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3053, 2477,  944,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,  617,  259, 1589,  190, 1824,   98,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2843,    1,   39,   45,  674,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  778,  980,    1,    1, 3000,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1013,  293, 1874,  224, 1126,    1,  387,   93,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3207,  614,    9,  388,  671, 1010, 2795,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  123,  417, 1010,  677,   69,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  923,   51, 1251,  183,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  942,   37,    1, 1033,    1,  616,    1,    1,  365,  261,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1362, 2185,  207,   85, 2092,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1861,  531,  420,   30,    1, 2298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1720,  334,  664,    1,  334,    1,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  321,    1,   37,   33, 2785,  629,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,  102, 1126,  176, 1802,    1,    1,  155,  104,    1,\n",
      "          182,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  395, 2003, 1585, 2414,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971, 1203,    1,   59,    1,   32,  403,  507,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  828,  588,   37,    1,  492,    1, 3348,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,  329,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  491,    1, 3375, 1210, 2024,  220, 1094,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  913, 1658,    1,    9,  166, 2789,   45,  166,  356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3251, 1752,    1,    1,  202,  193,   63,  105,  856,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105,    1,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1477, 1990,  572,  551,  105,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  650,  952,  105,  365, 2113,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,   36, 2162, 1950,    1, 1763,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  716,  198,  207,  197,   32, 1022, 1023,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  166,    1,  951, 2102,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3276,   32,  119,  142,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   61,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314,   37,    1, 1469, 1629,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  398, 1484, 1929,   98,  829,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1013,    9,  388, 2986,  187, 1157,   64, 2162, 1950,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1457,   45,    1,  741,  958, 1459, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2377,  813,   72, 1856,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1290,  396,   28,    1,   32,  105, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1427,  492,    9,    1,  187,    1,    1,  105, 1777, 2739,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  886,   12,  365,    1,    1, 2654,  183, 1136,   32,  803, 1151,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2393, 1722, 2917,  176, 1687, 1022,    1, 3008,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1396,  829, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  364,  140, 1383,    9,  914, 2093, 2107,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  617,  618,  544,  858,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,  547,  335, 1096,    9,  163,    1,   12,    1, 1477, 1990,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2087,  433,  292,  845,  439, 2359,   32,  704,  551,  705,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  325,    1, 1228,    1,    1,  675,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 3363,   37,  186,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  224, 2355, 1013,  833,  612, 2253,  861,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,   12, 2071, 1331, 1998,   92,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  463, 2170,  951,  539,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,    1,    1,   98, 2992,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2094, 3012, 2981, 1415,   37,  754,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2078,  288,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1363,   37, 1403,   40,    1,   37,   91,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3132,  361, 1123,  907,  187,  420, 2471, 3294,   37, 2901,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  533, 1360,  612, 2446,  711,  333,    1,    1,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  439,   45,  567,  914,  199,    9,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  633,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 3255,  691, 1285,   39, 2741,   32,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,  166, 3206,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942, 2471,    1,   32, 2701,  593, 1990,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  506, 2587, 1763, 2052,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   45, 3243,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  550, 2318, 2079, 1849,   26,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2142, 1022,    1, 3272,  590,    1, 1923,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  818,   15,    1,    1,  193,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,  225, 1137,   98,  550,   45, 1250,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  111,  117,    1,    1,  105,  333,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,    1,   27, 1762,    1,  140,  104,   26,  444, 3169,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2498,  640,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  765,   37, 1195,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1, 3177,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 3111, 1539, 1450,   32, 3155,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307,  267,  197,  190,   77,  383,  187,  102,  720,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1187,  365,  647,   82,    1,  105, 2187,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  794,  111, 1107,  525,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,  587, 2253,   37, 1195,  477,  297,  529,  636,  423,   98,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1811,  404, 1057,  297,   10, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,    1,  479,   15,    1,   32, 1169,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1464, 1463,    9, 2725,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1038,  966,  420, 1261,  103,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,  664,    1,    1, 2700,  774, 2394,  460,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  759,   39,   37,  388, 2264,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  167,   52,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1192,  191,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1550,    1,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  194,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2, 148, 140,   1,  54, 856,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 384,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  294, 1456,   12,    1,   66,    1,  197,   93, 1045,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,  952,  104,  764,   37,  470,   69,  636,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051,  387,  395,  187,  656,   45,  593,  275,  218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,   12,    1,  580,    1,    1, 1867,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  810, 1385,    9, 2890,  384, 3261,  475,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1809,    1,   45,  306,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  103,  314,  710,  939,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066,   61, 1117,    1,   45, 2309,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1796,  458, 1086,  381,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1140,  656,   37, 1865, 1060,   45,    4,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3151, 1949,  810, 1292, 1981,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  190,  606,    1,  131,  104,   32,  734,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  964,   90, 1244,   37,  619, 1991,   37,    1,  962,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739,   36,   37,  693, 2161,   12,  772,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3363, 1401,  202,   45, 2591,   37,   52,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,    1,    1,   32, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  357, 2769,    1,  103,  676,    1,    1, 2780,  808,   32,\n",
      "          166,    1,    1,  318,  361,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 2613, 2383,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2509,  600,  215, 2128,    1,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1683, 1428, 3365,  907, 3363,    1, 2905,   37,  582,  754,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   49,  924,   12,  526,    1,  756,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230, 2726,    1, 3204,  833,  612,  176, 2826,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   10, 1445,  863, 1918,  919,  236,  237,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2789,    1, 3364,  187,  453, 2409,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,   26,  417,   69,   27,  105,  106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  393, 1426, 1845, 1259,   98, 1858,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  197,  418,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1360,  612,    1, 1437,   65,  379,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  506, 2476,    1,  220, 1515, 2261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12, 1043, 1738,    1,    1,  245, 2801,    1,    1,  631,\n",
      "          276,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1789,  147,    1,    1,   12,  863, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1709,    1,   12, 1377,  631,    1, 2319,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   98,    1,  187,  460,    1,    9,  105, 1133,\n",
      "          996,  356,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3173, 2005, 1632,  176,  104,   26,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2464, 1284,   81,   37,    1,  548,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2659,   37,   77,    1,  535, 1863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,  472,   39,   45,  128,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640,   37,   44, 1159,  547, 1333,    1,  631,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1202, 2497, 3155,  187,   46,  271,   85,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  381,   37,  130,  449,  294,  458,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1537,    1,    1, 2889,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  288,   37,   26,   28,    1,   32, 1381,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1232, 2614,   98,    1,    1,  947,  697,   37,   16,   23,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3236, 1421,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1632,   32, 1022,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2569,  195,    1,   32,  104,  147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 3365,   32, 3360, 1683,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105,    1,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1485, 1273,  259,  132,   66,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1445,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1993, 1159, 2936, 3293,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  393, 2271,   37, 1251,  403, 1739,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1822,  860,    1,   45,    1,    1,    1,  420,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,    1,    1,    1,    1, 1448,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  770,   45,    1,  232,   12, 2059,   61,    1, 1976,   32,  298,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  198,    1,    1,    1, 1602, 2539, 1821,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3213,   98,  166, 1260,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800,    1,    1, 2111,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3282,    1,    1,    1,  801,   37, 2073, 1385,   45,  104,   26,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  195,  432,  226,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2862, 3082,  949,  187, 2377,  713,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  534,  190,  491,   39,    1,    1,    9,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   81,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  782, 1799,    9,    1, 2759,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1853,    1, 1665,   61, 1851,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  726, 2151,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    1, 3154,   32,    1, 2162,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066, 2660, 1918,  297, 2846,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3117, 2712, 3271,    1,    1,   32, 3235, 1798,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  213,    1,    9,  920,    1,  193,   37,  588, 2708,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1718,   51, 1021,  463,  464, 2176,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826, 3207,    1, 2316, 1918,  384, 3208, 2795,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051,    1,    1,  361, 2278,  289,   32,   98, 2759, 1228,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,  251,    1,  279, 1402,    9,    1, 2043,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  852,  760, 1524,  671, 2029,    1,  627,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2918,  927,    1,  220,    1, 1522,    1,   37, 1174, 2818,    1,\n",
      "            1,  267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  104, 3160,  952, 2649, 1323,   32,  942,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  474, 1707,   24,  693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  105, 2107,   74,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1420,  936,  119, 1952,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   10, 1454,  119,  187, 2832,  686, 2163,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2147, 1585,    1, 2335,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  402, 1918,  590,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3134,   39,   45,  671, 3126, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2999, 1994, 2819, 3050,    1, 2980,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   25, 1376,  187,   69,  102,  470,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,  98,  14,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 220,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   28,   37, 3140,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1079,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  327, 1828,  245, 1139,   45, 1396,    1,  267, 2076,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 2067,  166,   97,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  879,  222,   37, 2851,  382,  328,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  476,  241,  863,   32, 2018,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1986,   98, 3339, 2129,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1338,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2454,  999,  424,  356, 2700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  104,    1,  759,    1, 2069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158, 3007, 2528, 1230,    1,  163, 1230, 3011,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  546,   79,  365,  340,    9,  207,  259,  347,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  151,   28,  415,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3391, 2751, 1523,   98, 3279, 1316,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,   95,  473, 2905,    9, 1610,  477,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2763,  656,  892, 1051,    1, 2348, 1108, 2575,  220,  552,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1092,  671,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   46,  600,  166,  887,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3045, 2856,  600, 1147, 2548,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   18,    1,   37, 3024,  452, 1194, 2350,    1, 2977,\n",
      "          267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,   44, 1167,    1,   28,   37,  166, 2225,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968, 1113,  338,   37,    1,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  912,    1,  726,  388, 1942,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   42, 1994, 2143,  400,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3014,  251, 1211,    1, 2234,    9, 1718,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1591,    1,  288,    9, 1126,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,   69,  102, 2004,  245, 1315,  105,  106,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  108,   45,  197,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1796, 1123, 2308,    1,  154,  759,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296, 1867,   32,   95, 1273,  618,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2445,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   85,   98,  552,  552, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   60, 1993,   28,  548,   94,    1,   85,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3168,    1, 3178, 1758,   37, 3179,   45,    1, 1938, 3197,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1796,  681,   84,   28, 1278,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 1861,   37, 2000, 1204,  548, 3358,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3006,  774, 3395,    1,  777,  778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,    1,   32, 1477, 3098,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2470,    1,  409,  498,   37, 1421,    1,  191,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2550,  782,  388,  459,   45,  238,   32, 1965,  608,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  879,  119, 1844,    1,    1,  297,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1523,   27, 2755,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32, 2089,  133,   32,  967, 1621, 2045,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  256, 1186,   12, 2073,    1,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2954, 1827,   85,  361,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994, 1319, 2832,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   30,    1,  265,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2736,    1,  220,  602,  191,    1,  176,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2634,   37,  949, 2627, 2177, 1825,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,  302, 1712,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1900, 1604,   98,    1,   37, 2446,  585,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1908,  220, 1545,    1,  801,   37, 2069,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1249,  572,  739,   98,  845,   69,  636,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  743,   12,  155,  158,  327,    1,  159, 1473,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2265,  446,  939,    1,    1, 2224,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2714,  365, 1277,  754,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  758,    1,  779,  453, 1117, 1525,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,  686, 1114,  191,    1,  840,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  302, 1710,  764,    1,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  612,  759,   39,  361, 1330,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  668, 2852,  665,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,  140, 3101,  543,   98, 2708,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2993, 1614, 2994, 2995,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  296,  313,   37, 1257,   20,   12, 1117,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  382,    1,   64,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  197,  418,  187,   15, 1427,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  487, 2700,    1,    1, 1281,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  435,   60,  327,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  864, 1564, 2673,  693,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,    1,  166, 2721,   45, 1033,   12, 2773,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3208,  463, 3165,  729,    1,    1,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129, 2246,    1,  884, 2882,  631,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2442,   37,   38,   81,  388,    1,  977,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  334,  321, 1093,    1,  220, 1695,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2307, 2213,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193, 1284,   79,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,    1, 3140,  531, 2735,    1,  294, 1414,  565,    1, 3045,\n",
      "            1,   74,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,    1,    1, 2573,   37,  151,   48,   32,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 2036, 1419, 3101,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  605,   32, 1691,    1,    1, 2438,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3173,  683,    1,    1,    1,    1,   98,  147,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2807,    1,    1,  162,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  696,    1,   12, 1045,  686,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  776, 2007,  892,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2650,  167,    1, 2580, 2851,  328,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3207,  894,  429,    1,  671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    1, 2847, 1427,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1507,  493,  376,  636, 1279,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  183, 1090,    1, 3193, 2467,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3345,    1,  220, 3343, 1386,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1186, 1579, 2500, 3036,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1034,    1,  166, 2551, 1045, 2697,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2275,  387,  736,  187,  916,   37, 2346,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  980, 1273,  668,  325,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1902, 1765,    1,   37, 2277,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3361,  619,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1636,  760,  162,    1,  613,  768,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  803,    1,   23, 1321,  384, 1430,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1228,  833,  612,  271, 1506,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144, 2344,  289,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2004,    1, 2405, 1750,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  391,    1,  197,  407,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1671,   37,   46,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  539,  458, 2262, 1910, 1530,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1966,   12,    1, 1581,    1, 1984,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  493, 1271,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2040,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91, 2506,  600, 1793,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1661,  704,  222,  580,  133,  297, 1405, 1340,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388, 2538,   32,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 551,   1,  12, 197, 407, 118,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  37, 138,   1, 399,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3355, 2598,   37,   97,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1136,  104,  782,  199,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,   96,   37,    1,    9,  764,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  671, 1078,   37,    1,   79, 1076,   12, 2208,  142,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181, 2384,  449,    1, 2382,  259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,   28,   32,  166, 1089, 1090,  293, 2928,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  636,  490, 1146, 1703,  187,  104,  679,   25,  245,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    9,  705,    1, 1417,    1,  424,   51,   52,  460,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275, 2776,   10,   12,  248, 1886,   37, 1140, 1590,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3193, 1075,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,  542,   39,   45,  674,   32,   91,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056, 1994,  741,    1, 1919,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2412, 1173,   37,    1, 2350,  220,    1,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,    1,    1, 1980,   37,  759,  442,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2592, 2272,   85, 2177,   98, 1792, 2166,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,   37,    1, 1354,   45,    1,    1,  386,    1,   39,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3175,  872,  420,  385,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,   37,    1, 2048,   45, 2641, 1772,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  912,  608, 3358,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  295, 1036,    9,  104,  182,  354,  424,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1717,    1, 2013,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3225,    1,    1,    1, 1012,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  410,    1,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  301,    5,  302,  640,    1,   32,  233,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1009,   10,  459,  365,  301,    5,  125,  302,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,   37,  125,  102,  548,  594,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  267,  204,   61, 2764, 3394, 1098,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2087,    1,    1, 1066,  103,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1736,  618,   77, 1284,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2321, 1849,    1,    1, 1061,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   85,    1,  193,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1627,  195, 2019,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  845,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  165,  277,    1,  319,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1172,   12, 1173,  115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2776,  105, 1136,   37,    1,   39,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3124, 1489, 1463,  714,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1721, 3358,  351,   66,  187, 1421,   45,  447,   12,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296, 1042,  829,  695,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1656, 2525,  686,  220,    1,    5,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2911, 1994,  531,    1, 1587,   45, 2275,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1221,  565,  859,  361, 1608, 1221,  565,  311,  859,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3097, 1557, 1004,  863,    1,    1,    1,  133,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3178, 2845, 2069,  913,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  597,    1, 1731,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1090, 1271,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1518,  530,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 1214,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  980, 1110,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  381, 1236, 1327,  297, 1047,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  298,  113,   28, 1639,  589,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2994, 2188, 2995,  443,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  537,  548, 2164,    1, 2206, 2435,  729,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  506,   45,    1,    1,  801,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  849, 1701,   37,   52,    1,  191,  848,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  848,   50,  353,  682,    1,  202, 1307, 1141,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1748,  168, 1273,   98,  179,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  388, 1534, 1167,  116, 1299,   61, 1568, 1114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2017,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2110, 1405,   82,   12,  669,    1,  302,    9,   59,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,    1,  331,    1,    1,   32, 1169,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1951,  798,   45,  365,   69,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  340, 1251,    1, 1778,   37,  686, 1537,    1, 1411,  356,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,    1,    1,    1,  777,  413,  758,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1257,  960,  361,    1,  700,  271,   79, 1429,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3140,  361, 1430,  360, 1428,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  618,    1,   32, 1021, 2285,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2692,  967, 1090,  542,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1,  258, 1013,  112,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  297,  119,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2103, 2727,    1, 2895,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  193,  187,  445,    1,    1,  202,  388,   37,  504,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2132,    1,  787,   32,  507,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    8,  786, 2324,   32,    1,  861,  328,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380,    1,    1,    9, 2018, 2924,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 1127,  872,   98, 1228,  187, 1085,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   28,   37, 2572,   32, 1056, 1450,   32, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3204,  765,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 1648,   37,   33, 1211, 1084,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2826,    1,  163,    1,   12,    1,  361, 2442,  439,  671, 3106,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1333,  665,  855,    1,   45,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2068,   12,    1,    1,    1, 1667,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2827,   32,    1,  452,   51,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328, 1105,  787,  353,  800,   15,  159,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  111,  782,  453, 1067,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1233,  361,  479,  489,   39,   45,  785,  786,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2664, 3340,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  306,    1,  150,  207,   15, 1253,  224,  716,  331,   32,  207,\n",
      "          174,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,  884,  674,   45,  464,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2505,    1, 2501,    1, 1624,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1298,    1,   32,  428, 2800, 1002,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  878, 2493,   37,   52,  105,  581, 1023,   23,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  363,    1,   45, 2376, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2238,    1,  657, 1421, 1731, 2234,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1215,   45, 2235,  614,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,   37, 2654,  861, 2976,   98,  737,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,    1,  166, 1868, 1172,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  114,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3364,    1,    1, 1567,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  275,  618, 1866,  844,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  391,  371,   37,  125,    1,    4,   32,   91,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 1057,  297, 2288,    1,  677,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296, 2562,  168,  115,    9,  105, 1299,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  403, 1739, 1090, 1586,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1242,    1,    1, 2122,    1, 2122,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1472, 2277,   10,   12, 1288,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,  606,  166, 1285, 1232, 2620,  640,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3280,   39,   37,  665, 2890,   32,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  658, 1159,  166, 2288,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2899, 2790, 2483, 1411,   84,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  765, 1967,   37, 1022,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  217,  138,  636,    9, 1001,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2519,  433,    1,   32,  272,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,   28,   98,  636, 1500,    1,   93,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1, 3067, 2774, 2555,   45, 3118, 1223,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  316, 2757,  267, 1123,  132, 1270, 1530,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3183,    1, 3182,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3276,    1, 3290,    1, 2935, 2941,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171,    1,  362,  384, 2401,   32,  903,    1, 1741,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1019, 2663,   61, 1976,   98,    1, 2921,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  950,  986,  103, 1001, 1132,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,    1,  331, 2948,    1,  384,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  527,  140,  562,    9,    1,  881,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2106, 1178, 2405,    9,  726,   32,    1, 3367, 1002,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,   85,  187,  109,  997,  470,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2994,  117,    1,  187,  218,  332,  641,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1203, 2871, 1021, 1129,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  123,   37, 3234,  151,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3203,  546,   37,  335,  449, 1385,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  523,  837,   45, 1786, 1535,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144, 1489,  147, 1002,  695,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2856, 1056,  163,    1,   12,    1, 2548,   32,  531,   12,\n",
      "         3383,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1884, 1177, 2497, 1327, 1056, 2572, 1720,    1,    1,  433,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  550,    1,  150, 2025,  449, 2725,   32,  166,  365, 1935,  443,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1398,  612,    1,    9,    1,   12,  994,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2932, 1000,  377,    1,   32, 1718,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1361, 2226,  321,  612, 1937, 2349,    1,    1,  202,  334,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2563,    1, 1445, 2803, 3265,   32, 2760,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962, 3117,    1, 1264,  841,  631,  220,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3334,    1,    1,  997,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    6,  102,    9,  395,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777,  710,  884, 1361,   37, 2082,   98,   26, 1039,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1376,  227,    9,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3168, 3090,   32,  581, 1385,  176,    1, 3282, 1938, 3197,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  245,  914,  852, 1735,    9,  773,    1,  202, 2063,  167,   52,\n",
      "          885,  724,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1082, 3072,  522,   32, 3369,    1,    1, 1061,  176, 3051,\n",
      "         2147,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2934,   37,    1,  166, 2586,   45, 2614,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1583, 2414,    1,   32, 3339, 2625,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  368,    1,  162,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  715,    1, 2430,  297,    1, 3005,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  719, 1018,   69, 1031,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018,    8,  331, 2764, 2765, 1638,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  922,  191,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2308, 2243,  858,   98,  105, 1151,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  702,  252,   32,  987,  361,  311,    1,  202,  193,   32,   15,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,  614,   37,  147,   37,    1, 1384, 1495,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   58,  197,    1,  157,   28,    1,  225,   85,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1780, 1140,  919,  386,   37,    7,  726,  297, 1545,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2792,  691,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2770,    1, 3114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  701,   98,  242,   69,    1, 1099, 1453,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1830,    9, 3127,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  872, 2090,   42,    9, 3077,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1435, 1190,  267, 3369,   26,   37,    1,   45,    1,   32, 3118,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12, 2211,    1,    1,  207,  105,    1,  331,    1,   28,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428,  211,  105,   92,    9, 3036,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 1493, 1333,  176,  730, 2614,   32,  105,    1, 1007,    1,\n",
      "         1417,    1,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  317,  411,  682,  187,   69,   61,  816,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596, 2641,    1,  365,  414, 1015,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  147,    1,   35,   22,  438,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2409, 2347,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  515,  545, 1035, 1018,  548, 1038,   16,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1,   51, 1388,  297, 2333, 2527,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  777,  778,    9,    1, 2070,   43,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1171,    1,   95,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  178, 3095,  606,  315,    9,  388, 2053, 1501,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327, 1249,  104, 3115,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2961,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1236,  297,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1977,   55,  105, 1762, 1838,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3079,  729,    1, 1711,   45, 2638, 2548,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  434,   28, 2471, 1813,  166,  810,    1,  361,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  732,   37,    1,  959,    1,    1,  541,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1852,  267, 1099, 1453,  494,   51, 1188,   37,  168,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3313, 1297, 1516,  670, 2017,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  645,    1,    1,  640,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1364, 1365,  839,    1, 2950,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  786,   32,    1,    1,  220, 2693,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730,    1,  353,  242, 1690,  525,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1700,    1, 3340,   32, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2137,   81,  176,    1,  384, 2912,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428, 3397,   37,  531,    1, 2179,  226,  220, 1065, 1190,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282, 3204, 1542,    9, 3169,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,  260,   28, 2072, 1340,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2229,    1,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  920,    1,  176, 1158,  166,  865,   45,    1,    1,    4,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1233, 1149,  741,  444,  477,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2843, 2523, 1268, 1206,    1, 1580,  656,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089, 3340, 1855, 2886, 3395,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2254,   37,  151,    1,  112,   45,    1, 1286,  590, 1145,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1821,  639,  475,   37, 1540,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9, 2024,   32,  430,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2508, 2262, 1219,   32,  912,  332,  927,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567, 2037,    1,   37, 1123, 2462,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  116,  223,    1,  321, 1403,   98,    1,    1,  506,   30,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  939,  187, 1009,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2879, 2946,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1013,   61,   98,  176,  306,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  945,   69,  267,  475,  190,  865,   37, 1053,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  159,   28,  118,   32,  449,   74,   45,  442,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1249,    1,    1,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1260,   37,   52,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2786,    1, 1231,  191,  166, 3092,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428,    1,    1, 1530,   32, 3118, 1512,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  147,   37, 1709, 1393,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,  419,  647,  225,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160, 1278,  919,  104,   93,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1364, 1365, 1260,  155,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  590,  388,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2637,   12,    1,  140, 1940,   12,  593, 1990, 2080,  517,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1354, 2095, 1450, 1251, 2764, 3394, 1298,    1,  420,  782,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2700,    1,  365,  846,  119,   98,  116,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,  458,   67, 2126,    1,   32,    1,   12, 1952, 1084,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  815, 2268, 2457,   37, 1285,  902,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3198, 2963,   32, 1022,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  137,   32,  927, 2199,  815,   45,    1, 1469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3249, 1980,   37,  877, 1131,  105, 1794,  978,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  667,   25,   71,    1,  967, 2084,  504,  452,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796, 1292, 1713, 3120,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,  188,    1,  307,  308,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2821,    9,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  195, 1463,  716,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1924, 1056,    1, 1723,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,  678, 2236,   45,  217,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1147,    1,  254,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  204, 2233,   77,    1,   39,   45, 2205,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1486,  207,  354,  703,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2087,  433,    1,   79,  903,    1, 1447, 2001,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2736,    1, 1301,  602,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,  987,  591,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1048, 1049,   61,    1,   32, 1050,  538,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  381,    1, 1130, 1046,  422, 1340,  927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  630, 2011,   98,    1, 2836,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   61,  424,  579,  166,  183,    1,    1,   55,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1955,   12,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2, 506,   1,   1,  32,   1, 428,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  50, 459,  24, 220, 215, 622,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2992,  167,   52, 1411,  183,    1,   32, 1017,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   30,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1717,  787, 1906,  908,    5,  591, 1907,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1002,    1,    1, 2712,    9,    1,   32, 2178,  863,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 1940,  335,  671,  361, 3077,   32, 3292,  199,  776,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 1361,  798, 1647,   98,    1,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,   37,  665,  453,  327,  112,   28,    9,  333,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  213,   37, 1198,  909,   98,  976,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  766,   32,  105, 1935,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2236, 2867, 2792,    1,  389,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  449,  698,  105,  270,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380, 2764, 3394,  893, 2572,   32, 3279,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  352,  782,  943,   45, 1622,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,   37,  686,  176, 2275,   98,  861,    1,  954,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  602,    1,    1, 1183, 2156,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942, 1760,    1,    1,    1,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3238,  967, 2133, 3288, 1857,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  121,   12,  856,  444, 2834,  190,  193,    1, 1511,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1827,   39,   45,  667,  863,    1,  267,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  413,  781,    1,    9,  501, 1656,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  803, 2195,    9, 1794,    1, 1159, 2500,    1,    1, 2179,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1708,    6, 2606,   79,  384, 1407,  412,    9,  861,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  189,  392,    1,  469,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2002, 1009, 1484,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2331, 3169,  566,  581,  163,    1,   12,    1, 1938, 2809, 1684,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1872,   37,  631,    1, 2798, 1228, 1278,  918,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3274,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035,   37, 1642,  199,   32,  539, 1037,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 244, 120,  37, 119,   1, 131,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 374,   1,  72, 401, 197, 490,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2543, 2396,   32,  976,   37,  588, 1647,   98, 3118, 1512,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  156,   71,  158,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  501, 2308,    1,  671,  627,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3245,   37, 1306,  449, 1090,   45, 2925, 2318,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 3111,   32, 2140,   98,   64,  591, 2699,    1,  223,  997,\n",
      "         1192,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2249,  345,    1,  967,    1,    1, 2814,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  590, 1188,    9,  667,   67,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3302,   77,    1,   98, 3306,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2031,  353,    1,   59,  354, 2973, 1764,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1473,   98,  276,   32,   69,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  667,   26, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,  386,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  105,    1,    9,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1811,  404, 1094, 2909,    1, 1219,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  863,  932, 1961,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1264, 2203,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1525, 1013,  162,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2500,  917,  437, 3067,  104,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1363, 1539,   40, 1917,  220,  365, 1505,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3132,   16,    1,  590,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1310,   37,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  466, 2604,    1,  167,  764, 1021, 1273,   41,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1987,  105, 1628,  271,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,    1,  354,  548,   44,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051,   32,  331, 1074,  861,  132, 2552,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1830, 3107,    9, 3366,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  294,  295,    1,  296,    1,  297,  298,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37, 2192,   17,  105,  271,   98, 2071, 1331, 2019,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,  794, 1211, 2366,  220,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  391, 1329,    1,  810,  707,  974,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,  467,   37,  686, 1783,  156,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   32,    1, 2135,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1574,    1,   98,  963,    1,  187,    1, 2827,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1902,    1, 3287,   37,  601,   73,  726,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1879, 1173,   37,    1,    9,  105, 2200,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32,    1, 1450,   32, 2597, 1056,  104, 2548, 2844,\n",
      "           32,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1559, 1159,   62,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2065,    1,    1, 2800, 1089, 1090,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,   98, 1171,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  267, 1463, 1558,  388,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 1157,  159,  123,  417,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181,  361,    1,  726,    1,    1, 2565,    1, 1654,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   37,    1,  361,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2511,  369,    1,   37,  151, 1117,    1,  669,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1521, 2693,    1, 1704,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  716, 2173,    1,  136,  759,  895,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  581, 1463,    1,  697,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  944, 2582,  917,    1,    9, 2977,   12, 1821, 2813,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280,   37, 1844,  365, 1788, 2472,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  524,  525,   15,  670,   32,  645, 1034,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  361,  442, 1749,    1,    1, 1183, 2113,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,  267,  193,  840,  644,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2339, 2568,   45, 3038,    1,   32,  447,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3003,    1,   85,    1,   32,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   25, 1376,    1,  123,  220,    1,  354,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  403, 1447,    1,   39,  176, 2719,   10,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2135,  456,   85,  531,  285,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1110,  619,   32, 1194,   37,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   99,   37,    1,   32,   94,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2939,  972,   39, 1114,    9,  519,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1085,  151,    1, 1361,   12, 1228, 1876,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  853,    1, 2797,   98, 2500, 2485,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  938,    1,  565, 3038,  578,  187,    1, 2751,  856,   81,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299,  879, 1009,   12,    5,    6,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   20,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  640,  119,   61, 3214,   12, 1509, 2814,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1848, 1682, 1041,  611, 2113,    9,  636, 1336,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  384,    1,    1,  261,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1492,    1,    1,  163,    1,   12,    1, 2823,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  700,  548, 1034,   45,  276,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  764, 1000,    1,  880,   12,   29,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2970, 1089, 1675,  193,    1,    9, 1763,    1,  202, 2698,  151,\n",
      "         2588,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1, 2196,    1,    1,  161,  841,  469, 2030,   32,  166,\n",
      "         2736,   12, 1819,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   30,    1, 1912,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,  335, 2615,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1079,  166,  317,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  749,  480,  902,  790,  788,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3405,   32, 2571,  474,  142,   37, 2199,  365,  557,  540, 3279,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1537,  721,  146,  444,    1, 1281,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1375, 1670,   59,   32,    6,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1023, 1204,  191, 1169,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  744, 2306,    9,  829, 1377,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1384,  726,  599, 1885,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2379,    1,  361,    1,  631, 1159,    1, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  506, 1094,   37,    1,    1,    9, 3339,  548, 2271,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2318, 1580,  338,  419,  548,  550,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  288,    9,  119,  186,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  612, 2716, 2349,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   10, 1876,  198,  548, 1209, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,  105,    1,  384,  306,   12,  825, 1013,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1702,   98,    1,  220,  148,    1,  440, 2264, 1900,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   71,    1, 1572,  191,   69,    1,    1,  441,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3369, 1583,    1, 1557,   37,    1,   45, 2571,  474, 2699,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  324,  958,  887,   46,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2708, 1260,   98,    1,    1,  736,   98, 3339, 2271,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1633, 1639,    9,  550,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  296,  315,  365,  880,   37,    1,   79,   20,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1,  342,  759, 1845, 2673,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  884, 1003,  176,    1,    9,  807,  673, 1004,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 2391,  845,    1,    1,    1,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1022,    1, 1550,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,    1, 2006, 1130, 3340,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,   42,  284,  573,  149,    8, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  639,  420,    1, 1718,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  286,  633,   37,  970,    1,    4,   37,  854,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,  546,    1, 2686,  187, 1370,   45, 1461,  750,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,    1,    1,    1, 1021, 1798,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3167, 2722, 3074,    1, 1022,    1, 2296,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,  884,  753,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1190, 3067, 3351,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3137, 1634,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  865,   37, 3329, 1411,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   26, 1039,    1,    1,  444,  829, 2194,  469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3089,    1,  119,   28,    1,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3359, 1707,    1, 1004,  297, 3339,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,  279,  538,  682, 1876,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,    1,  359,  474,   27, 1251,  672,  895,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2235,  159,  123,  415,  242, 2163,    1,  284,  390,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  765,   39,   32, 1030,  176,  654,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1220,  522,   98,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  328, 3196,  546,   28,  166,  542,   32,  968,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,  253,   37, 1982,  467,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,  315, 2184,   14,  525,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2614,  542,  753,  872,   12, 2463, 1258,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  539,    1,    1,  191, 2741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1200,  140,   32,  848,  132,    9,  849,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   64,  799,   37, 1403, 2817,  361, 2705,   37, 3349,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2602,    1,    1,  267, 2269,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1586,   51,    9, 1539, 2306,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1748,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3168,   12,  985,   61, 1533,  384, 2626,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2292, 1316,  531, 2414,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1451,  407,   37,  730, 2614,  548,    1,   37, 1056,  356,   24,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  935,  536,  636,  443,  187, 1808,  256,    1,  541,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 2036, 1113,   67,  948,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3114,    1, 3147,  176,    1,   45,  443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3189,   12, 2804,  338,  337, 2337,   98,  825,    1, 2579,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1353,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1031, 1071, 1990, 1975,  105,  784,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1380, 1230,   32, 2886,   12, 1311,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   45, 1050, 1764, 1990,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  200, 1718, 1021, 2168,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1477, 1555, 1090,  959,  297,  176, 2916,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1838,  417,    1,   14, 2054,  246,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 325,   1,   9,  59,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 289, 187, 460, 733,   1,  50,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,   51,  125,  453,  693,    9,  647,  187,  445,  187,  786,\n",
      "           72,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  379, 2047,  531,   12, 1344,    9, 3105,   32,   91,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307,   37,  693, 2341, 1412,  841,    1,   32,  453,   41,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821,  927, 1464,   37,    1,  453,    1,  361, 2421,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 2216, 3118, 2751,    9,  645,    1,   32, 2292,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3068,    9,    1,  327, 2794, 1211,   80,  259, 1484,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  849,   37,  624,    1,  220,  848,  548,  214,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  829,  132,  155,   26,  756, 1574,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  315,    1, 2235, 1904,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  580,   43,    9,  840,  792,    1,  792, 1090,  675,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  442,  488,  593,   12, 1875,    1, 3079,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2677, 2448,  787, 1917,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  485,    1,  372,  326,  486,  132,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2266,   12, 2059,  680,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  387, 1332,    1,  163,    1,   12,    1,   15,   28,\n",
      "          419,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  342,   78, 1421,    1,   98,    1,   23,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  457,    1, 1415,   37, 2276,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  167,    1,   12,  312, 1116,   52, 2740,  892,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1861, 2399,   37,    1, 2656,  297,  531,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,  361, 2708, 2325,   32,    1,  361,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,  548,  420,  310,  770, 1976,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1,  613,  288,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2257,   39,   45, 2792, 3273,  220, 1987,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  442,  910,  703,   37,  119,    1,  131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2135,  691,  267,  460, 1905,  531, 3102,    1, 3377,   61, 1530,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1848,   37,    1,    1,  636, 1336,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  459, 1522,    1,  132,  220,  391,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,  778,    1, 1083,    1,    9,  535,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 166,   1,  61, 920,  32, 124,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 554, 608,   1,   1, 860,  37,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035, 1070,  398,  611, 2349,  920,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1430,   37, 2035, 1009,   12, 2113,    1,    1,  163,    1,  903,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1893,    1,   15, 1121,  176,  971,    1,  479,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2614,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  444, 3369,    1, 3184, 1980,   32, 1428,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1509,  636,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  458,   45,  507,   37,  125,    1,  388,    4,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1452,   32,  726,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,   26, 1039, 2995,  384, 2993,  313,   37, 1787,  829,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2173,  927, 1791, 2089,  133,  191,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1763,   12,  913,   37,  151,  654,  124,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584, 1874,    1, 3305,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3337,  729,    1,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,   69,  633,  155, 1356,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  338,  187,  107,  387,   71,   32,  109,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,    1,    1,   32,  557,  540, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1795,  156,   28,   98,  851,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1305,  103,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,  384, 2523,  548,  581, 1385,   45, 2957,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  732, 1831,   37, 1604,   32,    1,  187,  793, 2329, 1346,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1021,   45,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3378,   37,   26,  776, 1462,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2451,   45,    1,   32, 1833,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  389,   93,    1,   32,  385,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,    1,    1,  297,  531, 3102,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  880,   95,   37,  451, 1564, 2218,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  458,   45,  507,    6,  284,    1, 1149,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707,  105,   84, 1415,   37,    1, 1117,    1,  163,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2994,    1, 1220,    9, 2157, 2995,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2813,    9, 3088,    1,   45, 1090,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1797,    1,    1,  487,  540,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,  792, 2080, 3024,  792, 3022, 1976,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3405,  288,   37,  907, 2774, 2153,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,  315, 1913,  163,    1,   12,    1,  250,    1,   37, 1012,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2619,   98,   37, 1334,   32,    1,    1, 2107,    1, 2779,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,    1,    1,  221, 1159,  858,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2700, 1000,  365,  459,   45, 1204,  176,  403,  361,  463,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3389,  686,    1,    1,  187, 2782, 2055,   37,    1,  102,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1106, 1626, 1013, 1522,    1, 1781,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387,  377, 1895,  585,   32,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2095, 2919,    1,  880,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2376, 2223,  855,  859,   37, 1348,    1,  792,    1,   45,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3363,  288,   37,   52, 3343, 1009,   32, 1551,   45, 1448,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492, 2263,   32,  531, 3148,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  548,    1,    1,  729,  590, 1048, 3289,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779,   37, 1046, 1133, 1787,  384,   32, 1505,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  542,    1, 2507, 2814,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1614, 2336,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  885,   74,   45,    1,    9,  104, 2924,  361, 3361,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3379, 2985,    7, 2095, 3060,  297, 2950,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   45,  365, 2580, 2432,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  132, 1229,    1,  297, 3343, 3365,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  506,  782, 1017, 1621,    1,   37,    1,  596, 1793,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1414,  837, 1312, 1147,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  729,   21,   37,  123, 1503,  214,  191,  356,  439,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2303, 1116,    1,   45,    1, 2700,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,   93, 1509,   32,  547,  537,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1047,  256,    1,   37, 1638,   45,  217, 1997, 1205,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1545, 3055, 1159,    1, 1267,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  922,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3173,  683,  140,  395,   26,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1163,  572,  197,  418,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2045,  829,   12, 2881,  108, 1033,   45, 1718, 2039,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3267,  921,    1,   32, 1742, 3295,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,   12, 1279, 1353,  361, 3034,  614, 1561,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2123,    9,  777, 1085,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3374, 2328,    1, 2572,   32, 3101,  477,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  515, 2427,    1,   38,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  225,   70,   71,  187,   69,  102,  470,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  720,  680,  195, 2054,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  231, 2206, 2989, 1810, 1509, 1675,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,    1,  193,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2868, 1949, 2784,   37, 2826,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1687, 1022,    1, 3008, 1618,   28,    1, 1298, 2124,   45,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  590,  132,  220,  971,    1,    1, 1411,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,    1,   32,  227, 1134,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,  947, 2263,   56, 1769,   37,  151,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2411,   37, 1154,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2843,    1,    1,  332,  631,  176,  837, 2630,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  177, 2572,   32, 2597, 1345,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   85,  532,   28,  187,  293, 2478, 2527,  164,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,    1,  220, 3169,    1, 3230,   28,  444, 3198,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2673, 2834, 1665,  311, 1428, 2673, 1063,  475,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  875,  768, 2096,  220,  455,   12,    1,\n",
      "            9,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  219,  474,  879,  829,  199,  421,  231,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,  539,   82,  580, 2139,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3245,   32,    1,  361,    1,   39,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 1214, 1022,    1, 2296,  680,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  647,  353, 1735,  572,  983,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3157,  813, 1856,  220,  410,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  885, 2041, 1463,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1415, 1173,  176, 2387,  361, 2355, 1013,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1147, 3080, 1360,  612,   52,  820,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 2962,    1, 1401, 3115,   37,  601,  404, 1684,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  386, 1086, 1545,   12, 1045,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,  121,   69, 1479,  141,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 1853,  726,    1,  361, 2498,  444, 3334,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  474,  140, 2069,  432,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  550,  365,  224, 2549,    9,    1, 2910,  105, 2387,  629,   98,\n",
      "            1, 2261,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492,    1,   12,    1, 2457,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  997,    1, 3222, 3275,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3239,    1, 2565,    1, 3301,   12, 2667,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1435,    1,    1,  191,  671,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,  267, 2924,  190, 1334,   32, 3339, 2191, 2328, 1450,   98,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,  440, 1965,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  858,  614,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  813, 2912, 1268,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  721, 1458,    1,  187,   82,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  294,    1, 1558,   28,  191, 3163,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,    1,    1,    9,    1, 1123,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  142,   37,  439,  342,    1, 1559,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1962,    1, 1273, 1074,  881,    9,    1,   32, 2573,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1674, 3134,  386,   78,    1, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213,   37,    1, 1545,   12,    1, 2422,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1127,  140,    1,   98,  271,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  929,    1, 1610,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  611, 2705,  139,    9, 3099,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  157,    1,    9,    1,  913,   13,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2623, 2624, 2130, 1976,   32, 1194, 2725,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  255,   94, 2494,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2278,  775, 1117, 1525,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835, 2404,    1,  993,  475,   37, 2237, 1094, 1411,  339,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  103,    1, 3204, 2963,   32,  581, 1385,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2278, 1564, 1844,    9,    1,  220,    1,  151,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2708,  446, 1082,    1,    1,   32, 2299,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3045, 1492, 3395,   16, 3347,   32, 1727,    9, 1204,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  855, 1216, 2587, 2889,  195,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  773,  606, 1595,  698,   37,  818,  834,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2820,  353,  699,  242,  197,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3051, 1414,  774, 1444,  606,  590,   57,   37,    1,    1,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  801,   32, 2528, 1838,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3312,   37,  449, 2017,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1766, 1767,  662,   37, 1776,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  325, 1056,  681,    1,  155,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,  232, 1110, 2225,  421,    1,    9, 2410,   74,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  947,    1,    1, 1388,   32,    1,  787,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  686,  531,    1,   69,  965,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1524,  726,   32,  105, 1559, 1631,    1,   12, 1045,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   39,   45,  593, 1990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3321,  583,   32,  354,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   60, 1086, 2600,   32, 2028,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1645,    1,  297,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  879,  829,  117,  132,   37,  465,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1173,    9,  417,  102,   98, 2088, 2105,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12,  365,    1,  619,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  615,  661,    1,  572,  716,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,  361,  326,  798, 1146, 1703, 1151,  846, 2666,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2634,  207,  197,   28,    1,   32,  449, 1023,    1,  387,    1,\n",
      "         1661,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2751, 2856, 1147, 1583,    1,    1,  104,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  147,    1,  709, 2751,   37, 2162,    9,  350,    1,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2045, 2425,   37,  151, 1883,    9,    1,  131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3256,  186,   37,  688, 2720, 2796,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232, 3234,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2998,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  295,  267,  460,   51,    1,  573,  315,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  197,  188,  176,   51, 1535,  124,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181,  181,   98,    1, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  183, 1034,  115,    9,  827,  274,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2844,  187,  104, 1414, 1260, 2764, 3381,   12,    1,   32,\n",
      "         3155,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  428,  420,  782,    1, 1278,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2137,   32, 2597, 2856,  176,  177,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  709,    1, 3129, 1292,  928,  176,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,  421,    1,  858,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1233, 1149,   37,  741,   98,  477,  522,    1, 1267, 1313,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1614, 1117, 1525,  861,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  493,    1,    1,  973,  636, 1279,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2226, 1532,  166,  917,    1,    9,  219, 1984,    1,  267,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  681,   37,    1,    9, 1583,  993, 1876, 1604,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092, 1070,  103,  163,    1,   12,    1,  147,   37,  817,  912,\n",
      "          605,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1, 1260, 1645, 1396,  548,  557,  540,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1139,   45,  460,    1, 2954,  565,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,  172, 1215,  361,  848, 1303, 1539, 1273,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1, 2531,  498,   98,    1,    1,    1,   98, 1256,  551,\n",
      "         2196,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1082, 1488,    1,    9,   22, 1225, 1294,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,    1,  856,   32, 2597, 2572,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1106,  614,   37,  166, 2780,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,  232, 3207,  321,   77, 3208,  671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2206, 2989, 1018,   32,    1, 1173,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  571,    1,   45, 3182,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1884,    1,    1,   39, 2685, 2642, 1090,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2314, 3358,  580, 1890,   45, 1983, 1867,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 365, 161,   1, 167,   1,   1,   1, 428,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 224, 418,  32, 218, 714,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1726, 1998,   37,   52,    1,  548,    1,  401, 3371,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2959, 3120,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3120, 1421, 1796, 2681,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  540, 2681,  456, 1549,   45, 1212,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1194, 1843,  207,  418,   98, 2232, 1376,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3311, 3310, 1723,    1,  891,  892,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  147,  221, 1391,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2816,  187,  510,    1, 1530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   40,  259, 1241,  810,  166,  917, 2415,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1240,   52, 2615,   45, 2325,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1900, 1083,  388, 2127, 1001,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  103, 2334,    1,  187, 2957,  953,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1831,   37,  930,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,  738,  220,    1, 2153,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 1821,  639,  313,    9,  365,   22,  846,  119,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  936,  469,    9, 2128,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98, 1545,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  844, 1442,    9, 2734,  591,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,   61,    9, 2913,    1, 1851,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 1447, 2404,  590, 1986,   98, 2673,   46,  220,  403,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  182,  132,   37, 1413, 2611,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2183,  487, 2224, 1190,    1, 3084,  939,   32,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1043,  338,   98,  242,   69,  636,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,  936,  365, 1273, 1151,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1170, 1008,    1,    1,  187,  453,   82,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  457,  963, 2981, 1539,   98,  429,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3359,  868,  132,  220, 1557, 1384, 2789,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,  698,   66,  816,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2695,  105,  880, 1631,   22,  846,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,  615, 1937,    1, 1890,  115,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1572,  384,  166, 1030,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,  675, 2384,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  590,    1,  129,  161,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  936, 1230, 2528,  361, 1230,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  303,   67,  304,    1,  305,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1462,  681,  987,   32,   98,  443,   98, 2095,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962, 2475,  563, 1987,    1, 3263,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1231,  548, 1628, 1664,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  597, 1883,    1,    1,   28,   98,  159, 3000,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2658,    1,   37,   52, 2297,  365, 1277,   45, 2217,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056, 1676,    1, 1418,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1492,    1,    1,   45, 1428, 3406,   61, 1584,  168,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  206,   12,  581,  401,  197,  418,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,    9,  365, 3118,   46,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3030,  267, 3399,   32,  403,  464,    1,  590, 1421,   45,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  439,   45, 1018, 1015,  187, 1215,    1,    1,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2328,  210,  323,   32,  166,  730,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12, 2308,  168,   98,  477,    1, 1981, 1675,  653,   79,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2136,   90,    1,    1,   98,   10,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3006,  619, 1038,   32,  447, 2596,  722,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2925, 1090, 1829, 2926,  176, 2570,  787,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1770,    1,   37,   92,  116, 1998,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   39,   45,  711,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1633,    1,    1,   98,  222, 2552,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  600,    1, 1346,    1,    9,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386, 1831, 2216,    1,    9,  354,   45, 1505,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,  744,  593, 1139, 1434,  119,   32,    1, 3163,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176, 1022,    1, 3008,    1, 1298,    1,  202,    1,   45,   29,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1233,   37,    1,    1,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1723, 1426,    1,   32, 1405,  373,  776,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2703, 2644, 3102,   32,  531,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  993,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  942,  155, 1417,    1,  131,   32,    1,  942,  333,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,    1, 2062,  288,  365, 1757,    9,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2707,  162,    1,  562,    9,  342,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   28,  202,  857,   69,    1,  392,  682,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  111,   15, 1348,   37,   71,    1,   28,    1,  384,  105,  356,\n",
      "         1490,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1013, 1522, 1299,    9, 1697, 1491, 2165,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2676, 1702,    9,    1,    5,    6,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1900, 1207,   37,    1,  856, 1316,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  424, 2306,   32, 1123,    9, 1893,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2454,  724,    1,  590,    1,   12,   61,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3006, 2833, 3365,   32,  531, 2764,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3228, 2315,  166, 1691,    1,  454, 1444, 2497,  460,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  596, 1562, 1715,  989, 1277,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  289,    1,  289,    1,  289,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1559,    1,    1,  187, 1340,    1,  542,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220,    1,  361,    1,   39,   45, 1675,    1,    1, 2590,  105,\n",
      "          183, 1641,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  640,  187,  585, 2199, 1588,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1809,  460,    1,   37,    1,    1, 2355,  675,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2206, 2435, 1110,  872,  420,  385,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2290, 3259,  498,   37, 1145,  220,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  775,    1,    1,    1,   12,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  389, 1924,  105,  502,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1213,  797,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1082, 1945,    9, 2921,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  335,  429,   32, 1872, 3004,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1118,  205, 1996,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  622,    1, 1426,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,    1,    1, 3204, 1249,    1,    1,   37, 2449,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2890, 2826,    1,  140,  455,   12, 1194,    1,  671,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 2224,    1,  949,   45, 2708, 3080,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  548,  390,    1, 3236,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,  105, 1575, 1159, 2218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  179,  361,  180, 1776,  792,  170,   45,    1,    1,  792,  559,\n",
      "           79,   45,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,   69,  633,   32,  121,   61, 1415,   37, 1686,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1822, 1463, 2725,  388,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2308,  474,  759, 1845,  132,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1813, 1218,  361, 1255,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  920,    1,    1,    1,  105,  365,    1,   45, 3053,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   65,  167,    1,   98,  347, 1232,  954, 1071,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,  220, 2961,    1,    1,   76,   81,    9, 3201,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2823,  315, 1980,   98,  227,    5,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1934,   12,    1, 1679,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3116, 3217, 2069,  892,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   72,   73,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2227,    1,  365, 2043, 1159, 1225,  512,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1442,   37, 2929,    1,  150,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  327,  861,  680,  114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  797,    9,  851,  298, 2372,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  552,  552,  611,  302,  765, 1836,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  624,    1,   37, 1463,  250,    1,    1,  165,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1976,   32,  511,    1,   37, 1797,    1,  805,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,   70,   71,  115,   45, 1183,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2097,   45,    1, 3338,   79, 2883,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1654,    1,    1,    1,  142,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1077,   37,    1,  453, 1224,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1748,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361, 2355,  418,   32,  455, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2637,    1,  917,   37,  151,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3238,    1,   37,  168,   98,  166, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 1542,   37, 1413, 1107,  912, 2285,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  650, 2397,   51,    1,   98,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9, 2275,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1101, 1230,    1, 1198, 1158,  225,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614, 1833,    1,   32,  878,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  593,    1,  753,    9, 1563, 1064,  384, 2073,   10,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1377,   37,  104,   37, 1403,   28,   60,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1631, 1159,  197,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974, 1957,   32,  365, 1015,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  244,    1,   32, 1412, 2382,  293,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1750,  105,  386,  219, 1067,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  420, 1087,   37, 2446, 2587,  657, 2336, 1151,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  295,   37,  508,   79,    1,  359,  361, 1737, 1346,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1186, 3067,    1,   32, 2292,   32, 3369,   12, 3118,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3262, 3164, 3317, 1542,   37,  865,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  584,  171,   12,    1, 2317,  786, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    1,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  588,  754, 1844, 2306,  176,  878,  873, 2578,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  581, 3018, 2630,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428,    1,   32,    1,    1,  765,   37,  861,    1,   32, 1633,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  421,    1,   37, 1343,  460, 2440,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1056, 3343, 2137, 2856,  176,  177,  249,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  941, 1682,    1,  331,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1355,    9,    1,    1, 3363,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  903,    1,  182,    1, 2611, 1149, 1313,  176, 1953,   45,\n",
      "         1895,    1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  972,   37,   92,  163,    1,   12,    1, 1656,   15,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,   12, 1056, 3365,    1,   37, 1148, 3361,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  709,  491,  929,  146,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  577, 2689,    1, 1254,   32,    1, 1618,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3238,   12,    1,   51,   52,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226,  331,  193,  166,  449,    1,   37,  619,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1241,  665,    1,   32,  617,  618,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171,  237,  267,  460,  190,  125,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3369,   32,    1,  297, 3118,    1, 1428,  232,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676,    1,  928,  548,  245,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  590, 1023, 1553,  220, 1023, 1204,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  631,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  534,   37, 1046,  776,   98,    1, 2772,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2478,   28, 1513,    1,   39,    1, 1024,   32,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3207, 1408,  671,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1463,  361,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1796,    1,   92,  568,   32,  871,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1008,  597,  755, 1213,    1,   45,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3375, 1333, 1530,  548, 1887, 3101, 2548,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3226,  103, 3241,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  547, 2476, 2572,    1,  786, 2249,  361,    1, 1530,   32,  501,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2614,  619,    1,    1,    1,    9, 1854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  915,   45,    1, 3033,    1,    1,  944,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176, 1122,    1,    1,  707,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  531, 3006, 2856, 1056,    1, 3365,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25, 1285,  417,    1,   60,   85,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1024,   12,    1,   92, 3013,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1236,  224,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1797,    1,    1,  176,  166,    1,    1,   32, 2197,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2414, 1056,  104, 2548,    1, 2803,  786,   32, 3360,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3157, 2263,  547,    9, 2328, 1260,   98, 3363,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2384,  453,  645,    1,    1,    1, 1117,    1,   98,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2673,    1, 3150, 1774, 1750,  715,    1,  548,    1,   12,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2765,    1,   37,   52,   19,    9,  522,   32, 3360,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1107, 2086,  579,  894,   52, 2740,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2655,   45, 2859, 2971,    7,   37,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3369, 2682, 1428, 2429,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993, 2994,    1, 2677,  949,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  500,  387,  501,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302, 1710,    1, 1038,  199,    9, 2650,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,    1, 2814,  176,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783, 1586, 1577,  187,  453,    1, 1872, 1873,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1789, 1151,  633,  952,  198,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2547, 2572,   32, 1676,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2083,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3277,  460,   12, 1602,  176,    1,    9, 3177,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1187,  224, 2355, 1013,    1,  762,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3174, 2270,   37,  856,   37,  759,    1, 3295,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  935,   12,    1,    1,  686,  191,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   98,  258, 2165,    1,    1,   12,  105, 3091,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  863, 1149, 3340,   32, 3360,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236, 1022,    1, 1034,  115,  166,    5, 1178,   51, 1526,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1128,  936, 1180,    1, 2871,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3123,  688,  311, 2936,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1822,  138,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647, 1774,   39, 1056,  365,  883,    1,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  132,   32, 1820,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 2038,  361,    1, 2153,  907,   32, 3113,   37, 2000,  863,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1715,  365, 1428,  261,  167,  606,    1,  531,  443, 1186,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   45,  507,   37,    1,    1,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2615,    1,  140,  449, 2213,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  119,  448,    9,  105, 1460,  442,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  296,  162,  168,  115,    9,  105,  880,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314,  551, 1692,   37,  508,   79,    1, 1149,  187,  460,  802,\n",
      "          220,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   93,  361,    1, 1243,   45,  612,    1,    1,  619,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3120,    1, 3083,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  814,    6,  605, 1469, 1114,    1,  225,   79,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3237,   51,   84,   28,  105, 1569,    9,  105, 1090,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3371,    1,  187, 3354, 1065, 1190,  528, 1860,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,  142,   98,  691,  129,  458, 1501,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  396, 1885,    1,  444, 2161,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   12,    1, 2721,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 2043,   37,  764,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  726, 2580,  328,  105, 2204,  698,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2772, 1090,   61, 1809,  105, 1887,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2830,    1,  594,    1,    1,  548,  984,    1,    1,    1,\n",
      "            1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  179,   37,  125,    4,   32,   15, 1183,    1,  322,   85,  288,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275, 1877,   37,  470,    1,  223,  408,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056, 3343, 3365,  259,  754,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1, 1581, 1766, 1767,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  294,   37,  125,    4,  176,    1, 1967,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  524,  525,   15,   71,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 1994, 2819,    1,    1,  176,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,    1,  198,  367,    1,   14,   15,   71,  191,    1,  118,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  430,  477, 1086, 1010,  937,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1604,    1,  138,   79,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  733,  442, 1131,   37, 1132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   30,    1,    1,  243, 2979,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  251,  590,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,    1,  215,  384,  636,    6,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2, 590,   1,  98,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  98,   1,   1,   1,  39, 191,   1,  98,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,   27,    1,   98,  889,  109,  509,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2700,  506,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2632,   32, 2751, 1731,    1, 3361, 2567,    9, 2476,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1240,  193,   52,   81,  444,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   66,  242,   63,    4,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  327,    1, 1380,  192,    1,   32,  643,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1545,  680,   97,  187, 3181,    1, 1178, 1179,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  886, 1987,    1,    1, 1159, 2800,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3328, 2651,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 2153,  697,   37,  693, 2927,   46,   37, 2707,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1167,   12, 2398, 2024, 1652, 1236, 1227,  415,  786,  388,  199,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39, 1099,   12,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  294,  156,   28,    1,  641,  157,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 2827,   32, 2028,  513,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  968,    1,  794,  453,  449, 2328,   37, 1821,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  584,    1, 2039, 1174,   63,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3404, 1031, 1434,  361, 1697,   37, 1937, 3358,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1157,  159,  439,   28,    1,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 2924, 1388,  220, 3045,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  881,  325,  199,    9,  810,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,  903,    1, 1423,   46,  187, 2153,  973,    9, 3072, 2024,\n",
      "          132,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,  640,  786,   59,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3013,    1, 3278,    1, 2337,  460,  321,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 1056,    1,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3068, 1380,   80,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  163,    1,   12,    1, 1940,   12,    1,  335, 2505,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,  296,    1,   37, 1245,   28, 1246,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2528,    1, 1573,    9, 1408,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1360,  612, 1343,   32, 3172,  357,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2313,   12, 1567,  515,  163,    1,   12,    1, 1333,  176, 3096,\n",
      "          671,  428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3359, 1877,   37, 1636, 3339, 2625,    1, 1950,  640,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  105,    1,    1, 2354, 1658,  454,   37, 1604,   32,\n",
      "          105,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  670,   98,   69,    1,    1,   86,    1,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2511,  172, 1581,    1,  384,  104,  422,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1705,   37,    1, 2375, 1281,    1,   98, 1006,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  986,   59,    9,    1,   50,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3254, 1765,  645, 3262,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1658,  327,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1450, 3153, 1559,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2856, 1056,  163,    1,   12,    1,    1,   32, 1212,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 3103, 2844,   98,  667, 2921,    1,  232,\n",
      "          267,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652, 1718, 2355, 1921,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  168, 1427,  492,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2765,    1, 1229,   37, 2237, 2018,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1018,    1,    1,  354,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  166, 1158,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1956,  147,  267, 1076,  719, 2015,  432,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,    1,  148, 2426,  972,   37, 1348,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1557, 2137,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25, 1285,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  147,  261,  444,    1,  625, 1167, 2109, 2638,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1277,   61, 2177,  100,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1128,   37, 1155,  250,   32,  903,    1, 1417,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   96,  297,    1,    1,   37,  163,    1,   12,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 2494, 1097,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1297,  166, 1412,  535, 1343,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2956, 1627, 1903,   98,    1,    1,    1,    1,    4,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  835,    1,  700,    1,    9,   59, 1714,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  397, 1579,  909,  444,  104,   32,    1, 1559,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  750, 1586,   28,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1360,  612,  142,    9, 1503,  129,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3233,  726, 1114,  528,    1, 2907,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,  647,  721,   37,  360,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428, 2883, 2924, 1997, 2156,    9,  531,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  561, 1539,  116, 2502, 2678,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3106,  488, 3136,   32,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  147,   37,  804,   98, 3378, 1727,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1585, 1401,  105,   12,  608,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  802,  829,   12, 1117, 1525, 2362,  105, 2195,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3307,  565,    1,    1,  202, 1977,   37,   52,    1,  600,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  429, 2048,   45, 1714, 1640,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398, 2037,   39,  798,  444,  224,  378,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1585,   32,  463, 3343,  787, 2414,  786,    1, 2766,   56,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3164, 2145,   79,  215,    1,  361, 1866,  754,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2748,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1022,    1, 3318,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1877,  856,  297,    1,  768,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1, 1545,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  386,  295,   37,  125, 1202,  361, 1289,   37, 1407,  541,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,  140, 3343,  863,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  982, 1158, 1230,  259, 1954,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1687, 1022,    1, 3008,    1,  388,  128,  361,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  474,    1, 1862,  600, 2585,  593,   12,  449,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1941,  104, 2548,    1,    1, 3155, 2751,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1210,  388,  265,  763,  453,  132,  220,    1,  251,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,   79,   46,  220, 1485,  458,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  670,  608, 3079,    1, 2799,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1076,  288,    9,  671, 1078,  142, 2013,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  196,    1,   28,  176,  551,  612,  613,  887,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2373,  365, 1151,  220,    1, 1017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  650,   32,    7, 1002, 1463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,  794,  105, 1164,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2321,  606,  183, 2454,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1641,    9,    1,  187, 1625,   45,  413,    1,  142,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  321,  166,  104, 1403,  105,    1, 3093,   37,  531,   32,  166,\n",
      "         1411, 1056,  537,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,  193, 1542,   37, 1195, 2673,   46,  121,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   28, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,  296,   46,  245, 1979,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1848,  494,  619,  611,  199,   32,  636, 1336,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1, 876, 612,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 220, 987,   1,   1,   1,  13,   1, 166,   1, 176, 247,  81,   3,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 1047,    1,  959,  182,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,   97,   32,  105,  628, 3283,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2984,    1,    1, 2918, 2820,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3247,  815,    1,  472, 1090,   32,  726,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3079,    1,    1,   45, 1066,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2912,    1,  528, 2712,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1643,  251,    1,  861,   33, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,  431,  422,  133,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  487,    1, 1426,   39,   37,    1, 1763,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  370,  162,  543,   45, 1876,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  857, 3307,    1, 2125, 1458,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  170,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3181,    1, 2445,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  227, 2539,    9,  105,  227,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1394,  105, 1090,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   69,  965, 1450,    1,  532,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 3293,    9, 1056, 2476,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,  140, 3077,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  260,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3176,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162,  347,   32, 3118,  677,    1, 1492,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  449,    1,    1,  331,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1931,  297, 3356, 2024,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1861,   37, 1248,  439,   37,    1, 1895,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1412, 2611,    1,  348,    1,  781,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2571,  474, 1353, 3118, 2699,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1159,  105,    1,    1,    1, 1398,  612,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 3389,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2464, 2264,  729,    1,  187,  778, 2323, 1258,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  864,    1,  121,    1, 2673,  529,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1170,  682,   98,  479,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  195,   25,  410,    1,    1,  374,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1883,  325, 2215,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,    1,  331,  693,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1140,   37,    1,    1,  612,  917,  786,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2967,  997,  584,  741, 2205,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  730, 1731,  361, 1079, 3063,  764,  567, 2372,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  697,   37, 1539,  449,  517, 1108,   32,    1, 1033,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1229,   32,   46,    9,   45,  141,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1364, 1365,  894,   52, 2613,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1925, 1583,  190,   52,    1,    1, 1282,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3199,  267,    1,  388,    1,  763,  166, 2502,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1401,  454,   98, 1708, 2290,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  365,  593,    1, 1411,  992,  205,    9,  457, 1821, 1697,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2169,    1,  762, 1997,    1,   32, 3343,  741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1444,  125, 2349,   39,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 1830,    9,  627, 1821,    1,  629, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3053,   37,  907, 2214,    1,   98,  865,   37, 3024,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,    1,   93,  187,    1,  297,    1,  202,    9, 1354,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 3066,  361, 3215,  837, 2741, 2078,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,  159, 1269,   88,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  603,    9,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  523,   42,  297, 2089,  927,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  375,    1,  166,    1, 3156,   32,  105,  593, 2198,  439,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1059, 1247,  873, 1411,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2275,  361,   10,    1,  730, 2614,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  224, 2355, 1013, 2549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,  661, 1918,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    6, 2336,  279,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  506,  782,  163,    1,   12,    1,  441,    1,  244, 2311,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   37, 1636,   29,    1, 1316,  593,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  758,  879,  829,  117,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1296,   28,  187,    1, 2123,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2821,  321,  860,    1, 2531, 2471, 2531,  446,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 2710,  437,  267, 2072, 3379, 2596,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  663,    1, 1536,    1,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1926, 1927, 1229,   37,   52,  125,   79,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2991,  794, 1228,  659,    9, 1095,  124,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3371,  884,    1,  187, 2018,   12,  365,  446,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,   89,  267,  104,    1,  220,  673,  448,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,    9, 1158,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3213, 2226, 1360,  612,  151,  885,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1161,  953,   32,  166, 1108, 2054,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  530,  187, 1785,    6, 1588,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  132,   61, 2740,    1,  311, 1604,  891,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  328,  104,  560,    1,  664,  128,  528,  347,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3122,    1,  150,   12,    1,    1, 1631,   85,  105,    7,  422,\n",
      "         1798,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  567,  914,   51,   52,    1,   98,  119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2944, 1086,  507,   12, 2315, 1844,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  773,   66,    1, 1595, 1332,    1,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3029, 2585, 2744,    1,    1,    1,   37, 3024,  548, 1700,  257,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1636,  176,    1, 1224,   32, 1352,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  197,   28,  187,  306,  256,  388,  280,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1645, 2673,    1, 2405, 2029,  602,  548, 1313,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  656,    1,   37, 1343,    9, 1238,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2265, 2404,    1, 2924,  190, 1334, 2191, 1094,  796,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,   44,    9,    1,  157,  345,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  119,  354,    9,    1,   32, 2084,  171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1830, 2992, 1151,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1675,  325,    1,  669,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968,   12,    1,   82,  368,    1,  102,  894,   71,   32,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  755, 1419, 3028,  328,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294, 1456,  197,  418,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  286,    1, 1080,  384,    1,  585, 1910,  105,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3072,  387,  166, 1125,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1479,  922,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1742,   12,  954,  897,    1,  118,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,  786, 1056, 1136,    1,   45, 2820,  361,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  322,   79,  667,  446,  528,    1,   32,  806,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,  735,  293,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1171,   85, 1766, 1767,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,   37, 3140, 1398,  612,    1,   32, 2265,  863,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2369,  453,    1,   98, 3383,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  550,    1,  150, 2025, 1720,    1,  361,    1,    1,  612,   18,\n",
      "           37,  850,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  174,    1,  160, 1278,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  480,  885,   84,   32,  503,  832,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1137,  530,  104,   37,  105,  365,  845,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,   32, 1273, 2913,  662,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1396,    9, 1411, 1778,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3267, 1141,    1,    1,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3256, 2497, 2720, 2796,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2966, 1887,   32,   12, 2490,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26, 1039,  162, 1217,  384,  215, 1386,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2875, 3033, 2905,    9,  885,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1987,  967,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1242,  354,    1,  968,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2002,    1,    1,    1,    1,    9,    1,  714,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1260,  531,   12, 1850,   69,  965,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1612,    1,  575,    1,  577,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,   12,    1, 1350,  475,  267,    1,    1, 1360,  612,    1,\n",
      "         1470,   45, 1712,  963, 2122,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1249, 2413,  397,  958,  695,  444,  104,   98,  777,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,  417,    1,  409,   25, 1285,  242,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3173,    1,  191,  632,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  572,  105, 2875,  710,   98,  861, 1665,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1607,   37, 1787,   29, 2759,  650, 2278,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1070,    9, 3406,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2834, 1822,   52,    1, 2198, 1358,    1, 3359,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158,  256, 2210, 2403, 1021,  282,  517,    1,    1, 3011,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,  332,  449, 1385,  631,  176,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  654,  593,  641,  499, 2247,  102,  251,  440,  809,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564,    1, 1809, 2181,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3298,    1,  166, 2218, 1772, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 1042,    1,  674,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 2147,  108, 3399,   37, 1334, 2017,  384,    1, 1606,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1, 2037,   32,    1,   98,    1,  142,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  631,  176, 1022,    1,   12,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2695, 1940,    1,    1,   32, 2657,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2114,   57, 1858,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1, 2576,  105,  356,   32,  756,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3127, 3082,   37,   52, 1683,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,  566,  864,   98, 2673,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  199,  421, 1913, 1843,  197,  338,    1,   98,  822,  408,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  407,   98,    1,  142,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  224, 2937,  168, 1273,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  954,  225,  218,  345,  321,   52,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,  251,   59,    9, 3149, 2751,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  942,  225,    1,  176,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   81, 3329,  631,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1,  864, 2673,  132,   66,    1, 2198,  163,    1,   12,\n",
      "            1,  764,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492,    1,    1, 2897,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2160, 2049, 2565,   37,   16,   79,  590,    1,  872,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1045,    1, 3215,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3198, 1564,  411, 2022,  176,  163,    1,   12,    1,   26,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2699,    1, 2028, 1104,  304,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,  891,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  510,   12,    1, 2785,  436,   45,  404,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3358, 1211,  176,  915,    1, 3359, 1112,  176,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  104,  358,  162,  562,   37,  125, 1149,  138,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,  113,  682,    1,   65, 2001,  764,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1823,  477,  449,   37,  335, 2522,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  694,    1,    1,  267,  397,  695,   98,    1,    1,  696,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3208,  249, 1021, 2151, 1675, 2630,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2745,  680,  405,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162, 1090, 1140,   98, 1139, 1694,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  810,   32,  105,   74,   12, 1604,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  475,  267, 1099, 1453, 2768, 1977, 1514,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2777,  311,  855,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1, 1750,    1,  246,   98,   25,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  398,  134, 1899,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,    1,  868,  411,  187,  854,    1,   37,   32, 1463,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   81,   37,   36,  997, 1324,  657,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  281,  282,  891,    1,  709,   82,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  300, 1663, 3208,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  645,   70,  550,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1024, 2753, 1114,    1,    1, 3143, 1249,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1024,  190,  930, 1332,    1,  187,    1,   12,  590,    1, 1213,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2953,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545, 1421,  119,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,  393, 1426,  132,  220,  359,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 1090, 1829, 2916,  176, 2206, 2207,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   45,  987,    9, 1915,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1968, 2384, 2666,    1, 1017,    9,  999,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3172,  991,    1,    1,   45,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   32,  136, 3217,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  754, 1434,    1,    1,  193,  104,  967,    1,    1, 2605,  606,\n",
      "         1171,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2858, 1028, 3161,  176, 2570,  171,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2801,    1,    1, 1761, 2226, 2969,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  517,    1,  405,    1,  552,    1,    1,  915,   37, 2447,    1,\n",
      "            1,    1,    9,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158,   12, 1465,   15,  167,    1,  220, 1230,   12,  270, 1379,\n",
      "           12,  112,  499,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,   28,   37,  104,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,   68,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1603,  654,   82,   37, 1910,  669,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2307, 3108,  872,  420,  385,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181, 2827,   37,  105, 2250,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1128,    1,  365, 2105,    1, 1107, 2308,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,  794, 1994,    1, 2262,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,  159,  167,  698,  605,  906,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3356, 3357,  251,   37,  946, 2108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1297,  618, 1937, 1632,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1214, 1974,    1, 2887, 1991,   32,  273, 2162,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 1866,   37, 2012,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,  113,    1,    1,    1, 3384,    1, 1898,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  790,  908,  273, 1609,  672,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,   69,  102,   71,    1,   37,  276,  981,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359,  251,  105, 2306,    9,    1, 2129,  384, 3339,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3319, 1510, 2277,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   28,  104, 2456,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1528,  162, 1217,  187, 1411,  104, 3164,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 754, 757, 197, 921, 308,  98,  15,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 306,  12,   1,  15,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  762,   98, 2487, 2621,   66,   32, 3311, 3310,  521,  400,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  634, 3247,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  327, 1021,   37, 1844, 1222,    9,    1, 2130,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640,   39,  176, 1361,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,  361,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,  446,    1,  297,  247,  365,    1, 2237,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,   26,  242,  187,   69,  953,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2288,  787,   61, 1976,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1260, 1924, 2041,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2584, 2565, 2437,    9,  223,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2245,    1,   12, 3141,    1, 2094,  153, 2674,  354,   32,  105,\n",
      "         1559,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  709,  136,  475, 2430,    1,  669, 1426,  895,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,  361,    1, 1539,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  455, 1707,    1, 3139,   12, 1377,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  770, 1544,  191, 3207,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  896,    1, 1394,  454,    9, 3177,  361,  624,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3044,  166, 2821,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   15,  710,    1,   37, 1752,  136,   82,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777,  325, 1017,  384, 3028,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3348, 2985,   32,    1, 1683,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  705,    1,    1,    1,   32,  472,    9,  593,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  476, 1064,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1159,  166, 2124, 2060,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1057, 3084, 1991,    1,   37,    1,    1,   12, 2220,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  340, 3081,  629,  345,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2415, 1902,    1, 3287, 2222, 2709,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  614,    9,  166,  803,  112,  218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 1327,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,    1,  903,    1, 1447,   37,  439, 2673, 1699,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3359, 1877,   37, 1636, 3339, 2625,    1, 1950,  921,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3349, 1360,  612,    1,   37, 2774, 1004,    1, 1009,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,    1, 1194,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3359, 1877, 3339, 2271,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2298, 1124,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 2834,  469,  738,  410, 2407,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    9, 2101,   45, 2500,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 3106, 1086,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  746,  361,  829,  469, 2348,  844, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2102, 1781,   32, 2335,  219, 2064,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1118,  737, 2092,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  225,  574,    1, 1071,   37,    1,    1, 1379,   12,  112,  499,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3375,    1, 3095, 2844,   32, 3339, 1345,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1413,    1,   32, 3308, 1990,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   94,  681,   98,  577,    1,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   12, 1043, 1738,  418,    1,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  884,  105,  365, 1992,   37, 1228,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  180,   37,   47, 1023,   45,  453,  118,   48,   32,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1003,   37,  417,  736,  689,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2088, 2242,    1, 3251,  688, 2685,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328, 1157,  159,  123,  417,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  471,  472,   39,   45,  128,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  572,  551,  105,  730, 1777,  710,   46,   45, 1355,   37,   26,\n",
      "         1039,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  241, 1173,  176,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2562, 2335,  537,  611,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,    1, 3334,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1957, 1585, 2475,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973,    1,    1,  972,    1,   12,    1,    1,    1,  774,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  874,  781,  936,  147,  432,   45,    1,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1, 1774,  608,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  475,  387,  596,  275, 1278,   71,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   17,   45,    1,  441, 1046, 2387,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  267, 1284,    1,  220, 1512,   32, 3118,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 199, 421, 431, 399,  98, 755, 134,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,  22, 438,  48,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2098,  166, 3367,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1163,   12,  737,  156,   71,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1962, 1458,  365,  613, 1017,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1949,  103,  846,  660, 1151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3374, 1877, 3339, 2966,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  112,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2379,    1,  315,   37,  930,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3034,  861, 2762, 2952,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3323,    1, 3103,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1037,  275,  361, 2748, 1787,    9,  105, 2771,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1676,    1, 1000,    1,  356, 1691,    1,    1,   32,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  267, 3018,   37, 2728,   32, 2198,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  352, 1566,  840, 2245,   50,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1216, 2336,    1,    1,    1, 2232,  627,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,  259,  904, 1107,  112,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  844,    1,  395, 1662, 2243, 1651, 1597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1401,  219,  159,  242,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2933,  614,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,  104, 1401,   32, 2819, 1069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,   44,    9, 3066,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  136,   37,  125,  118,   45, 1604,   23,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,    1,  120, 1159, 3339, 2649, 2791, 3133,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2868, 1082,   91,   37,    1,  220,  163,    1,   12,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2752,    1, 2856, 3160,    1, 3353, 1700,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 2115,   37,  151, 2396,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  197,  921,    1,  570,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  511,    1, 1252,  335,  600,  580,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3196,   98, 1383,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  446,  796,    1,  267,  652, 1027,  193,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  681, 1866,    4, 2311,    1,  437,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 1285,   28, 1750,  105,  106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   28,    1,  118,   32, 1378,  442,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1127,  251, 1211,  207,  259, 1484,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492,    1,   11,    1,   32,    1,  182,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2224, 1579, 3339, 2271,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1449,  140,  199,  776,  176, 2041, 3292,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1641,   37,  912,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   23,  313,   37, 1641,    1, 1443, 2017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1718,  614,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,    1,    1,   32,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2186,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3014,  779,    1,    1,    1,  192,  221,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  756,  200, 2334,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1, 1750,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1797, 1585,   32, 3379,    1,  176,  177,  547, 1530,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1132,  151,   39,  634,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   37,  162,  885,    1,  176, 1751,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3080, 1284, 1515,   74,    1,  202,    1,   32,  147,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  727,  361,  196,    1,   28,    1, 1334,  115,   45, 1779, 1379,\n",
      "           12,  112,  499,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3242,   37,  606,  105, 1357,   32, 3066,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  755,    1, 3042,  161,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,  288,    9,  863,  726,    1,    1,   37, 1664, 3343,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2910,   77, 3161, 3278,  590,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12,    1,  267,  460,   61,    1,    1,  693,    1,  202,\n",
      "          590, 1031,   37,    1,  234,  182,  235,    1,    1,    1,  234,  182,\n",
      "          235,    1,    3,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 3343, 1708,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564,  942,  221,  220,    1,  151,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1923,    1,   39, 2486,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,   37,  151,  180,   32,  131,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2379,    1,    1, 2939, 1864, 1660, 2476,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2942,  601,    1,  671, 2471,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3034, 2264, 1371,    1,   37,   33, 1117, 1525, 1704,  157,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  557,  540, 2774, 1726, 2317,  548,    1,   37,  439, 2224,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  198, 2164,    1, 1199,  878, 1223,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  140,   32,   38,    1, 1056,   37,  168,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2962, 3188,    1,  547,    1,  187, 3244,  726,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3018,   37,  665,    1,   98, 1729,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361, 1486,   32, 1273,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  941,   37, 1377,    1,  149,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1543,    1, 2024,  357,    1,  443,    1, 2751,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  352,   42,  968,   69,  934,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2677,   26, 3253, 1542,    9,  786, 2069,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  288,   37,   26,  526,    1,  646,   29,   32,  260,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2677,    1, 1545,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2565,  380,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1537,    1, 1696,  176,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 2437, 2507,  182,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2964, 2988, 2786,    1, 2762,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1,  593, 2522, 3217,   37,    1, 2921,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,   22,   37,  588,  356,  881,    9,  573,  574,  589,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2663,   51,   52,  123,    1,   45,  638,    1,  361, 2990,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  531, 3384,  437, 2414,    1,  947,  475,  778,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,  413,    9,  372,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3149, 2774,  396,   36, 3071,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 2360, 1492, 1360, 3221, 2689, 1717,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1470, 1724,   45, 2820,    1, 2662,   12, 2918, 2984, 2981,\n",
      "          483,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,  566,  439,   37,    1,   32,  342,    1,  741,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1417,  551,  717,  267,    1,   37,  455,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   12,    1,    1,  640, 2184,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2102, 1107,  525,    1,  342,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  500,    1,    9,  306,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,   37, 1031,  996,  872,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  149,  444,  735, 1091,  614,   37,  776,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1720,  166, 1465, 1268,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2236,   37,  698,  176, 3284,    9, 1771, 1022,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   10, 3067,    1,  216,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  103,  116,  861, 2558,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  156, 2393,    1,   21,  737,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,  622,  586,    1,  938, 1075,   98, 1030,  260, 1564,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  506,    1, 1251,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 1294,  167,  877, 2784,   37, 1965,   32, 1890,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  346,   29,   37,   16,  954, 1115,   32,   72,  401,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  592,  267,  531,  967,  913,    9,    1,  996,  210,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3115,   37,  817, 2941,   97,  297, 1034,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   34,   15, 1470,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  982,   37,  125,    1,    4,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,   12, 1861,  852,   37, 1002,  548,  531,  516,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1009, 2591,  176,    1,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 2472,    1,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1822,   18,   81,   37, 3024,  548, 1674, 1597,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2175,    1,  707,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1459, 2860, 2225, 1818,  147,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,   51,  161, 1039,   45,  749, 2537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1110, 1851,  753,   61,  166,  627,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1625,    9, 1698, 1222,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  504,   98, 1577,    1,   69, 1315,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2734, 2986,   37,  335,  537,   37,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,  267, 1167,    1,  321,    1, 2527,  164,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1976,   37,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  534,  535,    1,   32,  119,    1,  311,    1,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,  361, 2902,  544, 1523,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328, 1257,    1, 1003,   37,  288,  283, 1434, 1371,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 2170, 1003,  176,  105,  449, 2799, 2300,   45,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  492, 1611,  782, 1875,    1,   32,  166, 2499,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  150,   37,  151,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  848, 1822,  138,   59,   37,    1,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,   28,  118,  479,    1, 1114, 1326,    1,    1,    1, 1548,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  347,  288,   37,   52,   98,  429,    9, 1694,   45,  356,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  213,   37,  322,   79, 1147,  734,   37, 2197, 1218,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004, 1643,    1,   28,  803,  112, 1699,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  183, 1107, 1994, 2086,  443,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2175,   37, 1892,  439,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2691,    1,  220,  885, 1204,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537, 1619,  458,  155,    7,   67,   37, 1598,  102,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  105, 2312, 2571, 2282,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2844,   32,  104, 2950,   45, 3155,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 2565, 3190, 1411,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  956,  220,  148,  361, 1883,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1045, 2793,    1, 1103,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  560, 1274,   71,  915, 1034,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3375,  907,    1,   16,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3018,    1,  444, 1230,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1698,    1,   45, 1081,  139,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1670,  105,    1,  633, 2722, 3074, 1215,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3204,    1, 1762, 1135,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3092,  475, 2137, 3306,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  129,    1,  361, 1821,    1, 2977,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1086, 3106,    1, 2034,  449,  726,  452,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2087,  433,  734,    1, 1822,   52,  969,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  725,    1,  578,    9,    1,  815,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158,    1,  166,    1,    1, 2851, 1021,  282,  517,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,   12, 1266,  546,  475, 1213,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,  856,   37, 1334,   98, 1171,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  142,   98, 1447,  458,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3101, 3372, 1458, 3359, 3339, 2271,  469,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1282,   12, 1283, 2600,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1243, 2580, 2851,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   15,    5,    1,  986,   79,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  695, 2791, 1159,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3385, 1360,  612,    1,  864,  927, 1757,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  373,  197,  338,    1, 1249,  689,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2980,  300, 2819,  327,  593,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  166,    1,  187,  166,  356,    1, 1086,   32,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800, 3308, 1990,  449, 1385,    1,  449, 3078, 2471,    1, 1140,\n",
      "            9,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  755,    1,   37,  829,   12, 3042,  161,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  278,  856,    9, 2181,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  395, 1760, 1163,  117,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12, 1069, 1239, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2110,  951,    1, 1834,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   31,  680,  674,    1,  267,   65,   12,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  160, 1161, 1276,   32,  385,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  186, 2072, 2275,   12, 2823,  142,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428,  639,  515,  864,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1900,    1,  297,  393,  238,  469,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,  197,   88,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  294, 2153, 2000, 3349,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  584, 2565, 3305, 1008,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123,  477,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1181,    1,  848, 1421,    1, 1731, 2019,  630,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  475, 1484,    9, 2322, 1159,  375, 3185,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1057,  897,  297,  192,    1, 1069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  793,    1,  981,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,   12,    1,  798,  133,   32,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 166,   1,   1,  28, 166,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  12,   9,   1, 615, 619,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  526,    1,  761,  246,   98,  374,    1,   12,  552,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,    1, 2855,    9,  365, 1009,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1477, 3337,   61,   91,   12,  972, 1257,  841, 3124,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,  331,   12,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  224,  376,  453, 1126,  636, 2320,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296,  253, 1947, 1539,   45,  365,  105,   37,  413,   20, 1117,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  591,    9,   94,  654, 1355,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2153,    1,  947,  475,  907,   32,  142,    9, 2024,\n",
      "          895,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  504,  548,   65,  155,  347,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004, 1087,   37,   47,    1,   12,    1, 1605,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2577,    1, 2297,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1930,    1, 3378,  776,    9,  339,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,    9,  166, 2355,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,   37,    1, 2471,  220, 2018,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 1356,  469,  321,    1,    1,  625,  232,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1178, 1988,   45,    1, 2925, 2308,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401, 3142,  608,    1,   28, 3226,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  215,  117,  700,    1,  140,  142,    9,  163,    1,   12,    1,\n",
      "          413,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,  412,   37,  224,  550,  778, 1063,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1787,   12, 1323,   37,   52,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3102, 1512,    1, 1645,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1478,   98, 1778, 1273,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  124,  565, 2934,   37,  544, 1103,  191,    1,  819,   37,  544,\n",
      "          227,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,    1, 1737,   98, 1547,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 1822,   26, 1039,    1,    1, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2056, 2822,    1,  488,  249,    1,    1, 2321,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,    1, 1924,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  171,  947,  588, 2383,   32,  709, 2925, 1863,   12,    1, 2162,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1,    1, 2688,    1, 2362,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1530,    1, 2347,  187, 2529, 3121,    1, 2755,  455,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2958,    1, 3322,   32,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,  548,  420,  310,  770, 1976,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,  163,    1,   12,    1, 1417,    1,   12,  590,    1,\n",
      "         2788, 1844,  323,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1017, 1148,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3256, 2712, 3186,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  391, 1329,    1,  707,  974,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 1130,  288,    9,    1,  176, 1718, 2396,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1481,   12,  454,   61,  105,    1,  501,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3376,   37,  856, 2095,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  233, 2424,  301,    5,  302,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2932,    1,  297, 2558,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 3372, 2094, 1625,   45, 2024,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   98, 1856,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2563,  125,  198,  230,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3065,    1,    1, 2903, 2214,    1,  384,    1,   32, 2921, 1606,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  190,  121,   12,   69,  764,  529, 1033,   12,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2427, 1838,   32, 2161,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   90,   10,   37, 2446,    1, 3039,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2648, 2801,    1,  982, 1832,   28,   98,  517,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3236, 2225,    1,  187,  365,  512,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3064, 1249,    1,  176,    1, 1787,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   32,  166,    1,   45,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128, 1415,   37, 2587, 1100,  769,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3175, 2277, 2202,   32, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220,  365,    1,  730,    1,    1,  602, 1249,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1043,  980,  191,    1,  185,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   12,  671, 1401,  104,   37, 2872,   32, 1940,   12,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  600, 2339, 3104,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  290, 1549,  443,    1, 1187,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  990, 2092, 1396,    1, 2650,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  232, 3133, 3369, 1260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  321,   62,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1023, 1204,   61,  671,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3194, 3195,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1227,   12,    1, 2007, 1120, 1411,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2615, 3294,    1,   98,    1,    1,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  684,  475,  476, 1032,   60,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  964, 1342,  365,  957,  475,   45, 1346,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   72, 2635,    1,    1,  191,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  121,   37,    1,  861,    1,  588, 2532,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2202,   37, 1832,    1,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  111,  818,  834, 1672,  118,   32,  496,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1200,    1,  829,   37,    1, 1089,    1,  288,  921,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  284, 1682,  321,  612,  335,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,   12, 3237,  361,    1,  726,    1,  671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2604,    1,    1,   37,   52, 1781,   32, 1314,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  765,   37,  737,  861, 2432,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,  361, 2275, 1388,  297,  531,  361,  105,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,  794,  365, 1917,   40,  259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1420,    1, 1579, 1966,    1,  934,    1, 2433,  691,  368,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,   22, 2625, 1176,  445,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2647,    1,    1, 1554, 2760,   32,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  761,   12,  156,   71,   98,  417,  408,    1,    1,   15,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3075, 1581,    1,    1,   32, 2839,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1298,    1,  444,   94,  187,  104,    1,    1,   32,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1273, 1091,  619,  166, 1263,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  146,    9, 3102,   12,  949,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2640,    1,  794, 1159, 1821, 1821,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938,  952,   37,  151,   39,  941, 1201,    1,    1,  615,    1,\n",
      "          335,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  832,  187,  137,  533,    1,  326,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,  313,   37,    1, 2436, 1285,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1896,   37,    1, 2047,   45,  395, 1810, 1725,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359, 2061,   98,  220, 3339,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1,    9,   59,  750,    1,  639,   24,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 1771, 1022,    1, 1993,    1,   98,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,  267,  228, 3226, 1810,   37,   52, 1231,  384, 3141, 2811,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,   25,  439,  417,   98,  677,   69,  102,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1024, 2437,  384, 3141,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  572,  156,   71,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  593, 2162, 1950,  384, 1094,   12, 3339, 2731,  418,   37,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  119,    1, 1876,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1730, 3043,   45,    1,  632, 1202,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1546,  951,    1, 1959,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1290, 1722, 1258,   37,  245,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1990,  833,  612,    1,  297,    9,  166,  104,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3361,   51, 2035,  863, 1010, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1771,    1,    1,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3253, 2120,    1,    1,  580, 3204,   32,   26,    1, 3257,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2546,  833,  612,  135,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,  362,  384,  377,  405,    1,  541,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,   12, 1009,  361,    1,  929,   37,  930,    1,   37, 1504,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   51,  936, 1213, 1064,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197, 1249,  236,  237, 1470,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1369,   37,  322,   85, 1541,   45,    1,  131,  187,   15,  245,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2110, 3260,  391,  512,  939,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 388, 863, 751,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 572, 156, 688, 689,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1021, 2139,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 1505,    1,    1, 1483,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2505,  476,   37,  125,  636,    9,  671,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2663,   45, 3001,   55,    1, 1976,   32, 2822,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 1674,  195, 2537,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  844,  765,  147,    1,  663,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  947,   37, 1152, 1545,  551, 1178,  163, 2308,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2862,    1,   12,    1,   45, 3351,    1, 1554,  104,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1,   71,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2839,   37, 1418, 2924,  384,  531,  191,  439,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  401,   59,  649, 2816, 3121,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1343, 2800,  176, 3010,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  657, 1456,    1,   37, 1100,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,    1,  138, 1812,    1, 3359,  580, 2429,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 2890, 1283,  287,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  197,  921,    1,  570,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   99, 1118, 2082,   45,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  111,  133,    1,    1,    1,    1,  384,  166, 2339, 1108,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2942,   32, 1568,  238,  920,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1875, 2476,  151,    1,  111,    1,  506,  782,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2596, 1665, 1414,   95,   37,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1398,  612,    1,    9, 1658,  560,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1817,    1,   37, 1174,    1,  788,  934,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1024, 1024,  361, 1026,  429,  388,   46,   98,  887,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1086, 1684, 3106,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  707,    9, 3098,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   64,  850,   69,  636,   81,  530,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3142,    1,    1,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  147,    1,  613,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808, 1809,  813, 1810, 1273, 1085,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1819,    1,   98,  105, 1151, 2747,  547,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  531,    1,  365,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  117, 1708,  292,    1,  931,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2596,    1, 2726,    1,    9,  166, 2502,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428,  289,   98,  531, 1580, 1512,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178,  650,  146,    9, 3365,  949,  187, 3125,  877,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  801,  187,    1, 1464,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2899, 1292, 1064,  247, 2866,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3329,    1,  709,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  352,   51,  193,    1,    9,  531, 1604,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1200,   32, 1259,   98, 1842,   50,   48,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2477,   61,   39, 1030,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2088,    1,  619,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3276, 1747,  750,   37, 1194,   73, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  597,  379, 1046,  133,  134,   32, 1022, 2281,  776,  297,\n",
      "         1405,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964, 1082, 1565,   36, 1950,  921,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  242,   98,   14,   29,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  321,  612, 1911,  535, 1381,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  977,  304,  459,    9,  574,  615,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3157, 2263,  547,    9, 2328, 1260,   98, 3363,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2753,  449,  219, 2579,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2527,  164, 1976, 2083, 2573,    1, 2060,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  208,    1,  592,    1,  940,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1583, 1830,    9, 1798,   32, 3339,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1711,    1,    9,    1,  164, 1593,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  295,    1,   37, 1488,   98,  199,  119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    9,   15,   28,  419,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2571, 2153,   32,  976,   37, 2000, 3118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3271,   32, 2799,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  105, 3121,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1, 1249,    1,    9,  121,   37, 1722,  176,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2932,  726, 2376, 2223,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   45,  869,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3360,  123,   37,    1,  741, 2116, 3363,   32,  631,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1,  163,    1,   12,    1,   37, 1195,  284,    1, 1196,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2585,  191,  104, 1159, 3118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779, 1249, 3064,    1,  801,   37,  810,  632, 1286,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1536,    9, 2240,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1900,    1,  163,    1,   12,    1,   98,    1,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2814,   45,  484,  967,   18,    9, 1850, 1423, 2024, 1861,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1473,   98, 1894,   14,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2563,    1,   37,  698,  951,    1, 3285,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213, 1380,    1,   79, 2072, 1590,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1778,  535, 1863,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2911,   32, 2944, 2303,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  389,  173,    1,  220,  367,  495,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1709,    1,    1,   12,    1,  659,   45,    1,   12,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1444, 1445,    1,   98,  166,    8, 1167,    1, 1354,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  389,  682,    1,   32, 1312,  257,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2693, 1976,   32,  105, 2854,    9,  449,  199,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  261,    9,  694,   32,    1,  297, 2022,  278,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147, 2924,   37,  335,  631,   32, 1345, 3357,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  156,  245,   88,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 2044,   69,  102,  190,  720,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1823,  921,  590,    1, 2570,  171,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1674, 2965,    1,  162,  726,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1822,  726, 1977,  365,    9, 3260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2117,  839, 3118,    1,    1, 2024,   46, 1195,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2578,    1,    1,  877,  460,  105, 1838,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  632, 1339,    1,  580,    5,  798,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1766, 1767, 2747,  365,  468,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  149, 2386,  829,   45,  840,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105,    1,   12,    1, 2495,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2708, 3364, 1484, 1094,  166,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3149, 3397,  108,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,  854,  361, 2018,    1,  397,   46,   98,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3251,  335, 1515, 1910,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2616, 2952,  187, 3381,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,    1,  671,    1,   12,  396, 2198,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  193, 1167,  786,  361, 2523,  335,  411,  631,  176,  273,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777,   12,   82,   61,   53,   98, 3028,  151,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  579,   12,   32,  166, 1510,    1,  538,    1, 1847, 1167,    1,\n",
      "          361,  388,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,  650,   32,  233,   61,    1, 2309,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2048, 2816,  567,  666,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   23,  884,  297,    1,  808,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3211, 2286,   37,  619,   81,   98,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2551, 1421,    1,  384,    1, 2760, 3273,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3363,    1,   37, 1918,   32, 3343, 1002,    1,  413,   37,  690,\n",
      "         1578,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870,  775,  838,  365,  327,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3052, 2872, 2106, 1990,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,  146,  147,  958,    1,   45,    1,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  964,    1, 1450,    1,   37,  583,   10,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1962,   37, 2035, 1273, 1074,    9,  649,    1,   45,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3303,   61,    1,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2804,   45,  365,    1,   61, 3340,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1957, 2856, 3101, 1305, 2262, 2856, 3375,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671, 1078,  315,   37,    1,   37, 1076,  693,  191, 1332,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614, 1334, 2793,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,  261,   39, 1378, 1002,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3192,   12, 2170,  877, 1735,  698,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1763,   12,  913,   37,  130,  654,  124,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1421,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2694,  171,   45, 1193,  187, 3045,   84,   28, 1450,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  741,    9,  365,  342, 1984,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1029, 1386,    1,    1, 1656, 1585, 2414, 2231,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2614,  565,    1,   32, 1214,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2933,   16, 2058,   79,  220,  289,   98,  112,  460,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  250,   37,    1, 1227,  195,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   59,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  259,  312,   61, 1488,  763, 2931,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1957,    1,   24,   98, 3202,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  619,  637,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613,  566, 1273, 1117, 1525,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  510,  765, 1750,  166,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  104,  573,  639,   12,  448,    1,   37,    1,  372,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2868,  387, 1647,   98,  864, 2390,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  794,  117,  973,    9,    1,  280,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3378,  776, 2317,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,    1,   61, 1542,   37,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035,  868,  132,    9,  365,   16,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  437, 1574,    1,  496,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 1763,   12,    1,  498,   37,    1,   59,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,   46,    1,   98,  861,    8,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  728, 2440,    9,  257,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 2594, 2392,  593, 1990,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  574,  571,  105,    1, 2309,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1883,  325,    1, 1228,   32,  331,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  267,  103, 3381, 2431, 1061,   32, 3383,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3118, 2024,   46,    1,  548,  861,    1, 1527,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1,    1, 1147,    1,    1,   32,  116, 1089,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3369,   12, 3118, 2219,  763,  531,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3241,  288,   37, 1421,  590,    1, 2309,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,   37, 2653, 1428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1796, 2161,    1, 2210, 1400,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 1178, 1156,    9,  215,    1, 2772,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  657,  376,  572,  983,  308,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   37,  764,    1, 2734,    1, 2853, 2868,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1953,  220,  587, 1460,   37, 1390,   12,    1,  963, 2122,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  359,    1,  419,  138,  125,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1414, 2833,  674,   45,  436,   45,  403, 3339,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  338, 1315,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  353,   72,  401,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   94, 1426,  365,  845,  444,   60,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094, 2414, 2710,    1,  650,   32, 3339,  477,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1181,  623, 2914,  593,   12, 1022,    1,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1594,  197,   98, 1691,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 2483,    1,    1,   32, 3118,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1601,   45,  224, 1126,    1,  191,    1,  802,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  581,  671, 3126, 1360,  612,   52,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2046,  456, 2147, 1010, 2095,  304,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3140, 1550, 1059,   28,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  385,   12,   67,  423, 1360,  612,   52,  166,  915,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  497,   37,    1,   98,  531,    1, 1485, 1407, 1190,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358, 1404,    1,    1,   37,    1, 1590, 2793,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1851, 1987,  321, 2446,    1, 3204,  176, 3329, 1990,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1464,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  842,  716,  594, 1463,  932,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1334,  838,  600,  635,  214,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,  361, 2238, 1835,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1704,   12,    1, 1331, 2403,   51,    1, 1100,    1,  657,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  994,    1,  150,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,    1,  600, 2282,  722,   32,    1,    1, 3058,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2229, 2232, 1765, 2276,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3129,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129, 1286,  108,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  391,   93,    1,   37,  151,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  542,  245,   32, 2518,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  730, 2614, 2408, 2619,   98,  872,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1831,    9,  545,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303,  108,   45,  442,  448,  629,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3199,    1,    1,   61,  845, 2395,    1,    9, 1488,  357,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2752,   37,    1,   37, 2751,   98,   46,    1,  477,  113,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,  325,   93,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  852,   37, 2311, 1108,    9,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2463,  576, 3332, 1263,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1469,   51,  764,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3239,    1,  460,   98,   32, 3201,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2414,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  233,   37,  817,  302,    1,  777, 2441,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  899,  900,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  507,   12,  638,  753,   32,    1,  321,  612,  877,  460,   39,\n",
      "           45,  449, 1385,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1140, 1638,    9,  617,  618,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1240,  606,    1,    1,   98,  220,  413, 1292,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3206,    1, 1986,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  686,  220,  119,   59,   60,  422,  599,  297,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   55,  105, 2209,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  470,  888,    9, 2347,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3358,   12,    1,  637,  297, 2708,  650,   12, 1983,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3311,  831,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  475,  580,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1004,  764,  384, 1428,    9,  890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1322,  166, 2332,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  863,   85,   37,  166,    1,  446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2754,    1,    1, 1098, 1465, 2086,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1973,  669,  686,  191, 1147,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,    1, 2480, 1089, 1090,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2004,    1,  282,   17, 1673, 1117, 1525,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1712,  936,  365, 1778,  328, 2549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  215,    1,  444, 3312,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  166, 2620,    1,    1, 1564,  105,    1,   45, 2748,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1043,   66, 2410,  143,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1427,  100,  321, 1403, 1691,  700,  542,   81,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1643, 1639,  384,   91, 2075,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  580, 1133, 2041,  115,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2922,    1,   37, 3323,    9, 1194, 1385,  712,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1,  104,  442,  850,  297,  851,  630,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2206, 2989,    1,  215,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2509,  104,  884,   44,   32, 1990,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  328,  313,   37, 2341, 2261,  444, 1260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2996, 2786, 2580,    1, 1816,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2052,  792, 1975,  792,  949, 1380,    1,  115,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,   12, 1009,    1, 3067, 2950, 2083, 2197, 2147,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3262, 2800, 1218,   51,    1,  142,  384, 1092, 1235,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2080, 1013,    1,    1,  150, 1781,   32,  104,  361,  395,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1, 1411,  659,   45, 2255, 3004,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1114,  879,  693,    9,  647,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1635,    1,  700,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1249,  121,    1,  801,   37, 3295,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,   37,  125,  600,    1,    4,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  315,  973, 1159,  104,  361, 1033, 2013,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 387,   1,   1, 548, 365, 356,  88,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  69, 102,  92, 197, 176,   1,  88,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  418,  187,  107, 1726, 1140,    9,  105, 1069,  125,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,    1,    1,  845,    1,    9,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  347,   98,  429,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123, 1340, 1194, 2907,  873, 1668,    1, 1714,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  193, 3230,    1,  202, 3001, 1426, 3179,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   74,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,    1,  415, 1315,  105,  106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2689, 1007, 1100,    1, 1128,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  872,   28,  220,    1,  176, 2656,  361,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2069, 1516,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2508,  696,  927,   45, 1585,  176, 2103,  617, 2616,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  102,  720,   32,  871,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   32,    1,   12,    1,    1,  822, 1592, 1937,  105,  629,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2771,    7,    9,    1,    1,  584, 1022,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  476,  388,  252,  593,  522,   98,  596, 1964,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2555, 2983,   32,  166, 1809,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  333, 1086,    1,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,   37, 1124, 1821,  191,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3374,  213,   37, 1911,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232,  103,  712,   32, 1417, 2090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861, 2091,    9, 1856,   45,    1, 3389,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,  861,  304,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1353,  210,   98, 1039, 2690,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3330,   46, 1888,  548, 1194,    1, 1185,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2673,    1,   37,    1, 1130,    1,  964,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1487,    1,  388,  124,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2965,    1, 1810, 2827,  191,  947,   32, 2107, 1336,  290,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2058,   79,  741,    9, 1031,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 3127,    1,   37, 1046,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  321,  612, 1937,  166,  439,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1348,   37,    1, 2164,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  389,    1, 1408,  367, 1113,   67,  816,  176,    1, 1146,\n",
      "         1703,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2964,   23,    1,   45,  388,  460,  861,    4,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1119, 1554,  104,   12,    1,   98,  166, 2125,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  505,    1,  475,  939,  176,  743,   12,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203, 2768, 2930, 1752,  105,    1,   45,  443,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1867, 2220,   45, 1393,  361, 2441,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1917, 1545,    1,  191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1084,    1,   37,    1, 1501,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405, 3291,  476,  388,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  777, 1089,   30,  915, 1377,   45, 3395,  215, 3102,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 2572,    1,  583,   32,  868,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1095,    1,   98,    1, 1230,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  616,   37,    1,  395,  517,  714,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  476,   37, 1195,   46,  220,  342,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  701,    1, 2681,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089, 3340, 1855, 2886, 3395,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1042,  166,  873,   98, 1672,  724,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  550,    1,  199,   12,  959,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3092,  899,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1583,   37,    1,  352,  132,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    9, 3358,  187, 1243,   45,  247, 3137, 2449,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 2984, 2820,    1, 2699,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,    1, 1632,    1,    1,   45,  166, 2177, 1027,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,   69,  442,   37, 1427,   32, 1411,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  585,    1,   39, 1056,  257,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  354,  227,    9,  575,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 1110,  421,    1,  105, 2815,    1, 2940,   28,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2596, 1396, 2597, 2696,    1, 2572,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  105, 2666,  167,   52,   32,  166,  272,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,  140,    7,  741,   98,  662,    9, 3339,  469,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  479,    1,  971, 1352,   15, 1826,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  221,  242,  187,   69,  102,  276,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1319, 1726,  698,  442,    1,  861,   46,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,   37, 2449,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2, 447,  37,  47, 600, 786,  72,  45,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 409, 159,  85, 115,  45, 104, 890,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1997,    1,    9,   59,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  150,  112,  469,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  388, 1987,    1,    9, 3262, 1831,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3245,    1, 2777, 1523,   98, 1602, 2539, 1267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2224,  991,    1,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1127,   37,   47,    1,   32,   91,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  972,   37,    1,   98,  539, 2170, 1114,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  176, 1604,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1366,    1,  384,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2297,    9,  405,    1, 1624,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  508,   79,    1, 1149,  481,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,    1,  166,    1,   45, 1104, 2209,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 1473,   81,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  444, 1658, 1678,    1, 3122, 1592,  361,    1,   32,  424,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  294, 2838,  288,   37,    1,  163,    1,   12,    1,    1,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  931,    1,  167,  865,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3345, 2833,    1,  475,   32, 2597,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   26,    9,  112,   32, 1890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3262,  458,   98, 3317,   37,  843, 2315,  865,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  410,    1,    9,  386,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3343, 3006, 1220,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340,   98,  429,    1, 1110,   98, 2365,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2077,    1,  971,  872,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   51,  606, 1976, 3155, 3384, 1967,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2072,   32, 1378,  863,  806,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273,  681, 1421, 2080,  517,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  187,  105,    1,    1,    1,    1,   61, 2085,  388, 2947,    1,\n",
      "          202,   61,  460, 2440,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1,  326,    1,  766, 2192, 1243,   45,  617, 1151,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  519, 2939,   98, 1171,    9,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1412, 2521,    1,  861,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1492,   12, 2072,  166,  671,    1,   12,    1,    1,    1,    1,\n",
      "         1018,  294,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 1300,  448,   51,  686,    1,   45,  646,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3053,   12,  729,  193,  297,  166, 2918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 2060,  703,    1,    1,  207,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2632,   32,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  224, 1658,    1, 1465,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  228, 2572,  187, 1884,    1, 2497, 2140,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1,  632,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1025, 1041,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  493, 1271,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1117,  741,    1,   32,  584,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178, 1550,  722,   37, 1641,   28,  851,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2942,    1, 1027,   44,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3276,  750, 1554, 3250,  810,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  610,  548,    1,  514,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  801,   98,  157,    9,  961, 1482,   67,  641,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2565,    1,  191,    1,  297, 1684,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2077,  884,   59,   94,   44,    9, 1796,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  921,    1,  705,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,   50,    9, 2615,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  475, 1484,    9, 2322, 1159,  375, 3185,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2527,  164,  400,    1,   85,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3382, 1061,  680,  487, 1994, 2095,  625,  163,    1,   12,\n",
      "            1,  476, 2251,  963, 2122,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,    1,  548,    1,    1,    1, 1748,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  590,    1,    9, 3358,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 3220, 3260,  951,    1, 3209,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  335,   81, 1311,   32,  368, 2771,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1718,  528,  342,  736,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2064, 1413, 1414,  176,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  123,   37,    1,    1,   32,  768,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  861, 1414,  321,  612, 2446, 1803,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  861, 2762,    1,  365, 1665,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2998,    1, 3119,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  761, 1539,    1,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3066,    1, 1991,  187, 2693,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  551,  760,  197,   28,    1,  159,  245,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,  891,    1,    9, 1411,    1, 1821,   95,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1033,    1,  420,    1,  572,  207,  490,  198, 1151,  102,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 168, 111,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 526,   1, 534,   1,   1,   9, 331,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  496,    1, 1980,   37,    1,    1,   45,  861,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1161,  741, 2424,  444, 1428,  103, 1513,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,  325,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,    1,   37,    1, 2308,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1885,  162,   39,  166,  501, 2591,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3172,  991,    1,    1,  879,  316,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3402, 3408,  420,    1,  103,  379,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284,  382, 1149,  477,   98,    1,   45,  103,    1,  971, 1953,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3231,  951, 1110,    1, 1090,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  858,   32,  166,  215, 1239, 2056,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3050,  933, 2819,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1674, 1675,  638,   48,    9,  447,   12, 1283,    1,  267, 1645,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   63,  166,  862,  189,    1,    1,  504,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758, 1013,  614, 1273,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1523, 1936, 1134,   32,  142,   37,    1,  674,   45,  721,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3236, 2712, 3256,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   66,  417,  187,   69,  256,   97,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2184,    1,  952,    1,   48,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2984,  927, 2865,  176, 2820,   12, 2009,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,  105,    1,    1, 3298,  140, 1114,   32,  785,  786,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3083,    1,   39,    9,  166,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  200, 1412, 1107, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  267,   10,    1,    1,  469,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2170, 1021,  681, 1413,   37, 1125,   28,    1,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 1656, 2596, 2414,  176, 2018,    1,  186,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,  726, 2764,    1, 3235, 1090, 2697,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1514,  837,    1,  408,  104, 1939,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2663,    1, 1289,    1,   37, 3020,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938,  551,  978,  231, 1034,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,  315, 2355, 1013,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3331,  688, 3083,   32, 2138,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1174,  176,  163,    1,   12,    1, 2735,    1,\n",
      "          220,  942,    1, 1212,  963, 2122,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   25, 2346,  411,  682,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  398,  868,   85, 1708,  518,  261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613,  200,    1,  612,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  129,  474, 2153,  288,  105,    1,    9, 1031,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,   28,   98, 1697,  471,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1592,  736,  297,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585, 2414, 1178,   27, 3149, 2208,  274,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1962,    1,  119,  846,   32,  613, 2107,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1292,  241,    1, 1159, 2507, 1000,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  166, 2063,  501,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3256,  384,    1,   45, 2586,   37, 2144,  356, 1281,    9,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,   68,   69,   70,  470,  699,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1484,    9,  163,    1,  903,    1,    1,   32,  531,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  952,  125,   45,   59, 1714,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1976,   32,  395,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  511,  275, 1216,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746, 1996, 1766, 1767,  412,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1492,  361,    1,    1,   32,    1,   98, 2527,  164, 2693, 1976,\n",
      "           32,    1,   32,  395,  101,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  359,  176,  104,  358,  190,  741,   98,  469,   37,  125,  138,\n",
      "          361, 1639,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1053,    6,   93,  570,  548,  572, 1424,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2117,    1, 2286,   37,  271, 3118,   46,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,    1, 1186,   12, 1185,    1,   32, 2637,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1173,  176, 3130,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2448,  386, 1908,  361, 1564,  460,    1,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  440, 2711, 2067, 1827,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1092, 1458,  766,   98, 1935, 2294,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 1821, 2978,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2594,    1,   32, 1477, 1990, 2107,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275,  565,    1,  275,  736,    1,  267,  657,   12,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  557,  540,  957, 2257, 2924,  384, 1030,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  640,  119,   98,  395,    1,  854, 1220,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3262, 1343,   39,    1, 2250,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129,  922, 1090, 1829, 1834,  176, 2295,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2962,  730, 2614, 1285,    1,    1,   77, 1224,  220, 2615,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  955,  151,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  303,  267,   69,  636,    1,    1,  763,   32,   12,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2729,  379, 2007,   37, 2684,    9,   46,  424, 2305,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  657, 2384,  365, 2336,    1,  202,  829,    1,  460,  918,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  903,    1, 3165,  271, 1159,  942,   12, 2592, 2147,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  358, 1070,  147,   37,    1,  118,  138,  125,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1159, 3220,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962, 1245,    1,    1,   37, 2035, 2315, 1045,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3231,  978,  548,    1, 2522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   63,  166,  862,    1,  159,  242,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129, 3021,    1,    1, 3129,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 1821, 3027,    1,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1013, 1522,    9,  911,   61,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1364, 1365,    1, 2083,    1, 2147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  267, 2673,  469,   61,  590, 2339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1340, 1415,   37, 2276,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2826,  439,  220,    1,  361,  591,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1094, 2414, 3375,   32, 1479, 3339, 2625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  315,  356,  439, 1027,   37,  335, 1147,\n",
      "         2774,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3371,    1,  187, 1557,    1,  741, 2038,    1, 2520,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2131, 1063,    1,  829,  297,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,  765,   37,    1,    1, 2462,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  957,  952,   37,  151,  487,  493,   48,   32, 1797,   69,\n",
      "          934,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   94, 2334, 1074,    1,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,  197,   28,    1,  844,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1, 1980, 1867,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,   42, 2089,  287,    1, 2430,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   51, 2192,    1,   37,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3351,    1,   12,  433, 2263,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  183,  132,    9, 2925,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147, 1360,  612, 1709,  597, 2696,   12, 1377,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 1617, 1454,  448,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  943,  166,  943,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1774,   39, 1230, 2528,    1, 2668,  220,  163,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1841, 1207,   37,  764, 1211, 3102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,   37,  899,  332,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 1024,  361, 1024,  563, 3318,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  179,  459,  131,  613,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 1017,   61,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,    9, 1031,   61,    1,   32,   14,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3105,  335,    1,  260,  424,  863,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1137,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,  446,  908, 2251,   45, 1485,    1,  361,    1,    1,    1,\n",
      "            1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  146,   32,    1,  375,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1938, 2607,  382,    1,    1,    1, 2713,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  344, 2950,  396, 2853,   32, 2597,   98, 1856,   45,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2862, 1810,  365, 1033,   91, 1320,  893,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1290,  396,   28,  388,  763,   76,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160,    1, 1816,  197,  937,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2802,  140,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   12, 3356, 1830,   37,   38,  297, 2646, 3346,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,   12,  647,  142, 1757,  431,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 2170,    1, 1211, 2176,    1,  105, 2267, 3136,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  310,   25,   28,   98,  157,    1,  417,   69,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  361, 2275, 2905,   37,  907,   32, 1515,  449,  736,   32,\n",
      "         2748,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2962, 3188,  140, 3212, 1523,  187, 3244,  688, 2807,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  288,   37, 1776, 1799,    9, 2117, 3118,   23,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3005,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311, 2565,    1,  796,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1935, 2294, 1997,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2136,   10, 1401,  191, 2047,  361,  595,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,  12,  37, 123,   1,   1,  32,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 361, 874, 877,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1604,   39,  920,    1,    1, 2248,  203, 1658,    1,  138,  334,\n",
      "           81,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  207, 2441, 2852, 1046,  365, 1994, 2086,  973,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2119,  198,  176,  230,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1855,  446,  267,    1,   12,  342, 1027,   37,  184,  602,   46,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2871,    1, 3190, 2220,  415,  638,    1,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  515,    1,  671, 2942,  140, 2492,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  433,  765,  581, 2650,  302, 2100,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,  315,  403, 2926,  250,    1,   37, 1012,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    9,    1,    1,  105,    1,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2347,    1,    1,   39,  191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,   12,  822, 1523,  297,    1,    1, 1258,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3206,  168,   28,    9,  333,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  447,  321,    1, 3348, 3382,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3009, 2684,  191,    1,  176,    1, 1089, 2577,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  348,   37,  151,    1,  114,    1,   50,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1423, 2090,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3001,   25,   32,    1,   32, 2124,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  572,  207,  197,    1,   98,  700, 1151,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2, 858, 251,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   69, 1784,   37, 1056, 1034,  845,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,  197,  307,  308,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2826,  395,    1,   37,    1,    1,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006, 1991,    1, 1450,   37, 1344,  938, 1075, 1159, 3038,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2159,  781, 1194, 1843,  197, 1660,  187,   15,   71,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2384, 1230, 2528, 1658,    1, 1107,  551, 2528, 2641,   32,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2700,  365, 2983,   51,  335, 1400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3152,    1, 1957,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,   65,   12,  590,  267,  104,  833,  612, 1188,   31,  837,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1891, 3101,  872, 1670,   37,  271, 1632,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1408,   98,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,    1, 3094,   45, 2708, 1219,   32, 3339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,    1,    1, 2668, 2597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,    1,  191, 2179,    1, 2212,    1, 3075,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  632,    1,  433,    1, 1839,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1933, 2352, 1932,  793,   12,  142,    9,    1, 1325,  285,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1290,  396,  245,  995,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1441, 1442,    1,   45, 1443,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358, 1426,    1,  132,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  163,    1,   12,    1,   51,  588,    1,  973,   98,  864,\n",
      "          909,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,    1,    1,    1,   37, 1839,    1, 2461,   10, 2443,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  120,  187,  365,  754,    1, 1174,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12, 1312, 1661,    1,   37,   52,   85,   98, 1661,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 2486,    1,  903,    1, 2926,  105,  551,  612,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868, 1454, 2676,   12,    1,   98, 1260,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  755,  794,  210,    9, 1003,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967,  463, 2170,   32,  559,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3342,  400, 2052,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1778,  328, 2900,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  236,  237, 1518,  242,    1,  202,  119,   69,  102, 1291,   74,\n",
      "           12,  682,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  631, 2823,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  810,    1, 1403,   32,  365,    1,    9,   94, 2579,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   85, 1270,   32, 1890,    1,  977, 2022,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  260,   45,    1, 1034,    1,  190,  248,  810, 3229, 2078,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2802,  140, 1183,    1,  593, 1990,    1, 1684,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,  566,    1, 2969, 1766, 1767,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2967, 1454, 1029,  863, 1578,   32,    1,   37,   87,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  845,  147,    1, 1689, 1655,  297,  450,    1,   45,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1233, 1149, 1648,   37,  856,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2072,  166,    1,  176,   83,   12,  654,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  829,  132,  155,   26,  756, 1574, 3011,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  398, 1360,  612,  222,  148,  214,  142,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2238,  459,    1, 2234,  220,  657,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  179,    1,  180,   25,   28,   98,  170,  716,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1641,    9, 2453,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3240,  631,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,  335, 1090,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  358, 1858,   46, 1686,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2772,   51,    1,  439,   45,  492,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1728,    1, 3051,    1,   37, 1878,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  913,   98,    1, 1638,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1089, 1090, 2692,   37,  877, 1887,    9,  829,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3130,  580, 1133, 1463,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3315,    1, 3191, 2013,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  633,    1,    1,    1, 1194,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  398,  261,    9,  148,   32,  647,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  590,    1,    9,    1,   32,  673, 2407,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1450,   98, 1778,  327,   12,    1,   32,  449, 1023,   45,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1173, 1087,   12, 1568,  365,    1, 2871,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3276,  472, 1178,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3342,  460, 1924,  415,    1,  220,    1,    1,  193,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  112,    1,  187, 2476,    1,   37,  942,    9,  164, 1593,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  311,    1,  615,  661, 1212,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2187,  693,   34,  225,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,   81,   32,    9, 3177,  220,  331,  142,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1292,    1, 3090,  298, 2585,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1,  121, 1421, 1651,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2533, 2322,    1,   37, 1352,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1877,    1,    9,  647,   17,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1465, 1466,   37,  138,   59,   37, 1911,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,   12,  597,  446,  580, 2909,  290,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3152, 3218,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1147, 2179, 1900, 1140,    9,    1,  890,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3087,    1, 2178, 2921, 1887,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388, 2890,  336, 3365, 1683,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,   92,    1,  574,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  794,   22,  868,   98, 3155,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  398,  246,  793,   12, 2099,    9,  118,  138,  125,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999, 1321,    1, 1994, 2819, 3050,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1760,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  596, 2639,    1,  220,  258,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,  197,   98, 1251,  674,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1741,    1,  398, 1800,    1,  951,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2, 206,  12, 716, 419,   1, 423,  32, 244,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 195, 749,   1, 384, 218,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1724,   37,  619,    1,   45,    1,   12, 2836,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1936, 1515, 1090,   37,  166, 1411, 1722,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1151, 1091,  288, 2364,   98, 1412, 1089,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  342,  872,  580,  741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,  548,  245,   98,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  129,   33,    1,  625,  884, 1601,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  479,   37,  439, 1233, 1069,  176,  250,   32,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   10, 1454,  443,   32, 1428,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  282,   37,    1,    1,   12,    1,   32, 2670,    1, 2771,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  474,  176,  177,  393,  359,   37,  930,  187,  138,    6,  698,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2658, 2269, 1360,  612,    1,    9,    1,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,   12, 1350,  149, 1394,   37,    1,    1,   45,  756,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  580,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1625, 2088, 2452,  321,    1,  244,    1,  332,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,    1, 3179,  548, 2472,    1,   39,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1526,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2692,  105, 1056, 2845, 1585,    1,  202,    1,    7,  111,\n",
      "         1144,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  635,   12,  244,   37,  245, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384,  105, 2229, 2849,    1,    1,   45, 2095, 2928,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,   37, 2237,  567,    1,   78,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1474,   37,  317,  322,   32, 2661,   98,  777,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2801, 1518,   32,   98,  215, 2226, 2969,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1431,  315,   37,  259,  460,   32,   98,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,  580,  361, 1691,   37,  804, 3379,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  710,   51, 1752, 1465, 1466,   82,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,   12,  103,  147,    1,    1,   45, 3359,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  384,  105, 1121,  698,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  353,    1,    4,   93,   32,  385,    1, 2252, 1641,   37,\n",
      "           10,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296,    1,  310, 1250,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2835, 1484,    9,  949,   45, 3365,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,    1, 3039,   12, 3040,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  809,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 1091, 1421, 1651, 2690,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  663, 3369,    1,   98, 3118,  719,   37,   52,    1,  191,  522,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3382, 1231,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3230, 2137, 1632,    1, 2779, 1141,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1,  845,  846, 1102,    1, 2193,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3325,    1,   37,    1, 2760,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1319, 2153, 1210,   37,    1,  593,  442,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3198, 1086, 1056,  356,  713,   32, 2592,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2206, 2207, 3183,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  884, 1871,   45, 2330, 2293,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  538,    1,    1,  384,    1, 1204,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  195,    1,    1,    1,  417,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1263,   61,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  398, 1707, 1708,  518,  261,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  463, 1447, 1980,   37,    1,   39,  132,  297, 2128,\n",
      "          125,    1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2611,    1,    1, 2078,  220,  348,  675,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,    1,  710,  884,  103,  518,  389,  176,  150,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1110,    1,    1,  705,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,   98,    9,  335, 1056,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,  332,   45,    1,  631,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1509, 1463,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  965, 2870,   32,  531,   12,  463,    1, 2498,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,  200,    1,    1, 1228,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  159,  504,  187,  802,    1,  615,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2748,    1,  903,    1, 1417,    1,  171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  330,  294,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1, 3365,  820,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977,   37, 1463,  880,  176,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  754, 2261, 2156,   32, 2884,    9,  505,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1940,    1, 2161,  388, 2267,  763, 2112,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,    1, 2373,    1, 1912, 1027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  108,  310,    1,   45, 1718,  767,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1798,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777, 1008, 1644,  548,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,  359, 1543,  138,    6,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  388,    1, 2372,   45, 3043,  968, 2162, 3273,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2956,  765, 1415,   37,    1,    1,  317,  361,    1, 1697,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,  814,   50,    9,  152,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1834, 3209,    1,    1,  498,   37,  365,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3132,    1,  631,  297, 3216,   37,   56, 1675,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12, 1043,    1,    1,  720,    1,    1, 1955,    1,    1,\n",
      "          276,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  587,  186,    1,  176, 1233,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   45, 2741,  108,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1360,  612,    1,    1,   12,  297, 1402,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  382,    1,    1, 1536,    9,  467, 1527,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428, 3406, 1882,   37,   64,    1,    1,   37, 2446,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 1701, 2192, 1322,   37,  105, 2294,    9, 1935,   12,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3116,  922,  437,  182, 3312,  720,   39,  361,  311, 2936,    1,\n",
      "           98,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1547,  801,  444,   60,    1,   94,  187, 1043,  225, 1738,  682,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2803, 3265,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2546, 1086,  824, 2441, 2610,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 1298,    1,  167,  544,  638, 2258,    9,  166,  104,   26,\n",
      "         1990,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2650,  134,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   46,  220, 3380, 2312,  227,  446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,  983,  738,    1,  739,    1,  572,   51,  245, 1139,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  340, 2162,   67,    6,    1,   13,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1256,    1,  552,    1,  485, 1948,  197,  338,  118,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1405,  858,  475, 1564,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1562,  531, 1002,  304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  439,   45,  166,  260,    9,    1,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1366,  321,  612,  913,  445,  225,   32, 1340,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  857, 1622,    1,    1, 1270,   59,    1, 2442,  774,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  729,  603,  115,    1,  193,   81,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3230,  140,   32,   73,  744,  297,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2625,   98, 3392, 2070, 2329,   32, 2597,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  150, 1749,  220,  613, 1605,  698,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,    1,    1, 1366, 1445,  176,  166,    1, 1411, 1034,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614, 1198, 3154,    1,    1, 2769,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  147,    1, 2539,    1,   45,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,   59,  163,    1,   12,    1,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129, 1740, 2654,  885,  593, 1990,    9, 2741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  534,  251,  119,  636,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    8,    1,  657,  788,  302,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1430, 1726,  319,  297, 1009,   12, 2113,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   45, 2994,    1, 3031,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  271,   28,  116, 2086,  437,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1631,  365, 1737,  297, 1021, 2285,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1614,  453,  326,    1, 2232,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2870,   32,  403,  404,  854,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 2708, 3136,  477, 1086,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,    1,   98, 1647,    1, 1128,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   65,   12,    1,  387,  340,   31,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1606,  251,    1, 1907,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2962,    1, 1879, 2712,  365, 1788, 1497,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 2460,   79,  741,    9, 1031,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3169,  801,   37,   72, 1385,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  872,  162,  453,   59, 2223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2309,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796,    1,    1, 1391, 2842,   45, 2970, 2502,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  544, 1292, 1681,    1, 1604,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,  477, 1908,   37,  105,  123,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   98, 2597,  947,    1, 3392, 2856,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  162,    1,   85,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  968, 1475,    1,   12,  734,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1349,   12,  221,   61,  105,    1, 2630,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2237,  105, 1479, 2282,    9,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  669,   37, 1073,  455, 2143,   50,   32, 1125,   45,  287,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  455, 1070,  403, 1447,    9,    1,    1,   45, 2249, 1796,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,  627,    9,  166, 3375,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2835,   37, 1584, 1407,  441,    1,  171,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,  418,    1,  202,  157,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1774, 1159,    1,  671, 3126, 1090,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  489,   39,  885,    1, 1918,    1, 1334, 2793,   32,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  262,  263,   12,    1, 1133,   37,    1,  297,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3262,    1,    1, 2503, 1545,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1328,    1,  898, 1813, 3118, 1302,    1,    1, 3369, 1583,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2268, 2214, 1924, 2566,   45,    1,    1,  398,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2844,   32,  344, 3389,  187,  104,  396, 2555,   45, 2183,\n",
      "         3381,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  207,  834,    1, 1344,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  182, 2693, 2790,  513,  514,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1528,  166,  917, 1178,   37,  631, 1477, 1990,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1072,    1,  150,    1,  166,  259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826,  116,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 1572, 3057, 1550,    1,   32, 2433, 3360,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1583,  267, 1240, 1237, 3114,  548, 2891,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 671,   1, 338, 548,   1, 214,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3339, 2625,   37, 1348,  187, 1183,  187,    1, 3359,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,   37,  130, 1074,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2104,  267,   77,    1,    1,   79, 2879, 1638,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1651, 1597,  140, 1405,  965, 1611,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1645, 1009, 1186,  416, 1298,    9,    1,  104,   32,  531,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,   12,  737,  244, 1124, 1146, 1703,    1,  155,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  996,    1,  578,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1674, 3126,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2835,   37, 1468,  622,    1,    9, 3358,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3029, 2981,    1,  220, 1821, 2190,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  852,   37,    1,   91,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1940,   12,    1, 2420,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  515,    1, 1537,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2642,  949,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361, 1361,  565, 1509,   32, 1023, 2472,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,    1,  855,   45, 3343,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2846, 1838,  191, 1809,  917,    1,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654, 1426,  132,    9,    1,   14,  524,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  166, 1746,  176,  148,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1823,  688,  191,    1,    1,  166, 1354,    1, 2502,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1266, 2182,   79,    1, 1149,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   65,   12,   67,  484,  193,    1,   37,    1,  218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3326,    1, 1061,   98,    1,   44,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  350,  444,  362, 1064,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  612, 1273, 2384,  365, 1778, 1273, 1775,   32,  602,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 3025,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,    1,   32,  163,    1,   12,    1,  863,    1,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  878, 2213, 2321,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3194, 3195,  546, 2565,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  176,   26, 2689,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3087, 2478,    1, 1789,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  190, 1140,    1,    1,   12,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   51,  211, 1821, 2190,    1, 2640,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1726,    1, 2658,   12,   39,    1, 1944,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1720,  183,  625,  681, 2784,  297, 1515,  248,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  592,  267,    1,  719,    1, 1560,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3078,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  203,   37,  151,  105, 2088, 1412,  844, 2198,  166,    1,  636,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163, 1594,    9, 3225,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1365,  396,  331,    9, 1842,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  539,    1, 1917, 2018,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  778, 1976,   32, 2741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  580,    1,   37, 1473,  444,    1,   91,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1968,    1,  365,   40, 2480,    9,  613,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  994,    1, 2476,  220, 1354,    1,    1, 2048,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2899,   81,   32, 1107,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116, 2264, 1210,  105, 1067,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  961,    1, 1318,  267,    1,    1,  193,    1,    1, 1509,  913,\n",
      "            9,  223,  639,  963, 2122,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523,   12, 1224, 3152, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  510,    1,  453,    1, 1316,  166,  463,  187,  584,    1,   39,\n",
      "          384,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2573,  387,  627,   32, 2517,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  491,    1,  183,   37,    1,  901,   69,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1340, 1924, 1514,  221,    9, 3271,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3204, 2660,  356,  439,  590,    1, 1569,  547,  257,  411,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  683,    1,   37, 1066,   59, 1171,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,  608, 3024,  906,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826,    1, 1086,  220,  163,    1,   12,    1,  361,  667, 2078,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1948, 2153, 2155,  105,  271,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  242,  737,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1830,    9,    1, 1798,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2729,  669,  267,  786, 2729, 3102,   32,  531,   61, 1211,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  865,   37,   95,   98, 1171,  528,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,  952,   37,    1, 1931,  297,   69,  125,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2477,  944,    1,   45, 1022, 3033,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1683,  187, 2774, 3382,    1,  105,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  741,   32,    1,  890,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   18,   28, 1139,    1, 3198,    1,   32,  395,\n",
      "           26,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  503, 1342,    1,   37,  231,  669,    1,   98,  749,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1425,  166, 2517,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3114,  232, 3147, 2924,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  967,  105,  469,   37, 1865,    4,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  579,  166, 2488,  774,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2236,  729, 1555,   37,   52, 2867, 2792,  512,   12,  389,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2753,  581,    1,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2041,  826,    1, 1976,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1465,    1,  733,    1, 1501,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213,    1,  191,    1, 1545,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1492, 3303,  202,    1,    9, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   32,  630,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2890, 1674, 2379,    1, 2479, 2073,  671,    1,  913,   32, 2218,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1461,  477, 2414, 1056, 3339, 3006,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  207,   28,   98,  242,    1,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,   32, 2457,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1095,  325,  118,   48,   32,    1, 1074,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1752,    1,    9, 3101,  622,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  815, 1718,  361,  334,  234, 3041,  235,  190,  234, 3041,  235,\n",
      "           52, 1205,    1, 2881,   90,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963, 1696, 1409, 1492,    1,  803,    1, 1183,    1, 1871,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2999, 3050,  933, 2819,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2395,    1,    1,    1,    1,    1,  395,   12,  365,  792, 2213,\n",
      "         1740,  792,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1645,  947, 2263,    1, 1000, 1884, 2375,   32, 1994, 3387,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,    1,  384,    1,   12,  594,  698,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2862,    1, 1877,   37, 1403, 3093,    1, 3159, 1994, 1537, 2751,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2392,   72,  401,  207,  354,  703,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   45,    1,  361,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3327, 2297, 2800, 2565,  176,  463, 2926,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2843, 2523,    1,    1, 2876,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2470,    1,  409,   37,  973,    9,  403, 1447,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  107,   37,    1,   69,  102,   32, 2160,   45,  104,  863,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  631,  574,   37, 1212,    1, 2017,  384,  395,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2885,    1, 2843,  220,  119,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  804,  815,  247,  846,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  893,   45, 2343,   12,    1,   37, 1046,  776, 1411, 1034,    1,\n",
      "         2877,  267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,  421,  315,    9,  399,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  160, 1063,  640,   39,  176, 2102, 1402,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2918, 2784,  719,  365, 2662, 1917,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  691,  167,   84,   28,    1, 2678,    1,  446,  108,  548,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2857, 1188, 1488, 1896,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3160, 2414,    1,   32, 1815,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  794,  777, 1013, 1017,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1158,   12, 1230, 2869, 1863, 1046,  166, 1104,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386, 2192, 3092, 1011,    9, 2112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2708,    1, 2572, 3374,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  872,   45, 2617,    1,   37,    1,   37,    1, 3358,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1106, 1107, 1353,  759,   37, 2192, 2102,  105, 1328, 1787,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,    1, 2172,   51,    1, 3033,    1,  354,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3129,    1,    1,    1,  665,    1,   98, 1171,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  475,   12, 2177,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,  267, 2536, 2162, 1950,   32, 2003, 2960,  407,   37,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2102,  525,  640,   64,  297, 1402,   32,  215,  361,  942,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,  794, 1230, 1529,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  912, 2285,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  373,    6,  381,    1,  159,  720,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118, 2751,    1, 3369,   45,    1, 1450,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  649,  518, 1190,  267, 2335, 1146, 1703,  996,   93,    1,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1645, 3365,   32,  531,   37,   52, 1683, 1371,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2246,  942,    1, 2618,  317,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1104,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1485,    1, 2414, 1700,    1,   37,   92,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1317,  704,  104,  682,  548,  572,  197, 2482,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2004,  829,   34,    1, 2043,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1937,    1,    1,   37, 2275,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,   37,  712,   28, 1023, 2117,   12, 3118,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2242,    1, 2319,   45,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3232,  415,  786, 1090,   39,   45,  449,  913,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999, 2257,  166,    1,   98, 1994, 2819, 3050,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3058, 1407, 2282,    1, 2562, 1183,  611, 1145,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  459,  331,    1, 1228,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2333,    1,    1, 1976,   32,    1,    1,    1, 2320,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2729,    1,  630,  190,  341, 2179, 1177,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3369,    1,    1,    1,    1,   32, 3118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1116,   32,    1, 1249,  308,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018, 1463,  546,    1,    1, 1461,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1389, 2156,   32,    1,    1,    1, 2579,  336,  298,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2540, 3254,   32, 2941,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,   61, 1277,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1187,  460,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  567, 1702,  163,    1,   12,    1,   69, 1750,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3155, 1345,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1656, 3035,  477,   27,  501, 2060,    1, 1530,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  477,  411,    9, 1853,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  840,    1,    9,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  859,  198,   60, 1563,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2484, 2771,  190,    1,   56,   45,  228, 3193, 3217,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  581, 2596, 1665,  851, 1478,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2163,    1,  786, 1167,  416, 2017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1405, 2281,  776,  431,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  301,  482,  588,    5,  271,    1,  774, 1469,  193,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,    9,    1,    1, 2337,  105, 1833,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  424, 1034,   32, 1230,  550,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2189,    1, 3338, 1316, 2468,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  511,    1,  449,  422, 2041, 1463,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2692,  542,  753,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  885, 3160,  384,    1,    1,   61, 2572,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190,    1,   18,   85,   98,    1,  920,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  519,    1, 3250,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   12,    1, 2695,   55, 1191,   98, 2901,  327,  593,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  841,  884,    1,    1, 1408,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,    1, 1841,    1,    1,  372,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2226,   12,    1,  939,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1690,  724,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2189,    1, 1911, 1582,  591,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  488,   37,  477, 2095,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  214,  693,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1867, 1139, 1263, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  682, 1876,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1, 1665,   37, 3101,  903,  250,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,  105,    1,    1,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3016, 1935, 1825, 1000,  105,  913,   32,  166,  327,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3151, 1756, 2093,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1680,    1,  951,    1, 2102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  208,    1,    1,    1,  547,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2102, 1107,  525,    1,   32, 1881,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1216,    1,    1, 1924,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 2352,  474,    1,    9,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,    1, 1151,  260,    9,  160,  623,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3188,   12, 2471, 1415,   37,    1,  763,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1041,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  242,  636,   45,  996,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2752,  947, 2572,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3089, 1287,   37,  688,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  213,   37,   59,    1,  786,  356,   24,  220, 1739,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   39,   45, 2073, 1463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,   12,    1,  571,    1,  315,   37,  439, 2646, 1512,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1523,    9, 1811,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  512,    1, 1218,  190, 2449,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 2344,   37, 1411,    1,    1, 2670,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3236,  576,    1,    1,  683,   37, 3319,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1074,    1,  285,  293,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1435, 2820,    1,  387,  590,    1,  395, 1220,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  852,   37,  166,  845,  439,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  790,    1,  410,  297, 1056,  365,  505,  229,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1,  197,   28,   98, 1495,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428,  232,  108,   45,    1,   45, 2292, 1969,    1, 2891,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1396,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   91,   12, 1509,  750,  447,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387,  395,  646,   93, 1115,   37,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  105, 2342, 1265,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043,  338,  187,    1,  640,  275,  159,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3232,   18,   39,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2474,  259,  218, 1239,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 3101, 2874,   45,  403, 3339,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2879, 2843, 2034,  453,    1,  187,  166,  593,   12, 1354, 2947,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2221,  267, 2087,  433,    1,  596, 1793,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1173,    1,   12,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1778, 2987, 2988,    1, 1159,  166, 1264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2828, 2237, 2050, 1907,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  388,  301,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2373,    1,  723,    1,  331,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1603, 2024,    1,  288,   37,  245,  297, 2245, 2755, 2490,   32,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,    9,    1,   37,  606, 2181,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  661,   98,   25,    9, 1602,    1, 1837,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  225, 1279,  418,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3230,    1,    1,  220,  105,  119,    1, 1642,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,    1,  535,  656, 1614,   98, 1893,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2504,  258,  232, 3395,   32, 2966,    9, 2705,   45, 3105,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,    1,   79,    1,   12, 2130,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  203,    1,   61,  460,   37,    1,  116, 2542,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,  123,   32,   98, 1039,   45,    1, 2796,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   12, 1389,   45, 2162,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  611,    1,  545, 1668,  331,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  241, 2875, 2640,  387,    1, 2784,  528, 2323,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2106,   69,  551,  493,  369,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  344, 3403, 2414, 1147,  947,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151,   12,  792, 2813,    9,  166, 1291,  792, 1258,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2800,  986,    1,   37, 2912,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492,  736,  105,    1,    1,  548,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3320,   12,    1, 1231,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128, 1203,    1, 1021, 1129, 2007,   37,  114,    1, 1242,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1879,    1,   39,    9, 1694,   45,  914,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 1173,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1290,  396,   71,    1,    1,  805,   45,  585,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3386,  312,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3330,    1, 2110, 1334, 1568,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2097, 2321,    1, 2563, 2368, 1045,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  224, 2384,  613, 1108,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826,    1,    1, 2744,   98,  247, 1674, 1677,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3251,  288,    9, 2016, 1605,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,    1, 3174,   32,  395,   26, 1286, 3179,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   68,   70, 1348,    1,    1,  220,  102,  176, 1312, 1034,  687,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1602, 2305,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  409,   25,  417,   60,  338,  951,    1, 1547,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1329, 1149,  690,   24,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3248, 1338,   45, 3130,   32, 3201, 1924,   55,  105,  984, 1585,\n",
      "          384,  166,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 3256, 1285,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  275,   11, 2495,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503, 1454,    1,   98,  749,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2004, 2650,  302,  765,   37,  233,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  856,    1,    1, 3000,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,    1,   79,    7,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1564,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 3160, 1156,  297,  531,  966,  548,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  315,   37,   47, 1541,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    9, 2586,  297, 3077,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1169,    1,  102,   71,    1,    1,  388,  763,   76,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3033, 1504,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1981,   32,  231,    1,    1, 3079, 1523,    9, 2027,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  926,  408,   54,  105,  356,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1760,   15,   45,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1177,    1,  773,  385,   15,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  863,    1,  576,   69,  417,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2140,    1,    1,  187,    1,  477,    1, 1255,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3123, 1249,  311, 2936,   32, 1050,  922,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  943,  920,  813,    1,    1,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  736,   37, 1174,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1481, 1349,   37, 1413, 1170,  853,  538,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1159, 2218,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3358, 1187,  193,  606,    1,  232,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3403, 2766, 1056, 2548,   32,  539,  458,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2328,    1, 2596, 2856, 1056, 3354, 2548,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,    9,  105,  365, 2866,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1010,    1,    1,    1,  934,  418,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999, 2257, 2194, 3050,  384,  778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3052,  184,  411, 1385,  522,   32, 2445,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2642, 1285, 1110, 1340,  640,  590,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  281,  282,    6,  197,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1127,  520,  163, 1594,   98,  858, 1251,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2608, 2607, 3060,  513,  514,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3385,  650,   12,  259,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3257,  418,   28,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2069,    1,   32, 1684, 1948,    1, 2477,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,   12,   93,  837,    1,    1, 1994,   31, 1553, 2030,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3387, 1648,   37,  319,  856,  187,  388, 2985, 1156,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1214,   12,    1,   39, 2119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  476,  388, 3167, 1675,   32,  552,    1,  704,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1802, 2489,   85,  943,   45,    1, 1708,  115,   45,  741,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,    1,  152,  422,  399,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1181,   37,   47,  163,    1,   12,    1,  845,  846,  259,   32,\n",
      "          411,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3344, 1940, 1260, 2597,  336,    1,  176,  177, 1530,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035, 1070,   37, 1642, 1175,  920,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  699,  115,    1,  417,   69,  696,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,  559,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  571,  220,  726,  187, 2563, 1285,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2722, 3074,  801,   37,    1, 2433, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2563,    1,    1, 2365,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2298,    1,  458,   45,  507,   12,    1,  170,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  571,   37,  531,    1, 1484,    9, 1314,   98, 2646,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1, 3276,  759,  105, 2463, 2101,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  596, 1793, 2048,  176,  629,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380,    1,    1,  475,   37,  103,  317,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   32, 2835,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715, 1061,  297, 3043, 2673, 2108,  442,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1900,  736,    1, 1560,   98, 3153,  663,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299, 1458,    1,   85,   98, 1089,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  449,    1, 2518,  724,  190, 1371,   52,    1,   98,  617,  618,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12, 1849,  808,   32, 3360,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1, 2798,  221,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  164,    1,  453, 1194, 2566,   32, 2490,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  982,   96,  617,  259, 1159, 1084,  841,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178,  147, 1707,  732,    1, 1378,  776, 1220,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2677,    1, 1171, 2489, 1159, 2882,  637,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2048,  713, 2074,   32, 1029,   37,  741,   32,  480,  863,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3079, 1477, 1990,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707,  193, 1724, 1542,    9,  342, 2927,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 1778, 2232, 2762,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1230, 1220, 2087, 1568,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2800,    1,   32,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548, 3358,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  388, 1942, 1648,    9, 2333,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  663,  437,    1, 1212,   12,  299,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1761,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  264, 1343,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   98, 1123, 2620,    1,  888,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117,  741, 2718,   37,    1, 1228,    9,    1,    1, 1610,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3096,    1,  571,  187,    1, 1327,  335,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,  650, 1458, 2532,  220, 1186,  202,    1, 1058,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 2107, 2512,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1191,    1,  500,   51, 1413, 1414,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1, 1394,   37,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  100, 1908, 1876,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1616,  191,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  458,  437,  835,    1,  551,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2533, 2322,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713,   26, 1039, 2657,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3359,   37,  846,   28, 3339, 2271,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  908,   22,  942,  283,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087, 1042,  315,   37,  665,    1, 1017, 1159, 1087,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1340, 2768, 1977, 2189,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  179,  213,   37,  151,  180,    9,  372,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 2581, 3292,  550,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  332,    1,  628,  631,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3365, 1683,  384,    1,    1,   32, 1640,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2571, 1964, 2396, 1268,   32,    1,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384,  996, 1021,   37,  996,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  190, 2192,    1,  472,  698,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   45, 2163, 1236,  381,  297, 1405,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,    1, 1377,   45,    1,    1,  695,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1280,  100,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3255, 1056,  463,    1,   32,    1, 1509,   45,  356,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  954,  366,    1,  245,    9, 1194,   73,  339,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  388, 1013,  280,    1,    9,  218,  332,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  666,    6, 1021,   37,  331,   32, 1817,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  487,    1, 1973, 2153, 2243, 1850, 1423, 2024, 1907,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,    1,    1,   98,  149,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  103, 2764, 3394,    1,  416,  667,    1, 2180,   32, 1275,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  155,  331,   37,  764,  574,  124,  349,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  864, 2259,   98, 2390, 1806,  193,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374,  650, 2572,   32, 1461,  477,   32, 3339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   68,  102,   37,  168,   28,  220,    1,    1, 1007, 1220,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380,  812,   46,  220, 1537,  446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1142, 1143,    1,   83,  254,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2186, 1593, 2874,   45, 1023, 1204,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,  535, 1523,    9,    1, 2577,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965,    1, 2982,  328,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  211,   37, 3076,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  557,  540, 1658,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1622, 2751,   32,   46,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,    1,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3213,  782, 2127, 2363, 2177,   37,  690,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159, 1150,  187,  197,    1,  983,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  748,  716,  122,  600,  393,   12, 1959,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1591,  225, 1137,   98,  236,  237,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3066, 1550,  411, 1888,    1,    1,   96,   85, 1092,  693,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  446,   37,  877,  163,    1,  903,    1,  714,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 2668,    1,  187, 2158, 1426,  193,   39,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994,    1,   41,   37,  686,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,    1, 1815,    1,    9, 2018, 2024,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3255,    1,  653,   28,  187, 2741, 1154,    1,    9,    1,  361,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,    1,    1,  132,  852,  972,   37,  439, 1371,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  649,  137,  619,  501, 1125,   37, 1706,   32,   25,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  716,    1, 2977, 2550,    1,   45,    1,    1, 2218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361, 1528,  582,    1,  628,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,  199,   37,  125,   37, 1948,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  528,    1, 2456,    1,    1,  686,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424,  199,    1, 3280,    1,  198,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2700, 1835, 2056,    1, 1463,    9, 2527,  164,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1592, 1937,  119,  356,    9,  104,    1,  390,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2, 886, 325, 104,   1, 437,   1,   9,  59,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 764, 166,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  147, 1360,  612, 2199,    1, 2201,   12,    1,  142,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1, 2844, 1897, 2592, 1663, 2472,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  961,  448,  490,   37,  119,  182,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  951,  365, 2036,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,  105,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2049,  267,  195,  776,  307, 1567,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1123,    1, 2554, 3260,   37, 1918,  297, 3209,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,    1, 1830,   37,  693, 1863, 1211, 2367, 1160,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   59,  166,    1,  454,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2758,  449, 1816,  424,  339, 3011,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  667, 1065, 1190, 1216, 1799, 1378,  863, 2819,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   12,    1,   46,   28,  647, 1416,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3365, 1575, 1211,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   45, 3369,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2466, 1822, 2303, 1623,   45,  585,  302,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,    1,    1, 1018, 1194, 2553,   32,  891, 1010,  753,    1,\n",
      "          181,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2887,  546,   32,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   37,    1, 2641, 1772,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  273,    1,   37,   77,    1,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1373,   37,  335,  166, 1981,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  828,   37,  619,  961,  138, 1083,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2298,    1,  176, 2673,  250,   32,  463,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2308,  361,  542,   76,   37, 1046,  134,   32, 2811,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925,    1,    1, 2954,  600,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2801,    1,  982, 2274,   98,  517,  259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,    1,   20,  973, 2608, 1499,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  854, 2785, 1950, 1784,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  198, 1838,   37,    1,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  964,    1,   98,    1,   45, 2237,   37,  395,    1,  267,  121,\n",
      "          190,    1,  129, 1184,  963, 2122,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1380,    1,  449,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,  105,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1, 1236, 1479,  137,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,   12,  472,   39,   45, 2336,  809,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  551,    1,  498,    1,  214,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2994,  777, 2995,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1030, 1559,    1,  884, 1383,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,   37,  125,  102,  548,  594,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3014,    1,    1, 2798,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1912,    1,    9, 3207,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2919, 1920,   32,    1,  400,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   48,   32,  854, 1339,    1,   37,   52,   53,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1630, 1988,   45,    1, 1077,    9,  286,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1255, 1107,  344,  345,  921,    1, 2577,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  997,  403, 1447,  600,   37, 1539,    1, 1461,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1419,    1,   37,  883,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  828,   37, 2360,  790,    1,  503,  297,  749,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3369, 1454, 2270,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1918,    9, 3196,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  386,  111,  162, 1280,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,   16,   79,  872, 2043,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,  488,   37,    1, 1428, 3118, 2824, 3399,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  395,  317,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1077,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3012, 3027,    1, 2604,    1, 2421,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1668,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12, 2325,   45,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1095,  213,   37, 2010,    1,    1,   98, 1611,  778,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  787, 1809,  315,    9,    1,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2382,   37, 1521,  365,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374, 2042, 3090,    1, 1585,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   89,  361, 2378, 1674,    1,    9,    1, 2826,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1818,  147, 1458,  544,  193, 1140,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  776,  288,    9,    1, 2518,   32,  195,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3155,  202, 1345, 1258,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1443,  753,    9,  166, 2491,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   72,  548, 1260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,  227,   32, 1600,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178, 1492,    1, 2476,  166,    1,  920,  315,   98,    1,  649,\n",
      "         1975,   37,  163,    1,   12,    1,  963, 2122,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,   12, 3359, 2386, 1533,  917,   45,    1,  443,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  369,    1, 1564, 1299,  973,    9, 3019, 1151,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1572, 1414,  759, 1619, 3391,  163,    1,\n",
      "           12,    1, 1039,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  952,  365, 1259,  220,  342, 1167, 1760,    1, 1859,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,    1, 2080,  517, 2872,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1285,  417,  187,   69,  102, 1473,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  479,    1,    1,  627,    9,  730, 1571,  872,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503,   12,  749, 2129,    1, 1021,   45,    1,  191,  776,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  977,    1,    1,  384,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  517,  738, 1010,  119,  845,   94,  361,  800,   60,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  189,  981, 1118,  949,   45,  172,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1, 1243,   98, 1465, 1151,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2536,  187,  902, 1831,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 3356, 2431,  267, 3357,  190, 1174,    1,  297, 2375, 1602,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1283,    1,   53,    9,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3349,   12, 2177,    1, 1532,    1,  191,  799,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  179,    1,  746,   32,    1,    1,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3389,   51,  335,    1,   32, 1081, 1708,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094, 2224,  213,   37, 1211, 1156, 3375,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  166,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3381,  437,  267,  460, 2399,   37, 2856, 1147, 1190,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1412,    1,  218, 1618,   28,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1350,  695,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3024, 1204,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1920,  325,  331,    1, 2247,  548,    1,    1,  204,  416,\n",
      "          166, 1514,  786,  963, 2122,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2016, 1606, 1149,  474, 1337,   46,  190,  231, 1145,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  548, 1183,    1,    1, 1147,  358,   81,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190,    1,   52,  170,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1647,   66,   32,    1,   37, 2500,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  864,   37,  899, 3107, 3366, 1851,    9,  187, 1183,  187,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  321, 2686, 2687,  856, 2502,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  886,    1,    1,    9,    1,  769,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  196,  733,    1,   50,    1, 1408,    7,   17,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  195, 1091,  661,  192,    1,   32,    1,  856,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  683,    1,   98,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2842,   45, 2292,   32,  531,  187, 2688,   61, 2572,   32, 3155,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1944,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1809,   45,  105,    1, 1178,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  848, 1572,  437,   37,  151,  849,    9, 1270,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1221,   51,   52,    1, 1204,   39, 1221,  548,  810,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   63, 1148,  166,  730, 2614,   37,  105, 3154,    1, 3238,  277,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,    1,  116, 2179,  406,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   71, 1577,   34,  275,  159,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  401,   45,    1,    1,   45,  116,  420,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3198, 1337, 3169,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3092,  134,    1,  220,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  288,   37,  877, 3072,   59,  384,    1,   39,  166,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2978,    1, 1976,   32, 1739,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3062,    1, 2284,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  752,    1,    1,  396, 1405,  710,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1159,    1,  627,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676,    1, 1152,   45, 3038,  439, 1232,    1,  193,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 845,  69, 102,   1, 104, 954,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 104,  25, 245,  32,   1, 276, 452, 871,  98,  69, 102,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,    1, 2930,  400,    1,   37,  312,    1,  178,  774,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796,   25,    1,  411,  390,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1345, 2361,   32, 2764, 2646,  548, 2024, 2699, 1464,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2837, 1999, 1530,   32,  942,  851,  298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,  361,    1,   45,  166,  317, 3358, 1015,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1592,  913, 1019,    1,   98,  105, 2056, 1171,   37, 1850,  395,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  861, 1906,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   14,   15,   28,  699,  187,   76,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  566,   48,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  867, 2055,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  338,  384,  119, 1588,   51,  907,  889,  719,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790,    1,  538,    1,   98,  195,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 2161,   12, 1394, 2107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,    1,   45,  593,  103,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,    1,  669,  936,  955,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   12, 2334,  365,  846, 2965,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,  183,  112,  783,  953,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1459, 1702, 1994, 2834,  469,  548, 2596, 1260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2107,  420,  105, 1628,   74,    9, 2512,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  793,   96,   37,  388,    1,    1, 1010,  104,    1, 1681,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962,    1, 2907, 1408, 3117,   32, 3235,    1,  631,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755, 1396, 1273, 2492,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   72,    1, 2457,  300,  104,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   85, 2474,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  684,  615,  388,    1,  548,  720,   32,  685,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2264,  774,  326,  327, 1131,  333,  105,    1,   45,  166, 1215,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3151, 2308,   37,  665,  365,  693,   98, 2601,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   82,  387,  547,    1,    9,  777, 1085,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  393,  359, 1947,    1, 1907,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868, 1702,    9, 2390,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,  131,   48,   32,  141,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 3035,  477,   27,  501, 2060,    1, 1530,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  683, 1070, 2925,   37,    1,  247, 1323,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,    1,  400,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  571,   37, 3225,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  390,  417, 2527, 2116,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3244,    1,    1,   37,  619, 1354,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2677, 3191,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  375,  407, 1159, 3179,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1811,  404, 3364, 1484,   98, 3375,   37,  439, 3344, 2139,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1585,  176, 2197, 2178, 2147,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510,    1, 2732, 1530,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3170,  354,  590,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,    1,  729,    1, 1412, 1107, 3049,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  176,  612,  353,    1,  131,  354,   98,    1,   44,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2571,   23,    1, 2024,   46,    7,   37, 3118, 1560,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1092, 2039,   37,  837, 2189,  912, 2285,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   37,  588,    1,   45, 3385,  475,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2899,  407,   98,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746,    1,  747, 1584, 1515,    1,  544,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1061,   32, 3043,  722,   37, 1260, 1147, 1065, 1190,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2292,    1,  297,    1,  388,   32, 3118, 1428,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2297, 3141, 2308,   45,  166, 1034,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3345,  774, 1444,  606, 2572, 1485, 3102,  844,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3035,    1,  501, 2060,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962,  375, 1401, 3209, 1415,   37, 1131, 1684,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  947,    1, 1942,  361, 1786,    7,    9,  903,    1, 1973,   46,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1329,   37,  138,  971,   50,  372,    9, 2326,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  584, 2484,    1,    1,    1,    1,  981,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   92,  116, 1998,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  845,  147,   37, 1709, 1983,    1, 1816,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213,    1,  105,  304,   37, 1130,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  384,    1, 1013, 1522,    1, 1699,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2508,    1,    1, 1228,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2882, 1804, 3270,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,   37,  480,    1, 2400, 1871,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1159,  166, 2162, 2060,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  849,   12, 2543,    1,    9, 1869,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051,  349,   45,    1,   61,    1,    9,  166, 1434,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1648,   37,  690,  529, 1649, 1650,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   30,    1, 1924,  590,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  870,    1,  200, 1378,    1,    1, 2575,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1238,   22,  474,   37,  856,  486,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1743,   98, 2442,    1,  884,  913, 1517,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3302,  794,  927, 1159,    1,  966,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   45,  507,  891,    1,   45, 1051,   80,  618,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   55,    1,   30,  505,  195,   61, 2567,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2890,    1,    1,  548, 2494, 1675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2298,  176,    1,   50,  665,  373,    1,   98,  166, 1569,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,  467,  147,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  693, 1211,  207,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758, 1774,   39, 1117, 1525,    1,    1, 1754, 2759,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  865,   37,  602,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1442, 1414,    1,    9,  531, 3082,  966,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,   37,  439,    1,   16,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,    1,   59,   32, 1796,  704,  551,  705,  656,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2991,  251, 1101, 1089, 2549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  117,    1,   37,   52,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2031, 1226, 1114,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  387, 1107, 1516,   32,  617,  618,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2748,   12,  354,   61, 3013,   12,  504,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187, 2378,    1,    1, 2822,    1,  176,  354,    9, 1886,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  429,   79,  519,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1913,  401,  156,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,  267, 2275,  833,  612,    1, 2095,  443,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2529, 2596, 2137, 1296, 1619, 2597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1720, 1346,  321,   52,  388, 2342,  763, 2964,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1, 1234,    1, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1309, 2483,    1,    1, 1251,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3187, 1707, 3328,   12,   59, 2497,  693,    9, 3177,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1549,    1,  474,    1, 2179,    1,    1,  267,  592,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1898,    1,  645,    1, 2413,  550,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2835, 1702, 3101, 2708,  895,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3377,   12, 1623,  729, 2126, 2353,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  220,    1,    1,  273, 2222, 1564,  105,  183,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1699,  105,    1,    9,    1,   28, 1658,  327,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2657,   45,    1,    1, 1564,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087,  433,  420,  267,  249, 1389,  596, 1793,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,  786, 2847,  726,  176,    1, 2579,   12,  171,    1,\n",
      "          628,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   69,    1,   27,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  166,   16,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3094,    1, 2572,   32,  163,    1,   12,    1, 1995,   98, 1147,\n",
      "          787,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,    1, 1718,  167,  665, 1570,   32,  166,    1, 1311,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2018,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   71,  388,  763,   76,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1993,    1,    1,  272,  454, 1750, 2771,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  587,   32,  430, 1140,    9, 1018,   69,  477,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  313,  176,    1, 2264,  220,    1, 1708,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  418,  187,  567,  431,  163,    1,   12,    1, 1549,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  823,    1, 3161,    1,  894,  726, 3193, 3217,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1090,   45,  166,   74,  125,    1,  730, 2614, 1045, 1086,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884, 2144,    1, 2741,   27, 1805, 2872,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  726,  105,  905, 2581,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2991,  708, 1159, 1003,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1029,   12, 1459,  140,  480, 1743,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2807, 3229,   37, 2553,   39, 2069,  547, 1675,    1,    1, 1857,\n",
      "            9,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2800,  522, 1167,   12, 1960,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236, 1022,   66,    1,   28,   98,   68,  636,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1147, 3006, 1220,  331,   37, 1211, 1645,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 2019,    9, 2706,    1,    1, 3004,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,  284,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,    1,    1,  191,  741,    1, 1426,   39,   37, 1384, 2789,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1498,  736,  858,  191, 1021,  847,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  218, 2596,   32, 2490, 2414,  786,    1, 2803,  176,  177,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3075, 2864,  350,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117, 1525, 3002, 1284,    1,    1,  420,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3068,  116,    1,  614,    1, 1962,  361, 3068,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  793,  354,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 1194, 1267,   45, 2579,   45, 2468,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181, 2422,  138, 1084,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3149,  650, 3067,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2002, 2924,   37, 2449,   32, 3349,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2919,  384,  166,  323, 2593,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585, 2566, 1236,  715,  639,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1230,  580, 2015,  187, 1234, 1863,   15, 2401,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3183, 2647,  571,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1786, 2358,    1, 1259, 1484,   98,  196,   37,   47,  284,  728,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1378,  863,  844, 1442,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1306,  186,  691,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485, 3365,    1,   53,   37, 3381,  437,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1051,    1,    1,  698,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,  721,  833,  612,   81,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1327,  453,    1,  199,    9,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2807, 3103, 1090,    1,   37, 2675,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1721,  240,  328,   98,  314,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 1466, 1008,   82,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  544,  460,    1, 2026,    1, 1976,   98,  166,  116,    1, 2483,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1,  639, 1004,  903,    1, 1447,    1, 2439,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   37,  151,  217,   32, 1850, 1423,    1,    1,   45, 1423,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510, 2137,    1,    1, 2414,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1790,  313,  176,    1,  220,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,   37,  693, 1170,  538,  187, 1018, 1144,   32,  388, 1975,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  398,  261,  116, 2638, 2931,  625,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1990,  906, 2962,  183,  564, 1647,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  864,    1, 3107, 3366,  361, 2673, 2375,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1876,   45,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3226,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596,    1,    1, 1967,    1,  331,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1256,    1,  552,    1,  485,  884,   98, 1149,  187,  326,  486,\n",
      "          132, 1086,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1113, 1042,   32,    1,   78,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,   93,  570,  125,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   64, 1080,    1,  747,  156,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1100,    1,    1,  657, 1159, 2073,  913,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1229,   51,  764, 1549,   45,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2425, 1450,    1, 1117, 1943,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  872, 2090, 1249,  121,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  326, 1337,  573,  469,    9,  365, 1635,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  162, 1477, 1990,  302,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1988,   45,    1,  702,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  275,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3184,    1, 3347,   32,    1,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  207, 2429,    1,  365,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3231, 1306,  916,   37, 2935, 1131, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,   37,  123,    1,  111,  589, 1108,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  557,  540,  622, 2909, 2774,  787,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2765, 1491, 2834,  729,    1,  187,  638,  105, 1665,  187,\n",
      "         2085,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  252,    1, 2591,  548,    1, 1708,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884, 2461,  973,   37,  803,  681,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2884,    1,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1090, 2677,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1766, 1767,  105,  182,  517,    1,  488,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  315,   37,  764,  531,  429,  890,    1, 2702,  947,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1366,  565,  166,  249,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  200,  845,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  493,  102, 1637, 2085,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  863, 2900,  344,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3209,    1, 3233,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  696, 2468, 2250,  449, 2725,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  709, 3151, 1863, 2805,    1,  610,   37,  537,   32, 2772,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187, 2378,    1,    1, 2822,    1,  176,  354,    9, 1886,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1187, 1204,    1,   32,    1,    1,    1,  680,    1,   45, 2378,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129,    1,  251,    1, 1151,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 1034, 2587,  166,  224, 2355, 1013,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  348,   37,   47,   48,   32,  596,  486,   50,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2051, 1021,    1,  388, 1001,    9,  169, 1831,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,    1,    1,    1,    1,   45,  677,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,    1, 1632,    1, 2242,  115,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  388,    1,  115,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  487,  358,    1,  764,   39,  187,  793,  396, 2298,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1290,  396,   28,    1,    1,  526,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1488, 2995,  920,  166, 1509,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1366, 1445,  810, 3133,   37,    1, 1442,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1047, 1236,    1,    1,    1,    1,    9,  131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2642,    1, 1231,  220,    1,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147,  446, 1730,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982, 2587,  829,    1,    1,    9, 1718, 1775,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018,  812, 2531,  854, 1651, 2509,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1204, 2198, 1397,   32,  105,    1,  306,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1572, 1414,  798, 1918,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 1164,    1,   39, 1260,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  335,  105,    1,  460,   12,  166,    1, 2519,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  469, 1710, 1636,  861, 1906,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2700,   37, 2655,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,  936,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 1571,   92,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   81,   98,  247,    1,  548,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035,  716,   37, 1038,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  325,    1,  675,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  223,   45, 3358, 1229,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1231,  297, 2084, 2085, 1227, 2086,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3200,    1,   79,   37, 1254,  698,   32,  922, 2218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129, 2871,    1,  873,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2867,   37,  319,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267, 1994, 2275,  924,    1, 2588,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1002, 2911,   55,    1,  187,  876,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  313,   37,    1,  361,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1338,   45,  138,  895,  879,    1,  176, 1471,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1869,    1, 1008,    1,  886,  475,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3177,    1,   85,   37, 1691,    1,  714,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3109,  548, 1090,   45,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  810,  112,  301,  573, 1512,  729,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614, 2935, 2941,    1,  220,  726,  297, 2720, 2796,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  885, 1630, 1988,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 2275,    1,   45,    1,  505,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1924,  581, 1385,  712,   45, 3117,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1788,  794, 2069, 2826,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  104, 1117,  741,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785,    1, 1760, 1273,  259, 2530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1027, 2710, 1730,    1, 3104, 2469,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043, 1518,   28,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1107,  293,  313,   37,  576,   32,  538,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   70,   71,  530,  105,  106,  187,  616, 1173,   37,  107,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  162, 1328,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363, 1660,  158,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   47,   79,  810,    1,  942,  159,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  166, 3226, 3263, 2811,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,  548,  397,  909, 1665,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3075, 1086,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  644,  877,  365, 1260,   98, 2751,   32,\n",
      "         2646,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2227,    1,    1,    1,  810,  753,    9,  487, 1938, 3197,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2477,  944,    1,    1,    1,  210, 3053,    1,  928,  176,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433, 2466, 2094,   28, 2824,   32, 1250,   37,    1,  460,   85,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2578,    1,    1,  332,  631,   32, 1447,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2149,   37, 2111,  615,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  446, 2061, 1184,   67,  304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,   10, 1297, 1900,  544,    1, 1604,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  236,  237,   25,    1,  857,   74,  186,  528,  845,   69,  636,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3043, 3101, 2878, 2856, 3384,   32, 3140,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  331,    1,    9, 1808, 1831,   12, 1821,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  599, 1505,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2076,    1,  460, 1278,   37,  686,  131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  476,  105, 2069,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  691,   12,    1, 1680, 2326,   32,    1, 1523,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613,  200, 1615,   12, 1351,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035,  256,   37,    1,  260,    1,    1, 2707, 1006,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1707,  792,    1,  792,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1019, 1675,    1,    1,  361,  810,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1572,    1,  835,  215,   12,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 3005,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,   37, 1599,   26, 1039, 1228,  220, 2351,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  647,  482,  360,  148,   12,  693,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 2619,  547,  195,    1,   32, 1300, 1603,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  716, 3381, 3338,   32,  531,    1,  163,    1,   12,    1, 1583,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  768,   61, 2443,    1,  202,  669, 1877,   37,  856,   81,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,  259, 1167,    1,  334, 1488,  763,  334,  544,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2578, 1401,  593, 3154,  191, 1056, 1593,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,   37,  489,   39,   45, 2514,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  534, 1310,   37,  429,   79,  214,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  105, 1204,   27, 1762,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  365,  294,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1327, 2126,   62,  548,  354,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1,    6,  118,   45, 1346,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3116, 3217, 2741,   37,  335,   98, 3334,  176,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111, 1107, 2633,  190,   52,    1, 1387, 1890,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,  442,    1, 1353, 1114,   32,  871,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2369,  861,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1056,    1, 1021, 2633,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 1585,   32, 1619, 2597,  947,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2620, 1118,  698,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  166,  550, 1081,   12, 2823,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3380, 1921,   32,  215,    9,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   45,  507,   37,  508,   79,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  683,   37,  907, 3333,    9, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3094, 2572,   32,  531,  555,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3176,  298,   37,  449, 2085,  754, 3116,  922, 2712,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2147,   32, 2573,  456,    1, 1010,  861, 1665,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  715,  851, 1478,   32,    1,  548,\n",
      "         2393,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739, 3224, 1061,  548,    1,    1, 1159, 1544,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2, 326,  37,   1, 815,  45,   1,  32, 395,   1,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 411,   1,   9,   1, 389,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1022,    1, 3272,  590,    1,  584,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  384, 1033,    1,   98,  404,  540,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1640, 2774,  650,   12,  924,    1,  412,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,    1, 1720,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  112,  830,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,   12, 1861, 1484,    9,  342,   23,    9, 2170, 3279,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 2674, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968,    1,  395,  187,  218,  954, 1733,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,  626,    1,  216,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3376, 2884,    9, 3338, 1428, 1149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  779, 2815,    1, 1228,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3216,    1, 3260, 1343,    9, 1460, 1090,  140,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  340,  636,  288,    9,  848, 1675,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1138,    6, 2073, 1023,  197,  570,  187,  408,   71,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  854, 2162, 1950,  418,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  200,  645,   98, 1220,  275,  656,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,  580, 1797,    1,   32, 2254,   12, 2255,  149,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1517,   12, 2925,    1,  191,  166,    1, 2122,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,  449,    1, 1918,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545, 2243,    1,  331,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3375,  774,  166,  627,    1,   98,  741,    1, 3101,  522,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 2699, 1960,  166,  629,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  947,  489,  770,   45,  901,    1, 1178,    1,    1,  384,    1,\n",
      "            1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2072, 2855, 1915,  315,    1, 1018,    1, 1549,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,  530,  105,  106,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2411,   37, 1334,   98, 1346,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  765,  115,  220, 2972,  704,  551,  705, 1896,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   74,  395,    1,  548,    1,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 3098, 2373,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,  163,    1,   12,    1,   22,  477, 2414, 1056,   32,  531,\n",
      "           12, 3391,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  137, 1937,  567,  408,  187,  845,  187,  131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3048, 2923,  906,   37,  606, 2613,    1, 2074,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   93, 1380,  395,   32,  105, 1021,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  964, 2386,  163,    1,   12,    1,   45, 1427, 2146,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3231, 1508,    1,    9, 1056,  388,  537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2470,  267,    1, 1209,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  365, 1428, 3146,   98, 3369,  297, 3118,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101, 3057,   98,    1,   45, 1686,  297,  673,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  333,  167,  245, 1632,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3180,    1,   39, 1918,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1811,  404,  302, 1458, 2193, 2390,  626, 1027,   32,  864,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,  162,  673,  659,   45, 1778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  200,    1,    1,    1,    1,  234,  182,  235,    1,    1,\n",
      "            1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1100,   37,    1,  810,    1, 1069,   37,    1,    1,  226,   32,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2944, 1760,    1,  129,    1,  105,  223,  629,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   16, 2895, 2177,    1,    9,  363, 2966,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3261, 2352, 2500, 2485,  193,    1,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  565,  410,   98,  417,   14,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  488,  909,  444, 3369,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  341,    1,   39,    1,  827, 2615, 1675,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1654,  310, 3329, 1343,   79,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  195,    1, 1961,  191,  790,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3045,    1, 1619, 2597,    1, 1530,   32,  120,   45, 2292,   32,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    4,   37,    1,    1,    1, 3011,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,  267,  397,  522,  193, 2260,   37,  104,  863,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2786, 2987,  861, 2762, 1554, 1778, 2264,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095, 1042,  829,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3190,  313,   37,  439,  220, 1002, 2027,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1435,  220,  166,    1, 1938,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  102, 1253,   32, 1352,  191,    1,  118,    1, 2084, 1124,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  557,  540, 2774,  475, 2166,    1,  443, 2281,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 1536,    9, 2240,  467,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 2729, 2548,    1, 2572,  191,    1,   27, 2735,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  187, 2105,  168,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3003, 1536,    1,  767,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  709, 1361,    1,  291, 1682,    1, 1222, 1597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   68,   69,  102,  442, 1315,  105,  106,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2708,    1,    1, 3358, 2312,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3228,  750, 2853,   28,   37, 2788,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  472, 2025,    1,  744, 2990, 1979,   32,    1,  593,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  756,  757,  313,    9,  112,   17,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1963,  267, 3358,    1,  166,  916,    9, 2024,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3378,   12,  776, 2361,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3139,  140,  581, 3126,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260, 1045,  640,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1847,  166, 2277,   98, 1658, 1084,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  691, 2290,  365, 2036,  191,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1,  344, 2950, 1260,  538,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267, 1933,   76,   37,  912,  467, 1970,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3079,  720, 1524,   73,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398, 1550, 1100,  412,   37,  657, 2417,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3282, 3253,  614, 1632,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12, 3332,   12,   74,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,    1,    1,  912,  987, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1484,  927,   45, 1404,    1,   12,  225,    1,  792,    1,  792,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1024,   12,    1, 1777, 2739, 1401,  163,    1,   12,    1,  608,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1048, 1049, 2489,    1,   32,    1, 1523,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1629,  105,    1, 1345,  926,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3296, 2192, 3277, 1856,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1308,   32, 2941,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1062,    1, 2559,  166,    1,    9, 1832,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2226,    1,  182,    1,  331,    1,   12, 1913,  401,  197, 1249,\n",
      "         1721,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1,  121,  498,   37,    1,    1, 2471,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3358,   12,    1,    1, 1983, 2078,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 1648,    9,    1, 2382,   32, 3015,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1199,    1, 1167,  321, 1171,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2102,  920,    1, 2464, 1197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977,   37, 2564,    1,   95, 1411, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1436, 1002, 1380,   10, 1394,  115,   45, 2275,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  741, 1408, 1430,   98, 2041,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2151,  531,   12,  403,   69,  532,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 859,  37, 221,  50,  37, 273,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 104,  51,  81,   1,   1, 671,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2706,    1, 2718, 1787, 1443,   37,  105, 1463,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  232, 1708, 1268,   32, 3343, 2823, 1002,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,   28,    1,  307,  739,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  606,  590, 2047,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  559,  854,   37,    1, 1918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783,   42,   24, 2096,  220,  163,    1, 2196,    1,   12,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1065, 1190,  884,  631,   32,    1,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  811, 1666,  247, 2237,   37,  121,  297, 3102, 1512,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1247,  952,   37,  288, 1016, 2521,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,  552,  919, 1206,    1,  604,  731,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1488,  582, 1987, 1463,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   57,  809,    1,  187,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2246, 3152,  186,  857,  220, 2967,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 1447, 1082,  104,   37,  973,    9, 2108,   46,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1583,    1,  344, 1260,  176,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1817,    1, 1082,  365,    1,  187,  510,  431,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   81,  384,  166, 1530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1,    8,  304,   45, 3348, 1450,   32,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  428,    1,  190, 1073,   85,  548,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  591, 2640,   61,   98,  453,  454,   37, 1821, 2190,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  651, 1031,  488,  395, 1011, 1069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  140, 2161,   12,    1,  331,  671,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  105, 1567,   61,    1,    1,  579,   12, 1411,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,  688, 2846,  176, 1691,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   37, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106,  200, 1013, 1228,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2985,  167,   52,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,  267,  190,  588, 3057,  220, 1016,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1686,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,  641,   48,   32,  463, 1447,   12,  116, 1611,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2755, 1306,    1, 1249,  903,    1, 1739,   32,  365, 1546, 2771,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   89, 1082,  658,   93,   32,  346,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861,  475,   12, 1470,   98, 3353,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  315, 1017, 2578,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2978,    1, 2191,   51,  357, 1452, 2248,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1086,  164,  165,  776, 1261,  175,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676,    1, 1867, 1894,    9,  229,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   36,  469,   37,  221,  967, 2558,    1,  506,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160,  623,   93,  921, 2227,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612,    1,  166, 2308,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   79,    1, 1787, 3000,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   26, 1039, 1564,  544,  460,    1, 1872, 1610,  918,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178, 1009, 1484,    9,  522,   98, 2095,    1,    1,  446,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 2137,   10,  187,    1,  115,   45, 2823, 1002,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12,  116, 2995,  162, 2632,   32,  453,  248,  777,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1739, 1024,    1,    1,  168,   39,  220,  726,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   54, 1465, 1294,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  121,   12, 1821,  639, 1579, 1663, 1821, 2190,   12, 1411,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3051, 1421,  543,   37,  439, 1183,  521,  443,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  709, 3323, 1292, 1061,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,    1,  191, 1033, 2211, 2860,    1,  108,  403, 1447,\n",
      "            1,  864,  297,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2415,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 2107,    1, 2783, 1569,   32,  103,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2999, 2194, 1708,    1,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1060, 2827,  297, 1319, 2357,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  24, 653,   9,   1,   1, 597, 654, 655,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,  115,   32,  645,  199,    1, 1002,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  231, 1292, 1681, 1090,  515, 1523, 2579,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  160,  591,  187,   69,  102,  245,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3069,    1,  498,   37,    1, 2172, 2699,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    9,  350,    1, 2244,    1,  105,   92,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  852,  176,    1,    1,  229,    1, 2387, 1160,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 2688, 1333, 1530, 1941, 1147, 3082,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2838, 2651, 2615,   32,    1, 2712,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  602,  288,   37,   38,    1, 2765, 3060,   37, 2468,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  437,    1, 1855,    1,    1,    1,    1, 2606,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  199,  260,   45,  166,  326,  327,  112, 1837,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1685, 3116,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1081,  187,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  770,   45, 1920, 1976,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3306, 2256,   12, 1242,  176,  195,  798,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  612, 1713,  166, 1107,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,  376,  636,   45,    1,   80, 1108,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  162,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1600,  261,   51,    1,    1,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2550,  782,  388, 1534,   45,  238,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,    1,  175,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3128, 2379,    1,  321,   52,  531, 2876,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1390,    1,  359,  498,   37,  365,   24,    1,  194,  138,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  701,   98,  242,   69,    1, 1099, 1453,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1870, 1774,   39,    1,    1,    1,    1,  327,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1631,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  516,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3382, 2167,  531,  890,   52,   98,  199,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  409,   25, 1374,   60,    1,  417,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3180,    1,   32, 2046,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  104, 1401,    1,   32, 3077, 3126, 1090,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1352,  793, 1225,   28,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  393,  387,    1,   72,  401,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1282, 2539,    1, 1924, 2281,   98,    1, 1722,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 786,  39,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 326, 986,  39,  32, 987,   1, 400,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1773,    1,  848, 2228,   79,   32, 2480, 1090,  218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  548,    1, 1178,  928,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3239,  619,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2614,  606,  566,   98,  166,  183, 2223,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788,   12, 1629,   21,   37, 1753,    1, 1204,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481, 2386,  957,   45,    1,  311,  317,  443,  531,  469,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1652, 2351,   37, 1496,  388,  763,   26, 1039,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   37, 2192, 3034, 1561, 1876,    1,  315,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3213,  879, 1545,   24, 2191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3068, 2767,  112,    1, 1996,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1418,  384, 2826, 1010,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,    1,  590, 1031,   32,  104, 1731,    1, 1563,  548,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  140,  449, 1056,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2144, 2711,  565,    1, 1425,  166,    1,  402,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428,  387,  120,   32, 3343,    1,  532,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 1564,  581, 2564,  176,  880,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3370,  108,   45,  388, 1450,  187, 3376, 1950,  418,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  187, 3260,  971,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1340, 1194, 2907,  873, 2094,   43,  384, 2408,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3321, 2803,    1,  444,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  665,   28,  357,  973,   79,    1,  787,    1,   90,  142,    1,\n",
      "           28,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3311, 3310, 2930,  776,  852,  288,   37,  168,  115,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1536,   59,    1, 1300, 1996,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3272,  166,  386,   78,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  268,   26,   37, 1083, 1092,  142,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1690,   74,    1, 2770,  504,  128,   32,  163,    1,   12,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  590, 1188,   37, 1083,  129,  975,  142,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 1116,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1401, 3209, 1415,   37, 1131, 1684,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3118, 3396,    1,    1,   74,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1, 3018,    1, 2334,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 2414, 1312,    1, 2766,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  211,  256,   37,  842,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,  166,  163,    1,   12,    1,    1,  105,  183,  448,  361,\n",
      "         1298,  199,   37,   18,   81,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2774,  650, 1905,    9,  776,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 1118,  231,   45,   49,    1,  728,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  848,   37, 1876, 1234,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,  100,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056, 1855, 3365, 1683,   32,  531,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  862,  162,    1, 1140,    1, 2753,  449, 2925,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,  449,    1, 1151,  250, 2055, 1069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2031, 2032,  822,  408,  187,  390, 1687,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2857,    1,    1,  220,  105,    1, 2250,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2476,  565,    1,  220, 1117, 2208,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1782,   37, 2295,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3207,  162,   37,   77,  671, 3126,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2621,  729, 1533, 1979,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2815, 2208, 1294,  533,   51,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361,  967,  453,  582,   32,  166, 2599,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800,  872, 2934,   37, 2277,  220,  183,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   39,  384,  342, 1984,  260,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2500, 2946, 1696,   37, 1844,    1, 2700,  774,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1583,    1,   32, 1119,    1,  190,  138,  352,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  511,  951,    1, 3297,  105, 1090,  220,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2934,   37,    1,    1,   55,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3167,  810, 3009,  186,  608,  455,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1100, 1604,   37,    1,  769,  327,  593,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2887, 1523,   32, 1081,   12,    1, 2414, 1700, 1791, 2751,  622,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2263, 1391, 1755,   45, 2892,   45, 3362,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2206, 2207, 3183,  588,   37,    1,    1,  910,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  684,  102,    1,   63,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1, 1661,  197,  407,    1,  779,  157,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1435, 1087, 1310,    1,   37, 1250, 2261,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  774,  104,    1, 1563,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428,    1,  917,   37,    1, 2165,   32,  864, 3399,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  382, 2514, 2226,  753,   37,  764,  364,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  733,    1,  159, 1159,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105, 2494,   18, 2848,    1,  267, 3124,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2278, 1353,    1, 2575,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,    1,   98,  531, 2128,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 2429,   37, 1465,  725,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1,  325, 2215, 1013,  700,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  196,  387,  170,  745,  530,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2604, 1294, 2050,  105,  365, 1470,   45,  579,   12,   39, 1221,\n",
      "         1821,    1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   39,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  984,  238,    1,   98,  657,   12, 2894,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,  974,  365, 1173,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 3345,  240, 3082, 2434,  693,  751,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  290,  782,  590, 2210,    1,   32,    1, 3372, 1251,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1345,    1,   32,  531,   12, 2774, 2827,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2628,  436, 1262,  220,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2518,  427,  297,    9, 3282, 1740,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1316,  507,    1,  340,  361, 1121,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 3027, 2421, 3012,    1,    1,   45, 2604,    1, 2809,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   96,  537, 1691,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2888, 1631, 1159,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1790,  353, 1520,   71,   32,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821,   95, 2193, 1185,    1,    9, 2977,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1, 853,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 777,   1, 917,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  245,   98,   69,    1, 1151,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428,    1, 1203,    1,    9,  247,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   33,    1,  361,    1,    9,    1,  872, 1614,  361,  427,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,  455,    1,  520,  333,   45, 1796,  124,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1162,   32,  437,   11,  691,  965,    9,    1,  182,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1216, 1610,   47,   79,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1789, 1002,  354,   66,    1,  395,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3294,   12,  132,    1, 1229,  763, 2740,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  258, 1612,    1,    1,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,   37,  693,    1, 2549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  977,    1,    1,  875,  134,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2605, 1195,   46,  220,  864,   37, 1911, 1428,  909,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3190, 2126,  590,    1, 3089,  188,   39,   45,  103,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,  162, 2102,    1,  942,   61, 1411,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,   12, 2161,    1,  726,    1, 3126, 2116,  744,  119,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2685,  664,    1,   32, 2498,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  381,    1,  103,    1, 1969,  455, 1446,  287,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3140,  213,   37,    1,  531, 2735,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1350,  991,  613,  170, 2552,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3117,  664, 1114,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2705,   32,  531,  103,    1,    1, 1527,\n",
      "         1900,  661, 2022,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1774,   39,  340, 1251, 3044, 2168,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3262,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,  441,   37, 1155,    1,    9, 2977,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1191,    1,  500, 1421,    1,   98, 1220,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2202,  361, 2257, 3132,   37, 1918,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  845, 2393,    9, 3363,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2045, 1883, 1633,   37,  151,    1, 1501,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,  647,   37,  865, 2552,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  542, 2595,  544,    1,  166, 1833,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3132,    1, 1625,   98, 1247,  865,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 1133,   46,  187,  304,  868, 1348,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3256, 2139,   85,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974,  786,   85,    1,  786,   37,  168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2591,   32, 2823,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  777, 2454,  729,   26,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  632, 2924, 2856, 2751,   32, 3367, 2456,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993, 1781, 3056,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2680,    1,   28,    1,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,   37,  335,  581, 1173,  176,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788, 2615,  872,  420,  385,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2594,  490,   37,    1,  631,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,  267,  792,  334, 1445,    1,  792,   37,  758,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1559,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   28,  733,  861,  280,   37,  324,  437,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3365,    1,  191, 3157,  187, 1428, 1082, 1698,  927,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2864, 1194, 1856,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1582, 1080,    1,  176,  131,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  741,   32, 2823,  863,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1,   37, 1198, 2108, 3368,   98,  976,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,  476,   37, 2394,  460,  967,  590, 2673,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  625,  700, 1373,   37,  138,    1,  331,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  191,    1,   28,   37, 2834,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,   69,  393, 2774,   32, 1194,    1, 2024,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  770,    1, 1796,    1, 1976,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1702, 2264,   37, 2432,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  584, 2911,   51,  606,    1,  199,   37,    1, 1411,  104, 1009,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  156, 2393,  780,   12, 1022,    1,  356,  452,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  121,    1, 1359,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1412,    1,    1, 1465,    1, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3245, 1041, 2196,    9,    1,  427,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  822,    1,  898,   85,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3168, 1249,    1,   32,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,   46,   28, 2255,  801, 3004,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  317,  197,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1119,  297, 1188,    9,  846,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  156,   93,  953,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12, 1352, 1068,  568,   28,    1,  118,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  342, 1564, 2069, 2390,  693,   37,  864, 2283, 3399,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  938, 1075,   18,  680, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3066, 1542,   37,    1,  311,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,  166,  862,    1, 1308,    1, 1487,   79,  361, 1568,    1,\n",
      "          407,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   22,  942,  225,    1,   98,  231,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2183,  649,  650,   37, 2237,  903,    1, 1447, 1411, 1034,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  873, 2415,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,   37, 1000, 1262,   37,    1,    1,  917,   37,\n",
      "          804,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3317, 2810,    9, 2741,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,  108,   45,  143,   15,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 328, 409,  25, 410, 411,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1,  32,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,  829,  872,   37,    1, 1412,  754,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  166, 1569,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3369,    1, 2751,  759, 3118,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  267, 1625,  903,    1, 1447, 2673,   46,   37, 1348,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2315, 2755, 2225,   45, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1841,   45, 3347, 2827,   32,  531, 1816, 2069, 1377,    9,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  327, 2051, 1089,    1, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3172, 1090, 1829,  316,  176, 2755,  878,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 1610, 2494,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   92,   37,  649,    1,   50, 2013,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  520,    1,   39,   45, 2708,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1861,  580, 1450,   98,  810,    1,  176, 2789, 1929,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564, 1354,   45,  247,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3360,  288,   37,  698,    1, 2591,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  865,   37, 1019, 1617,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1230,    1,  328, 1631,  311,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,  14,  15,  85, 442, 910,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1, 498,  98,   1,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  732,    1,    1,  214,  943,  220,   35,  987,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  912, 2852,  664,    1, 1942,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,    1,   39,   45, 3201,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1900, 1140,    9,  596, 1793,  674,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1803,  187, 1711,    1, 3358,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  286,  287,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  267,    1, 1258,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741, 1536, 2118,   98,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3319,  442, 1183,    9,   51,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3334,    1, 2018,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,    1,   45,    1,  537,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,    1,   37,  166, 2860,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3322,  167, 1046,  105, 2848, 1463,   45, 1565,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3060, 1877,   37,  856,    1,  361,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,   12,    1,    1,   37,   52, 2399,  449, 1190,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,    1,    1,  657,  246,   98,  329,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  632, 1109,  852,   37,    1,   32,  682,   32,  365,  616, 1379,\n",
      "           12,  112,  499,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1829,  890, 1000,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1046,  776,   32, 1047,  133,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1797,    1,   37, 2354,  608, 3024,  906,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  667,    1,  532,  288,   37, 1124,  118,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2424,   28,  142,   37,  151,    1, 1933, 1541,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1711, 1314,  297, 3339,  489,   39,  315,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  193,  603,   85,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1166,    1,  260,  738,    1,  227,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 2587,    1, 2465,  297, 3144,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2018,  361,  854,   37, 1348,    1,   98, 1815,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3084,    1,    1,   12,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   81,  166, 2069,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2352,    1, 2735,  695,   32,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  506,    1,    9, 1227,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  778,  729,  105,  139,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  947,    1,  320, 1744, 1878,  487,    1,  298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  187,  365,  446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  167,  665, 1245,   98,  829, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1082, 3369,   37,  865, 3118, 3396,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,    1,  104,  105,  106,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2614,  565,   28,    1,   47,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  108,   45,    1, 1155,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3005,    1,  829,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  822, 1324,    1,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  593, 2933, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2483,    1,  605,  400, 1243,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   39,    9, 3250,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 305,  28,   1,  67, 423, 729,  32,   1,  88,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 397, 640, 104, 220, 909,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2511,    1, 2863,   37, 1155, 2943,  861, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1532,  388,  763,    1, 2189, 1484,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  267,    1, 3116,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232,  726, 3201,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1024,  884,    1,  363,  726,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1214,   12,    1,  948,   37,  690,  103,  455,  957,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2900,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1479, 3101,   23,  765, 1159, 2708, 1223,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,  334, 1445,  193, 1558,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1811, 1737,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1425,  166,    1,  166,    1,  565,  810,  112,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596, 1592,    1,   37,  506,  238,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  395, 1268,   28,    9, 1018,    1, 1705,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,  845, 2395, 2179,    1,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1668, 1421,    1,    1,   37,   56,  356,   24,  881,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  186,  550,    1, 2716,    9,    1,  115,   45, 2069, 2630,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  551,    1,  493,  325,   48,   32,  667,  222,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2753,   56,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,    1, 1479,  750, 1064,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3317, 1564, 3262,  319,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1454, 1645, 1322,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1364, 1365,    1,  650,    1,  220,  166,  957,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  721,  991,  166,  454,    9, 1610,  477,  191,  104,  358,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  113,  176,    1,    1,    9,  889,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2784,   37,    1,  685,    1,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  537,  611,    9, 1606, 2950,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   34,  439,  402,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1639,   66,   32, 3024,    1,   29,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,  166,  863,    7,  845,  275,    8,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  590, 2056, 2383,   32,  927,   45, 2392, 2705,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1435,    1,  476,   37, 1636,  691,   12,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2681,  716, 1328,  276,   32,  365,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,  361,    1,  271,   79,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2682,  800, 3092,  297, 3306, 1281,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2968,  287, 2668, 2197,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  203, 1183,  190,  824,   69,  915,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1852,   12,  673, 1654,    7,    1,    1,    9,  920,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  327, 1828,   71,  419,  481,   32, 1913,  401,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1718,    1, 2973, 1764,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977,  475,  939,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  301,    1,  569,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3369, 1707,  104,  134,   45, 3148,   32, 3118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,  894,  193,   52,    1,   43,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1700, 1530,   32, 3339,  399, 2625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,  104,    1, 1650,   98,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  897,  215, 1889, 1967, 2337,    1,  388,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106, 1187,  193,    1,  224,  932,   37, 2635,  365, 1279,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1848,   37,  138,  331,  599,    9,    1,  636, 1336,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1809,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2421, 1114,   32,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,  498,   37, 1442,  158,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  181,   32,   98,  129, 1684, 1090,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2977,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  626, 1353, 1159, 2642,  361,  465,    1,  220,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2890, 2826, 2250,  119,  844,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1463, 1494, 2675,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,    1,   37,  741,   32,   78,  420,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  936,    1,   45, 1102,  841,  280,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  200,  453, 1230,    1, 2913,  535,  656,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  597,    1, 2751, 1046,  449,    1,  443, 2938,  776,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 2153, 1388,  297,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1256, 1256,  696,   92,  978,  769,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  585,  245,   37,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1056, 3370,    1, 2632,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,  232,  716, 1945,   98,  242,  636,  837,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1412,    1,  810,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1269,  176,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1340,  729,   98,  429,    9, 1218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3190,    1, 3161, 2449,   32, 3278,    1,  361,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1056,  649,    1, 3340,   32, 2018,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 1461, 1462, 1463, 1464,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  105, 1054,    1,  191, 2292,    1, 1176, 1744,    1, 2705,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1857,   51,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2767,  613, 2759, 1671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1047,  256,    1,   37,  217, 1997, 1205,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  193,   37,    1,    1,    1,    7,    1, 1142,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503,  197,  338,    1,  583,  191,  749,  480,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  982, 1419,    1,  259, 1704,  196,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387,  590,  682,  384, 3371, 2237,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3095, 2572,   32,    1, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1597, 1633,   12,  478,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1585,  176, 1853, 1557, 1953, 2414,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  267,    1, 2390, 1259, 2011,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1645,  518, 1190, 1484,    9,  219,  626, 1563,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  716, 1256,  551, 1256,    1, 1026,  132,   27,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1829,   10, 2681, 1108,  729, 2919,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2224, 1500,  945,    1, 1291,   37,  327,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1751,  546,    1,   37,  335,    1,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 971,   1,   1,  37,   1,  98,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   6, 425, 426, 731,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 2096,  297,    1,  951,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2202,    1,   32,  288,  354,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2957,  353,  242,  207,  197,   32,  449, 1023,  202,  376,  570,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1013,    1,  794,  365,  777,  778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  119,  104,  442,  448,  915,  367,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   39,   45,  395,   26,   32,  449, 1385,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3096,  208,    1,  968,    1,   32,  593, 1990, 2471,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1173,  176,  163,    1,   12,    1,  622, 2705,   32,  531,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  430,  794,    1,    1,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3370,    1,   38,   32, 1855,    1,   12, 2772,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3207, 1930, 2516,  187,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,    1,  359,   18,   37, 1845,  630,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2826,  590,  117,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2449,  166, 3088,    1,   37, 2690,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  593,    1,  297, 1428,  861, 1906,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3227,  606, 1515,  454,   98, 3189,   74,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3096,    1,    1, 2828, 2857,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  214,   46,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1404,   45,  597, 1405,  475,  225,  333,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  477,    1, 2191,  365,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  742,  641,  386,   48,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375, 1343,   85, 3364, 1939,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1006,    1,  191,   94,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230,  361,  683,   37, 1292,   98, 1517,  176,  163,    1,   12,\n",
      "            1,   26,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  647,  482,  360,  148,   12,  693,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37, 2432, 1778, 2558,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  417,  408,    1,  116, 2401,   32, 1186,  506,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3193, 2107,  162,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1, 2693,    1, 1607,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230, 2668,    1,  187,  104, 1401, 2062,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  485,    1,  372,  326,  486,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147, 1800,  142,   37, 2199, 3386, 1916,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  102,    1,   32, 2163,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  451,    1,   32,    1,   81, 2275,  220,  612,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1024,    1,  835, 2241,   48,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1915, 2873,  815,   37,  120,    1,  191,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 189,  37, 125,   1,   4,  37,  92, 197,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 151,  39,  37,  52,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  251,  526,  278, 1876, 1144,    9,    1,    1, 2232,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2175, 1371, 2953,    1,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  395, 1070,  942,   37,   38,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1484,    1,   45,    1,  105,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 758,   1, 833, 612, 619, 460,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 359,   9, 104, 358, 467,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  190, 1093,  977,  335,  105,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,   78,  321,  612,    1,  207,  618,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2584,  365,    1,    1, 1542,   37,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1411,  686, 1427,    1,  286, 1500,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1227,  775,    1,    1, 1378, 2393, 2393,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1937, 1117, 2208,  187,  105,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1771,  171, 1249, 2451,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2960,  176,  539,  458,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1092,  476,    1, 1530,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3169,   32, 2033,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2703,  380,  557,  540,  528,  957,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  216, 2856,  176,  177,   32, 3339,  787,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2352,  214,  191,  386,  275,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3352, 1260,    1,  947,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,    1,   32, 1101,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,  506,    1,   45,  845, 2014, 1463,   98, 1938,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   68,   69,  176,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160,  102,  361, 2053, 2055,  120,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3267,  140,   98, 2410,   74,   45, 1742,   26,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1122,  853,  538,   37, 1174,    1,   98,  777,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  203,    1, 1532,  247, 2048,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380,  846,   28,  531, 2022,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1277,    1,  244,  720,    1,   51,    1,  571,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,  167,  271, 2213,  804,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3132,    1,    1,  361,    1,  967, 1827,    9,  273,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 1009, 1564, 2333, 1708, 2784,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1763, 2844,   32,  344, 1450,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  858, 1391,  111,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056, 3151, 2308, 1231,  220, 1809, 2162, 2429,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  763,    1, 1530,  357, 2249,   32, 2140, 2785,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  203,    1,    1, 1575,   98,  238,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1668,    1, 2469, 2681,    1,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2471,  119,  220, 1312,  103, 2954,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1380,  365, 1204, 1159,  453,  675, 1499,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3399,  163,    1,  903,    1,    1,  917,   37,    1, 2165,   32,\n",
      "          864,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885,    1,    9,    1, 1022,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  148, 1680,  142,    9,  647,   32, 2069,  693,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3274, 1564, 2315,  865,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2231,   32, 1459, 2282,  290,   61,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  778, 1976,   32, 2741,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  409,   25, 1285,   28,    1,  185,    1, 1737,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  331,    1, 2403, 2005,   85,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12,  879,    1,   12,   24,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 3030,   37,  531,  267, 3365,  565, 2793,    1,  101,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   95,  473,  619,  562,   37,  477,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  627, 2353,    9, 2333,    1, 2527,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962,    1, 1938, 2809,  696,  931,  688, 3296, 1114,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2666,  167,  843,  769,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1033, 2211, 2005,   37,  288, 2364,   98,  903,    1,  464, 2439,\n",
      "            1,  442,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 2573,   12, 3398,  952,   37, 1048, 2225,    1,    1, 1281,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,   37,  647,  720,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  732, 1085,   81,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  352,  267,  460,   51,    1,    1,   50,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 3388, 2024,  132, 1724, 2708,  232,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  420, 2508,  782,  345, 1813,  552,    1, 2936, 2909,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  857,    1, 1564, 3315,  889, 3116,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1106,    1, 2355, 1013,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  220,  282, 2367, 2695,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 1268,   98, 1220,  275,  656,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  389,    6,    1,   32, 2144,  257,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  665,   37,  166, 1463,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  561,    1,   45,  111,  161, 2607,  134,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 650,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2071, 1331,  326,    1,   37, 2728,   32, 2210, 1331, 1505,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1353, 3019, 1841,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,  104,    1,  182,    1,    1,   37,   92,  934,  518,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1,  326,  361,  766, 2704,  388,  617, 1151,  315,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  620,    1,  162, 1018,    1, 2925,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,  435,    1,    9,  163,    1,   12,    1, 3030,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3177,  261,  187, 3066,  769,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2885,   98,  103,   45,  166,  593,  548, 1062,  458,  726,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1891,    1,  517, 2153,   37,  907,   32,    1,   98,  652,   32,\n",
      "         1891,  593,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3381,  437, 2188, 1665,   37, 2856,  487, 3102,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  348,  908,  131,  752,    1, 1680,  158,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  622, 1995,   32, 3391,   61,  972,    1,  163,    1,   12,    1,\n",
      "            1,  774,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  631, 3244,   37, 1150,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  922,  366,    1,  546, 2565,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2005, 2615,  608, 2838,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,  584,   37,  496, 1080,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,    1,  872,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  443,   45,  166,    1, 1778,    1,  184,  166, 2693,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  479,    1,   34,  616,    1, 1417,  188,   98,  800,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  755,  861,    1, 1412,    1,    1, 2071, 1074,  618,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,  300,  453,    1,   37,   36,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,  218,   51, 1192,   37,  131,  191,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361, 3214,    1, 1634,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 1386,  884, 2102,    1,   37,   91,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,    1,   37, 1413, 1043, 1411,  339,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3381,    1,  535,    1, 1396, 1861,  297, 3102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2, 148, 325, 647,   9,   1, 131,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  94,  25, 186, 548, 198, 163,   1,  12,   1,  29,  88,   1,   3,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2805,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870,    1,  354,  570,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1794, 2097, 1583,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496, 2517,  389,  157, 1810,  921,   32,  104,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  352, 2415,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537, 3192,  872,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1095, 1353, 1159,  111,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  445,    1,  600,    1,   12,    1,  111,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3192,  539,    1, 2540,  463, 2170,   37,  759,    1, 3116,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    1,   45, 3180,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1528,   32,   46,   37,  151,  215, 1093,  574,   87,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2693,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2206, 2435, 1236,  829,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  856,  297,    1,  614,   37,  147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  559,    1, 1810,  547,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  893,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2161,  726,   72,    1, 3134,  671,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273, 2611,    1,  453,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1794,  132,   51, 1865,  388,  172, 2298,    9, 1783,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  396, 1861, 1769,   37,    1, 1590,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,  251, 1875, 1243,   98, 2071, 1331,  315,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,   39,   37,  837,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  520, 1119,   32,    1, 1021,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  546, 1682,  297,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  251,    1,  913,    9, 3358,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  668,  293, 1236,  388, 1935, 1151, 1091,   98, 2086,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1867,   16, 1414, 2768,  193,    1, 2343,   12,  917,   38, 1178,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2097, 2206,    1, 1022,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1492,   12,   19,    1,  460, 1240,  193,   52, 1492,  334, 2898,\n",
      "          460,   61,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3196,    1,    1,   12, 1625,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2293,    1,    9,    1, 2441,    1, 2700,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  561,  211,  225,  809,  804,    9,  257,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1020,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  531, 3382,  213,   37, 2756,    1,    1,    1,    1,   45,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947, 1360,  612,  250, 3373,    9, 2172,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1815, 2129, 1658, 1944,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3383, 3279,    1, 1414,   32,  403,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,  213,   37,  105, 1806,   98, 2390, 1699,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 3369, 2778,  543, 2024,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3095,    1,  294,  726, 2376,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1593,    1,   27,  492,  434, 1166, 2095, 2985,    1,   28,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37, 1865,  105, 2472, 2519,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   26,  705,    1, 1417,    1,    1,    1,    1, 2147,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2805,    1, 2665,  328,   61,    1,  227,  550,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  469,    1,  140, 1990, 2107,  187,   37,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  884,  225,   45,  567,  510,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2996,    1, 2762,   32, 2580, 2851,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2308,    1,    1,    1,   39,   45,    1,   26,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  177, 2844,   32, 2817,  187, 3121,    1,  640, 2140,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1479,    1,    1,  191,  861,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3385,  475, 1625,  864,  899, 3366,  226,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1973, 1260,  852,  198,   32,  166,   22,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3300,    1,   85,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3232, 1136, 2247,   37, 2522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2483,    1,  600,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,  104,  358,  952,  474,  138,  125,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  696,    1,    1,    1,   32, 2468,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,  187,    1,   61,    1, 1159, 1033,   12, 1869,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196, 2187,   45,  176,  551,  612,  613,  140,  432,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  379, 2625,  124,    1, 2263,   32, 1090,\n",
      "         2086,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1112,  347,   98,  429,    9,  920,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 1761,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,    1,  611,  199,    9,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1796,  301,    1,   32,  367,  245,    9, 1194,  339,   32, 1559,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  645,    1, 1901,    1,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 140,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 105,   1, 220,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  361, 1361,  469,    1,   37,    1, 2532,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1229,   37,  125, 1278,    1,  243,  448,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,    1,  187,   69, 1042,   81,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  779,    1, 3011,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   25, 2035,  186,  187,   69,  102,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  365,  361, 1691, 2983,    1,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  971,    1,   28,    1,  548,    1, 1169,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 1949,  810, 1292, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,    1, 2238, 1421, 1731, 2019, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  475,    1,    9,  389,  176, 3089,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  102,    1, 1146,  106,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1252, 1310,   37,  815, 1056,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1551, 2952, 1425, 2662,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  793, 1670,  183,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  691,   12,    1,  190, 1306,  449, 1056, 1867,   45,  854, 2522,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1285,   28,   98,  275, 2054, 1986,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  515,  562,   37,  395,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  829, 1259,    1,    1, 2264,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  375, 1464,   37,  726, 3126,   32, 1183, 1253,  357, 3163,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1405,  162,  168,  115,   37,   47,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  566,  172,  330, 1085,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1937,  411,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437,  353,    1, 2382,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1942, 2198,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  260,   28,   37,  151,  159,   32,  458,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2691, 1882,   37,  151,  365,  848, 2371,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  531,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788, 3322,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 2658, 1040,  640,   81,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1733,  992,   28,   37,  335,    1,  671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   25,   71,    1,  202,   69,  490, 1114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,  515, 1721, 1011,    9, 2112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  652,   37,  261,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  216,  167,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  353, 1455,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   63,  166,  862,    1,  338,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  388, 2647,  249,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  947, 2263,   32,  111,  161, 2607, 2574,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800,  884,   98, 1754,    1,  176, 1794,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2254, 1412,    1, 1239,  658,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1110,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2151,    1, 3046,   12,  638, 1844,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999, 2257, 1994, 2819,    1, 1708,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1529,    1,    1, 1914,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   26,  417,  187,   69,  102,    1,  331,  817,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2308,  474,  759, 1845,  630,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  678, 1481,    1, 2719,   10,  384,    1,  433,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   49,  155,   69, 1482,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3238,  162, 1194,  187,  730, 2614,  688,  705, 2796,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1436,  550,  590,    1,    1,    1, 1022,    1,    1,    1,    1,\n",
      "            1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  795,  256,    1,    1,  388,  541,  384,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   22,  942,   37,  151, 1266, 1497,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  622,    1, 1485, 2664,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,  104,  498,   37,    1,   98,  365, 1461,  750,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   95,  473,  474, 1579,  477,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   94,  654,  868,  283,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129,  922, 1090, 1829, 2722, 3074,  176, 2142,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2354,    1, 2873,  884,  449, 1121,  992, 2029, 2124, 2060,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  365, 2273,   45,  104,    1,  335, 1515, 2576,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1790,  572,  156,  120,  118,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2104, 2873, 1360,  612, 1154, 3015,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1554,  730, 2614,    9,    1, 1110,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  251,    1,    9, 3149, 2751,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1077,  233, 2746,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  711,   37,  712,   82,    1,  199,  333,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  622,    1,    1,  384, 2015,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 3268,    1, 1050, 2681,    1,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  176, 1411,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,  967,    1,   86, 2304, 2416, 1260,  420,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2023,   37,  288, 1074,    1,    1, 2461,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3361, 1335,    9,  388, 1663,  764,  176,  409,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1214,   12,    1, 2317,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,   17,    1, 1612,  817,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,  12,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 978, 769,  27, 526, 727, 246,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2094,    1,   37, 1718,  260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596, 1793,    1,  878, 1393,  293,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,   12,    1, 1512,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  920, 2086, 2769,  868,    1, 2206, 2989,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1802,   25, 1269,   98, 2557,   63,  104,   67,  484,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  277,  356, 1691, 1878, 1260,   32,  632,   36,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  758, 1525,   37,  815,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3200,  913,    1,  361,    1,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3060,    1,   37,    1, 1450,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1408,  453,  661,   98,  166,  116,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3357,   37, 2192,   28, 2108,  680, 3356,  787,  469,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,    1,   61,    1,  657,  220,  105,  365, 1280,   45,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   32, 1869,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  228,  583,  187,    1,  851,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3222,    1, 1282, 1385,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1980,   37, 1599,    1, 3031,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  460,  105,    1,    9, 2894,  279,   41,  357,  193,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2335, 2572,    1, 2347,   32, 1585,   32, 1850,  854,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   14,   15,   32,  455,   16, 1595,   71,   32,  871,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  168,   98,  166,  222, 1411,  356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3140,    1,  176, 1428,    1,  267, 1094, 2072,  163,    1,   12,\n",
      "            1,  443,   98,  531,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2227,  640,  395,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  388, 1574,  763, 2383,   32, 2425,    1, 1883,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1929,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2870,   32, 1785,    1,  104,  456,    1,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2280, 2572,   32,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  326, 2914,  593,   12, 1254, 2334,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597, 1436,  710,   37,  582,  758,  535, 1131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3247, 2731,  260,  198,   32,  714,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1500,   48,   32,  141,   37,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 1739,    1,  590,    1, 1252,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3239, 2963, 1114,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2476, 1188,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3199,  181,   32,   98,  364, 2198,  901, 1394,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1284,  361, 1278,  121,    1,  220,    1,   69,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   45,    1,    1,  105, 1217,   37, 2024,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   49,   66, 1284,    1,  528,    5, 1757,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2785,  686, 2140, 1489, 3121,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2529, 3121,  640, 1796,  540,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  348,   37,   47,  118,   45, 1537,    1, 2456,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  783, 2029,  104,  225,  218,  418,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2235,  826, 1228, 1041,    9, 2587,    1, 1228,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  334, 1822,   52, 2623,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  581,  503,  195,  580,  290,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  361, 2858,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1524, 1778, 2580,    1, 1255,   61,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2465,  138,   79,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1786,   37, 1776, 2501, 2502, 2678,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2425,  835,  176,   48,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  384, 1808,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  758,   37,  151, 1412, 1107,  669,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  391,  108,  247, 2924,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1720,  443, 1675,  907, 1089, 1675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  572,  197,  490,  118,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2685, 1542,   37,  132,  810, 1444, 1188,   61,  105,  442, 2274,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  399,   32,    1,  238,  149,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3231,  726,  539,  220,  105,  857, 1938, 2809,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398, 1579,  104,  358,  394,  132,    1, 1118,  695,   98,  138,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,    1,  191,   98,  260,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  297, 2101,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  584, 2471, 1090,   32, 2513,    1,  202, 1654,   32, 1194,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,  155,    7,    1,    1,   67,  191,    1,   37,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2957, 2612, 2336, 3044,  918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   13,   45,    1, 1118, 2092, 1952,  420,    1, 1635,    1,  700,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   32,    1,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  159,  388, 1039, 2690,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 3144, 1002,  852,  972,  454,   39,   45, 1512,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  917,    1,  334,   52,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  876,  612,  200,  469,   37,    1,    1, 1506,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  810,  809,   26,    9,  107, 1953,  864,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 2596, 2414,  176,  177,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3151,    1,  390,    1,  994,  267,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   71,    1,    1,   71,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2162, 1950,   32,  455, 3121,    1,  729, 2249,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713, 2701,   12, 1509,   32, 2158,   45, 2121,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1474,  703,  412,   37,  777,  778,    9, 2311, 2911,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2469,  917,    1, 1240,   52, 1991,   32, 1415,  808,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2313,   12, 1567,  515,  163,    1,   12,    1, 1333,  176, 3096,\n",
      "          671,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2408, 2165, 2438,  220,  943,   45, 2528, 1542, 1230,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  388,    1, 2111,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1294,    1,   28,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2, 104, 954, 641,   1, 118,  32,  72, 401,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 920, 579,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  517, 2860,  498,   98,  531,  734,\n",
      "          591,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1310,   37,    1, 2288,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  403, 1447,    1,   46,   98, 2673, 2108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,  681, 1776, 1089, 1994, 2086, 1017,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1509, 1090,   32, 1223,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,   60,  953,  444,  166, 1547,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1187,  460,  810,    9, 3218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   63,    1,    1, 1203,  617,  259, 1871,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  169, 1332,    1, 1690,  525,   15,  530, 1944,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2678, 1396,  365, 2842,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1110, 3252,  580, 2084, 1090,   45, 2318,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314,   12,    1,   45,    1, 1924,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  736,    1,  297, 1361,   26, 1039,  315,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2448,  386, 2151,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  647, 1702, 1901,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2698,   45,  425,  426,    1, 2192,   28,  663,   37, 2225,    1,\n",
      "          548, 1922,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1061,   32, 3043,  722,   37, 1260, 1147, 1065, 1190,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1928, 1082,    1,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  597, 1304,  710,    1, 2158,   37, 1335,  514,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213, 1484,    9,  838,   98, 1178,  163,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1448,  633,    1,    1,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2725, 1463,   32, 1674,  400,    1,  105, 1239, 2498,   45,    1,\n",
      "           41,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2476,  726,  671,  176,  593, 2501, 1675,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006,  949, 3365,   32,  121,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  691,   12,   12,  551,  552,    1,  948,    1,    1,  191,    1,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1290,  396,   71, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1879, 2035, 2125,    1,   12,  132,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,    1,  224,    1,   37,  777,  778,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3320,  190, 1734,  191,    1,    1,    1,  267,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128, 1936, 1003,  176, 1230, 2543,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,  396, 1428, 1876,    9,    1, 2343,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 1228,  293,    1, 2293,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2335, 2496, 1976,   27, 1951,  787,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  560, 1274,  176,  339,  845,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1812,    1,   12,  887,   45, 2628, 1021,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273, 3241,  872,  420, 1657,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  490,   37,  119,    1,    1,  105,  106,    1,   98,  109,\n",
      "         1057,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 1654,    1, 2591,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1764, 1990,  104,  631, 2062,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1, 1774,   39,  445,    1, 2366,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 396, 453, 142, 242, 763, 848,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 593, 420,  30,   1, 270, 724, 428,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  766,   37,   92, 1101, 1151,  568,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,    1, 3217, 2677,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  987,    1,    1,  105, 1488, 1204,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91, 2055,  365,  829,  927,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3296, 1289, 1056,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885,    1,   32,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   61, 2159,   12,  270,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  217,  167,    1,  133,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  303,    1,    1,   37,  686,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1141,  202,    1,  631,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,  359, 1195, 1903,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3045, 1152, 3361,   37, 1334,  754,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  275, 1110,   81,    1,    9,  777, 1085,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2563,  103, 2551,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1412, 2382,  775,  176,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  444,    1,    1,    1,  847,   28,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1292,  493, 1974,    1,   37,   50,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  275, 1523,   37,  674,  116,    1, 1618,   28,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,   27,  687,   98, 2308,   29,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2548, 2572,   32,  531,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,    9, 1178,  386,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,    9,  163,    1,   12,    1, 2841, 1984,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2528, 1230,   32,  199,    9, 1104,    1,  178,  774,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  126,    1,  598,   45,    1,    1,   79,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  121,  292,  315,    9, 1461, 1294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1551,    1,  124,  565,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  803,    1,  515, 3024,  453,    1,    1, 1724,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 2420,  627,  176, 2683, 1320,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  321,   52,  227,    9,  112,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  154,  321, 1504,    1,    1, 1211,   45,   44,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1965,  839,   37,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1963,   37,  865,   37, 1708, 2290, 1602,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   51, 2010,  649, 1196,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,   28,  548, 1721, 1083,  837,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1043,   28,  176,    1,    1, 1572,  191,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2702,  298,   32, 2741, 2414, 1700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2974, 1478,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,   98,  342,  104,   22,    1, 1559,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  176,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485,    1,    1,   98,  754, 1434,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2427,   37,  335,   98,  492,   32, 2701, 3179,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  635,   12,    8,  365,  244,  304,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3192, 2427, 1075,  854, 1150,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  438, 1063, 1064,   37, 1065,   12,  142,    9,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2142, 1022,    1, 1361,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1666,  385,    1,   16,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  548, 2756,    1, 3356,  852,   37,  890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  917, 2043,    9, 1116,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1861, 1454,  443,    1, 1082, 1016,   37,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2466, 1209,    1,  388,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1481,    1,  435,  142,   37,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,    1,  359, 1195,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  614,  548,    1,  220,    1, 2168, 3004,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,    1,  220,  197,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  286,  287,    1,   37, 1186,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  395, 3109,    1,    1, 2500,  663,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2068,    1,  204,    1, 1590,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  936,  315,   37,  125,    1,    4,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2596,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1122, 2243, 2480,  853,  538,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  463, 2571,  671, 1900,  697,    9,  170,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    6,  570,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  403,  464,  232,    1,  476,   37, 1348, 2673,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  166, 1746,    9, 1178,    1,  163,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,  193,  166,  449,   37,  168,  492,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1,  191,    1, 1593,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1249,  572,  308,  207,  174,   28,  118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1056,  384, 2347, 1638,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  187, 3144,    1, 1002, 1578,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,  845,  626,  408,    1, 1278,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2157,    1,    1,  302,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2389,    9,    1, 1601,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3167, 2110,    1, 2295, 3117,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2807,    1,    1,    1, 3103,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2578,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3261, 1268,  549,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2275, 1708, 1472,  661,   98, 1771, 1655,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  437, 1249,  191,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2450,   37,   52,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2945,  326,   12,  978, 2953, 1007, 2334,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2800, 2671,    1,  571,   37, 2028,    9,  195,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   70,    1, 1425,  813,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2004,  647,  879, 1889,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  256,    1, 1228,   37,    1, 3004,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2885,   37, 1046, 3286,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2692, 2690,    1,   37,  116,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,  776,    1,  648,    1,   37, 1721,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3342, 1877,   37, 1377,  147, 1250,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3024,   12,  105,  311,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1056,  104,    1,    1, 1758,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1555,    9,  166,  183,  786,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  489,   39,   45, 3116, 3217,   32, 2018,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  320,    1, 2998,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  776, 1380,    1,   32,  166, 1381,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,    1, 2081,  297, 3306,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  741,    9,    1,  361,    1, 2080, 2757,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   37, 2677,  365, 1013, 1522,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1039, 1662,  293,    1, 1465, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  344, 3403, 2414,   32, 3354, 3392,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  211,  164,  165, 1828,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  534,   12,    1,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  227,    1,    1,   76, 2697,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1877,   37,  865,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  348,  315,  333,   45,    1,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,  852,    9,  236,  237, 2457,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,    1, 2863,  149,  951,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1095,  738,  308,  187,  244, 1253,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  560, 1274,  245,    1,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 202,  32,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 567, 510,   1, 436,  45,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1723,   37, 1982, 1623,   45, 1405,    1,  424, 1034,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1082,  864,   37,    1, 1428, 2673, 1806, 1220,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,    1,   98,  485,    1,    1,   69,  716,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1584,   12,  943,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 2432,   37, 2324,  861, 2558,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2493,  460,   12, 1479,  922,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  397,  261,  444,  104,    1, 1281,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3075, 2237, 1554,    1,  220,    1,  448,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102, 1285,  242,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1298,    1,    9, 2504, 2751,  297, 1088, 2735,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963, 1340,  504,  677,   69,  102,   51, 1598,  996,   93,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  572,  105,    1,    1,    1,    1,    1,   98,    1, 1901,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2045,  224,  733,    1,   59,  159,  176, 2021,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1243,   45,  131,    1,  104,  626,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3266, 2277,    1, 1073,   39,   32, 1690,   74,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  395, 1273, 1974,    1, 1273, 1085,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233,    1, 1604, 2180, 1064,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  249,  361, 2325,  203,   37,  726,  166,    1,  741,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2563,    1, 1445, 2803, 3265,   32, 2760,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  336,    1, 1159,  395, 2203,    1, 1530,    1, 2249,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   22,   23,  794,  105,    1,  853,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3330,  696, 3260,  335, 2522,  631,  297, 3209,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   12, 1140,    9,   46,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3092,  519, 1982,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284,  856, 1123,    5,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2213,  171, 3331,  872,  420, 1657,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  919, 1212,  297,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  220, 2615, 1919,    1, 2268, 2614,  661,  807,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1345,  166,  624,    1,  721,    1, 1452,  220,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,  123,   85,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1404, 1550,    1,   45,  126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,    1, 1100,  769,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1396,  845,    1, 2355,    1, 3004,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1430,  446,  939,    1,  267,  190,  193,  582,  365, 1386,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  921,    1,   37,  726,  176,  395,   26,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1127,    1,    1,   98,    1,   80,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  242,   69,  102,  576,  374, 1315,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,   60,    1,  769,   37,  817,   98,  236, 1022,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3296,    1, 3319,   39,   45, 1264,  841,  631,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2116, 1251,   45,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  622, 1008,  388,    1,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1548,    1,  479,  480,  297,   59,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  447,    1,   32,  531,  734, 1523,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1354,    1,    1,   37, 1561,   28, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  794,    1,  444, 2433, 2005,    9, 3051,    1,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1360,  612,  423,  286,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1215,  477, 1757,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  108, 1448,   37,    1,  244,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1191,    1,    1,   37, 1910,    1,  700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187,    1, 1636,    1, 3132, 1173,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  994,  536,  938,  163, 1230,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  542, 2889,  548,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    6,    1,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   72,  104, 3160, 2572,   32, 3343, 3279,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  746, 1713,  166,   80, 2789,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925,  365, 1546,    1, 1022,    1, 2296, 2138,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1546,    1,  590,    1, 1041,  191, 2925,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2705,  529, 2292,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3284,    1,   37, 1306,  176,  177, 1056, 2119,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2673,    1,    1,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,  637,    1, 2417,   45, 1839,    1,   37, 1428,  475,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403, 1447,  733, 1011, 1527,   98,  258,  218,  463,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3028,   12,    1,  536,  365, 2995, 1681,  115,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  590,  132, 1724,   37, 2565, 2584,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3235, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2414,   32, 1789,  548, 3121,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2882,    1,  796,  548,  777, 2429,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1827,  176, 3127,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,  267,  645,  647,  142,   61, 2069,  693,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2942,  267, 2602,  548,    1, 1027,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2347,    1,   51,  193, 1343,   32, 3096, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  597, 2548,  582,    9, 1633,   32,    1,  220,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2551,  860,   37,   98,  166, 2041,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,   27, 2498,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158,  716,  601,  401,  932,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018,    1,  988, 1167,  167,  525,  166,  974,    1,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  619,  105,    1,    1,    9,  415,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  441, 1152,   45,  365,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,  631, 2193, 3093, 1287,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3382,  580,  241,   44,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1484,   79, 1539,   45,  938, 2454,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1853,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2437,  548, 1987,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  507,  539,  958, 1184,   32, 1933,  295,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3152,  563, 3218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,   96,   85,  148,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2374,  550,   98, 2125,  187,  241,    1,    1,   98,   10,  420,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1479,  215,  506,  387, 1298,    1,   32,    1,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   75,  267,  104, 1284,  453,  858,  100, 2444,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2268, 3081, 1924,    1,  105,    1,  267,  398,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,  166,  865,   45,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2149,    1, 2886,  696,    1, 1154,  166,   74,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1991,   37, 1171,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2373, 2627, 2177,  988, 1027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3029,   32, 2818,    1,    9, 2875,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  444, 1658, 1678,    1, 3122, 1592,  361,    1,   32,  424,\n",
      "         2193, 2800,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2786, 2558,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,   32, 1881,   45, 1700,  339,  687,  951, 1547,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  992,   28, 1934,  909,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101,   22,  477, 2414, 3006,  176, 2095, 2172, 2498,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1711,   45, 3101,    1,  186,  444, 3359,   12,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2800, 1178, 1179,  688, 3262,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 1763, 2572,   32, 1585,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  649, 2404,    1,    1, 1898,  220,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3086,  361, 3114, 2153,   37,  907,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,  640, 2275,   32,  736, 1376,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2681,    1,    1,   37,   10,   12, 2742,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1095,    1, 2183, 1499,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2476,  105,  784,    1,    1,  445,    1,    1,  420,  267,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,   61,    1, 2798, 2657, 2549, 2750, 3004,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643, 1644, 1380,   79,    1,  837,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1497,  606,    1,    1,    1,  202,  590, 2613, 2259,    9, 3250,\n",
      "         1751,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116, 2542,   12,  729, 1797,  332, 1408,  383,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   12,  551,  552,  376,  748,   98,  747,    1,  746,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,   12,    1,   46,  600,   26, 1039,    1,  829,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  167,  606,  105,  913, 1120,    1,  548,  810,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3021,    1,   37,   77,  671, 3126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3086, 2128,    1, 2134, 3114,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    1,    1, 2228,   79,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1050,  650,  580,    1,   98, 2702, 3389,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,    1,   37,  634,  698,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  166,    1,  166,  471,  433,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220, 1011,  340,    1, 1821, 2640, 1822,  125,   81,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3356,  213,   37, 2024,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2113, 1204,  286,    9, 2024,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1035,   12, 1521,    1,   51,   52,  105,  227, 1265,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   66,  526,  187,  189,  361,   69,  817,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2309,  252,    1,  199,  594,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2960,  167,  211, 1411, 3029, 1539,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  245,   98,    1,  331,  932,    1,   69,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1993,   64,   32, 1090,  786,   45,    1, 3179,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  433, 2104,  933, 3172,   12,  909,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,    1,  582,    9, 3184,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  191,    1,  700,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3319,  132,    9,  105, 1740,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2947, 2819,    1,   12,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  293, 1360,  612,  856,    1,  261,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1645, 3160,  488,   37, 1641,   28, 1583, 3373,  757,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962,    1, 1520,  187, 1110, 1334,   32, 2107,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 2861,    9, 1684,  187,    1,  744, 1224,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  934,   30, 1677,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1815, 2389,    1,   98, 2018, 2678,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  842,   12,    1,  162,  104,  432,    9,  365,  815,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,  420,  310,  770, 1976,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2808, 2539,    1, 3038, 2539,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094, 1004,  163,    1,  903,    1,  927, 3339, 1662,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968, 2424,  467,  652,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  964,  267,  121, 2567,   98,  365, 2673,  675,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492,    1,    1, 3348, 1665,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  190,  388, 1021,    9,  993,  475, 1719, 1488,  932,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,    1, 1176, 1533,   98, 3144,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  885,   74,    1,  852,  115,   37,  166, 2107,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192, 2741, 2308,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  584,  765,   28,  754, 1090,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2206, 2435, 1149,  477,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3079, 2934,   37,  271, 1632,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2957,    1, 1097,  548, 3087,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3083,  103, 3268,    9,  449,  726,   45,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1, 1125,   98, 2355, 1560,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  632,   25,  664,  131,   32,  265,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,   32, 1013,   45,  166,  792,  917,  636,  792,    9,   69,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2807, 3103, 1090,    1,   28, 2074,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2335, 2837, 2536, 1530,   32,    1, 2565,  298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  928,   32,  306,  851,  298,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1313,   32, 1815,  297, 1791, 2930,   45, 3065,    1, 2804,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3021,   37,  792,    1,  361,    1,  792,  247, 1477, 1990,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3128,   32,  531,  966, 2118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,   37,   26, 2753,   45,  124,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  390,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1713, 3262,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796, 3009,  688, 3330,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  683,  476,   37,    1,  166, 3103,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  580, 3308,  290,  297,    1, 1898,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1718,    1,    1,    1,   37,  829, 3042,  161,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 3095,    1,  547, 3375, 2572,   32, 3339, 1388,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1554,  548, 2316,    1, 2907, 2007,   37,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,    1,  359,    1,  498,   98,    1,    6,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2517,  952,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  631,    1, 1779,    1,    1, 1312,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3013, 3268,  872,  420, 1169,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  256, 1089,   37,    1, 2750,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2306,  288,    9,  667,  863,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  915,  356,   45,  164,  165, 2298,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  148, 1008, 2855,    9,  647,  721,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   95,    1, 2767, 2978,    9,  449,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 2826, 2841, 2226, 3046,  168,    9,  671, 1411,  199,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3111,  619,  764,  384,  487, 2924,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1870,  354, 1052,   98,  242,  327,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766,  140, 3016, 1935, 1876,  384,   32, 1092,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  407,  187,   10,  431, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3219,  836,  220, 1918,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1140,  460, 1018,  411,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  571,   37, 2028,    9,  351,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,  884,  297,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1,  342, 1164,   37,  429,  981,   46,   98, 2673, 1816,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1841,    1,  300,    1,  754,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2726,    1,   37,    1,   32, 1763,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361,  852,   37, 1151, 1998,   37, 1403,    1, 1890,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3142, 2934,    1,  321,  843, 1513,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  968,  812,  121,   12, 2825,   45, 1839,  651, 1259,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,  957,   12, 1450,    1, 2751,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2483, 2561,   32,  166, 2454,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1, 1536,    9, 2240,    1, 1261, 1448,  408,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2158,  571,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12,    1, 3224, 1762,  951,    1,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1739,  275, 2934, 2457,    1,  444,  590,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1891, 2122, 2246, 1657,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  132,  190, 1403, 1588,   37,    1,  878,  778,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2226,  331, 1542,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   68,   51,  245,  187,  568,  902,  109,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2921,    1,   61,  105,  183, 1000,    9, 2700,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  405,    1,    1,  808,   45, 1663,  625,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3356, 2024,  132,  167,    1,  531,  863,  469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428,  839,  716,   45, 3147, 1450,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1431,   37,  138,   59,   37,  130,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  449,  104, 1972,   95,   37,  451,  452,  245,   45,    1,  884,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  976,   37,  138, 2372,   45, 2743,    1, 1260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  103, 3382, 1484,    9,   98,  199,  741,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1976,   32,    1,    1,  195,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1918,    1, 1147, 1414,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  365,  613,    1, 2543, 2519,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2229,    1, 2192,    1,  105,   38,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171,   45,  166, 1013, 1299,  293,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,    1, 2088, 1616,   41,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1853, 1917,  365, 2036,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2293,    1,  612,    1,    1,    1,    1, 2097,  105,   74,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  702,  349, 2420, 2139,    9, 1728, 1797,  169,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  539, 1037,    1, 3166,    1, 2365,  297, 2484,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1, 2884,  320, 1744, 2946,    1,    1,    9, 2669,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,  812, 3360,   12,  863,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  212, 1236,  441,  297, 1395,  768,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  656,   45,    1, 3200,    1,    1, 1632,  888,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,    1, 1886,   98, 2371,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  132, 1086,  104,  977,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  856, 1965,    1,  726,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  374,  162,  503,  705,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1921,   32,  121,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2,  58, 738, 572, 236, 237, 308,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 513, 193, 514, 133,   1,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1018,  662,    9,  166,    1,   37, 1523,  105,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310,    1,  219, 2153,    1,   32,  451,    9, 1952, 2396,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  316,   12,    1,    1, 2158,    1,    9, 1517,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  572,  567,  390,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  294,  922, 1090, 1829, 2184,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  531, 2155, 2752,  957,   79, 2681,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,  176,  634,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2570,  787, 3266,  872,  420,  385,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  604,  218,    1,   37,    1,  220,   65, 1986,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096, 3144,  563, 2707,   32,  593, 1990,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2620, 2150,   28,  118,   32,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2164,  967, 1711,    1,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1583, 1527,  187,  395, 2817, 2856,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 1564,  460,  220, 1660,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 3005,    1, 1074, 1225,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1957,   37, 2190,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  657, 1463, 1151,    1, 1017,   37, 1289,   37,  846,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,  166,  667,   26, 2965, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2278,  775,   29, 1499, 1228,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,  166,    1,   32,  647,    1,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  793,  293,  167,  271, 1452,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503,    1,   98,  420,  460,    1,  749,  762,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2708, 3352, 2856, 3095,   32, 3339,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492, 1048,  896,    1,    1, 2985,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1294,  167, 1343,  808,   32,    1,    1,    1, 2932,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   37, 1075,   98, 2283,    1, 1352,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,    1,   28,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1, 2434,    1,   32,    1, 2853,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  634,  220,  365, 1110, 3130,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1166,  967,  166,  938, 2032, 1345,    1, 2626,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447, 1484, 1461, 1539,  716, 1801,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1739,  275,  515,    1, 2491,  354, 2085,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1687, 1022,    1, 3008,   98,  242,    1, 2393,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1818,  147, 2008, 1994,    1,  437,  117,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755, 1441,  829, 2194,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  321, 2546, 1343,  390,    9,  504,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  213,   37,  151,    1, 2203,    9,    1,  372,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2246,    1,  361,    1, 2213,   32, 3208,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267, 2131,   93,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1307,  267, 1732,  218,   37, 1121,    1,  332,   37,   71,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885, 1067, 1123,   32,  316,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,   23,   12, 1802, 1126,   14,    1,    1, 1215,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,   12, 1093,  574,  736,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3229,    1, 1464,   37,  138,   79,    9, 3103,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1090, 1372,    9, 2975,  424,  356,  161,   82,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  247,    1, 1746,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   12, 1611,    1,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 102,  51, 168,  28,   1, 202,   1, 729, 583,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 967, 197, 361, 105,   1,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,  590, 1931,  297,  365,  477,   23,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,   57,  861,    1,  548, 2095,  937,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,  820,  384, 2611,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1693,    1, 1385,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   61, 1176,  445,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  615,   32,    1,   47,  159,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  340,    1, 1494,  176,  105,  636,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  580,  709,  872,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 155, 156, 157,   1, 158,  37,   1, 159,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  33,   1,  63, 334, 712, 105, 856,   1, 506,   1,  88,   1,   3,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3144,   12, 1557,  387, 1438,   37, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2045,    1,  167,   52,   39,    9,  914,  548,    1, 3265,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  439,  242,   63,  156,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  166,  581, 1023,    1, 1018, 2484,    1,  361, 1918,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1963, 2007,   37,   26,  247, 2641,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3261,  744,   28,    1, 1984,   37,    1,  375, 3185,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  700,   27,   98,  679,  529,  509,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2620,  980,   37,    1,  115,   45,  786,   74,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  573,  977, 1210, 1067,   32,  654,  721,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2345,  424,  427,   61,  193,    1,   39,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  314,   82,  267,  927,   27,  439,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3261,  475, 1484,   98,    1, 2458, 2446,  792,    1,  792,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   75, 1579,    1,  528,    1,  122,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  857,  914,    1, 2495, 3260, 1159, 3220,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,  693, 1778, 2580,  861, 1779,  176,  317,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  524,    1,   12,   72,  401,  197,  418,   37,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,  315,  388,    6,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 1037,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  503,    6,  388,    4,  187,  156,  276,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  765, 1415,   37,    1,  201, 1021,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 1092,    1,    1,    9,    1, 1255,    1,  176, 1209,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 2994,  729,    1,   98,  116, 2542,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   98, 2692,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  819,    1,    1,   32,  818,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  420, 1528,   27,  132,   98, 1405,  767,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,    1, 1242,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1257,  614,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2569,    1,  508,   85, 2108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1751, 2850,   37,  449,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189, 1118,  949,   45,  172,  932,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  208,  209,  231, 1961,    1,   46, 1348,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39, 2119,  220, 2961,   38,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1,    9, 1222, 2759, 1708,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,    1,    1,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1933,    1,  369,    1,  936,    1,  630,  220,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3161,    1, 2101, 1056, 1569,   32, 3278, 1002,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 1150, 1270,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  588,    1,  159,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  693,  515, 1076,   45,  671, 1078,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  794,  104,  451, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  792,    1,  792,    1,  571,   37,    1, 3096,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  418,    1,  615,  661,  685,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,  488, 1094,   98, 2673,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  768,  400, 1355,  829,   12,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1202, 2596, 3391,  187, 2751, 1523,   98,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3227,  588,  258,  804,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2582,    1,   28,   37,  544,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  641,  667,    1,  214,  142,  328,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1017,  313,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  476, 1777, 2739,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  233, 2104,   37,  741,   98, 1412,  844,  302,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1423,   32,  116, 1121,    1,    1,  774,    1, 1443,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  220,    1,    1,    1,    1, 2885,    1, 3258, 2579,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1042, 1596, 1665,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  119, 2098,    1,    1,    1,   37, 2505,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,  172,  616, 1822,   52,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1100,  846,  769,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 1530,    1, 2006, 1941,   32, 1430, 2791, 1388,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,  140,  342,  432,    9,  647,  214,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  142,  967,    1, 2012,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094, 2257,   81, 1414,   32, 1850, 3339,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  550,    1,  140,    1,    1, 3222,    1, 3270,  338,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  121, 1376,  220,   56, 1567,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2158,   45,    1,    1,  162,  915,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  459,   56,  356,  881,  220, 1668,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479, 1042,  148,  279,    1, 1294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2015,    1,  361,   22,  942,  439, 2096,  297,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2573,  147,    1, 3398,    1,  695,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  691, 2797,    9, 1926, 1927,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2748,  584,  951,    1, 2110,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1640,    1,    1, 1438,  650,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  737,  197, 1660,  157,  921, 1944,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1147, 3006, 1211,    1, 2711,  176,  915,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2909, 2856,  187, 3128, 2770,  531,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  224,   12, 1126,  636,  288,  176,   63,  714,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   43,    1,    1, 3127,  176,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  986,    1,  182,    9, 1973,  217,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,    1,  288,   37,  664,  499,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2911,    1,   39,  440, 2621, 2165,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2332, 2745,   37,  619, 1018, 1158,   32, 1515,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  626,  361,  507,   12,  627,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 1668,  872,  420, 1169,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,   32,   46,   37,   47,  280,  176,  425,  426,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2252,    1,   45,  166,  104,   60,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2046, 2404,  884, 2024, 1263,   37,    1, 3079,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  936,   51,    9, 2978,   95,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3169,  801,   37,  104,   26, 2069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,   45, 2771, 2954,    1, 2051,  763, 1023, 1515, 2308,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  729,   21,   37,  123, 1503,  214,  191,  356,  439,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,   98,  161, 2607,  134,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1919, 1527, 2664,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1454,    1,   45, 3310,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3260,  913, 2941,    1,   98,  333,  892,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1631,  187,  109,  509,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,  777, 1013, 1564,  714,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1917,    1,  829,    1,  193,  110,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1484, 2866,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1658,  454, 1632,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2980,    1,  632, 1273,  618,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  440,  550,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  446,  447,  190,    1,   37,  448,  261,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3314,  256, 2149,    1,    1, 2149,    1,    1,   37,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  802,  829,   12, 1117, 1525, 2362,  105, 2195,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2897,   32, 3349,    1, 2868,  551,    1, 2440,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 1273,  618,    1,  983,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  132,  920,  986,   79,  444, 3248,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 2558, 1976,   32,  829,  861,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  208, 2237,  190,   52,  183, 1463,    9,  365,  592,  582,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  255,  112, 1176,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3018,   12,  354,   51,   52,  284, 2264,  504,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1317,   37,  123,   28,   37,  124,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,    1, 2751, 1046,  449,    1,  443, 2938,  776,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  985,  792, 2880, 1527,  792,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  166, 2146,    1,  267, 3169,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,    1,  187,  342,  113,  700,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1292, 1681,  259,  315,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  430,  122, 1876,   69,  102,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1238,   22,   12,  207, 1249, 1721,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  986,    9, 1338,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2757,   12,    1, 2274,    1,  384, 2107,   32,  968,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2159,  936,    1,  275,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2529, 2164, 2668, 1850,  455,    1, 2070, 2734,  304,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 2409, 1976,    1,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,  102,  276,   98,    1,  889,  109,  533,    1,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  298, 2425, 1883, 2789,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  134,  597,    1,  494,  220,  133,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1727,   37,  166,    1,  593, 3144,  719, 1658, 1876,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2533,    1,  166, 1509,   45, 2487,    1,  187,  683, 1173,   37,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  733,    9,    1,  331,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3061,    1,    1, 1313,  964,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,   96,   28, 1245,   98, 2708, 3136,  477,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267, 3183, 1210,    1,   81,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2, 199,   9, 522,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  37, 508,  79,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3318,    1, 1114,    9,    1, 1291,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  987,  967,    1,    1,   32, 1922, 1827, 3265,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1230,    1,   12, 2495,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,  460,   12, 1846,  227,   37, 1847,\n",
      "          334,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  894,    1, 1384, 2409, 1481,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  576,    1,  854,    9, 1700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1964,    1,    1,    1, 1744,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,   27,  119,  340,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359,  267, 2708, 2153, 1822, 2199, 3006,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310,  159,  700,   32, 1046,   45,  845,   69,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  395, 1429, 1071,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2266, 1707, 1484,    9, 1596,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 105,   1,  98,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 707,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3330,  140,  119, 1909,    1, 1185, 1624,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2531,   37,   47, 2108,   37, 2752,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2605,    1,  335, 1477, 1990,    1, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  344,    1,  176, 3081,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1550, 2330, 1841, 1559,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,    1,    1,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3119, 2651,  729,    1,    9, 2486,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1645,    1, 2682, 1094,  297,  412,   37, 3339, 1941,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  352,  353,   59,  354,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2222,   39,   45, 1674, 1675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3188,   30,    1,    1,    1,    9, 3252, 2958,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2325,    1,  493,  529, 1523,  297,  365, 1212, 2049,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1527, 1149,    1, 1010,    1, 3118, 2292,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  273, 3241,  872,  420, 1169,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1204, 1494,   84, 1415,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  477, 1086,  176,    1, 1097,   32, 1212,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   37, 1598,   31,    1,    1,  293,    1,  446,  267,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  702,  169,  170,   51, 1403,  388,  834,  809,   37, 2517,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2249,    1, 3162,    1, 3404,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  964,  488,    1, 2095,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  584,    1,  166,    1,  415,  967,   37,  713,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1051,  675,   37,  130,  552,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390, 2660, 1737, 1346,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,   12,  446,    1,   37, 1046,   85,  531, 3102,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2967,    1,   37, 1668,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1432, 3207,   12,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1857, 1641,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3127,    1,  288,   37, 1174,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   37, 2303,   98, 2109,  548, 1275,   29,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  671,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,   37,  429, 2396,  220,   10,  176, 1319, 1320,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  393,  359,   37,  741,   98, 1715,  138,  125,  630,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3099, 1321,    1, 1942,  469,  176, 1261,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2015,  167, 1403,  802,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  365,  535, 1863, 1443, 2102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1122,  159,  245,   98, 1069,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   12,  344, 2209,   61,  483,  105, 2549,    9, 2772,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  215,   12, 1247,  267, 1221,  321,   52,  590,    1,   98,    5,\n",
      "          641,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503, 2257,  749,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1, 1411, 2367,  220, 1994, 2693,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2777,    1, 1751,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1764,  796,  187,  718, 1971, 2565,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2262,  686,  531,   12, 3391,  176,  698,   45,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1861,  571,   37,  215,    9, 3025,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  590, 1534,   37,   81,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   75,    1,  365, 1074, 2285,  261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111, 1013,    1,   61,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  395, 2003, 1585, 2414,  176,  177,    1, 2249,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  262,  263,    1,   81,  187,  197,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,  140,  917,   37,    1,  413, 1160,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  225,  218,  186,    1,  191, 1507,   69,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  649,  116, 2678,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2459, 1766, 1767,  315,  221, 1836,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  954,   14,   15,   71, 1913,  339,   32, 1169,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481, 1349,  459,   59,  132,  220, 1170,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,   32,  112,  548,    1, 2751, 1198, 2782,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,    1, 1527,  655,  162,  356,  611, 2113,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1411,    1,  915,    9, 1056,    1,   32,  299,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  691,   12,    1,  459,  395,    1,  437,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1138,    1,   37,  125,    1,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1682,  774, 1369,   61,  603,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  855, 1932,   32,    1, 1225, 1253,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,    1, 1445,    1,  297,  903,    1, 1447,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  398, 1458, 2777,    1,   98,  710,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647, 1454,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1965,  927, 2797,   98, 1338,   45,  977,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2171, 2800,  872, 1625,  183,    1,    1, 1408,  872,   32, 1131,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1537,    1,    1,  588,  112,  220, 2018,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3042,  161,    1, 1372,   37,    1, 1117, 1525, 2608,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  215,  681,    1, 1117, 1943,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,  758,  794,  258, 1013, 1522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056,    1,   45,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,   37, 1539, 1972, 1821,  541,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  121,   37,  335,  674,   45,  493,  633,  462,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1976,   32, 2073,  632,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2701,  404, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,    1, 1351, 1564,  142,    9, 2024,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1617,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1625,   71,    9, 1390, 1746,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  947, 2625, 1327,   12, 1674,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3128,  387,  163,    1,   12,    1, 2924,  380,  531, 1387,  537,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2719,  316,  921, 1022,    1,    1,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197, 1946,  191,    1,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    9,  657,    1,  166,  627,  967, 1056,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548, 2119,    1,   31,  571,   37, 1802,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2371,  636, 1042,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  941,  420,    1,   32,  147,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2729,    1,  952, 2113, 1650,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  304,   98,  116,  223,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  971,  251, 1656,  920,    1, 2073, 2248,    1, 1690,   67,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314, 2489, 1018, 2747,   38,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  809,  105,    1,    1,    1,  111,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1396,    1,    1,    9,  861,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 1470,   45, 1821, 2536,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,  187,  105,  861,  629,    1,   37, 2997,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1042, 1778,    9,   26, 1039, 2639,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151, 1341,   12,    1, 2166,    9,    1,  372,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  693,    1,   59,  159,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1028, 2466, 1702,  301,    5, 1631,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2178,  709,  391, 3390,   32,  187, 1009,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2663,    1,    1, 2500, 2218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2556,    1, 1821,    9, 2832,    1, 1568,  238,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  267, 1789, 1009,   12,  104, 2446,  105, 2739,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361,  887,   37,   92,  460, 1085,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3263,    1,   32, 2138,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  107,    1,    1,   37,  125,   69,  297, 1069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2819,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2615,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  922,  671,    1, 2758,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  177,  249, 2572,    1, 2347,   32, 1853,   12, 2596, 2137,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  920,  357, 1745,    1,    1,   90, 2397,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1038, 1760,    1,  384,    1,  220, 2332, 1167,  529,  247,\n",
      "            1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 2962,    1,   18,   81,   37,  688, 2213,  171,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,    1,  548,  581,   74,   45,    1,  667,   26,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1211,   29,  300,  305,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2470, 1111,  600, 1994,  104,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  205, 1412,  844,  302,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  294,   22,  251,    1,  508,   79,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1019, 2829,    1,   37, 1204,  176,    1,   45, 1186,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 1786, 2358, 1518,  290,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,  193,  606,  489,   32,  458,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2701,  872, 1914,  580, 1995,   44,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   51, 1527,  506,   45, 2130,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2489,   28, 1412,    1,   41,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    8, 2673,  304,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2942,  980,   81, 1159,    1,  176, 1139, 1434,  907,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,  105, 2226,   12,    1,    1,   98,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,   12, 1619,  458, 1702,   28,    7,   67,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2942,    1,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1360,  612,  720,    1, 1003,    9,  404,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1089, 1090,    1,  921,    1,   59,  449, 1034,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  758, 1996, 1507, 3017, 1008,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968,   37, 2010, 3107,  250,  412,  187, 2868, 2770,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2441,    1, 1102,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2777, 2001,    1,  612,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,  162,  915,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2168,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  342,  476,  104,    1,   98,  397, 1058,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999,  456,   85, 1689, 3050,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,    1,  216,    1, 1056,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  952, 2470,   12, 1876,    9, 2177,  260,\n",
      "           98,  903,    1, 1447,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  223,   37,  151,  449,  223,    9,    1,  372,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2922, 1408,   28,   97,    9,  105,  442,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1786, 2358, 1268, 1099,  927, 1039,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1,   32,  220,  365,  844,  275,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1542,    9, 2227,  865,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,   32,  121,  186,  444, 2095,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  296, 1396,  166, 1117,    1,  220,  365,  851, 2436,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  459,  131,  301,    5,  125,  302,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  590, 1373,   45,  964,   12,    1,  468,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2057,    1, 1564, 2457,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  921,    1,   32, 2620, 1961, 3329,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790,   37,  231,  317,  218,  230,  127,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,   67,   70,  186,  548,  925,   65,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  440, 2718, 1988,   45,    1, 1117,   67,  210,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  493, 1738,  921, 1146,    1,  496,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  159,   28,  419,   98,  365, 1607,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  815,    1,   37,  792, 3001,  792,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2425,  325,   48,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2095, 3389,  686, 2835,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 1056,  681,  598,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2640,   45,    1,  548, 1034,   32, 1204,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810,    1,  565,   79,    9,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  834,  914, 2055,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  858,    1,  407, 1146, 1703,   32,  105,  356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2345,  544,  193, 1140, 1638,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3152, 1285,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,  949,  251,  658,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2949, 2946,   45, 2843, 1976,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  942,   12,    1, 2286,    1,   37,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1,    1,   32,   98, 3107, 3366,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2275,    1,  448,  187,   10,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1355,  240,  597,  391, 3401,  187, 1081,   12, 2674,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1186,   12,  449,    1,    1,  105,  458, 1268,   32, 2235,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2395,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3381, 2095,  437,    1, 2225,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  617,  618, 1427,  187, 1084,  931,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  957,    1,    9,  844,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  528, 1705,    1, 3300,  619,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 1731, 2682,    1, 1527,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  159,  686,    1,   32,  218,  714,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  769,  529,  657,   12, 2992, 1027,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2945, 1361,  494,  943,  275,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3319,    1,  191,  183, 2799,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  444, 1973,    1, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  447, 1625,  531, 3365,  190,   52, 1683, 1371,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,  613,   37,  151,    1,  728,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   58,   37, 1155, 2073,  553,  163,    1,   12,    1,  457, 2604,\n",
      "         1294,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035,   37, 1038,   32, 1352,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,    1,   98,  854,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766,    1,    1,  522,    1, 1786,    1,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2,  69,  70, 442, 530,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2962,    1,    1,    9, 3115,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  645,  395, 2003, 1585, 2414,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 1518,    1,  116,    1,   32, 1708,   37,    1,   39,  111,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  440, 2718, 1988,   45,    1, 1117,   67,  210,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1855,  446, 2405,   37,  342, 2396,   98, 2331,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273,   12,  183, 1272,   61,  729,  105,  183,    1,    9,  379,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2246,    9, 1602,    1, 1893,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 2061, 3369,  297, 3118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  572,  551,  105, 1433,  215,  538, 1900, 1210,   37, 2123,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  353,  861,  328, 3011,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3094,    1,    9,    1, 2523,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1433, 1796,    1,    1,  565,  320,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,  37, 319, 225, 218,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 197, 418,   1, 202, 157,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2275,  190,  151,  331,  844,  199,   32,   78,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   37,  674, 1021,  250,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  407,   37, 1030,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2155,    1,  191, 2050,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,  818,   37,  151,    9,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2197, 2864,    1,   74,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2413,  444, 3243,  187,    1,  162, 1452,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  398,   32,  829, 1377, 1484, 1953,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  671,  156,  245,   98,  417,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3289, 2779,  140,  455,   26,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,  879, 1151, 1998,  220,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233,  302,  692, 1994, 2095, 2079,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2464,    1,  150, 2361,  285,  548,   56,   74, 1108,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1398,  612, 2589, 2310,  116,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2925,    1,    1, 1531,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 1034,   32, 1697,  275,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1861, 1550, 2325, 2489,  808,   32,    1,   98, 2924,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  677,  963, 1714,   37, 1463,  963,  954,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1633,  187, 3362,    1, 1140,   72,   74,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387, 1032,   93,   32, 1033,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,  168, 2083,    9,  861,  764,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,  193, 1530,    1,  415, 2051,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   14,   15,   28, 1068, 1069,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1953,  220,    1, 2758,  548,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  299, 2424,  844,    1,  538,  302,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2702,   13,    1,    1,   98,  215,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1233,  361,  479,  489,   39,   45,  785,  786,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066,  614,   37, 1092,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12, 1876,   45,    1,   12, 1020, 1924, 1922, 2084,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284,  773, 1996,  111,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  224, 1996,    1,    9,  422,  432,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1585, 2478, 2597,    1,    1, 1999,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1509, 1228,    1,  100,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755, 1612,  619, 1558,    9, 1104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2149,  932, 1372,  384, 2623, 2624, 1953,  202,    1, 1112,  176,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2759, 1294, 1519, 1778,   29,   81,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3206, 2681,    1,   39, 1034,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643, 1008,  365,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1063,  590, 1421,   45,  864, 2673,  406,  176,  365,  778,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523,   61,  729,  166,  786,  202, 2885,   61,  181,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  978, 3138, 1403,    1,  754,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  420, 1994, 2095,  443,  729, 1044,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2991,  251, 1101, 1089, 2549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2332, 1413,  186,   32,  142,   37, 1211, 3340, 1527, 2664,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3052, 2935,  581, 2635, 2072,  942,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 2660,   54,  647,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1835,    1,    1, 2759, 3004,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3131, 1857,    9, 2615,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  255, 1354,    1,    1, 1398,  612,    1,   32,  567, 2124,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1656, 2813,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  702,   14,  357,  311,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  794, 1234, 1107, 2308,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  505,   29,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3083,    1, 1041,    9,    1,  873,  176, 2565,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  284,    1,    1,   51,   52,    1,  384,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   55,  105,  803, 2638,  792,  138,    1,   37,    1,\n",
      "          792,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   98, 1656,  230,   79, 1650,   37, 1300,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  630, 2011,   98,  864, 3146,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  381,    1,  103, 1682,  297,  455,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  966, 2945, 1594,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2868,    1,  395, 1407, 1190,    1,  403, 1447,   46, 1705,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3385,    1,  581,  549,   32,   12,    1, 1447,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  920,    1,   32,  386, 1218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2, 104, 358, 533,   1, 293,   8,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 162,  56, 537,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3124,   12, 2695, 2724,    1,  947,    1,    1,    1,    9, 2176,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,   12,    1, 1516,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  215,    1,  568,  680,  898,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2679,  384,    1,   12, 1829,   45, 2362,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2016,   12,    1,  162,   48,   32,    1,  942,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,   85, 1364, 1365,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  256,  365,    1,   37, 2340,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  155,    1,  629,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,  331, 1067,    1,   29,  132,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,    1,   98,    1,    1,  202,  460,   12,  105,    1,   45,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  882, 1401,   91,  159,   28,  886,   85,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   12,  647,  142,   51,  362,  384,    1,   48,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  612, 1273,   12,    1,    1,  868,  105,    1,    1,   45, 1067,\n",
      "            1,   29, 2776,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  342,   78,  498,   37,  288,   28,    1,   23,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2870, 2083, 1785,  458,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,    1,  715,    1, 1807,   93,   37, 1121,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  619,  166,  915,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1795,    1,    1,  726,  163,    1,   12,    1, 1583,   24,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3279, 2856,  547,  104, 2548,    1,    1,   32, 3360,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2980,  891,    1,    1,  284, 2474,  618,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2136,    1,    1, 1493, 2577,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2279,    1,  593, 2153,    1,    1,  632, 3071,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2805,    1,  460,   12, 1018,    1, 1523,   37,    1,  224,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1070,  398,   37,  899,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  422,   61,   66,    1, 1476,  574, 2760,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,   15,  701,  300,   25,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2, 105, 271, 220,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 702, 733, 124,  37, 754, 757,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,  313,   37,   52, 1479, 1821, 1863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  446,   12, 1056,    1,    1,  820, 2764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2862,  446, 2526,    1, 1061,    9,  926, 2504, 1386,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1295,  764,  219,   25, 1594, 1425,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,  526,   32,  857,  442,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32,  104,  477,   98, 1147,    1,   45, 3155,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  915, 1140,    9,  615,   37,  142,   98,  224,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1687, 1022,    1, 3008,  365,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,   25,  242,    1, 1572,  191,  275,  831,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2922,  167,   52, 1036,  403,   37, 1413, 3323,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,   10,  872, 1707, 1140,    9,  395,    1,  927,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  561,    1,  912, 2285, 2165,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  228, 2572,  187, 3121,    1, 1316, 2755,  455,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1, 1994, 1839,  187,  163,    1,  903,\n",
      "            1,  651,   46,  698,   88,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1415,   12,  808,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  361,    1, 1865,    1,   32, 2755, 1033,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  863, 1221,   37,   52, 1360,    1,  267, 1481,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,   81,   98, 3024,  548, 1700,  257,   98, 1821, 2190,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  284,  963,    1, 3156,   32,  557,  540,   37,   52,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192, 2535,   98,    1, 2427,  631,  854,  191, 2202,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  572,  105,    1, 1009,   46,   28,  777, 1085,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   37, 1706,  372,  297, 1056,  537,   32,  968,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1718,    1, 2759, 1294,  884,   79,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    8,  228,    1,   98, 1778, 2558,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2655,   37,  764, 1598,  557,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1412,  538,  105,  365, 1030,   32, 2086,  443,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,    1, 1586,   28,  846, 3004,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1214, 2689,   51,  865, 1232, 3220,   32,  931,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1027, 1355, 2468,   12,    1, 2608,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3335,  917, 1178,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2034,    1,   59,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  776, 1898, 1646,   37,  985,  629,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359, 1905,   37,  606, 2241,    9, 3372,  741,   98, 3339,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 2950,   32,    1, 2414,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1081,   57,  861,    1,  548, 2095, 1260,  937,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1786,  908,  196,  176,  551,  612,  613,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2292,    1,    1,   32, 2597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  114,    1, 2507,  715, 2641,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1120,  565, 2258,  334,  894, 1847,  600,  166,  590,    1,    1,\n",
      "           32,  166,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 2939,  140,  593, 3256, 2069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  616,  577,   98,  691,  741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,  386,   78,  140,   32, 1619,  507,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  430, 2774,   46, 1348,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  940, 1558,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1089, 1090,   15,   66,    1,  548,  119,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1190,   32,    1,   37, 1220,    1,   98, 1585,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1785,  947,    1, 3006, 1388,   32, 1633,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  585,  211, 2977,   12,    1, 1821, 2978, 1539,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3343, 1708, 1086, 3363,   12,    1, 2726, 2596,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   37,  218,    1,   37,  218,    1, 2198,  166, 1027,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   91,  140, 3129,   12, 1477, 1990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  916,   37, 1343,    9, 2315,  872,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1676,    1, 1046,  713,   37,    1, 1623,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1266,  475, 1213,    1,  796,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,  531,  734,    6,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1737,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3116,  922,  437, 2227, 3176,  877,  638,  402,  361, 1385,   28,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,    1,    1,   51, 1847,  855, 1282,  178,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  606,    1, 2298,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 3222,  227,  550,    9, 3243,    1, 1628,  550,    9,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3322,  565,    1,  176,  754,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3140,  680,  861, 1906,    1,    1,    1,    1,  105, 1055,  384,\n",
      "         3140,   37,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2994, 1618,  166, 2995,  218,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671,    1,    1,    1,  627,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1256, 1021, 1564,  198,  218,  714,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1,  286,  475, 1236,   56,  137,   32,    1,  927,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2453, 1360,  612, 1377,    1, 1281,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  850,  247,  705, 1154,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  621,  606,  590,  170,  315,  621,  475,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   37, 1413, 3069,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1110,  729, 2175,   28, 1139,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384,    1,   37, 3155,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  565,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2677, 2448,  787, 1545,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1592, 1210,  388,  957,  289,   98, 2972,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2496, 1976,   32,    1,   51,   52, 3347,    1,  294,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  878, 2458,    1,    1, 1753,  829,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  199,  421,   27,  132,  220,  422,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3198, 3205,    1,    9,  601, 3329,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1720, 3002, 1260,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2, 878, 908,   1,   1, 132,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  69, 102,  66,   1,  98, 236, 237,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  691,   12,   12,  551,  552,    1,  338,    1,  948,    1,    1,\n",
      "         1784,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,   22, 1612,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3236, 1445, 1421,    1, 1417,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 1082,  864, 2673,  522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  190, 1860, 2708,  863,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   12, 2849,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1021,   45,    1, 1944,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196,   37, 1539,  104,  517, 1074,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  169,  353,  105,  354,    1,    6,  356,  157,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  636, 1702, 1750,  105,  106,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 1591,    1,  952,    1,  714,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 2409,  396,  133,   32,  890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  189, 1360,  612,  912,  932,  191,  439,   45,  339,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1753,  947,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  223, 2420, 1893,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1987,  256,   37, 3215,   12,  533,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2171, 2800,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  471, 2969,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  567,  510, 2405,    9, 2732,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,  391,  980, 1058,   98,  993,  302,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1628,    1,    9,    1, 2667,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1866,    1,   98,    1,   45, 1628,  550,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  621,  315,  484,   98,  105,   98, 1657,  296,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178,  851,    1,   79,    1,    1, 2844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,   26,    1,    1, 1426,  915, 2144,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275, 1562,  211,   32, 3136,  420,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  949, 2432,   37, 2324,  861, 2762,   32, 1778,    1,  756,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1, 1216, 1712,  345,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  391,   93,   37,  151,    1,    9,    1,  372,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2748,    1,    1,  275,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1423,  155,   93,  739,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  837,   45,  768,   43,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1879,   77,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1035, 2487, 2907,   37,  631, 3108,  608, 3079,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3169, 1287,   37,  688,    1,  176,    1, 3329,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3361,  276,   37,  576, 2073, 2024, 2699,   37, 2646,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2925, 3244, 2807,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  844, 1108,    1,   45, 2474, 3048,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,   81,  104,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,  978,   12, 1151,  475,  884,   28, 2348,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  160,  102,   28,   32, 1332,    1,  187,  493,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112, 1416,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1120,   12,  579,  334,  190,  361, 1360,  612,   52,    1,   37,\n",
      "         1937, 1720,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0],\n",
      "        [   2,    1, 1658, 1536,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  150, 1658,    1,    1,  525,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340, 1194, 2907,  873,  321,   52,   53,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2977, 2700, 1000, 2481,   45, 2820, 2312,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2634,    1,  766, 2243,  529, 2727,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2076,    8,    1,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   67,  490,  187, 1678,  565,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 393, 782, 394,  37,  77, 793,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 163,   1,  12,   1,  25,  71,  69,   1, 671, 245,  88,   1,   3,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359,    1, 1557,   37, 1413, 3057,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178, 1231,   32,  215, 2734, 2162, 2215,  927,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 2572,   32, 3343,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1008, 1644,  187,  475,  283,  655,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1568,   38,    1,  984,   38,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2307,    1, 1465, 1254,   32,  593,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1573,  105, 2267,  808, 2876,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2028, 1760,  104,   60, 2600,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2751, 2253,   37, 2856, 3340,  863, 1149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715,  471,   37, 1192,  176,    1, 1224,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  933, 2786, 1700, 2119,   32, 3118,  220,   28,    1,   45,\n",
      "           22,  285,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 1196,  176,  119,  845,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087,  361, 2634,  693, 2627,  988, 1825,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,  176,  754,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  388, 2496, 1976,   32, 3383,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  644,  877,  365, 1260,   98, 2751,   32,\n",
      "         2646,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  927, 2343, 1532,  182,  384,  163,    1,  903,    1,  210,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2281,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2533, 2331,   45, 2467,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773, 2510,  951,    1,  848, 2371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  180,  572,  197,  418,    1,   34, 1470,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  868,  411,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  215, 1108, 1682, 1986,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  716,  995,  242,  572,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1583,    1, 3339, 1219,  548,  336, 3389,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  181,    1, 1532,   32,  511,   12, 3020,    1,  776,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3322, 2110,    1,  220, 2557,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790,  387, 1064,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2885,  113,    1,  631,   32,  273,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1902,  833,  612, 2760,    1,   51, 1343,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1965, 2550,    1,    1,  836, 2337,    1, 1408,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,   37,    1,  220, 3385,   37, 2394,  104,  396,  565,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3178, 1426,    1,   26, 2069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1072,    6,    1,  187,  582,   45,  104,   50,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1273, 1732, 1091,    1, 2693,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  292,  163,    1,   12,    1,    1, 1994,  195, 1896,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1247,  729,    1,   37,  342, 1849,    5,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 2384,  613, 1108,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  207,  953,   98,  800,  605,  174,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3294,    1, 2615,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   64,    1,    1,   37,  582,   81,   37,   36,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  316, 2757,   37,  973, 1031,   32, 1123,  302,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2841, 1277, 1288, 2312, 1884, 2539,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,   37, 2654,    1, 1901,    9,  104,    1, 1108,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2801,   37,  693, 2311,    1, 3085,  517,  618,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800, 1090, 2415,    1,  951,    1, 1037,    1,    1,  446,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2528,  949,    1, 1292, 2593,    1,   55,    1,   45,  493,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2656,   79,    1, 1017,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  326, 1042,    1, 1021,    1,  846,   37, 1948, 1361,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2329,    9, 2646,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1965,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1988, 3370, 1098, 1905,  176, 2322,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3282,   64, 1118, 1186,   12, 1764, 1990,  427,   32, 2637,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1386, 3067, 2596, 1260,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,   42,   98,  737, 2432,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,    1, 1425,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1110,  951,    1, 3231,    1, 1090,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  300, 1412,  112,  931,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1904, 1606, 1149,  877,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,   37, 1348,    1, 1196,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  463, 2170,   12, 1076,  697,    9, 2050,  170,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  420,    1,  514,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2, 803, 112,   1, 337,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 437, 108,  98,   1,  45,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1123,  892,  428,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715,  996,  471, 2202,   39,   45,  128,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  405,    1,    1,   81,  548, 1987,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1178,   61, 2566,   45,    1, 2508,  549,  924,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1149, 1334,   39,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  275,  494,  388, 1862,  600, 1278,  506,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2005,  104,  297, 2468,    1,    1, 2228,   79,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  640,   37,  427, 1691, 1434,  119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  667,  171,   37,  619, 1994, 2095,    1, 3273,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2377,  813,   72, 1856,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1876,  217,  695,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  776,    9,  236,  237,  187,  978,  769,  701,   98,  937,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1650,  649,    1, 1196,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  818,  139,    9, 2213, 1361,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1636,  541,   37, 1327,  548,    1,  467,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228, 2054,   32,  350,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3075,  571,    1,   37,  121,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2520, 1251,  745,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  464,  954,  383,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1233,   37,  125,  568, 1010,    1, 1220,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,   26, 1039, 1665,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  200,    1, 2168,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  365, 2842,   45,    1,   32, 1186,   12,    1,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2279,   81,   32, 1948,    9, 3076, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  446, 2347,   32, 1225, 2291,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1191, 2264,   37,  729, 1937, 1744,  378,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,  688, 1759,  309,  202,  729,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,    1, 1310,   37,  417,  689,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2460,   28,  166,    1,    9, 2741,    1,  267,    1,  548,\n",
      "          354,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708, 3006,  114, 2328,   32, 3339,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   46, 1195,   32,  142,    9,  903,    1, 1423,  876,  612,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,  353, 1913,  401,  197,    1,  983,  418,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2523,  729,  547, 1048,   32,  455,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  288,   37, 1776, 1799,    9, 2117, 3118,   23,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  270, 1704,  166,  116,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284,    1,    1,  186,    9, 1352, 2423, 1856,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  790, 1454,  453,    1,   45,  749,  230,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,  764,    1, 1607,  414, 3031,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3092,   37,    1, 3181,  539,    1, 2292,  548,  922, 1990,  427,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496,  249,    1, 2192,   39,    1, 1243,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  218,   61,   32,   44,  187,  107,   12,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 2170,  140,    1,  497, 3255,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  537,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  457, 1202,    1,   10,   22, 1821,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1141,  297,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 3181,   37, 1468, 3328,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1652,   82,  756,    1,  929,   37, 1910,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,  787,  639, 2239,   37, 1361,   12,    1, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3177,    1, 3187,  791,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  345,   37,    1, 2705,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  678,    1,    1,    1,  872,   28,    9,    1, 2873,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178,  610,   37, 1204,    9,    1, 2772,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 166, 275,   1,   1, 873,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  37,  10, 198,  60,   1,  88,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  369,    1,    1,   37,  168, 1300,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3345, 1220, 1407, 2924,  319,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1037,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,    1,   32, 3035,  354,  365, 1788,  317,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  270,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2851,   51,    1, 2205,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  755,    1,    1,    1, 1942,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1443, 1051,   12, 2465,    1, 3000,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   47,    1,    1,  440, 1077,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  176, 1062,  458,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3339, 3352,    1, 2708,  993,  475,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  735,    1,  256,  114,   37,  301,    5,  302,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 2692, 2086,   61,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3012,    1,  603, 2312,    1, 2312,  227,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3359,    1, 3339, 2129,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1204, 2319, 1089, 2294,  162,  915,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1718,    1, 1991,    9,    1,  443,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  640,  187,  109,  509,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2645, 2868,    9, 1896,   32,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  487, 2095, 2985,    1,   37,  147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2468, 1877,   37,   77,   97,   98, 3387,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1494,   39,  444,  342,  768,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1958,    1,   74,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,  190,  698, 2379,    1,   32, 1090,   56,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  396,  247,    1,  872,  190,  920,  726, 1322,  384,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2604,    1, 1821, 3027, 2421,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  134,   37,    1,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 3397,  267, 2024,   32,  463, 3369,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1081,   57, 1797,  861,    1,  548, 2095,  937,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   68,   69,  102,  221,  760,  813,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  993,  652, 1271,   32,  104,  299,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  738,  220,    1, 1612,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  327, 1091, 1173,   63, 1936, 2851,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2924, 2856, 3045,   32, 3369,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1064,  665,  171,   37, 1463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  415, 2119, 1159, 1888,    1,  683,  476,   81,   32,  903,    1,\n",
      "         2227,    1, 1007,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,   52,  707,   81,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3069, 2577, 1461, 1604,   37, 1795,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,   12,  365, 2452, 1465,   61,  810, 1616,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,    9,    1,   98, 2675,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 3102, 1683,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2523,    1,   37, 2144, 1333, 1918,   32,  455,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  535,    1,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1277,    1,    1,  167, 2394,   37,   52,  671, 2003,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1436,  550, 1345, 2414,  176,  177,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1109,  572, 1578,   98, 1171,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1770,  961, 1294,    9, 3118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  741,   32, 2113, 2010, 1743,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  475,   45,  956,   37, 1540,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3005,    1,  829, 2432,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  936,  138,    1,  362,    6,    9, 1499,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  195,  167,   92,    1,  856,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3255,    1,   37,  319, 2741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1118, 2492, 1626,  949,  297,  861,  122,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428, 2883, 2924, 1997, 2156,    9,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1800,  649,  650,   12, 2081,   45, 2770,   37,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   42,  573,  149,    1,  335,   44,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  695,   96,   28, 1245,   98,  647,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37,   52,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  947,  475,   12, 2836, 1946,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  642,  643,   57,  245,   32, 1352,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3104,    1, 1474,  379,  856, 2123,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1212,   21,   37, 1427,  382,  568,   32,  537,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 2170,    1, 3107, 3366,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  967, 1658,  858, 2582,  453,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2065,  497,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  363, 2966,   51,   52,  105, 2177,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,   69,  102, 1473,  528,  876,  612, 2509,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  936,    1,    1,    9, 1256,    1,  361,    1,  207,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2221,  108,   45,  981,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98, 2124,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1658, 2995,  809,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2183, 2710, 3384, 1941,   32, 3339, 1585,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   51, 1860, 1675,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3117, 2712, 3271,    1,    1,   32, 3235, 1798,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   26, 3308, 1990,   32, 2304,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,  927, 1921,  176,  166, 2918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 2160, 2049,    1, 1037,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2429,  167,   23, 2741,   37,    1, 2784,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3183, 1285, 3318,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  770,    1, 2260,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1342,    1,   82,  548,    1,  939,   37, 1413,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  580,    1, 2015,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1128,   37, 1378,    1,    1, 1718,   98, 2168,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   40,  321,   52,    1,  191,    1, 1450,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  978,  769,  245,   98,   69,    1,  954, 1279,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1855,  669,   37, 1910,  531,    1,  548, 2886, 3340,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,    1, 1536,    9, 1126,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2089,  290,  155, 1574,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 1974,    1,   32,    1,  354,   37, 2920,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2144, 2095, 2985,    1,   32,  487,  147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  555,   32, 1687, 1022,    1, 3008,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,  794, 1412, 1107, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2804,  598,   45,    1, 2214,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  225,  188,  548,    1,  157,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  331,  551,  517,   12,    1,    1,  187, 2252,    1, 1351,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,  353,  105,  242,  737,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1936,  567,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1205,  191,  829,    1,  306,    1,  150,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  692,    1, 1547, 1146,    1,    1,    5,  469,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  140, 1350,  400,    1,  321,    1,  647,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2969, 1766, 1767,    1,  384,  657,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  612, 1273,  775,  365,   40,  259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2405,    9, 2906,   98, 1044, 1318,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  698,   37, 2813,    1,  202,  590, 1421,   45, 3088,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  510, 1564,    1,   98,    1,  540,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1811,  404, 1830,    9, 1204, 2198, 3358,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3310,  400,   66,  187,    1,  384,  698,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1543,  105,    1,  384,  166,  489,   85,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  627,  729,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380, 1484,    9,  365, 1992,   37, 1815, 2096,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2920, 1253, 2959, 1056,   32, 1559,    9, 1367, 2246,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1242, 1748,   37,  877,    1,  319,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    8,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1902,    1,    1,   51, 1343,  444, 3227,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1497,    1,    1,    1,   61, 2745,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  411,    1, 1121, 3115,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  342, 1353,  927, 1159,  657,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1629, 1236,  286, 1630,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612, 1140, 2349,    1, 2226, 2233, 1140,  334,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  262,  263,    1,   81,  187,  197,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1492,  254,    1,   12, 2179,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006,  429, 2753,   45, 2547,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   81,   37,   36,  834,  920,    1,  623,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321,  326,  792, 1031,  166, 1090,  792,   32, 2759,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3364, 1484,    9,  439,   45, 3344,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1028,    1, 1372,   37,  686,  166,  971,  665, 2533,    1,    9,\n",
      "          920,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2321,  176, 2807,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  957,  434,   32, 2755,  121, 3338,   32, 1313,  297,    1,    1,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 425, 426, 159, 245,  98, 594, 818,  15,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 778, 952,   1,   1,   1,   1, 150,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  664,  822,  856,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1568,   38,    1,  984,   38,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  526, 1051,    1,  761,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  618,  665,  593,   32, 2473,   45,  166,   38,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947, 1000, 3373,   32, 1022,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  273, 2171,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  166,    1, 2060,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  160,  623,   98, 1616,   32, 1869,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  476,  802,  191, 1282,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3391,    1, 1800, 1665,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  988, 2056,    1,    1,   45,  166,  608,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3021,   61, 2317,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  433,  102,  190,    1,  468,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  531, 3006,  798,   37,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398, 1800,  941,  400,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3277, 2331, 1179,  321,   77, 1515,  838,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  211, 1648,   98,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   98, 1965, 2900, 2795,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32, 3279,   32,  531,   12, 3356,  787,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,   51,    1,  220,  104,  297, 2439,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  972,   37, 1048,  148,  132, 1039,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  640, 2350,   37,    1,  854,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  903,    1, 2388,  220, 1844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  709, 3258, 2965,    1, 2424, 2017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422, 2008, 1476,  574,    1,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  531, 1953, 2061, 2597,   37,  588,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   66,  187,    1, 1021, 1039,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1998,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1414, 2884,    9, 3384,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1266,   82,  796,    1,  159,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98, 2717, 2895,  506,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  122,  600,  889,  973,   69,   37,  119,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  560, 1274, 1556,  915, 1034,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3075, 2864,  350,   27,    1, 3346,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  548,  181, 2454,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  884, 1544,  444, 2819,    1,  909,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,  908,  196,  142,    9,  176,  612,  613,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  729,   32,  166, 2884,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1259,  313,   37,  764,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2663,    1,  782,    1,    1,   37,  203,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247, 1187, 2316,    1,    9, 3276,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  296,  739,  183, 1220,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1227, 1419, 2580, 2851, 2706, 1958, 2495,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  215, 1527, 1202,  582,   39,   37, 3349,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  140, 2080,  517,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1866,   37, 3209,  220, 3305,    1,    1,    1,    1,  707,\n",
      "           37,  166,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 2306,  288,    9, 1611,   45,  632,   69,  633,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 1135,   45, 1228,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  167,  105,    1,    1, 1018,    1,    1, 2973, 1764,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,  315,   37, 1539, 2968,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885, 2619,   98,    9,  885,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2862,  171,  535,  958,  650,   12,  854, 2237,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2813,    9,  166,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  671,    1,  861,    1,   98,    1,    1, 1608,  953,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,   32,  395,  619, 1805,   28,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2137,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2048,   32,  166,    1, 1075, 3048, 2923,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  267,  284,  215,  947, 1812,    9,  563,  564,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   51,   52,  905,  191, 2829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  852,  361,    1, 1998,   37,    1,  282,  542,  361,  327,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147, 1579,  104,  358,    1,  220,  348,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1818,  147, 1392,    1,    1,    1,  171, 1760,   98,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   46,  297,    1, 1815, 1096, 1090,  891,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1607,  231,  829, 1013,  338, 1533, 1139,   45,  224,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1035, 1377,  396, 2289, 1924, 2566,   45,    1,  776,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   60, 1042,   37,  365,  340,  444,   94,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947, 1761,    1, 2596, 1585,  176, 2103,  617, 2616,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3260, 2712, 3232,   37, 1832,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12, 2571,   12, 2673,    1,  134, 2917,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1918,   45,    1,    1,  919,   25,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614, 1833,  288,    9, 1090,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1048, 1049,  353,  720,   32,  197,    1,  202,  921,  739,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1373,   37,  877, 1678,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3236,  190,  698,    1,  220,    1,  187,  512,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  985,   45, 1250, 2582,  590,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1340, 1921,  786, 1139,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2658, 2269, 2598,  754,  384,  208, 1010,  716,   45, 1939,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1260, 2803,  187,    1, 2770, 2924,   32, 1815,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2445,  246,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  531, 3382, 1082,    1,   37,  720, 2108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,  267, 1186, 1710,    1,   37, 3102,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 2339,   37,  166,   71,   45, 1178,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  693, 2774, 2198,  105,    1, 1243, 3011,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3118, 2024,   46,  588,   37,  271,    1,   98,    7,  861,    8,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  396,  104,    1,    1,  315,    1,  397,  261,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  861, 1075,    1, 2747,  166, 2987, 2693,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1, 2254,  875, 2255,   43,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1802,    1,   39,   45,  339,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1151, 1491,   25,    1,  657,  276,   32,   91,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  617,  259, 2806,    1, 2393,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1283, 1074,  424,  356,   12,  294,  922, 3154, 2522,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1153,  160,  437, 1713,    1,    1,   32,  842,  149,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,  803,   84,  187,  395, 1268, 1821,  656,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1122,  853,  538,   37,    1,   98,  777,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   45,    1,    1, 1563,    1,   85,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,  376,  453, 2364,  187, 1220, 2493,  800,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,  167,  576,  388, 2924,   37,  531, 1190,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  971,  730,    1,  802,   28,   37,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3149,    1,  396,    1,    9, 3071,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  204,  614,  384,    1,   37, 1090,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3243,  183,  354,   37,  487, 2711,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,    6,  102,   32,    1,    9,  365, 1607,  260,  918,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  733,   59,    1,   98, 2102,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  658,  613,    1,    1, 1715,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374,  859,  365, 2328, 1450,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  268,  142,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,    1,    1, 2706, 2232,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3402, 3408,  398,    1,  163,    1,   12,    1,  297,  400,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  953,   98,  303,    1,  455,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  105,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1656,    1,    1, 2438,    9,  971,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  848,   12,    1, 2695,   55, 1191,   98, 2901,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  197, 1315,  308,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  166, 2918,   32, 2849,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2463,    1,  166, 3152,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   71,  187, 1282,  142, 1757,  431,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    8,  228,    1,   98, 1778, 2558,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  852,   37, 2963,  590,    1,  539, 1037,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1227,    1, 1158, 1330, 1107,  176, 1273,  259, 1091,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  384, 2376,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3079,    1, 2844,   45, 2527,  164,   32, 2490,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1536, 2704,    1, 1559,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  953,   32,    7,    1,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12,  572,  197,   28,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  633, 2328, 1830,    9, 1198,   79,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  798,   98,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   10,  498,   37,  411, 1700, 2789,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  356, 1691, 1920, 1976, 1530,   32,    1, 2012,  176,    1,\n",
      "         1688,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  353,  245,   32,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1725,    1,  691,    1,  903,    1, 2036, 1937, 1259,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2018,   98, 3131,   45, 1364, 1365,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   59,    1,  855,  590,    1,  579,   12, 1411,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1633,    1,  187,  567, 2137, 2921,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1778,  951, 1718,  777,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,    1,  294,  498,   37, 2689, 2284,  405,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32, 1656, 2909,  187, 3128, 2770, 2924,   32,  531,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1721, 2360, 1361,   12,   26, 1039, 2366,  315, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3036,   45, 2598,   61,  645, 2438,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 1564,    1,  531,  516,   37,  726,   81, 2789,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2017,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 1415,   37, 2943,    1, 1135,  220,  849,  132,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  786, 2595,    1,  813,   98, 1292,  493,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  526,  916,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  936,  365, 2516,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3172, 1090, 1829, 2748,  584,  176, 2110,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  207,  681, 1398,  612,    5,  116,   19,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  640,  119,   94,  340,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  397, 1297,  342,    1, 1130,  686,  104,  220,  442,  909,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2837, 2844,   32,    1,  851,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2222, 1494, 1632,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3207,    1,    1, 1608, 1137,   37,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    9, 1121,    1,    1,    1,   37, 1306, 1956, 2522,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1765,    1, 1098,   45,  826, 1273,  662,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1461,  750,   95, 1463,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111,  378,   98, 1171,   37,  686,  119,  374,  325,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  543,   69,  764,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401, 2107,    9,   32,  141,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2031,  777,  778,    1,    1,  669,   12,  822,  396,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1433, 1366, 2047,  166, 1412, 2661,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  420, 1899,   12, 1541,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1284,    1,  600,  478,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,    1, 1563, 1220,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,   12,    1,   98,    1,  105, 2401,   32,  170,  406,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  403,  464, 1461, 1539,    1,   37, 2470,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437,  321,  544, 1298,   37, 1124, 1069,  357, 1027,   85,  408,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   25,   25,   37, 1075,    1, 1332,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3290,    1,  583,   32,  354,   37,  365, 2741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,   12,   12,  551,  552,    1,  801,    1, 1572,  191,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,  176,  460, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  666, 2865,   39, 1021,  361, 2817,  584,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2573,    1, 1053,    1,    7, 2179,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  191, 2565,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  220,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2804,   32, 2945,    1, 2734,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2714, 1515,  365, 1277,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2700,   32,  497,   37,  506, 3001,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,    1,  447,   81,    1, 1311,    9,  455,   98,  861, 1906,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2546,  614,  548, 1230,  220,  636,  443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1720,  754,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1652, 1718, 2355, 1539,  424, 1034,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1557, 1118, 1994, 1230,  302,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  389, 1201,    1,   98,  329,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1107, 1396,  388, 2633,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1994, 2275,    1,  576, 1525,   37,   78,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460, 2221,  566,    1,  187,  116,  210, 1153,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1718,  361,   26, 1039,  166, 2273, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  155,    1,  970,  570,   98,  626,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,  641, 1461, 2320,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3227,  664,    1,    9,  166,  914,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  496, 2931,   37,   92,  613,  777, 1085,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,   37, 1752, 3343, 1009, 1428,  267,  861,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  742,    1, 1166, 2085,  204,  614,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111,  773, 1937,    1,  120,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  242,  187,  197,  509,  470,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  992,   81,   32, 1739,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  137, 1673,  119,    1,  390,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  787,  232, 3251,  190,  221,   37, 2016, 1411,  356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1497, 3229, 2787,    1,  548,    1,  917, 3131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 1449, 2781,   32, 2857,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326, 1025,  288,   37,   47,  453,  466, 1465,  112, 1379,   12,\n",
      "          112,  499,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1147,    1, 1333, 1530,  539,   45, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  409,   25, 1473,   37,  105, 1056, 1034,  845,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2266, 1070,    1, 2153,   37, 1428, 1896,   37,    1,   62,   32,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  822, 2887,   32,  166,   26, 1039,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1747,    9,  105,  457, 2328, 2728,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3281,   12, 3181, 1249, 3314,   32, 3116,  922,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,    1, 1534, 3024,   12,  559,    1, 1821,  199, 1425,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  179,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65, 1268, 1953,    1,  697,   37, 1083, 1184,  347,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  199,    1,  420,   98, 1256,  551, 2196, 1908,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1419,    1, 2677,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  233, 1426,  630,   37,  771, 2591,   98,  301,    5,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1074,    1,  167,  194,  116,    1,  361,  860,  861,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1,  132,  220,    1,  626,  700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    8,  167,    1,  132,   37, 1806,  864,   12, 2673,  210,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3214, 1518,   98,    1,   12,  686,  119,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1025,   37,  562,  148,  142,    9,  647,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1938, 2607,  382, 2206, 2989,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3364,  288,   37,  726, 2708,  741,    1,    1, 1042,   39,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  561, 1079,   37, 2192, 2311, 2911,  388,  199,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2087,    1, 1056, 1130, 1988,   45, 1939,  564, 2337,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2427, 1594,    1,   98,  854,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,  446, 1564,  454,    9, 3371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  581,  916,  726,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    7,    1,   32, 3311, 3310,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2196,  389,  361,  590,  786,    1,  247,    1,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,  267,  395,  190, 1982,   46,   98, 2500,  663,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 225, 186, 640, 105,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,  32,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  741,  509,  715, 2122,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1723,  261,    9, 2254,   32, 2255,  768, 2096,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158,  936, 1437,   45,   94, 2102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1720, 2136,  110, 1590,  166, 1354,    1, 2279, 1924, 1221,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,  171,  921,    1,   32, 3134, 3201,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2137,  686, 2729,    1,    1, 1999, 1530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3389,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   37,    1,  955,  956,  220,  342,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1652, 1419,    1,    1, 1718, 2973, 1764,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   12, 2877, 2007,   32,  121,    9,   69,    1,  734,   46,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  193,  889,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2476,    1, 3347, 3340,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2343,  738,  247,  924,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2335, 1530,   32, 1796,  437,  344,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  375, 1401,  411,  973,  176, 1548,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2597, 2328, 1260, 2414, 1056,  104, 2548,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1051, 1586,   28,  552,    1,    9,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189, 1666,    1, 2092,   37,  465, 1169,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  315,   37, 1753, 2106,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  220, 2851,    1,  852,   37,  166,  627,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  437,  782, 2298,  220, 2208,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 1484,   79, 1539,   45,  938, 2454,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  223,   37,    1,    1,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204, 1774,   98,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1247,  992,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129,  922, 1090, 1829, 2295,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  535,    1,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  953,   37,  339,  340,  951, 1547,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  206,   12,  197,  418,    1,  202,  225,  338,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,   45, 1574,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2226, 1398,  612, 1847,  203,   37,  335, 1997,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,   12,    1,  218,  884,  105,  686,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2094, 2199,   37,  390,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3378,  776, 2361,  548,  339, 1183,  271,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2415,  542,   76,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,  159,    1,   85,   32, 2088,  442,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1016, 2789, 1401,    1, 3372,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  108,   45,    1, 2960,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1281,  333,   45,  238,    9,  197,    1,  223, 2042,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3250, 2563, 2528,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2159,  682,   98, 2238,    1,  983,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2951,  531,  863,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  709,    1,  609,  580,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22, 1256,  359,  138,  302,    1, 2124,   37,  793,    1,  267,\n",
      "          232,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  567,  799, 2097,  584, 1166,  666,  686,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  954, 1353,  528,  677,   69,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  103,   45,  166,    1,    1,    1,    1,  119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  764, 2556,    9,  105, 1488,  454,   37, 2116,    4,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2693,    1,  187, 1104, 1117, 1525,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,   37,  865,   37,    1,  218,  220,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1294,   45,    1,    1,   37,    1,    1,  384, 1282,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1027, 1128,  244,   92,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1959,  186,    1, 1214,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1244,   77,  572,  327,   93,   98, 1171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  275,  304,    1,  242,   69,  817,   98, 1033,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  200,  673,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  105, 1298, 1176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2396,    1,  103,  275, 2153,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  879, 2338,  115,   45,  163,    1,   12,    1,   29,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   51,  417,  453,  647,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2960,  640, 2764,    1,  844, 2190,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739,    1, 2094, 1824, 1412,  844,   37,  166,  617,  259,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,   26, 2871, 3169,    1, 3257,  759,  166, 1381,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2246,    1,    1,   32,  914, 3201,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2955, 2483,    7,  808,   32,    1,   12,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671, 1078,  475, 1484,    1,   54,  142,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2786, 2762, 2952,   32, 1227, 1357,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777,    1, 1361,  710,    9, 2355, 1718,  973,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2170,  580,  365,    1, 1665,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3172, 1090, 1829,    1,  176, 2748, 1771,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   28,  123,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   25, 1269,   85,    1,   69,  122,  817,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  119,  754, 1844,  686, 1478,   32,  147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1458, 2197,  142,    9, 2826,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  306,    1,  150,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1478, 2977,   24,    9,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  596,  616,  604,  102, 1269,  548,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1572, 1414,  973,   37,    1, 2774, 2060,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1011, 3150,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3198,   37, 1046,    1,    1,   32, 2197, 3329, 2069,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  667,  446, 1481, 1484,  391,  863,   98, 1352,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3331,    1,    1,  123,   98,  228, 1863,  442,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  460,   28, 1114,    1,  664,  183, 1090, 1114,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  726,  803,    1,    9, 3303,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1620,  596,    1,    1,  506,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3325,    1,  191, 3164,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  754,  102,   77,   98, 2066,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947, 2263,    1, 2689,    1,  195,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1484,    9, 1281,   32,  442,   45,  638, 2087,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2353,    1,    9, 2730, 1942,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2275, 2257,  117,   45,    1,    1, 2118,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 1360,  612,    1,  297,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   43,    1,  297, 1013,    1,  378,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  524,  525,   15,  410,   32,  645, 1034,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3348,  593, 2864,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1450,   32, 2835,    1,  357, 1370,   45,  596,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,  953,   37,  365,  340,  951,   94,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2909,  135, 1033,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  102,  245,   98,    1,  996,   93,  739,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  456, 1283, 1089, 1675,   50,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1159, 2033,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181,  193,  330, 3317,  221,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  147,  484,   51,  417, 1251,   45, 1234, 2308,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   69,  102,  526,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  469,   98,  454,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2137, 2856,   32, 1619, 2018,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  398,   57,  545, 1035,   37,  946,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2967,   39,    9,  914,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1001,  977, 1556,   32,  645, 1034,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2748,   12,  750,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1822, 1937,  844,    1,   61,    9,  311,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  934,  313,   37, 1835,  201, 1021,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2936,   37, 1838, 2596,    1,  427,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  210, 1297,  249, 2436,  705,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,    9, 1879, 1497,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1009, 3380, 1554,    9, 3360,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  778, 1391,    1,    1, 2179,  736,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   15,    5,    1,  162, 2069,    1,  432,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2263,  297,  116,  312,  396,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  923,  610,   32, 1037,  680, 1133, 2819,  625,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  534,  251,   59,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3214,  640,  384, 2507, 1479,  922,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  613,   37, 1027,  116,   93,    1,  275, 2153,  774,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374, 1707, 2756,   32,    1,    9, 2708,  890,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  493,  102,  103,  105,    1,   32,  171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2471,  220,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1366, 1584,  542,   85,  405,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3172,   12,  484,   98, 2755, 3010,    1, 1908, 2081,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  144,  145,  376, 1183, 2113,   93, 1396,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1, 1009, 1530,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  125,    1,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  123,   37, 2098,  786,   45, 1123,   12,    1, 2078,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  524,  525,   15,   71,   32, 1893, 1034,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  927,  991,    1,   32,    1,  400,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2870,   32, 1147, 1223,    1, 2006, 2572,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,  567,  799, 2682, 1159,  584,    1,   98,  454,   37,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  691,  155,    1,   32, 1033,  297,    1,   37, 1421, 2024, 1259,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  935,  315, 1821, 2057,  669,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  451,  232,   12, 2059,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  978,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2615,  167,   52, 2198,    1,  411,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  333, 1478,  331,    9, 1831,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2935,  449,  889, 3116, 1684,  220,  754, 2250,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  645, 2819, 2574,  815,  224,    1, 2826,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  786, 1333,  631,  176, 1739,   26,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550, 2680,   32,    1, 2693,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2183,  649,  650,   37, 2237,  903,    1, 1447, 1411, 1034,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1088, 2527,  164, 1018,    1,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2022, 1002,   30,    1,  855,   32, 3144,  863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,  830, 1420,    1, 2023, 1796, 1651, 1597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  326, 1268, 1718,  656,   32,  968,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  935, 1426,    9,  166, 3009,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98, 2325,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1068, 1069,    1,   28,   32,  367,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  375,    1,    1,  187, 3261,  891,    1,  927,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3056,    1, 2215,    1, 1077,   37,    1, 2994,  270,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  374,  338,  187,   69,  102,   71,  329,  682,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   32, 2866,  297, 1412, 1107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  166,  631,  176,    1,  229,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1733,  361,    1,    1,    9, 2027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  941, 1663,  149,  444,  938,    1,  328,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1,    1,    1,  872,    9, 2334,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2523,   98,  103,  176, 2620,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1509,  454,   37, 1192,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1621,    1, 1444,  565, 2177,   37,    1,  220,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110, 1173,   37,    1,  270,  444, 3200,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,    1, 1328, 1057,  600,  903,  464, 3162,   32,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1170,    1, 1967,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2634,    1,  766,   16, 2869,  529, 2727,  327,  593,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9, 3213,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,  884,   48,   32, 2992,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1213, 1296,   28, 2030,  176, 2374,    1,    1,  844,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    8,  786, 2324,   32,    1,  861,  328,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  176, 1411,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428,  639, 1458, 2673,  132,    9,  864,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1753,   37,  222, 1649,  625,   32,  878,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2999, 2706, 1297, 2264,    1, 2966,   98,  923,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1108,    1,  176,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   10, 2609, 2587,  166, 1357,    1,   32,  443,   98, 2095,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3039, 2772, 1090,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2262,   98, 3144, 1002,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,   51,   71,   98,    1, 1057,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  395, 1021,  407,   98,  218,  714,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2767,  535,  656, 1614,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,  365,  454,   37, 1093, 1658,  754,   12, 1603,  197,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2964,  168, 2026,    9,  111,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  384,    1,   37,    1,  579,  105,    1, 1056,  537, 1564,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  666,    1,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1215,    9, 3301,    1, 3239,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2893, 2356,   45,  926,  134,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1472, 2277, 1425,  365, 2741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,    1,  326, 2035, 1151, 2657,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   45,  166,  403,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   30,  112, 1161,  383,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 550,  32, 870,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 294,  22, 387, 131, 388,  32,  88,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2485, 1572,   37, 3207,   12,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  114,    1,    1, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  657, 1625,   37,  764, 1155,  116,   45,  166,  627,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1520, 2384,    1, 1465, 1616,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1620, 3343, 1002, 2393,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2752,   12,    1, 2751, 2782,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  329, 1086,   28,    1,  374,  953,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  592,  943,   37, 1445, 1539, 1527,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  129, 3134,    1, 1090, 3210,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,    1,   12,    1, 1890,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  225, 1042,  187,    1,    1, 1057,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1552,  187,    1,  832,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1419, 2544, 2232,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584, 2767,    9,  567,  666,    1,    1, 2738,    1,    1,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   37,  209,  955, 1482,   68,   69,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,    1,  105,    1,  357,  166, 1411,    1,  183,    1,  270,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  746, 1825,   80,   37,  479,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  666,    6, 1021,   37,  331,   32, 1817,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  653,    9,  331,  460,   24,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3405,   32,  557,  540, 2774, 1223,   98, 2024, 2699,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1468,    1,  737,  354, 1052,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1183, 2113, 1633,   12,  354,   32,    5,  400,   51,  764,    1,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1233,  580,  477, 2661,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3216,  726,   37,   26, 2522,  220, 3175,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,  361, 1363,  872,   28,   98, 1273, 2255, 2461,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,   12,  553,    1,    1,    1, 1896,  191,  284,    1,   37,\n",
      "            1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3359,  162,  183,  726,  204, 2556,   32,  741,   98,    1, 2129,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2924, 1539, 2731,    9,  531,   12, 3391,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  296,  315,  388, 1898,  220,  395,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018,    1, 1992,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  732, 1949,   56,  388,  541,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296,   51,  109, 1202,   32,    1,   22,   12,  152,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,  61,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 593,  32, 870,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 608,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 496, 777, 818, 834,  28, 118,  32,  88,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,  453, 2876,   36, 2286,   37,    1,  220,  105, 2930,\n",
      "           44,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  501, 1141,   37,    1,  855,   32, 2142,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  179,    1,  180, 1413,   32,  131,  132,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  720, 2197, 3329,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  527, 1475,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,    8, 1939,  420,    1,  202, 2919, 2126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  457,    1, 1957,  608, 1285,   45, 1821,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  986, 1612,   37,  151,  479, 1975,    1, 1527, 2107,  220,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,    1,  220, 1700,  617,  681,   32, 1033,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1853,    1,   32, 1242,  187, 1585, 1950,  640,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2615, 1247,   12,  114,    1,    1,  105, 1298, 1176, 1568,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  812, 1428, 3365,  949,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  129,  392,   15,  689,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1050, 1234,  778, 1914,   37,  138, 3003,  331,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  386,    1,  359,    1,  498,   98,    1,    6,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3173,  765, 1159,  395,   26,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2321,  288,   37, 1421, 3229,    1, 2719,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  583,  166, 3239,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2738, 2960,    1,   32, 1619, 2597,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2596,  307, 3374,  837,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2596, 2414,  104, 3160,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   77, 1018,  661,   98,  166,  249, 1411, 2009,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1375,  256,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 3175,    1,  813,    1,    1,  361,  166,    1,  105,   12,\n",
      "          245,  786, 1090,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  938, 1075, 2699,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1144,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  967,  590,  400,   37, 2259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,    1,  220, 2994,    1,  202, 1875,  469,   37, 1605,  384,\n",
      "         2997,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2617, 1807, 1698,  471,    9,  302, 1963,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129,  922, 1090, 1829, 2459,  176,  584,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1370, 1262,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  994,    1,  150,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147, 3397, 1458, 2625,   98, 3155,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2490,   12, 2736, 1082, 1945,   32, 2292,    1,  323,  463,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  364,  884,  180, 1990, 1684,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2734,    1,  105, 2273,  361,  166,  627,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1600, 1567, 1380,  942,   32,  593, 1990, 2701, 2069,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  578, 2557,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  657, 1749, 2616,   98,  105, 1151,  700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  402,  834,    9,  105, 1465,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056,    1,  681,    1,   32,  147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1894, 2608,    1,    9, 1110, 3130,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  746,   37,    1, 1117, 1525,    1,    1,  361,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  295,  587,  588,   28,   37,  131,   32,    1,  573,  589,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2603,  921, 1886,   45,  166,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  909, 2317,    1,  193, 1946,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1273,  259, 1281,   51,   52,   27,  439,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  404,  602,    1,  105,    1,    1,  537,   98,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3128, 2770,  854,    1,    1,    1,   98, 2108,   15,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739,  105,  551,  331,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  597,    1,    1, 2844,   32, 2597,    1, 1260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   12,  462,   37,  142,    9,   49,   50,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  348,  515,  793,  764,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087,  433,  315,  973,    9,  657,  788,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2614,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  348, 2165,    1,  593,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,  200,  647,  721, 2855,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,   12,  721,    1,  253,  360,  148,  214,  142,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  116,  195,    1, 2370,   97,   32,  942,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   25,   26,  417,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  225,  338,   98,  157,  586,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3349,   12,  446,  105, 1529,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3194, 3195, 1009,  640, 2667,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 3267,   37,  907,    1,   32,  581, 2069,   32, 1056, 2119,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612,    1,  297,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  267, 1821, 2190,  472,  340,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  546, 2565, 3301,    1, 2929,  267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   78,  489,   39,   45,   46,   37,  125,  644, 2150,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,   12,    1,    1,    1, 1126,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2942,    1,  413,    1,   32,  331, 1211, 3295,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  868, 3155, 1656, 2596, 2414,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,    1,    1, 1343,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1362,  213,   37,  151,  275, 2211,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1550, 1096,    9, 3343, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  227,  550, 1451,    1, 1628,  550, 3238,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1105,  787, 1690,  525,   93,  307,  308,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1211, 2878,  698, 1936,  251,  384,  440,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2145,   37,  138,  284,   45,    1,  408,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  183,    1,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2832, 1260, 1645,   32,  557,  540, 2774, 1223,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428,    1, 1727,    9, 3102,  949,   32, 3360,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099,    1,    1, 1006,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  305,    1,   98,  459,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3215,    1,  449,  311,  522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  220, 1700, 1669, 2341,    1, 1851,   56,    1, 2449,   32,  166,\n",
      "         1948,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  270,   32,  166,    1,  361,   39,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2910,  481,  190, 1021,  183,  934,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964, 1625,  632,  441,  190,  619,  227,  132,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  647,    1,  148,  693, 2552,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  764,    1, 1575,   98,  238,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,   37,   84,   28, 2149,  751, 1294,   37,    1, 2328, 1450,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  261,  444,  171,  777,    1,  625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1861,   37,   81, 1862, 1247,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1712,  292, 1228, 2463,   37,  125,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2577, 2873,  644,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,    1,    9, 1400,  815,  140,  432,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1965,    1,  891, 1600,  548,    1, 2699,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1,    1,  405,    1,   37,    1, 1371,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1283,    1,  267,  267,  168,  168,    1,  277,    1, 1328, 1987,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  934,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  162,    7, 3256,  389,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  469,    9, 2179,  788,    1, 2424,  453,  449,  741,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,   51, 1188,  388,   67,  641,   37,    1,  954,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1008,    1, 1213,  318,    1,    1,    1,    1,  971,    9,\n",
      "          111,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1648,   37,  576, 2978,   37, 3015,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2853,   28,   37,    1,   12, 2840,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1652, 1536, 1350,  149,  951,    1,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  566,    1,    1,   45, 3018,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 2272,   85,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647, 2489,  750,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2140,    1, 1523,    1, 2817,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  765,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1839,    1, 1447,    9,  522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1445, 1627, 1090,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2275, 1898, 1995, 2375,   37, 2834,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12, 1733,  765,   37,  981,    1, 1021,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2700, 2898,   29,  384, 1821, 3027,  321,   52,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1139, 2113,  612,  302,  347,  417,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 1342,    1,  187,  453,  365,   82,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579, 1564, 1018,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2700, 1000, 2953,    1,   32, 2884,    9, 2141,  165,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  646,   32,  572,  897,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1988,   45,    1,   79, 1186,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3363, 1877, 2678,   98,    1,    1,  229,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2208,  891,   32, 2091,  691,  863,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2490, 2527,  164, 2705, 1124,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  437,  325,    1,  223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2543, 2519,  614,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,  810,   32,  166, 2225,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1081, 2369,    1,  861,  548, 2095,  937,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,    1, 1077,    9, 1165,   45,    1,  388, 1219,   32,  539,\n",
      "          458,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  455, 1897,   56,   74,  442, 2699,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2153,    1,  465,  404, 2024,  753,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   52,    1,  357,  334, 1445, 1558,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  119,   32, 2364,   45,    1, 2498,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  107,  213,   37,    1,   39,    1,  109,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 2924,   32,  531, 1174,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1431,  387,    1,   32,  453,  627,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  331, 1093,  114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   81,   32,    1,    1,    1, 2565,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1249, 3253,   32, 2069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2700,    1, 2786, 3012,  436,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  166, 1228, 2234, 1530,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2308,  474,  146,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1279,  977,    1, 1469,   37, 1344,   17,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   45,  166, 1230,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1,    1, 1155,    1,  444,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,  414,  823,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  794, 1228,    1, 2639,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2275, 1648,   37,  856,   10, 2075,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,  897, 2995,  332,  118,   32,  786,  339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,  118,  720,   32,  572,  156,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1025,   37,  151,  814, 1501,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2473, 2367, 2419, 1828,  298, 1778, 1273,    1,  920,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2151, 3260, 1045, 1086,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1931,  297,  195,  230,  127,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1527, 1149,    1,  105,  837,   32, 2299,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 3289, 1656, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,   12, 1619,  458,   66,  998,  347,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  163,    1,   12,    1, 2731,  167,    1,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  169,  225, 1137,  548,  700,  325,   48,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2525,  361,    1, 1160,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3360, 1166,  166,    1,   61,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  104, 2548, 2572,   32, 3343, 1523,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  422,  515,  166,    1,   28,   37,  224,   12, 1126,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186, 1974,  164,   13,   12, 2234,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1891, 1074,  267, 1985,  365, 3365, 3338,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  140,  395,   26,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  964,    1,  997,   45,  669,    5,  839,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1, 2911,   39,   32,  119, 1397,   32,\n",
      "          602,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2760, 1554,    1,   32,  888,  361,   98,  114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275,  442,  134,   98, 1513,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 885, 633, 139,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  12,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   95,   37,    1, 1821,  920,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2263, 1532,   32, 1051, 1039, 2690, 2607,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2477,  665,   98,    1,    9, 1694,   45,  356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2120,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  503,  162,  227,  550,   98,  195,   37, 1504,  749,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1039,    1,  213,   37, 1421,  220, 3216,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2533, 1454, 3304,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1994, 2819,    1,    1,  176,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1759,  309,    1, 1259,   66,    1, 1789,  441,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2991, 2384,    1, 2549,    9, 1095,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1936,   95,   32,  903,    1, 1661,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275, 1229,   37,    1, 2095,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,    1,   79, 1628,    1,  191,    1,   79,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   37,  619,   39,   45,  105,    1,    1,    1, 1198,    1, 1018,\n",
      "          863,   51, 1604,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3115, 2935, 1131,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2556,  388,  774,   98,  365, 1940,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  858, 2493, 2947,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  361,  447,   37, 2000, 2320,   45,    8, 1897, 2404,   12,\n",
      "         2237,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1081, 2369,  861,   98,    1, 2921,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 3097,    1,   16,   96,  166, 1117,    1,  163,    1, 1159,\n",
      "          105,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3225,    1, 2642,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2428, 1676,  336,    1,    1, 1220,   59,   94,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1228,  934,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  365, 3372,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2537,  261,    1,   39,   45, 1855, 2784,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  614,   37, 2379,    1,   32, 1013,   45, 2041, 1394,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1591,  332,  636, 1137,   32,  714,  605,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878, 2458,  361,    1, 1753,  829,    9, 1350,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 793,  46,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  37,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,   91,  176, 2413,   98, 1649,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1982,  861, 1119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  657, 1042,  315,    9, 1766, 1767,  412,  402,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,  942,  162,    1,   98, 1204,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2835, 1625,   37,    1,    1,   45,    1, 2162,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2175,   37,  105, 2355,   27,  334,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  854,  664,  411,    1,   32, 2620,  686, 2069, 1463,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1933,    1, 1712,  176,  656,   45, 1523,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  565, 2745,   37, 1330,   32,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715,  460,  639,  744,  119,   73,   98, 2542,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,  310,    1,    9,  453, 1021, 1151,  973,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  275, 1030,    1,   45, 1412,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2004, 2993, 1564, 1796,  973,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,  434,  105, 2995,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1283, 2087, 2614, 3186,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   45,  105, 2423,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  545,  476,   37,  168,   37,  611,  920,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  282,  659,   45,  224, 2355,  193,  205,  405,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  947, 2263,  297, 2147, 2950,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1831, 2682, 2371,  187, 2510,    1,  837,  969,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  709, 1956,  232, 1550,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1829, 3144,  741,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   12,  475, 1718,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1061,    9,    1,    1,    1, 2942, 1564, 1018,  516,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  508,   79,  600, 1612,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1351,   37,  303,  967,  105, 2312, 1133,  100,   37, 2535,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3275,    1,   39,    1,  320, 1394,  650,  364,  162, 1383,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   69,    1,  384, 1146,  106,   32, 1033,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   61,  424,  221,  191, 2114,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273,   12,    1, 1041,    1, 1714,    9,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2227, 2533,  967,  247, 2364,   98, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2298, 1976,   32,    1,  293,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3244,    1,   32,    1,   56, 1090,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2114,   37,  693,  617,  259,  659,   45,  844,   16,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2870,   27,  163,    1,   12,    1, 3150,   32, 2597,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2694,  171,   45, 1193,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   12,    1,  535,  656,  729,  338, 1139, 2928,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,  438,  159,    1,   98,  605, 2199,  115,   45,  845,  147,\n",
      "          484,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2378, 3289, 2347,   32,  245,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1190,  894,   77, 2178,  448,  469,    1, 1721,  774,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3116,  922,  311, 2936, 1908,  220,    1,    1,   32,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 1405,    1,  321,   52,    1,   37,  166,  104,    1,  147,\n",
      "          261,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  387, 2485,  191, 2208, 2402,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2179, 1641,    9,  968,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  463, 2571,    1,  693, 2518,    1,    1,   32, 2184,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1673,    1, 1260,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1968, 3007,    1,   28,   40,    9, 1273, 2798,  918,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1187,  247, 1722, 1509,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  342,  335,   20,    1,  296, 2096,   37,  397,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2442,    1,   98,  166,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  225,   70,  245,  144,  145,    1, 2302,  720,   98,  739,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2308, 2362,  167,   52,  915,  916,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1662,   98,    1,    1,    1,   39,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2245, 1087, 2232,  437,  387,  197,   32,  572,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  726,   32, 2161,   12,    1, 2069,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   12,  365, 2549, 2094, 1013,  754,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2397,  190,    1,  680,  786, 3137,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  957,  190,  544,  810,  460,  321,   37, 1211, 1527,  475,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1048, 2455,   45,  203, 1366, 2898,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  485, 1948, 1644,    1,    1,  939,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  561,    1,    1,   79,    1,    1,    1,  588,  901, 1661, 2596,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  746,  315,    1,   80,    1,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1721, 1937,  790,    1,  365,  503,    1,  195,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  294,  295,  155, 1915,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2192,  105,  311, 1242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  519,  688, 3250,    1,  439,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  488,    1, 2095,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  800,   60,   66,    1, 2065, 2064,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200,   47,    1,  361,  745,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1819, 2690,  384,  326,   37, 1752,   26, 1039,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  834, 1013, 1522,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2236,   37, 1413,    1,  176, 3182,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  119,  441,    1,  297, 1273,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  381, 2120,  547,  548, 1446,  287,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1619,  458, 1874,  592,   12,  395,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1794,   61, 1542,   37, 1844,  444,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1792,  643,    1, 1185,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  422,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2541,   45,  171, 2868,   32,  395,    9,   46,   98,  403, 1447,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  519, 2939,    1,    9, 1517,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   43,    1,   54, 1802,    1, 1159, 1803,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  190, 2507,   95, 1539, 1821, 2057,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   98,  103,  548,  411,  868,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1107,    1, 1707,    1,   85,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,  105,    1, 1370, 1051,   12, 2805,    1,   98, 2348, 1225,\n",
      "         1499,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  462,  721, 1579,   49,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  104,  560, 1274,  245,  915, 1034,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,  919,  356, 1281,   98, 2539,    1,   45,    1,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1017,  542,    1,    9,  449,    1,  176,  365, 1090, 2692,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,  865,  187,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 2580,  861,  328,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  216,    1, 1485, 2147,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1668,  619, 2967,  384, 3152,   32,  142,   37,    1,    1, 1331,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2881, 1778,    1,  166,  454,   37,  168, 3004,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2238,   37,  843, 2979,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,  407,   98,  395,   69, 1220,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2932,    1,    1,    9, 1125,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1087,  868, 2723, 1318,    9,    1,    1,   46,   45,    1, 2759,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  437,  353,  242,  572,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  884,  631,   32, 1228,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3254, 2329,    9,  166,  631,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1855,  446,    8, 1263,   98, 1194, 1856,   45,    1,   45, 1428,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3340,   32,  531,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  105,    1,    9, 1022,  913, 3108,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1855, 3102, 2572,   32, 3360,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1257,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  799, 2405, 2029,  584,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  790, 1579,  815,   45,    1,    1,   32, 2990,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1760, 1089, 1090,    9,    1,    1,  649,    1,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  509, 2449,    1,  528,  636,  832,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3177,    1,   85,   37, 3024,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1123, 2871,    1,    1, 3271,  123,   37,  105,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  102,  365,  988, 2168,   37,    1, 1443,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2162,   45,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  613,  777,  412,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2381,    1,    1,   61, 3141,   12, 1509,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1284, 1393,  111,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051,   37,   26,  704,  705,  656,   32,  455, 1411,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  488,  116, 2931,    1,  220, 1204,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2476, 2760,    1, 2057,  176, 2826,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1874,    1,  220,  365,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   63,  166,  862,    1,  223, 1042,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3051, 1386, 1822, 1947,    1, 2117,   23,   32, 3118, 2764,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1920,    1,    1, 1988,   45,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  220,    1,  187, 1879, 3229,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3213,  967,    1, 2537, 3277,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  524,  525,   15,  410,   32, 1893, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   56, 2844,   32,  344, 1260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,    1, 1551, 2646, 3346,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2004, 1128, 1614,  340,  439, 2232,  260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  169,  942,  546,  103,  710,    1,   12, 1644,  884,  297,  187,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1, 3358,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   39,   45,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361, 1850,    4, 1822,   52,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2578, 1258,    1, 1343,  176, 1181,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2940,   39,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2884,    9, 2580, 2851, 2558,   66,   32, 1698, 2482,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 1564,  166,  985, 1192,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,    1,  180,  759,  399,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2468,  884,  105,  631,   32, 2910,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2863,    1,  755,  872,   28,   37,  877,    1, 2219,   45, 2332,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  219,    1,  168,    9, 2585,   98, 2820,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  613, 1017,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   66, 2410,  242,  548,    1,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   26,  417,  187,   69, 1784,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1360,  612,   52, 2175,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1646,  420,  640,  761,  159,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2835,   12,    1, 2770, 3140,   12,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,  103, 3209,  920,    1,  162, 1267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1373,  433,  102,  167,  245,  191,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1515,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1830,   37, 1539, 3072,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1518,  699,  143,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1419, 2183, 2431,   37, 3356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1,    1,  122,  297,  679,  529,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  422,   12, 1381,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   34, 2571, 2027,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,  202, 3132,  565, 1533,  384,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  331,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777,   37,  130, 3028,  861, 1541,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   92, 2057, 1347,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3199,    1,   28,  105, 2795,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3364,  267, 2330, 3339,   46, 1822, 2535, 2041, 2655,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  742,  288,    9,    1, 2699,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  580, 1610,  422,  521,  149,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,  108,   45,  388, 1021,    6,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1474,    1,  629,    1,  191,  531,  104,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 1546, 1082,  249,   37,  335,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387,  932,  530,  308,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2960,   45,    1,    1,  696, 3361,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 3212,    1, 1530,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328, 1282,   12,    1, 2246,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2519, 1607,  231,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2959,  186,  608,    1,    9, 1194,  726,   32, 1559,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,   25,  317,  803,  682,   32, 2204,  605,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,  726, 2161,   12, 1660,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2389,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 3013,    1,    1,    9, 2696,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 1386,   37,    1,   37, 2468,  600,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   10, 1450, 2275, 2136,  267,   10,   32,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,   37, 1947, 1718,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  189,    6,  377,    4,    1,    1,  311,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1237, 1658, 1117, 1525,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  266,  353,  197,  744,  131,  752,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,    1,   37,  686,  166, 1605,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  592,  721,   90,  208,   37, 1664,  734,    1, 1511,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433, 2424, 1133, 1465, 1994, 2650,  302,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  203, 1183,   61, 1658, 1412, 2290,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  144,  145,  387, 2073, 1023, 1315,  308,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3244, 1398,  612, 2535,    1,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1, 1681,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1733,   90, 1796,  650,  247, 3346, 2770,  565,  792,    1,  792,\n",
      "           45, 2537,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 1962,    1,   98,    1,    1,  269,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3375,  588,   37, 2237, 3358,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1624,   37, 3333, 1241,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3239,    1,   28,  548, 1357,   45, 3301,   12, 2667,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433, 2540, 3153, 2220, 1281,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1654,   24,   37,  109,  971, 1448,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,  193, 1542,   37,  151, 1117,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1962,  200,    1,  618,    9, 3068, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  581, 1267,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  315,   37,  125,    1, 1149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861,  681, 2123,   37, 1505,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2757, 1810, 1988,   32, 3386, 2930,  776,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386, 1426, 1845,  132,  220,  359,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  111,  575,    1,  220,  224,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1842,  551,  613,  744,   28,  104,  331,  591,  574,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  147, 1707,  668,    1, 1107, 1091, 2086,  396,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   28,   37,  846,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  381, 1041,  297,    1,  574,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,    1,  829, 1753,  923,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   10, 1484,    1,  600, 1994, 2275,  378,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162, 1217,  297,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1041,    1,    9,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715, 1011, 1885,    1,  733,  419,   48,   32,    1,    1,   37,\n",
      "            1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3155, 1656, 2596,  640,  104, 3111,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3142,  167,  815, 1590,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  581, 1766, 1767, 2461,  437,  992, 1836,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,    1,  447, 1673,  449, 2539,    1,    1, 1150,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  376,  649,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  967,    1,    1,    1,    1, 1844,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1687, 1022,    1, 3008,  105,    1, 1551,   45,  114,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3186,  688, 3266,    9, 1909,   73,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2694,    1,  552, 2491, 2693,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   37, 1584,    1,  442,   32,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  671,    1,    1,  580, 1857,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   56, 1130,  317, 2056, 1215,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1035,    1, 1070,    9,    1,   12, 2488,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273,  259,  772,   37,  103,  131,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 1053, 1419, 1778, 2580, 2851,    1, 1211,    1, 2812,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,    6,    1,    4,   32,  602,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  245,    1,  565,   28,   37, 1515, 1691,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2157,    1,  884,  105, 2337,   37, 1125,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1763,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  641,   49,    5,  302,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  803,    1,   51, 1289,    1,   37, 2500, 2218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1214, 2761,   61,   74,   37,   74,  220,    1,    1,   98,  917,\n",
      "         3265,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  157, 2549, 1781,  191,  334, 1228,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,   23,   12,    1,  343,  297,   20,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2838, 3224, 1333,   32, 3078,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  794, 2355, 1013, 2549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1497,  186,   37, 2712, 3115,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  437, 1261,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  388, 1999, 1530,  548, 2164,   32, 1081,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3068,    1,  911,  220, 1228,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2984, 1456,  986,  581, 2237,   37, 2662,   12, 2919, 2918,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523,   51, 1334,  590,    1,    9,  920,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  755, 1042,  829,   12, 3042,  161,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 2252,    1,   37, 1046,    1,   32, 3310,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  192,    1,   98,    1,    1,   32,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123, 1497,  565, 1480,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  159,   45,  327,   13,  324,  701,  548,  326,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  557,  540, 1512,    1,    1,  239,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  506,  782,    1, 1746, 2699,    1,    1, 2353,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1,    1, 1632,  455,   12, 1850,    1,  274,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  196,   59,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2614,   37, 1508,    1,   37,   56,  356, 1259,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2685,  726,   32,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 1625,   29,  321,   52,    1,  384,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2071, 1331,    1, 2992,  920,    7,   37,  657, 1560,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  267,  171,   69,  681,  167,  142,    9,   49, 1541,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3319, 2712, 3231,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  601,    1,  452, 2078,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  607, 2257,   39,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,   90,    1,  204,   12, 1542,   37,  856,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3068,  794, 1158,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602, 1484,    9, 1553,   37, 2199,   60,  276,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,    9,  914,  220, 3265, 1987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1586,   28,   98,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1013,    1,  361,  222, 1028,  220, 1521,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,  384,  829,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  764,    9,  901,  361, 2713,  618,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162, 1018,  274, 2690,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,    1,  476,  105,    1,   45, 2355, 1013,  218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3227,  132,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1099,   12,    1, 2089,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2643,    1,  254,  810,  917,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2453,    1, 1822, 2654,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2967,    1,   37, 1668,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2583,  190, 3164, 2741,  444,  942,    1,  653,   28,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,   32,  870,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2643, 1890,    1,  166, 2171, 2771,   61,    1,  220,    1,  361,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 2306,   32, 1123,    9, 1893,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,  709, 3164, 1240,   77, 1573,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1971,    1,    1, 1764,   39,  220,    1, 1987,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  275,  580,    1,  320,    1, 3010,  187, 1018,  402,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1360,  612,  489,  166,    1,   98, 2193, 3149,  778,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1486,    1,    1, 2021, 1041,  342,   59,  191, 1645, 1852,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1625,   37,  665, 1092,   32,  105, 1273,  259,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,    1,  187,   69,    1,  242,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  686,  487, 1583, 2791,   32,    1,  531,    1,    1,  590,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2238,   37, 1021, 1411,  848,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,  691,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  550,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3183,    1, 2672, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   61,    1, 1488,    1,   61,  460, 1452, 2267,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   85,    9,  657,   32,  572,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,  640,  365,  340,  671, 2405,    9,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878, 2696,    1, 2387, 1879,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  988,    1, 1928,   32,  365, 2759,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  936,  365,  552, 2168, 1167,  321, 1844, 1718,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   49,  533, 1027,   69,  297,  105,  106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3334,  825, 2069,  444, 2741,  187, 2018,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,  476, 2571,    1,   32, 3118,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1061,  297, 3379, 2147, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2868,   37, 1697,   37, 1811,  404,   98, 1332,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2607, 2198, 1780,   45, 1038,   32,    1, 2206, 2989,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2153,    1, 3377, 2772,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1,    1,  167,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1625,   37,  798,  166,  403, 1383,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  178,  770,   45,  487, 3102,    1,   27, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,   99,   12,    1, 1082,    1,    1,    1, 1511,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2328,    1,  176, 1215,  846,   45, 1620,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1290,  396, 1269,    1,    1, 1071,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,    1, 2856, 1485, 3091,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3260, 3232,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2103, 2727,  187,  985,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1384,    1,   37,    1, 1763,    1,  290,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129,    1, 2783, 2513,  726,   45,  914,  220, 1548,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,   25, 2487,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,   37, 2346,    4,    1,    1,  219,  112,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  311,   12, 1107,  132, 1086,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,   12, 2699,   37, 2918,  431, 3048, 2818,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  326,  956,    9,    1, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,  920,   12,  199,    9, 2024,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3134,  942,   12,    1, 1564,    1, 3141,  865,   37, 1959,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2150,   51,   52,    1, 1206,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1419,  365,    1,    1,    6,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2479,  631,   32,    1, 3129, 1787,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2542, 2576,  449,  356,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3168,    1,    9,  590,    1, 1114,  176,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  973,    9,  853,  538,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700, 3361, 2572,   32,    1,  187, 3155,    1,    9,  810,   39,\n",
      "         1995,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1710,  619,    5,  591,  680,  302,    1,  191,  104,  233,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,  166, 1604,   23,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,  155,  737,  983,  837,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  666, 2817,  584,    1, 1554,   56, 1530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1914,  325,    1,  437,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2642,    1, 1586,   28,  449, 1479,  922, 1918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2246,    1,  980,   81,   32,  548, 3265, 1857,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925,  879,  284,   45,  453,  844, 1495,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  258,  957,  741,  155,    1,   12, 1625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  615,   81,  550,  369, 1605,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 2997,    1,   26,   28, 2580, 2851,   37, 1260, 3031,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2189,  239,  168,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,   37, 1876, 1234, 1242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1591,  159,  120,   98,  714,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,  186,  608, 2615,   32, 2513,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649,    1, 1065, 1190, 1450,   10,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   12,  551,  552,    1,   98, 1109,    1,  734, 2552,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,    1,  632,  622, 1967,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1815, 3146,  321,  612,   52, 1961,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  862,  942,  733,   48,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1296,   28,    1, 1127,  271,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,   34,  389,    6,   37,  118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  325, 2968,  856,  700,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1488,  763,  166, 1509,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   80,  682, 1737,  220,  458,   45,  507,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,   37, 2654,    1, 1901,    9,  163,    1,   12,    1,    1,\n",
      "         1108,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  861,    1,  191, 2355, 1013,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  688, 2468,   37,  759, 1940,   12, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3151, 2308,   37,  907,  167, 1291,   18, 1159,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3276,  619, 2716,    1, 1608, 1194,    1,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1178,  325,   28, 3017, 1008,   32,   10,  973,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1407,    5,    1,    1,   37,  163,    1,   12,    1,    1,  506,\n",
      "          267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  116,  361,  760,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492, 3060,  993,    1,   37, 3006,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,  951,    1,  166,    1,  203, 2948,    1,  105,    1, 1816,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878,  157, 1735,  202,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,   34,  861,  548,    1,   22, 2421,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  268, 1949,  857, 1469,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  121, 1821, 2640, 1478,   98, 3024,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614, 1918,  786,    9,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  342, 1082,  949,   45, 1147, 3365,    1, 2061,  864,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  348,   37,   47,   48,   32,  486,   50,    9,  152,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1502,  353,  118,  197,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1704,  861, 2454,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1790,  936,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1474,    1, 2198, 1077,    1,  105,  506,  782,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  851, 1830,   37,  288,  846,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1476,  574, 1541,  245,  118,   32,  871,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 195,   1,   9, 230,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 266, 353, 354, 744, 372, 752,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2476,  875,    9, 1832,  220, 2427,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790, 2373, 1901,   45,    1,    9,    1,    1, 3031,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,  964,   98,  965,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2212,  861,  162, 1251,   45, 2301,   92,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  903,    1,  904,    1,    1, 3096,  437,    1,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1433, 1187,  166,  443,   77,    1,  104,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  469, 1702,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69, 1298, 1382,  187,  104,    1,  504,   76,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1353,   32,  104,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1809,  105, 1844,    9,    1, 1731, 1255,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3006, 1662, 2968,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  197, 1042,  202,  387,  198,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  719,   37,    1,  460, 1499,    1,    1,    1,    1,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1991,   37,  506,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2550,   98,    1,   45,  395,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1538,    1,    1, 2782,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  284,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1141,   37,    1,    1,    1,  548,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101,    1, 2414, 3384,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228, 1088,    1,   32,    1, 2527,  164, 2716,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 2755,  325, 1541,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  527,  353,    1,  354,  528,  242,  529,  408,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,    1,   96,  297,  915,  317,   37, 1733,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1401, 2158,   45, 2121, 2855,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  389, 2172,    1,  205,    9,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56,  104, 2548, 1046, 2322,   32,  602,  297,  531, 3082,  966,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1435,  691,   12,    1,  566,  395,  458, 1429,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,   26,    1,   98,  954,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  282, 2367, 2695,    1,   45,  166, 1034, 1399, 2775,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  770,   45, 2433, 1920, 1976,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1309,  891,  453, 1013,    9,  365,  650,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2964, 1445,   26, 2713, 2690,  525,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1404,   45, 1405,   12,  508,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1366, 2582,  590, 2309,  202,   37, 1418,  384, 3116, 3217,    1,\n",
      "          267,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  964, 1921,   32, 2707,   98, 2507, 2237,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  462,   37,  142,    9,   49,    7,   69,   50,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  167,  877,  218,  714,  906,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  782,  363, 1569,  176,  415,  166,  917,  199,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 1652,  875, 1350,  149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1256,    1, 1417,    1,    1,  710,    1, 1554,  669,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1022, 2350, 3286,  515,  691, 1285,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1261,  376,  157,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1809,    1,    1,   37,    1,  190,   52,  105, 1787,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  921,  413,    1,  693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962, 3117,    1, 1264,  841,  631,  220,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1932,   37,  125,  541,  424,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1023, 1204,   12,  949, 2306,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 2321, 2856,  388,    1,  763,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,  104,  883,    1,  284, 1565,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  583,  191,  732,  880,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1574,  361, 2383,  600, 1257,   12,  467, 2092,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  661,   98, 2890,    1,  395,    1,  105,    1, 2826,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 733, 487, 285,  37,   1,   9,   1, 131, 104,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 796, 297,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2213, 1427,    9, 2939,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2610,    1,    1, 3005,    1, 1905,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  189,    1,  920, 1961,   37, 1169,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  802,    1,  453,  449,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  874, 1713, 2992,  613,  858,  437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2053, 2055,    1, 1374,   32, 1169,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   14,   15, 1285,   28,  187, 1656,   15, 1269,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2692,  775,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  818,    1,    1,   45, 3229, 1574,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  799,    1,   39, 2796, 3138, 1090,    9, 1517,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1341,  975,    1, 1501,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1022,    1, 2296, 3232,  872,  420,  385,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1668,    1,   12,  105,  686,   32, 2760,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1, 1015, 2108, 1268,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,  140,   32,    1,   43,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3365,   32,  531, 1046, 2162,  187, 1757,  431,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2027, 1924,    1,    1,   10, 2431,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  716,   45, 3356,  787, 1302,  630,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2,  25, 439, 995, 242, 187,  69, 102, 720,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 596, 616, 219,  25,  71,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1934,  879, 3093,  650,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 3228,    1,    1, 1863,    1,  928,  548,    1, 1948,    1,\n",
      "          298,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1056,  681,  598,   45,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 1190,    1,   37, 2341,  949,   45, 3073,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2423,   32, 1345,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,    1, 1354,   17,  384,  822, 2429,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 744, 968,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1, 658, 506,  88,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2967,    1,    1,  741,   32,  584,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,   61,  999,    1, 1507,  361, 2051,  493,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 722, 723,  32, 702, 311,   1, 724,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 103,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3231,  563, 1110,    1, 2555, 3235,  539,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,    1,    1,  590, 2181,   32, 1675,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  908, 1671,   37,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  760,  224,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  967, 2463, 2589,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,    1,   45,    1,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2266,  583,  191, 2059,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1617,   61,  855,  176, 2643, 2826,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  636, 1124, 1822,    9,   69,    1,   37,   52,    1,  446,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  397,    1, 1838, 1034,   45,    1,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3188, 1401, 3244,  608, 2807,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  425,  426,  376,   15,  570,    9,  367,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  868,  671,    1,  197,  361,  408,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,  603,   28,   37, 2391,    1,  105, 1292,   61,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  647, 1707,  148,   12,  214,  142, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  456,   85, 1994, 2819, 2567,  437,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1170,  484,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  198, 2164,  640,  403,  455,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1457,  782,  700,    1, 1717,  191,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1133,  478,   76,   37,  583,  294,   12, 1913,  401,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  561, 2833,  331,   32,    1, 1228,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,    1,  104, 1140,   37,  221, 2924,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  386, 2905, 1523,   45,  166,    1, 1534,  444, 1545,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1126, 1611,   79,   37,    1,  698,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3378,  750,  872, 1070,   37, 1418,  384,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2229,  705,  985,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  997,   37,  817,   98,   25, 1128,  343,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3262, 1545,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2977,   37, 1776,    1,   45,  365, 1280,   45, 2983,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,    1,  166, 1243,  384, 2859,    1, 2655,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  954, 1258,    1, 1437,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777, 1008,  365, 1644,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  236, 1022,    1,   98,  776,  297, 1405,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  207,  861, 2429, 1239, 2056,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  389,  682,  423,  560,  347,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 3177,  142,    9,  593, 1863, 1624,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,  861,  293, 1166,    1,   61,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  833,  612,    1, 1495,   45, 1940,   12,    1, 2161,   12,\n",
      "            1,  482,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2421,   32,  395,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  626, 1110, 1740,   37,    1,    1,  493,  250,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2066,   69,  640,  593,  954,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652, 1236,  829,  297,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1051,   82, 2954,  220,  302, 1712,   37,    1, 2964,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,  200,  845,  846,  207, 1085,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2662, 2699,    1,   81,  449, 1748,   45, 2820,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1037,    1,    1,  923,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2974,  872, 1542,   37, 2428, 2695, 2223,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3174,  140,    1, 1684,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,   12, 3372,    1,  488,   37,  319,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61, 1997,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  334,  321,  151,  105, 1311,    1,  202,  321,  334, 2810,   32,\n",
      "          460,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  119,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2978,   12,    1, 1539, 2306, 1961,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 1756,  891,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1094, 2257,   39,   45, 3046,    1,  380, 1530,  187,    1, 1082,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,  980, 2915,   37,    1, 2024,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  350,  176, 3339, 2735,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1413,  632, 2701, 2954,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2514,  459,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  526,   15,   23,  636,  125,    9,  526, 2104,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3188,   37,  619,  449,  698,  951,    1, 3326,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2964, 1604,   39, 2851, 2987, 2693,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2762,   32, 2994,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1461,    1, 1464,   37, 1604,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  785,    9, 3222,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  315, 1738,   71,   32,    1,  347,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2252,  179,    1,  180,  170, 1770,    1,  613,  293,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  245,  995,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3250,    1, 1971,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3250, 1523,  315,    9,  519,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1739,  275, 2934, 2457,    1,  444,  590,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  724,  434,   61, 1715,   27,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  437,   45, 2458,    1,    1, 1236,  829,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1584,   12,  193,    1, 2292,   32, 3141,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  978, 3138, 1421,   72,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  474,  744,    1,  477, 2306,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2738,    1,    1,    1,   32, 2142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  713,  460,   39,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  667,  947, 1013,    9, 2313,    1, 1260, 2566,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  636,  477,  891,   32,  430,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  215, 1787,   45,  854,  486,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  197,   51,    1,  706,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2983,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 1470,   45, 1821, 2536, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  593, 2965, 3270,  288,   37,    1, 1955,    1,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1665,  384, 1204,   98, 1965,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,   21,   37, 1289,    1,    1,  191,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537, 1190,  640,   39,  176,    1,    1,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1702,    1,  395,  447,    1,   32, 1742,    1,  738,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1968,   40, 1917,  614,   37, 1363,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1626,    1,   37, 2997,    1, 2994,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2308, 1260,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2256, 1672, 1809,  589,   98,   81,  962,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1,   28, 1102,    1,  931,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3072,    1,    1,  522,  321, 1154,    1, 1521,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  134,    1,  220,    1,   32, 3070, 3102,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1163,   12,  737,  156,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,    1, 2005, 1159, 2033,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  121,    1,    1, 1839,    1, 1259,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  213,   37, 1749, 1145,   37,  194,    1, 1469,   32,  849,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1771, 2402, 2485,  515,   10, 2025, 2591,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2942, 1458,   39,   45,  183, 2107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  409,   25, 1253,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1723,    1,  848,  220,   59,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   46, 1813,  705,    1, 1417,    1,  960,    1,  474,  729,   32,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1174,   32,   22,  854, 2596,  776,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1428,    1,    1, 2266, 1082,  497,   37,    1,    1,    9,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1550, 2266,   12, 1596,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  164, 2134,  211,   32, 1405,    1,  776,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2579,   12, 2273,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2055,    1,  943,  411,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2605,  753,   37,  698,  810,  297,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  116, 1353, 2179,    1,    1,  506,  782,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  787,  665,  331,  636,    1,   98, 2872,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788,   12, 1629,  267,   51, 1753,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 2860,   51,    1,  297,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  228, 2844,   32, 2970, 1177,   32,  447,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1528,    1, 1008,    1,  331,    1,  405,    1,  475,  172,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1821, 2640,    6,   85, 1011,    1, 1489,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1801,    1, 2997, 1614, 1258,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3255,    1, 2297, 1863,   45,  166,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2916, 3256,  872,  420,  385,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,  220,    1,   69,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700, 1140,    9, 1428, 1358,   98, 3036,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  790, 1574,  337,    1,  469,   37,  151,  229,  384,  215,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 1579, 2180,    9,  597, 1789,  650,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1186, 1625,  361,    1,    9, 3102,   32,  531,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3364, 1484,    9,  439,   37, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,  802,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,  460,  796,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3156, 2201, 1295, 1999, 1530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2991,  361, 1095,  877,  166,  777,  112,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 225,  70,   1, 548,   4,  29,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 395,  37,   1,   1,  98, 284,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  485,    1,  361,    1,    1,    1,  518, 2054,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,   25,  123,  242,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  446, 1401,    1,  176, 3025,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808, 1346,  193,    1,    9, 2596,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  511,  936, 2128,    1,   32, 2774, 2517,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  383,   69,  640,   91,   60,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2634,    1,  326,   37,  508,   79,  176, 2177,  988, 1027, 1597,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  316, 1123,  176,  629,    1, 3167,   51,  588, 1077,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1149,  176,   56,  960,   32, 2206, 2435,  168,   98,  477,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1829,  208,  114, 2414,  249,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   46,  861,    1,    1, 2359,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1988, 2356,   45,    1, 3389,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1327, 1086,    1, 1147, 1844,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  166, 2177,  454,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1, 1057,  600,  527,  869,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  103,  187,  239,  817, 1069,    1,  341,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1230, 2528,  361,  163,  956,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2844,   32, 2752,  336, 1374,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1676,    1,   32, 3344,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1079, 3063, 1070,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1316, 2735,    1, 3382,  155, 1067,   45,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  925,    1,  727, 1864,  613,  132,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  726,    1,    1,  267,    1,   12, 2565,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   28, 1220,    9, 1697,   61,    1,    9,  818,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  164, 1333,  139,   30,    1,  910,  790,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  957,    8, 1081, 1697,  304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  176,   48,  906,    1,  385,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237, 2489, 2789, 1468,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  267, 2289,   12,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3276,    1, 1114,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3173, 2751,    9,  105, 1389,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,  102,   71, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  531, 1987, 2116, 1672,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  539,  458, 1841,  513,    9,  949,   45,  531, 3102,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  517,    1, 2226,    1,   12,   26, 1260,   37,  335, 3391,  384,\n",
      "          531, 2751,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2924,   37,    1, 2837,  384,  557,  540,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  557,  540, 2832, 1046, 1645, 2924,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,    1, 3130,    1,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2862,  622,    1,  267, 3093, 1851, 1144,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,   12,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1307,   12,  636,  672,  162,  227,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  335,    1,   32, 1139, 1171,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,   61,    1,    1,  590,    1,  193, 1884,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   81,   37,    1,    9, 1110, 3130,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3096,    1, 1684, 1625,  439,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,   12, 1009,    1,   32,  365, 2224,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37, 1198,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,  331,  613, 2264,   77,  617, 1397,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,   12, 1818,  147,  991,  454,    9,    1,  361,    1,  170,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12,    1,   37,    1, 1411,  356,  535,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1102,   32,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777, 3005,    1, 1231,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  773, 2669,  105,  218,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2188, 1877,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1861,    1, 3380,   37,  429,   46,  297, 2834,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1962,    1,   37, 1594, 2405,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  342,  134, 2064,    1,  657,  297, 1100,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  407,  388,  763,   98,  889,  509,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2909, 2856,  176, 1853, 1557,  186,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  382, 1218,    1,  105, 2947,    1,    1,    9,  274,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 191, 365, 844, 132,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 187, 529, 815, 418,   1, 395, 566,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  801,  187,  159,  698,  605,   32,  409,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 3006,  360,    1,    1, 1220, 1419,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  191,    1,    1,  508,    1,  565, 1958,  166,    1,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1008,  678,    1, 1644,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  593,    1,    1,  493, 2372,    1,  267,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  198, 3087,    1, 2433,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   15,  720,    1, 1009,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  477,  163,    1,   12,    1,    1,   32,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1069,  490,   32, 3360,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,    1,    1, 2631,  619,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  885,  339,    1,  885, 1385,   45, 2039,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  459,  302,   37,    1, 1839,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,   71, 1750,  119,  105,  106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203,  190,  166, 3183,  132,  220,  166,  270,   45, 3229,    1,\n",
      "            1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1232,  334, 1445,    1,    1,    1,    1,  321,   84,   32,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1797,  195,    1,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1053, 1760, 2500, 3036,    1, 2103,  617, 1116,  562,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2550,    1,  627,   98,  395,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3112,    1, 2942,   98,  119, 1171,   37,  671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  437,  267,  967,  590,  315,   37,  151,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1842, 2807,  872,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,    1,  928,   32,    1,    1,  548,  947, 1948,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,  435,  365,  861, 1259,  220, 1081,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 2580,  861,  328,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,  548, 1884,  338,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  167,  877,  388,   45,    1,  887,    1,   82,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,   37,    1,  125,  636, 1778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1017, 1148,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   28,  361, 1075,    1,  199,   39,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  889, 1675,  475, 1454,  673,  910,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1117,  442,  267,  605,    1,   32, 1352,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2693,    1, 2988,    1,    1, 2432,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3370, 1450,  104,  622, 1967,   32, 3376,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  761,  967,  229,   32,  260,   37, 1504,    1, 2351,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    9,  215, 3102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  288,   37,  949, 1106,    1,    1, 1626,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1465, 1466,  325,    1,  176,  331,  265,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  476,   37,    1,  168,   98, 1821,   95,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056,    1,    1, 2572,   32, 2504, 3348,  463,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2689,    1, 1401,  166,  454,   32,    1, 1618,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,  708,  103,    1,  710,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1913,  401,  156,  701,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1712,   37, 1776, 1778,  328, 2549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 1697,  105, 1585,    1, 2547,    1, 3053, 2770,  258,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018,    1,    9,  649,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  936, 1230, 2543,    1, 2627, 1234, 1863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  560, 1274,   79,   32, 1893,    1, 1034,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169, 3090,  176,  455,   26,    1, 2779,  801,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  294, 3102, 2572,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,  140, 2255,   43,  444, 1361,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3272,  331,    1, 3298,    9, 2227, 1383,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2477,  944,    1, 3053,   98, 2069,    1, 2699,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1, 2540, 2451,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,    1,   90,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   28,  384,   85,  680,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,   12, 1513,   32, 1512,  187,    1, 1707,    1,  469,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2448,  386,  512,    1, 3277,   37, 2565,    1, 1194,  427,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  626,    1,    1,  102,  583,  163,    1,   12,    1,  244,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,   22,  359, 1542,   37, 1195,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1089, 1090,    1,  921,    1,   59,  449, 1034,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  593, 1281,   98, 2500, 3036,    1,  215, 1544,   28,   37,  104,\n",
      "           97,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  528,  247,    1,    1,    1,  682,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1479, 2836,  826,    1,   32,  447,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37, 1636,  285,   32,  854,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  862,    1, 1281,  868,    1, 1318,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  167, 1371,  420,   37, 1604,  465,   95,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1264,  187,  931,    1, 1717,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    9, 1714,  994,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,    1, 2764, 2765, 1634,  722,    9,    1,    1, 1450,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3143,    1,  565,  820,   98, 1368,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2631,  565,  920,    1,   32, 1246,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2346, 1125,   98,  183,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,    1,    1,   32,  955,  662,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  344, 1656, 2596, 2414,  228,   32, 2597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187,    1,    1,    1,    1,   37, 2856,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777,  708, 3028,   37,    1,  453,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2671,    1,  142,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056,   96,   45,  105,    1,  508, 2072, 2288, 1277,  298,   98,\n",
      "            1,    1,  420,  963, 2122,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   51,  606,    1, 3012,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 542,  32, 111,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 657,  32, 260,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  884, 1003,  176,    1,  220,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1183,  713,   61,  297,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 1539, 2457,   32,   86,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  190,   52, 1103,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1349,   12,    1,    1,    1,  168, 2391,  845,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 1585, 2414,   32,  539,  458, 1193, 1108,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1805,   22,  275,  967, 1019,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284,   45, 2153,   32,  386, 1147,  662,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   68,   69, 1137,   37, 1034,  845,   98,   64, 1491,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  174,    9,  483,    1,  417,    9,    1,  529,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  551,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1117,    1,  475, 1061,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  760,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363, 1627,  517, 1523,  444,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1340,    1,    1,    1,  361,  638, 3212, 2911,  289,   98,    1,\n",
      "           12,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,  140, 1876,    9, 3339,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3061,   16, 1791,    1, 2402, 2558,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1396,    9, 1411, 1778,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  994,  387,  120,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3029, 3027, 1478,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  424, 1034,   12, 2462,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  924,    9, 2313, 2572,  191,  947,  267, 2009,  729,   26,    9,\n",
      "         2281,  134,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  159,  335,  105, 1150,   98,   69,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2034,    1,  131,   32,  572,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  487, 1407, 1190, 1921,   32, 2245, 3118,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2565,    1,   98,    1, 1910,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2455, 1458, 3016, 1935,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1564, 1819, 2690,   26, 1039,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,    1, 2018,   32,   46,   37,    1, 2024,  226,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1050, 2122,    1,  297, 3387, 2909,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1408,   28,  227, 1604,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1718,   37,   52, 1781,  176,   26, 1039,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  220,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  861, 1414,  856, 2751,   32, 2597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2618,   37,  759,  593, 1990, 1286, 3179,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1821, 2190, 2640, 1830,    9,  865,  754,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018, 2108,    1, 2343, 1999,  864,    1,  267,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  848,  884,   98, 1230, 2543,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 2748,    1,    1,  162,  166, 1217,    9,  920,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2534,    1,  162, 2024, 2223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 3382,  213,  439,    1,    1, 1345, 1258,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  938, 1075,  680, 2328, 1260,    9, 2674,    1, 2539,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2616, 2914,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   20,    1,    1,  753,   37, 1154,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3403,  868,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1817,    1, 1082,  365,    1,  187,  510,  431,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,   90, 1583,   37, 2905,   37, 1910, 3339,  680,  114,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  317,  682,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1830,    9,  502,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  105, 2210, 2234,    9,  105, 2071, 2403,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1087, 1017,   32,    1,  163,    1,   12,    1,\n",
      "          124,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  396, 1254, 1465, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  782, 1678, 1810,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1009,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3177, 2753, 1777, 2739,   32,  714,    9, 2448,  386,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3374, 1082,    1,  863, 1860,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   34,    1,  142,    9,  647,   37,    1,   54,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3167,  154, 1947, 3251,    1,   37,  316,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2137,  135,    1,  695, 2789,   12,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 1095,   51, 1389, 2608, 2607,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 3006, 2253,   37, 2856, 3365,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1122, 2243, 2480,  853,  538,    1, 2928,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  591, 2640,   61,   98,  453,  454,   37, 1821, 2190,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2959,  186,  608,    1,    9, 1194,  726,   32, 1559,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  488,  148,  220,  149,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2868,  903,    1, 1447, 2960,    1,  612, 2673,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213,    1,  191, 3177,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  550,   32,  870,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,  475,   61,   76,   37, 1599, 2089,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  388,  763,    1, 2946, 1229,   37,   52, 1685,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   95,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158,   12, 2102,  920,    1, 2464,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3244,    1,    1, 1631, 1827,  886,  951,    1, 1497,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  512,    1,   61, 1558,  191, 3233,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 1034,   32, 1090,  550,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1128,    6,  102,   98, 1744,  163,    1,   12,    1,  301,  280,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,   37, 1753,  297,   29, 1617,    1,   98,  954,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  326, 2334, 1114,  396,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,   22,   23,  607,  610,   32,  126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  449,    1, 2355,   37, 2355, 2665, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2628,  876,    1,  476,   37,    1,  219,  164,  165,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3238,  967, 2133, 3288, 1857,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110, 2967,   61,    1,  204,  321,    1,  105,  750,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  395, 2694,  443,   98,  620, 2931,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228,    1, 2844,   32,    1, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3087, 2162, 1950,  640,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  812, 2977,  673,    9,  639, 1822,  920, 2394, 1167,  460,\n",
      "           61,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,  93, 994,   1, 150,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 756, 757,   6, 157,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1920, 3102,   61,  820,   32,  531,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  822, 1787,   37, 1281,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2469,    1,    1,  820,  191, 3319,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  565,  603, 1159,    1, 2001, 1532,  191,    1, 3348, 3382,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  111,  668,    1, 2145,   37,  138,    1,  331,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3219,  120,   32,  581, 1023,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,  197,  490,   98,   15,   45,  378,    1,  224,  225,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3290,    1, 1971,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  146,    1,  695,  444,    1,   98,  963,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,    1, 2274,   98,  613, 1075,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  845,    1,  187, 3009,    1,   32,    1,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1344,  187, 3171,    1,    9, 2615,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2925, 1675,   98,  844,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  765,   37, 2412,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   22,  438,  267,  667, 1852,    1,  662, 1377,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1520,   37, 2446,  840, 2419,   32,  163,    1,   12,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3169, 2598,   37, 2197, 1010,  716,  204,   12,    1,  191, 1066,\n",
      "          220,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 1466,  325,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1051,    1,    1, 1605, 2320,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2590,  981, 1987, 2195,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3175,  335,   72,   73,  384, 2615,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,  884,   84, 1159,  455,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   68,   70,  276,    9,  705,    1,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2646,    1,    1,  191,    1,    1,    1, 1830,    9,  388,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  851,  298,   32,    1, 1924,  601,    9,  793,   32,  537,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1359,   12, 2059,  939,  384,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2355, 1013,    9, 2993, 2994,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3167, 1834,    1,  584,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  746,  197,    1,  459,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 2329,  248, 2179, 2789,   98,  215,  531, 1563,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  609,    1,  776,  398,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100, 1408,  453, 1273, 2088,  361, 1125,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3256,    1,  884, 2069, 1575, 1159,  119, 1772,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2414,  786,    1, 2766, 2006,   32, 1619, 2597,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,  782,  885, 3043, 2623, 2624,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  846,   29, 1074,  415,    9, 1116,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2700, 1198,    1,   98,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1680,  197,  897,  202,  932,  583,  191,  529,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1861,  580, 1463,   45,   10,    1,   98,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  156, 2393,  322, 2622,    1,    1,   12,  354,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2024, 2223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2662, 2918,   12,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,  749,  304,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1615, 1781,  191, 1613,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  726,   30,  730,   78,   98,  166,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  810, 2496,  384,    1,  851,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1861,  361,  811,   37,  429,    1, 1022,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1357, 2454,  167,  771,    1, 1450,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3247,  153,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1046, 1044,    7, 2043,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  251,  441,    1,  861,  420, 1108,  327,  593,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181,    1,   98,  179,  220,    1,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,  792,  460,   12,  193, 1167, 1366, 1445, 1769,   37,    1,\n",
      "         1718,  792,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2870,   32, 1850, 3339, 1223,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1749,    9,  845,  846,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   14,   15, 1124,    1,    1,  664,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  430,    1,    1,    1, 1130,  103, 2571,    1,    1,    9,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1477, 1990, 3009,  865,  220,  105,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  189,    1,  680,  323,    1,    1,  920,  580,  649, 2015,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 3005, 1450, 1106,    1,  187, 1108,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  753,  890,   37, 1403, 1488, 1204,    1,  590,    1, 1492,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141,    1, 1454,  104,  872, 1010, 2081,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  403, 1447,  267,  463,   12, 1794,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,  332,  756, 1228, 2690,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1170,  267,  453,    1,  103,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,   74,   61,    1,   12,   74,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  580,  535,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1680,   37,  138,   59,    9,  395, 1074,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3358,    1,   32,  247,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967,    1, 2589,   32, 2069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1759,  309,    1, 2962,   28,    1,    1, 1708,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2602,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,    1,  715,    1, 1697,   37,  403,  464, 1585,  778,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  455, 1123, 2308,   37,  477,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   55,   56,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3051,  957, 2386, 1557,   45,    1, 2282,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1811,  404,    1,    1, 1338,   45, 1647,   98, 3101,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1317,   51,  123,    1, 1329,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  376,    1, 1089,    1, 1220,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1607,    1, 3004,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1863,    1,    9, 2854, 1345,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   10,   98, 2095,  856,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2486,   79,   37,  698,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  398,   32,    1,   43, 2621,  220,    1,   98, 1816,   45, 2007,\n",
      "            1,  191,  217,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,    1,  611,    1,   45, 3006,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1029,   69,    1,  191, 1002,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,  800,    1,   60,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  447,   12,    1,   39,    9, 1056,  257,  220, 3288,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1763,   12, 1421, 2829,    1,    1,  261,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2919, 2162,   45,  487,    1,  176,    1,  135,    1,  548,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  241,    1,    1,    6,  197,  570,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1290,  396,   71,   37,  547, 1034,  845,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1408,    1, 3134,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,  37, 877, 714,   9,   1, 428,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 982,  37, 130,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2676,  670,  300,    1,   37, 1514,  778,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2102,    1,   39,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1512,    1,    1, 3144,  297,    1, 2823,  741,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,   12, 1658,    1,    1,  203,  600,  105,    1,  649,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  192,    1,   51,  193,  194,  195,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  551,  365, 2036,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1157, 3397,  513,    9,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  258, 2773,    1,  162, 1327,   79,   37, 2315,  698,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2366,  190,   52, 2812,    9, 1211,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796,  624,    1,  616, 2071, 1074,  259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1190, 1112,  176,  573, 1605,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962,  686,    1, 1401, 3231,   37,  726,  297, 2685,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  294,  267,  104,    1,  247,  611,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,   12, 1254, 1940,  335,  656, 1267,  176, 1675,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  755, 2593,  453,  248,    1, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1640,  144, 2830,  271, 1159, 1021,  250,    1, 1056, 1530,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  213,   37,   47,    1,   12,  365, 1546,   32,   59,  132,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,  565, 2780,    1,  361, 1433, 1658,  112,  894,  815,  786,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2502,  856,  921,  215, 2521,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  391,  197,   85,    1,  392,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  267, 1228,  167, 1121, 1465,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2618, 1268, 2701,  593, 1990,  220,  726,  297,  602,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1128,   37,  480,    1, 2400, 1129,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314, 1692,    1,    1, 1469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2355,    1, 1144,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1256,  551, 1256,   37,  151, 1026,    9,    1,  131,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  596, 1732,   15, 2011,  119,   32,  572,   45,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51, 1031,  626,  293,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  236,  237, 1931,  702, 1560,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861,    1,    9, 3363,   12,    1,   32,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2412,  193, 1542,   37,  688,  461,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 1308,    1,  934,    1, 2182,   79,  284, 1149,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  193,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1, 2196,    1,   12,    1,  728, 1361,   12, 2255, 2355,\n",
      "         1294,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,  365,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1894,    9,  166,  439,   45,  166,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2275,  794,  581, 1260,   98,   10,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,   51, 1413,  829,   32,  342, 1350,  856,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  197,    1,  983,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230,    1, 3001,  631,  104, 1787,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1948, 1949,  326,  486,   24,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1977,    1,  600,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  331,  612,  458,  197,  418,   98,  377, 1628,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  463, 2926, 1240,   52,    1,  384, 1573,   32,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  429,   98,  444, 2846,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  231, 1230,    1, 1294,  619,  105, 2322,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1625,   37, 1348, 1148,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  460,    1,   16,    1,  468,    1,  486,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1132,  572,  197, 1993,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739, 3186,    1, 1231,  220,    1, 2408,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3089, 2040,  405,    1,    1,    9,    1, 2977, 1425,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 2786,   45,   20,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1186, 1974,  164,   13,   12, 2234,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  730, 2614,  759, 1145,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  716,  720,   32,  819,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1291,    1, 1465,   32,  365,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2500,  663,    1, 2504,  446,    1,   12,    1,    9, 2500,  663,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1425,  166,  593,  361, 1159,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  755,    1,    1,    1, 2863,  973,    1, 1085,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296, 2463,   32,   95,  617,  259, 1017,   51,   52,  877,    1,\n",
      "         2973, 1764,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3227, 3252,    1,  634,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3269,   37,    1,  384, 3238,   12, 2849,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2177,  100,   37, 2535,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  220,    1,  182, 2041,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962, 3117,  186,   37,  688, 3271,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2408, 1917, 2408,    1, 3191,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3192,    1, 1426, 1463,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2823,    1,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1110,    1,    1,    1,    1, 1031,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1273,  716, 1253,   32,  244,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   68,   70,  245,  528,    1,  679,   69,  997,  115,   45,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1,    1,    1,    1, 2433,  455,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  381,    1,    1,  218,    1,  372,    1,  209,    1, 1212,   12,\n",
      "         2084,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   12, 1839,  484,    1,   32,  691,   12,  863, 1708,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2708,    1, 2934,   37, 1937, 3358,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2924,  123,   32,   98, 2162,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,  105,    1,  384,  306,   12,  825, 1013,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  249,  190, 1188,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,    7,   37, 1973, 1918,   98, 2675,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1458, 1430,    1, 1140,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 2472,    1,    1,  515,  386,   78,  105,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1879, 3130,   32,  260,    9, 2205,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3117,  619,  538,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  156, 1270, 2316,   32,  572,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1, 1209,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  153, 2871,    1,  166, 1292,  472,   81, 1167,  416, 2017,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  449, 2547,    1,  297, 1645,  625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129, 2843,  726, 1086,    1, 1844,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  616,  123,  187, 2674, 3121,  424,  356,  640, 1789,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  822,  992,  698,    9, 1988,  163,    1,   12,    1, 3400,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2049,    1,    1,  195,  338, 1139,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   37,  429,   49, 1611,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2807,  665, 3229, 3321,   98,    1, 1638,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284, 2746, 1096,  786,   45, 1515,  248,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1685,   97,    1,    1,    1,  765,   37,  125,   79,  923,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160,  102, 1180,   28,   31,  997, 1348,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  710,   37,   52,  136,  475,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1566,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1645, 2924, 2844,   32,  557,  540,    1,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  566, 2924, 2271,  384,  531, 1411, 1657,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1,  715, 1068,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790, 1454,  453,    1,   98,  749,  230,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1247,   90, 3061,   37,  865,   37, 2789,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1839, 1639,    1,  166,  408,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  925,    1,   98, 3227,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1183,    1, 1183,  148,  647,    1,  167, 1724,  606, 1744,\n",
      "            1,   37,    1, 1379,   12,  112,  499,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1123,  688,  730, 2614,  415,    1,  445, 1488,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2942,   37,    1, 2069, 2107,   45, 2826,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  848,    1,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  267,  978, 2953, 1631,  846,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  754, 1465, 2264,    1,  861,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  587, 1048,  454,    9, 1390,    1,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1591,    1, 1564,  331,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  176,  810, 1425, 2712,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1310,   37,    1,  647,   17,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1977,    1,  600,    1, 1001,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,    1, 1837,    1,   15,  570,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2469, 1527, 2664,   32,  531, 3047,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2142,    1, 2906,    1,   37,  332, 1929, 2545,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1203,    1,    1, 2871, 1129,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,    1,  114,  640,  104, 2699,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2995,    1,  444, 2026,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2998,  398,  261,   32,    1,   45,  171,   32, 1117, 2208,  149,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,  159,    1,  238,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1109, 1957, 1010,  752,    1,  389,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785, 1574, 1188,    9,  107,  109,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  978, 3138, 2712, 2720, 2796,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  113,  700,   63,    1,    1,  925,   65,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  576,    1, 1263,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  457,    1,  140,  331,    9, 2098,  166, 2069,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   26,    1, 3023,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1702, 1013, 1017,   37,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  746,    1,  829,   32,   59,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1787,    1,  671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1009,    1,    1, 2140,   32,    1,   45,    1, 1512,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 2164, 2414,    1, 2803, 1060,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2, 148,  32, 147, 297, 647, 750, 428,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 474,   1, 365,   1,   1,  24,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1654,  187,  671,    1,  170,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1902,  900,    1,    1,  574,    1,  290,  267,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2556,  191,  166,  947,  105,  227,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,   12, 2751,    1,  957,    1,    9,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 197, 176,   1,   1, 641,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 758,  37, 698,   1, 285,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  795, 1236, 1697, 1074,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  275,    1,   37,  693, 1876,    9,  455,   12,  803, 1244,\n",
      "         1844,  191,    1,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  466,  275,  166,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12, 1619,  458,    1,  453,    1,   45,  166,  954,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  859,  388, 1527,   37,  430,   37,  856,    1, 2141,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  754,  757,  737,  197,  418,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1178, 2827,  297,  395,   36, 2705,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1221,   61,  590,    1,   32, 1123,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  433, 2104,  765,   37, 2010,    1,  412,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1141,  220, 3349, 2292,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,   39,   45,  247,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,  103, 1569,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3242,  515, 1024,  753,   45, 2741, 1140,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,  613,    1,  387,  242,  572,  983,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  726, 2316, 2138,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1, 2196,    1,  379,    1,    1,   32, 1783, 1294,  927,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401, 3115,  608, 2563,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978,  769,  670,  187,  156,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  387, 1183, 1890,  115,   32,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,    1, 2514,  361,  808, 1343,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1773,    1,  848,  877, 1702,   63, 2063,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1458,   85,   98, 3107, 1220,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3398,  190,  193,    1, 2789,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,    1,   37,    1,   10,   98,  247, 1513,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3064,    1,    1, 2712,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  207, 2441, 2852, 1205,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2468,    1, 2710, 3006, 3043,   45,  722,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1, 3313, 2827,   37, 2250,  176,  311,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  218, 1298, 1382,  176,   26,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12,    1, 2866,  220,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1592, 2898, 1926, 1927, 1928,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1, 2593, 1429, 1446,  700,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2297, 2388,   12,  979, 3229,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  624, 2436,    1,    1, 2542,    9, 2977,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   28, 1796,  437,   37,  207,  132,    9, 2226, 2969,\n",
      "         1085,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2795, 1258,   37, 2535, 3310,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   49, 2089, 1131,    1,  632,  232,  108,   45, 1001,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340,  442,  526,    1,   60,  410,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,    1,    1, 1713,    1,   98,  209,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 1414,  221,  123,   37, 2646, 3346, 1142,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2046, 3397,  738,  220,    1, 3079,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3120, 2035,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1056, 2855,  798,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,  491, 3339,  399, 1530,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,  365,    1,  918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  439,  166, 3148,  920,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  758,    1,    1,  224,   98, 1273, 1085,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  150,  353,  118,   71,   32,  983,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  632, 1223,    1,  187,  964, 1877,  856,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1, 1821, 1294,  441,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1407, 2541, 2770,  531,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947,  335,   28,    1,    1,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1400,    1,  305,   71,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2583,    1,   37,   52,   32, 3255,  193, 2800,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  424,  199,    1,    1,   30,   28,    1, 1542,   37,  151,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  235,  661,   98,   25,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056,  938, 1075,    1, 1345,    9, 1515, 2853,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984,  515,    1,  105, 1849,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2087,  433,  812, 1094,   12, 3339,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384,  324,   45,  395,   37, 1167,   45,  166,  593,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2592,    1,   37,    1,   32,  408,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  267,    1,  220, 1725,  996,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1870, 1518,  755, 2240,  220,  225,  752,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   12, 1009,   37,  582,    9,  854,   12, 2670,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2658, 2269,  686,   32, 1046,  191, 2382,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2190,    1,   13, 2961,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2066,   69,  640,  593,  954,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1619,  458,    1,   67,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  190, 1195,    1, 2675,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,    1,  191, 3279,   32,  404, 3114,  163,    1,  903,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  430,   37,  429, 1651,  622, 2172, 1411, 1034,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  557,  540,  650,  267,    1,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1013,    1,    1,  111, 1107,  773,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1574,    1, 2383,   98,   69,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  458,    1,    1, 1889,  682,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2235,  616,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  758,   37,  151,    1,    9,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1,  398,    6,  829,  822, 1469,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  474,    1,  705,    1, 1417,    1,  960,    1, 1903,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537,    5, 2096,  576,    1,  159,  417,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3192,  105,  365,    1,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  957,    1,    1, 1154,  395,    1, 1228,  293,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  389,    6, 1253,   32,  385,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1204, 2361,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1663,  251,   37,  335, 1501,  457,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123, 3232, 2286,   37,    1,  730, 2614, 2494, 1844,   32,  593,\n",
      "         2522,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1166,  460,  810,    1,    1,    1,  140, 2472,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  691,   12,    1,  868,   69,   79,  404, 2255,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  116,  815, 1229,   37,  125, 1159,  844,    1,  361,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  631,   37,   59,  745,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1380, 2857,   81,   98, 1171,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311,  951,    1,    1,  819, 2518,    1, 2487,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,   47,  965,   48,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  415, 1584,  460,  720,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3269,  190,   16, 2697,    1,  365, 1788,  317,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2328, 1260, 2414,  163,    1,   12,    1, 2924,   32,  531,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2993,  794, 2994,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358, 1426,  132,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3039, 1939, 1090,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  231,  782, 1817,    1,    1,    1,    9,   10,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  873,  729,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,    1,    1,    9,  166, 3009,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1117,  841,  818, 2693,    1,    1, 1136,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147, 1458,  649, 1920,   12, 1334,   32, 1186,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  786,   45, 1186,   12,  915,    1, 2201,    1, 1518,   85,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  253, 1066,  741,   98,  148,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  228, 2844,  187, 2203,    1,  891,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2680, 1644,    1,   37,  930,   32, 1657,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  384, 1965,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1140,   37, 3187,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  774,    1,    1, 1608,    1,   37,  176,  551,  612,  618,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3310, 2930,  776,   37, 1174,  892,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1796, 3102,    1, 2572,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1592, 1152,   45,  861, 2558,   32, 2157,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1293,  996,    1,   32,  365, 2224,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   64,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2959, 2712,    1, 2584,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  615,  388,    1,  187,  163,    1,   12,    1,  616,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2425, 1994,    1, 1228,   61,  105, 2980,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 3365,    1,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  259,    1,    1,  220, 2229,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3173,    1, 2779,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  197,   28,   98,  365,    1, 2166,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1,  845,    1, 1089, 2382,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1823,  662, 1008,  449,  940,    1,  365,  893,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  365, 2434,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1043,  338,  297,  419,   98,   69,  509,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1019,    1, 2952,  915,    1, 2500,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3405,    1,    1,   32,  365, 2564,   37,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  256,  304,   37,    1,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  743,   12,   82,    1,  862,  939,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  163,    1,   12,    1,    1, 1976,   79,  584,  540,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   63,  166,  862,  503,  418,    1,  419,    1,    1,  159,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343,    1,    1,   37,   52,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3129,    1, 2310, 1924,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2647,    1,  852,    9,  885, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3064,  166,    1, 3022,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 2764, 3394,  722,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  547,  938, 1075, 2548, 1530,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   81,   37,   81,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  442,  443, 2897,  297,    1, 1859,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3229, 2246, 3285,  865,    1,   37, 1913,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2883, 2774, 3102, 1928,    1,  957,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1653,  361,  687,   45,  166,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2783,    1, 1684,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 1383,  176,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  549, 1159, 3226, 3263, 2811,  167,  335,  199,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  682,    1,    1,  247, 1567,   32, 1194,    1,    1, 3275,\n",
      "         2250,   32, 2732,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61, 2331,   45,    1, 1537, 2457,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2, 148,  32, 170,  46, 760, 647,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 220, 242, 347,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3300, 1838,   79, 3079,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193, 2745,  220,    1,  356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1277,    1,    1,   45,  903,    1,  331,    1,    1,    1,\n",
      "          928,  428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 2027,   45, 1565,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3256, 1285,    1,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777, 1268,  756,   32,  395,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2179, 2402, 1090, 2094, 2325,   37,  327,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,  163,    1,   12,    1,  588,   37, 1496,  505, 1345,\n",
      "         2209,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   26,   37,  865,   37,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   51,  606, 2918, 1967,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1577,  675,  353,  197,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   15,   32, 1252, 1253, 1254,   32,  166, 1255,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  657, 2808,   98,    1, 1151,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  104,  358, 1625,    9,    1,  191,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2931,    1,   37,   52,    1,    1,   32,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  155, 1915,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  437,  692,    1, 1766, 1767,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2834,    1,  969,   32, 1953,  220, 3380,  446,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,   37,    1,   28, 2026, 2454,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,    9, 1940,   98,  166,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,  261,   39, 2834,   32,  851,  298,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1039,  668,  293,   37, 1753, 1465, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1076,  671, 1077,    9,  671, 1078,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 2094,  903,    1, 1212, 2150,  122,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  103,  147,  908,    1,    1,  170,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,    1, 1484,    9,  741,   98, 3339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   31, 1071,   37,    1,  327,    1,   67,   71,  997,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  577,   98, 1107,  112,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  746,  251, 1766, 1767, 1108,   37,    1, 2264,    9,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  124,   37,   47, 1870, 2261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  433, 1579,  131, 2108,  302,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2690,   37, 2988, 1778,    1, 2762,  920, 1300,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,  814,   50,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  200, 1273, 1013,    1,  224, 1246,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   98,  166,    1, 1305, 2693,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1040,  814, 1041,    1,   32,  399,  220,  422,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,   36,    1,    1,  674,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,    1,  199,    9, 2244,  441,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2892,  664, 1818,  147, 1377,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596,    1,  597,  475,  598,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2170,   12,  719,   32,  289,  187, 1984,   61,  288,    9, 1953,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  792, 2268,    1,  792,    1, 2638,    1, 2372,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  582,    1, 2577,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2386,  957,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2017,   98,  112, 2516, 1108, 1697,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  274,    1,    1,  920,    1,  384, 1515,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2295, 1300, 2641,  251, 1211, 1766, 1767,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593, 2965,    1,  884,  105, 1628,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2246,  749,  550,    1,  361, 1658,  985, 1639,   45, 1997,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  418,  548,    1,    1, 1073,    1,   45,  493,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  120, 1010,  577,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  848,   37,    1,  691, 1463, 2522,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1913, 1843,  197,  418,    1,   34,  308,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810,    1,   28,   37, 1642,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2270,   37,  335, 1018, 1987,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 2170, 1086, 2942, 3126, 2813,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  296,  958,   20, 1995,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1386,  792,   51, 1188,   37, 1083,  962,  792,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1465, 1046,  981,    1,   37,    1,  669,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,  361, 2613,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32, 2597, 1656, 3389,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   45,  579, 1240,  606, 1846,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3170,  288,   37, 1306,  581, 1463,  444,  691,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999, 2186,    1, 1450,  923,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  469, 1415,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 3356,  908,  469,   37,  439, 1345,   32, 2646,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1220, 1137,    9,    1, 2624,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  151, 1564,  326, 1277,   45, 2943,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2806,    1,    1,  714,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340, 1194,  754, 1844,  873,  460,   12,  707,    1,  707,    1,\n",
      "         2626,    9,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  709,    1, 1542,    9, 3327, 1015,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3320, 1917,    1,  552,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   75,  991,  196,  887,   45,  176,  612,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089, 1090,   13,    1, 1536,    9,  467,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  353, 2786,    1, 2432,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843,    1, 1090,   45,  629,  548, 1044,  247,  454, 1114,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  506,  441, 2139,   37, 2555,  112,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  267,  460,  967,  590, 2339, 2673,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  590, 1421,  914,  190,  619,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3096,  872,  710,  614,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1789, 1286,   15, 1269,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  646,   28,    1,  202,  193, 2398,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  113,  399,   46,   32,  573,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228, 2258,   37, 1075,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1973,  190,  588,   37,  271, 2771, 1826,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1492, 1976,    1,    1,  928,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  111,  361, 1452,   27,  754,    1,  365, 1030,   32,  166, 2095,\n",
      "          856,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1845,  630, 2011,  176, 1361, 1215,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  460,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162,  191,    1, 1175,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  683,    1,  697,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1325,    1, 1025,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  903,    1,   12,    1,    1, 1203,    1,    1,   32, 2318,    1,\n",
      "            1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  707,  548,  531,   12, 1354, 2556, 1178,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1034,   32,  231,  321,  166,    1, 1403,  460,  411,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2752,  952,  764,   37, 1211, 3365,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2631,    1,   37, 1296,   79, 3290,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1985, 2572,   32,  104,   22,  477,    1, 2950,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  579,  190,  334, 2192,   28,    1,  415,   37,  619,  284, 1604,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401, 3228,   37, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  584,    1,  972,    1,  105,  450,  686,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  952, 2470,  764,   98,  903,    1, 1447,  548, 2735, 2716,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   25, 1594,  242,  187,   69,  640,  119,  845,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  525,  187, 3253,  884,   98, 3204,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1436,  267,  460, 1360,  612, 2564,   37,    1,  810, 3278, 1675,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  163,    1,   12,    1, 2548, 2572,   32,  531, 1450,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2226, 1398,  612,    1,   37, 2844, 3347,   12, 1727,   37, 1861,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  802, 2195,   37,  829, 2194, 1705,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1674,    1,  939,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1260, 2188, 1484,    9,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,  304,    1,    4,   29, 1625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  176,  397,  211,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  193,    1,   37,    1,  903,    1,  464,    1,  420,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37, 1539, 1778,  535, 1863,  361, 1106, 1107,  525,   98,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  321, 2366,  877, 1361, 2230, 1114,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2115,  574,  267,   37,  429,   49, 1611,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2034, 1117,    9, 1705,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  315,  365,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  903,    1, 3165, 2816, 1159,  463,  464,   36,   32, 2592,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  476,   39,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  479,  361,  971,  664, 1737,   37, 1196,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  755,  378,    1,  453, 1521,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1976,   27, 1739,  540,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  669,   32,  182,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  458,   45,  507,    1, 1288,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,   37,  319, 1839, 1259,  548,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  891,   37,    1,    1,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  803, 2171,    1,  453,  845,  275,  789,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2254, 1236, 1361,    9,  131,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2550,   37, 2709, 1159,  649,  637,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  166,  491,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1774,   39,    1,    1, 1310, 1114,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,  365,   24, 1277, 2437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  984, 3131,    1,  219,  615,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  388,  763,    1,    1,  612,    1,    5,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  868, 1114,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  338,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2747,  166, 2987, 2693,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  410,   98,   49,    1, 1549,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1844,    1,   12, 1218,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  195,  432,  515,    1,  284,    1, 1821,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  924,    1,  479,   53,    1,  947, 1975,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1564,  453,  813,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1412, 2521,    1,  861,  105,  596, 1995,   98,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12,  449,    1,    1,   37,   52, 1532, 1159,  668,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  442,  910, 1052, 2645,   37,  800,   60,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,   69,  477, 1552,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3106,   32,  539,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,   81,   98, 3024,  548, 1700,  257,   98, 1821, 2190,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2942, 1564, 2315,  865,  176,  593,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,    1, 1261, 1841,  333,    9,  225,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051, 1396,    1,  220,  365, 2239,    1, 1228,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  765,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  327, 2186,  636,  245,   37, 1121,   32,  601,  401,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,  613,   37, 1636, 2395,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1603,    1,    1,   32, 1708, 1117, 1525,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1528,  566,  215, 1093,  574,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359, 1484,    9, 1437,   45, 1094,   12, 3339, 2731,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2726,  611,  199,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3012,  298,  256,   37, 2977,  317,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  696, 3257,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2676, 1730,   51, 2596,  163,    1,   12,    1, 2458,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1649, 1370,   45,  596, 1793,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  108, 2650,  167,    1,  328,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2476,   37,  619,  885, 1333,  176,  121,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3007,    1,  279,  552,  552,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190, 2366,  877, 1361, 2230, 1114,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  593,   12,    1, 1178,  928,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  515,    1,   37, 1428,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1971,  664,    1,    1,    1,    9,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  535,  656,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1206,    1,  625,   66,  187,  449,    1,   32, 2650,  856,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2137,   32, 2597,  837, 1056,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  550,  369,    1,    1,    1,    8,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  315,  787, 1849, 1766, 1767, 1074,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1851,    1,    1,   32,  525,    9,  461,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  159,  245,   98,  800,   15,  570,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428,  190, 1306, 1580,  837,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2796,  688, 3266,  548,  390,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2, 433, 302,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1,  98, 166, 116,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  245,    1, 1194,  339,   73,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1951,  828, 1947, 1689,  971,  625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,    1, 2699,    1,   32, 3360, 1721,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190, 2553, 1675,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   76,   37,  619,    1, 1175,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1411, 1385,   45, 1700,  454,   46,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1583,  475,  267,  330,  723,    9, 3339, 2271,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116, 1013, 2165,  726,    1,   45,  111,  117, 1278,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  707, 1166,  590,  769,  606, 2626,   63,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3079, 2253,   37, 1195,  443,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   64, 1720,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  750,    1, 3318,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1100,  159,  670,   32, 2160,   45,  572,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 2695,  105,    1, 2699,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  213,   37,    1,  191,    1,  484,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2982,    1, 1761,  238, 1924,   98, 1965,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1186,  213,   37,  531, 2128, 1119,  187,  104, 3160, 1156,    9,\n",
      "         1038,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1542,   37,  877,  813,   32, 1171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1460,  844, 1463,    9,  829,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1229,   37,  606,  566,   98,  635,   12,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   56, 2844,   32, 1101,    1,  384, 3121,    1, 1985,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1952,  617,  259, 2495,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1670, 1285,    1,    1, 2954, 2286, 1089, 1090,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1200,  845,  846,   17,   28,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2142, 2151, 2206, 2207,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91, 1373,   37,    1,  861,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1042,    1,    1, 1253,   98,  800,   60,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1089, 1675,   15,   28,  419,   32, 1332,\n",
      "            1, 1721,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  741,    9,  365, 1009,   37,    1,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   45, 1582,  166, 1354,    1,   78,   37,    1, 1658,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  273,    1, 3171, 1586, 2615,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  613, 1017, 2141,  317,  567,  396,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2945, 3123,   12,  183, 3044,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,  292,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  131,  961,  448,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1717,  447, 1366,  190,   52,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3105,  813,  698,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,   71,  115,   45, 1850,  889,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  415,    1,  176, 2349,  920,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  352,   37,    1,    1,   50,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2347, 3200,   81,   37, 1306,  914, 3201,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220, 1281,    1,    1, 3021, 1654, 1747,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  242,  347, 2797,    9,  487,  467,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,  361,  326, 2914,  365, 1017,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1902, 2753, 1394,   32, 3287,  726,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1127, 1077,    9,  104,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3324, 2489, 2843, 2523,   32,    1, 1090,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,   12,    1, 3054,    1,   27,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  299,  908,  182,  301,    5,  125,  302,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1569, 1010,  568,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  548, 1117, 1525,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,   37, 1776,  365, 1280,   45, 2983,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  892,    1, 2290,    1,    1,    1, 2041,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095, 2257,    1,  384,  680,    1, 2268,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  315,   37,    1,  531, 1001,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1667,    1,  548, 1890,   32,  455, 2164,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   20,  132,  580, 1786, 2358,    1,  231,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  449,  972, 1144,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  187, 1448,  102,  554,    1,  911,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1281,    1,    1,  238,  873,  821,    1,  163,    1,   12,    1,\n",
      "          437,  267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2094, 1170,    1,   37,  538,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,    1,  284,    1,    1,  384, 1821, 3027,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   32, 1089, 1263,    1, 1926, 1927,    8,  304,   37,  163,    1,\n",
      "           12,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,    1,    1,    1,   45,    1,    1,  193,  445,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  180,  267,   75,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175, 1421,    1,   37,  105, 1056,  356,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2748, 1249,  584, 1022,    1,   32, 2138,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3069,  288,   37,    1, 3144,  907, 3399,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3022,  434,   61,  183,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861, 1553,    1,   37, 1569, 2832,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1336,  105,    1,  460, 1116, 1294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548, 1700,  339,    1,    1,  547, 3145, 1827,   37,   52,    1,\n",
      "           32,  914,   12,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2459,  951,    1, 1531,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3012, 3027, 2682, 1159, 3013,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962, 3021,    1, 3263,   37,  726,  297, 3300,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3161,    1,  590,    1, 3161, 1022,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101, 3160,   61, 2572,  187, 2708, 2256,  744,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1149,   37, 1515,  756,  725,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  992,   85,  187, 3103, 2565,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964, 2416,    1,   37,    1,   10,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2433, 2153, 1555,    9, 2571,    1,   37, 2571, 1681,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,    1, 1089, 1090, 1429,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1089, 1090,  218,   61, 1568,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   37,  588,  439,   45, 2108, 3368,  176,    1,  342, 2396,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3009,  528, 3307,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2559,    1,  911,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,  606, 2222,    1, 1513,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1366, 1445,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,   45, 2869, 2308,    1,  176, 1230,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2420, 1108,  279, 2359,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1576,  774, 2110,  387, 1405,  494,  187,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1, 1725,   37, 1421,  802, 1782, 2029,  593,   12, 2084,\n",
      "         1211,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  733,    1,    1,    9,    1,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,    1,  361, 2511,  614,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3355,  590, 3341,  741, 2191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1290,  396,  245,   37,  547,  339,  340,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  268, 1895,  567,  914, 1518,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3079,    1,    1,  247, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    5, 1211,    1,    1,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1427,  884, 3186,  103,   45,  166, 2209,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  193,  707,   37, 3103, 1724,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65, 2104,  919,  347,  361,  267,  388,  641,  565,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3144,  863,   32,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 2656,  566, 1972,  333,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,   37,    1, 1479,    1,   32, 2673, 2054,  964,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2329,   81,   37,  103, 1638,  176,  104,    1, 3154,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,  116,  681,  588,  365,  178,   45,  983,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3238,  167, 1306, 1694,   45, 2522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  207, 2086, 2221, 2598,   32,   37,    1, 2733,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  931,  335,  631,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  753,   37, 1594,   98, 1273,  844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2397, 1822,  335,    1,  992,   37,    1,  903,    1, 1423,    1,\n",
      "          650,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2819,  166,  923, 2999,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 1558,  191, 1922,  793,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 1013, 1522,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  512,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2076,  387, 1735, 2232,   15,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9, 3076,    1, 2941,  789,  140,  183,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  947,  361, 3092,   37,    1,    1,    1,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2827,    9, 2804,    1,    1, 2572,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2452,    1, 1230,    1,    1, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089, 1675, 1000, 1515, 2179, 1067,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  640,  361,    1,   81,  680,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280,   12, 1333,  176,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1959,   65,  475,  288,   37, 1910,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942, 1044,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,   37,  693,   40, 1228,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,  253,  360,  797, 2362,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  404,  539, 2426,   32, 3144,    1,    1,  342,  952,   37,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1,  882,  361,  715, 1300,    1, 1074,    1,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1375,  295,  256, 1108,  278,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61, 2086,    1, 1718,   15,    1,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1855,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974,    1,   28,    9, 2069, 3078,   45,    1, 2695, 2223,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2031,  778,  190, 1003,   37,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  491, 1268, 2009,   37, 1898,  220,  462,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  258,    1,   51,   52,    1,  220,    1,  548,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   29,    1, 1211,  384,  163,    1,   12,    1,  625, 2928,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3170,    1,    1,  665,  854,   98,    1,   45, 1918,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3171, 1586, 2615,  730, 2614, 2428, 1451,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3160,  610,    9,  531, 1038,  966,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3247,    1,    1,  162,   37, 1046,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 2646,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,   76,   37,   92,  347, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 212,  32,   1, 372, 214,  45,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 776, 191, 114, 994,   1, 150,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1571,  936,  166,    1,   45,    1, 2168,  472,  166,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3131, 1987,    1, 1931,  297, 2843,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   74,    1, 1608,  726,    1,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1156, 2708,  650, 1042,   39,   45, 2107,   37, 1504, 3358,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1417,  551, 1417,  197,  388,  763, 1660,   98,  417, 1184,  408,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1268,  963, 2102,  525,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147,    1, 3395,    1, 1130, 3047,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1269,  187,   69, 1137,  224, 2781,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  927, 1898, 1899,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  891,    1,  549,   45,    1, 2244,  669,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98, 2615,  730, 2614, 2522,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779,  801,   37, 1447,   26, 3295,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 2763, 3024,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2518,    1,  357, 2310, 1841,    1, 1433,    1, 2881,  833,  612,\n",
      "          619,  460,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1363, 1660,  158,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    7,    1,   32, 3276, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3375,  838,   37,    1,    1,  191, 3359,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1122,   82,  387,  853,  538,   98,  617,  618,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  418,  548, 1622,  587, 1140,  477,   37,  125,  109,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1,  904,    1,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  492, 1190,   12,  593,    1,   32, 2603,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096, 1186, 1004,  522,  548,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  433, 1458,    1,   85,   98, 1089,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  204, 2233, 1844,    9,  903,    1, 1256,    1, 2696,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1262,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  295, 1807,  372,  354,   32,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1394,  384,  166,  104,    1, 2823,  736,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 3025, 2399,    1,  548,  487,  993,  277,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1269,  187,  289,  614,   37,  347,    1,   60,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  582,    1,    1,  437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   12,  327, 1131,    1,  191,  324,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,  459,  993,  788,  302,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  780,    1,  196, 1508,  613,  132,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  593, 3045, 2856, 3361,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102, 1473,  530,  105,  106,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3358,   32,    1,    1, 2786,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2576, 1856,  220,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1218,  967, 2721,   45,  105, 2699,   37,  166,  730, 3022,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1188,    9,  107,   37,    1,  388,  864,  876,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  195,    1,   32,  356,  506,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  638, 2821,  193,  810,  460,   12,    1,   37,   52,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  386,   82,  387,  792,    1,  792,  389,    6,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 1963,   37,  631, 2734,  574,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2531,    1,    1,   98, 2237,   37, 1256,  551, 2196,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1149,  817,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  691,   12,    1,    1,  140,  449,  104, 3258, 2630,   32,    1,\n",
      "         1869,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777, 1268,  395,  756,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3065, 2572,  191,  356, 1691,  597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  700,  315,    1,   12, 2084, 2085, 1904,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  647,    1,  326, 1832,   28,    1,    1,    1,  176,  148,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,   92,    1,  197,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,    1, 1333,    9, 1589,  854,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1944,   45, 2820,    1,  176,    1,    1,  361,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2275,  844,  117,    1,    1, 1260,    1,   98,   10,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   69,    1,  493, 2054,  190, 1188,  372,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  420,  267,  584,   37,  114, 3301,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117, 1525,  126, 1396,  730, 1777, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   26,  242,  187,   69,  102, 2338,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   32,    1,    1, 1763, 1673,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1239,  459,   45,  105, 1115,   98,  236,  237,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,  139,   32,  487, 1300,    1,    1,  191,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1051,  325,  460, 1499,  698,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2500,  663,  437,  606,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  199,  421,  197,  338,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2628, 2493,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1855,  342, 2927,    1,  191, 1744, 1645,  361,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,    1,  448,  640,  119,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3117,  588,   37, 1334,    1, 1264,  841, 2107,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2554,    1,  631,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,    1, 1022,    1, 2540, 2906,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2161, 1021,   37, 2069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3175,    1, 3231,    1,   28,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2045, 1577,  387,   15,    1,  237,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2136, 1905,    9, 2322,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006, 2253,   37, 2856,  531, 3365,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   75,    1,  808,  187,  116,  259, 1852, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  984,  889,   66,    1,  679, 1220,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3208,  121,  475, 2137,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1583, 3400, 1554,  611,   32,  455,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2062, 1009,  267,  204, 1360,    1,   37, 2449,   32, 1021,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 1886,  384,  302, 1712, 1465, 2948,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1039, 2569,    1, 1464,  195, 1463,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 2131,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 352, 147, 991,   1, 132,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 162,   1, 389,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1056, 1479, 1796,  623,  441, 1083,  156,  739,  963, 2122,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,    1,  453, 1135,  918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1087, 1518, 2611,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  483,  384,  424,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2877,  200,    1,    9,  890,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   39,   45,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 2261,  220,  365,    1,  279,  861, 1151,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  872, 1044, 2469,    1, 1827,  361,  917,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  928,  176,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2888,   32,  206,   12,  400,  610,   37, 2335,  537,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2939, 1554, 1443,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  510,    1, 1549,  540,    1, 1554, 1530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1289,    1,    1,   37, 1278,  302,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2184, 3152, 1421,  656,    1, 2523,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3066,   61, 1685,    1,  508,   79,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 1530,    1,   92,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3112,  487, 1938, 3197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497, 3229, 2424, 1463,    1,  865,   27,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3075, 1564, 2069,    1,   45,  356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  960,    1,  474,  439,   46,    1, 2905,    9,  477,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,  361,  829, 1003,    9, 2210, 1421,   98,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1086,  284,    1, 1958,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  147,    1,  342,  484,   37,  222,    1,  179,  170,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110, 2125,    1,    1, 2925,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1475,    1,  649, 1763,    1,    6,  248,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32,  531,    9,  579,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3253, 1774, 1159,  915,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,    1, 2759,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  411, 2022,    9,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1200,    1,  829,   37,    1, 1089,    1,  288,  921,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   84,    1,   32,  166,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  443,  736,    1,   98,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1345,  176, 3339, 2791, 1554, 1530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3095, 2856,  547, 3375,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1809, 2258,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,   32,  111, 2502, 2872, 1231,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2183, 3370, 3350, 1061,   32, 2755, 3360,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,  929, 1564,  590, 2001,   98,    1, 1563,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  902,  608,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2448, 1179,    1,    1,    1,    1, 2689, 3177,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1023,   45,  111,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  778, 3381,  437,    1, 1056, 1147, 2548,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  132, 2011,   32, 1471, 1016, 2096,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437,   37,    1,  365,  845,  846,  613, 2294,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  439,   37,    1,  943,   98,  294,  541,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327, 3397,  313,   37, 1211, 3365,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 313,  37,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  25, 104, 996,  29, 576,  25, 242,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  968,  695, 2789,  952, 1032,   38,  384, 1002,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1216,    1, 2508, 1804,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   28,  166,    1,  593,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  737,  197,   28,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  361, 2254,  875, 2255,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3271, 2446,    1, 2685,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,  166, 1567,   32, 1798,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307, 1713, 2341, 1412,  293,  437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,    1, 1143,    1, 1142,  267,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,   32,  166, 2482,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579, 1710,  334, 1210,   37, 1937,   32,  829,   12, 2997,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056,    1,   45,  104, 2548,    1,   37, 2611,   32,  602,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1697, 2298,  898, 1897,    1,  477,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  223,   37,  125,  408,  191,    1,    1,    4,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,    1, 1361,  875, 2255,   43,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1186,  134, 2985,   32,  163,    1,   12,    1, 1634, 2095,  400,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,    1,  359,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1154, 1001, 1720,  334,  686,  166, 1898,   98,  166, 1938,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564, 3141, 2218,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2792,    1, 1750,    1,    1, 1281,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  872,   45, 2919,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  217,   98, 1001,  328,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1249,  236,  237,   12,  689,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 1053, 1022,    1,  572,  207,   37,   12,    1,  331,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  945,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2822,  249,  588,    1,  872,   98,  596, 1793,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  168,  115,   37,  332,  752,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3094, 2572,   32,   69,  965, 2960,   32,  430,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,  294, 1983,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1537, 1538,  477, 1627,   72,   74,    1,  102,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2856,  176,    1,  186,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1537, 2702,  298, 2414,    1,  297, 2347,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  580, 3367,    1,  297, 1156,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  683, 2622, 3168,   37,  759,    1, 2579, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  544,  193, 1140,  695,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2227,  730, 1571,   12,  884,  297, 1233,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  245, 2884,   61,   98,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  203,    1,  565, 1696,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  268, 2093,  857, 1469,  176,  669,    1,  124,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2615,  619, 3171,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1404,   45,  104, 3102, 1564,    1, 1727,    9,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,  213,   37, 1198,  976, 2108, 3368,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,   25,  245,    1, 1572,  191,    1, 1033,    1, 1065,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1107, 2610,    1,    1,  288,    9, 1186,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118, 3133, 1061,   32, 3369,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 1582,  167,  583,  932,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 3369, 1822,  439, 2292,   32, 3118,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,    1, 2410,  100,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181,  623,  353,  143,  763,   76,  572,  207,  244,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  615,   51, 1753,  121,  187,   49,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 1190, 2770, 3358,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2004, 1181,   37,  665, 2177, 1825,   32,  618,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1356,  917,   37, 1753,    1, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1848, 1682,  514,   45,    1,  636, 1336,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,   21,   15,  530,  308,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1, 1373,   37,  332, 3024,   29,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1757,    9,  864,   12, 2673,  927, 1428,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  864, 1867, 1183, 2320, 1461,  187, 1428, 1063, 2407, 2673,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1204,   98, 1965,  972,    1, 1409,  396, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2839,    1,  469,   37,  489,   39,   45,  531,  191,  439,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497,    1,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   64,    1,    1,  335, 1401,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2226,  331,   28,    9,  105, 1211, 1539,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,  600,  818,   15,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 1188,  193, 1406,  297,   69,  636,   71,    9,  920,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3301,  193,  707,   37, 2771,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  365,  105,  551,  331,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3186,    1,    1,    9,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  915,    1, 1250, 2306,    9,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1670,  581, 1967,  764,    1,  105,   12, 1054,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1929,    1,   98, 1355,   45, 1345,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  761,  936, 1479,  776,    9, 1646,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2656,  476,  764,  220,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  666, 1251,  331,   32,   15,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  513,  193,  514,   37,  136,  133,   44,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   66,   98, 2662,   12, 2820,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  889,  157,  410,    9,  163,    1,   12,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3332,   12, 2318, 2174,  187,  166, 1245,  140,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232, 1807,  204, 2233,  619,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1678,  361,    1, 1594,   39,    9,    1,   37, 1791,    1,    1,\n",
      "         1831,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 1861, 1937,  753,    9, 2708,  171,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2429,    1,    1,  476,   37,  319,    1,  161, 1597,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3110, 2489, 1176, 2127,   98, 2786, 3100, 1027,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3111,  774,   28,   37, 3045, 2572,   32, 3391,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,  491,   34,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1181,  155, 1101, 1102, 2412,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,    1,    1, 1247, 1631,  247,   38,   32,  354,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1206,    1, 2746,  912,   75, 2118,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  606, 2725,    1,  190, 1697,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   83,  190,  439,    1,  176,  654,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,  421,  244,  686,  191,  183,  822, 1482,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  375,  489,   39,   45, 2743, 1953,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3062,    1, 1185, 1624,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1089, 1713, 1183,  260,   45,   39,    1, 1017,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790,   12,  754,    1,  566,  963,  229,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  848, 1572,  132,  744,  849,  151, 1145,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380, 1484, 1953,  220, 2406,  105,  270,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  388,    1,    1,    1, 1851,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999, 1419, 1056,  365, 1013, 2043,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1879,    1,  420,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   38, 3211, 1884, 2712,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  835, 2215, 1013, 2683,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  615,    1,  410,   29,   37,  289,   98, 1411,  389,  420,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2307,    1,    1,  501,  827,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2428,  105,  807,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,  852,    9, 1891, 1876,   37, 1211, 3365,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,    1,   32,  878,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1564,  105, 1343,    9, 1652, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  993,  788,  343, 1010,  122,    9,    1,\n",
      "          856,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,  952,  365,  776,   32,  331,  768,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  104,  422,   57, 1093,  574,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1414,   98, 2731,   32,  531, 2774,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2409,    9,    1, 2789, 1061,   32,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1354, 2095, 1450, 1251,  680,  517,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  228,   51, 1752,  105,  668,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1532,    9,  949,   45,  487, 3102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1266,   37,  125,    1,  388,    4,    1,  716,  594,  572,  156,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1185, 3343,  985,    1,    1, 1728,    1,  337,    1, 1554,  942,\n",
      "           32,  227,  223,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3155,   51,   52,    1,  787,   37,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497, 1421, 2787,    9, 1183, 2113,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1056,    1, 3340,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018, 3343, 1920, 1492, 1710,   52, 1009,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1680,  166,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1,  171,   12, 1045,   98,  260, 1282,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2463,    1, 1834, 2475,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1665,    1, 1608,  166,  713,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  312,  515, 3081,   37,  736,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730,    1,    1,   37,  619, 1766, 1767,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2912,  162, 1140,   28,    9, 2792,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2929,   32,   46,   37,  288,   28,  219, 1283, 1049,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1022,    1, 3008,  406,  897,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  167, 1306, 1056, 1675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,   51,   52, 2198, 1213,  297,    1, 1559,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2539,    1,    1,    1, 1668,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32, 1981, 2891,   45, 1147, 1583,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,  736,  297, 2208,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1028, 1785,    1, 2357,  202,    1, 1220, 1031,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1, 1789,    1,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3115,    1, 2753, 2315, 1880,   32,    1,  427,  444, 3250,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,  511,  275,    1, 2388,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1711,   45,    1, 1772, 1999,  901,   32,  715, 2641,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  636,  720, 1391,   91,   25,  682,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2629,  865,   37, 3118,  548,    1, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647, 2037,   17,  105,    1,  361, 1211, 1901,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2748, 1287,   37,  688,  584, 1022,    1,   32, 2138,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1354, 1975,   32,    1,  506, 1980,   37, 1496,    1,  420,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,    1,  166, 2848, 1463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260, 1493, 1066,  548, 1045, 1086,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  193,  514,    1,    1,    1, 2694,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3059,    1,    1,  636, 1306, 2760,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  108,  310,    1,   45, 1718,  767,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178,  386,    1,    1,    1, 1231,  220, 1995,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3056,    1,  884, 1003,  176,  829,   12,  157, 1456,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  669,   37,   47,  649,    1,   32,  163,    1,   12,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  236, 1022,  288,   37, 1269,    1,  458,  932,  184,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  825,  265,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3257,   37, 1289, 1739, 2306,   37,  247, 2462,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,  544,  460,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1561, 1680,    1, 1159, 1658, 1001,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3084,  796,  297, 2180, 1559,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  428,    1, 3175,  442,    1,   37, 3251,    9,    1,    1,  361,\n",
      "          105,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144,  741,  105, 1665,   37,  539,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3354, 2924,  380,    1, 2517,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1333, 1530,   32,  531,  947, 2190, 2891,    1, 1056,  104,\n",
      "         2548,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,    1,  524,    9,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2763,   48,  105,    1,  176,    1,  182,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,  425,  426,  818,  834, 2441,  111,  361,   79,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1260,  176, 1688,   45,  878,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1107,    1, 1764, 1355,  773,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1133, 2041, 1489, 1528,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  492,  877,  365, 2263,   32,    1, 1887,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,   12,    1,  176,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  861, 1228, 1396, 1778,  279,  618,  361,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1033, 1944,   10, 1918,  187,   92,    9,  443,   98, 2095,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1431,   37,  231, 2089,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  162,    1,   59,  825,  132,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3005, 2493,  105,  818,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   12,  365,  327, 1013, 2549,    1,  762,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1199, 1007,    1, 1117,    1,  705,    1,   12, 1192, 1159,    1,\n",
      "            1, 2749,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3160,  267, 2699,  193,    1,  384, 2047,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  487, 1938, 3197,    1,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  952,    1,   37,    1,    1,   32,   95,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1879,    9, 1915, 1699,    1,  139,  591,  619, 1876,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1333, 1530,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1285,  242,  187,   69,  102, 2338,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2186, 1593,  863, 2539, 1729,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  638, 1186,  140,  671, 1114,   32, 1171, 3292,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  681, 1044,   39,   32,   91,    1,  267, 1247,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  829,   37, 1539, 1778,   32,  166, 2829,   45,  166,\n",
      "            1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,  958,  581, 2623, 2624,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1481,  140,  674,  297,  233,   37,    1,    1,   98, 1021,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613,  200,  645, 1615,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  476,  808,   32,  854,   12, 2457,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1938, 3197,    1, 1282,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3254,    1,   12,    1,  820,  411,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1185, 3375,  753,    9,  317, 3358, 3093,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1606, 3147,    1, 2773, 1492,    1, 3148,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  754,  757,  155,  157,    1,  921,  308,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  632,    1,   45, 1839,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3076,  919, 1281,   98,    1,  378,   98, 1975,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  531, 1426, 1674, 3096,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3303,    1,   98,  914,   45,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2757, 1574,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2137, 2856,   98, 2835, 3101, 2735,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1695,    1,    1,  952,    1,   32,  163,    1,   12,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   32, 1759,  309,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  843, 2943,    9,  207,  844,  624,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796,    1,   25,    1,  187, 1326,  504, 2957,  948,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2045,  328,  262,  263, 1576, 1976,  590,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  225,  338,  187,  332, 2300, 1660,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1484,    9, 1330,  290,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2005,  907,   32, 2925,   12,  914, 3201,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  215,  161,  931,   37,   52,    1,  220,  449,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1641,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 388,  45, 166,   1, 361, 377, 803, 441,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 326,  12,  72, 401, 156, 361, 983,  28,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1, 1103,   32,  445,   45, 1033,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2290, 3259,  688, 3219,   32,  754, 3201,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  614,    9,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1,  987,   32,  187,  636, 1500, 1719, 2066,  244,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1821, 2190,  122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1640, 3109, 3071,  650,    1,   37, 1260,  947,  317,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1458, 3364,   32, 2708, 2107,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2705,   32, 1585,  176, 2018, 3392,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056,  388, 2476, 1980,   37,    1, 1674, 2841, 2304,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  379,    1,    1,    1,  778,    9, 3076, 1171,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2977,  765, 1836,  220,   10,   12, 2918,  361, 1965,  469,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,   66,    1,  548,  329,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  105, 1470,  384,  166,    1, 2041,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  510,    1,  531,  122, 1198,   69,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1458,   26, 1039,  220,  365,  639,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   96,    1,  729,  387,  730,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2982,  726,    1, 1394,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971, 1500,    1,  548,  800,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2496,   45, 1056,    1, 1976,  463,   45, 2597,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1751,   51,  606,   37, 2553,  548,  514, 1727,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   60, 1287,   98,   69,  720,    1, 1489,   29,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2877,    1, 1407, 2924,   32, 2891,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2800,   12,    1,  928,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  523,  156,   28,    1,    1,   79,  927,  805,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  654,  566, 1089,   98, 1220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1975,   98, 1171,    9,  232, 2760,    1,   32,  649, 1938, 3197,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3021,  744,  411, 1224,  187, 2523, 1141,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3264,  729,    1,   98,   37,  129,  389,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  287,    1,  481, 1064,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1477, 1990, 3129,  219,  872, 1401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1661,  331, 1408,   28,  166, 1437,    1,  202,  284, 1721, 1937,\n",
      "          800, 1898,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1,    1,  841,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1816, 2095, 1665,  304,   32, 1850,   91,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  388,  497,  420,    1, 1655,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3175,    1, 3236,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089, 1090,  420,  841,  696, 2698,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1341,  975,  792,  218,    1,    1,  792,  308,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3348,    1, 1086,  220,    1,    9, 2024,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  992,   85,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3225, 1421,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  224, 2355, 1013, 2549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597, 3053,    1, 1820,   98, 1821, 2057,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  931,    1,    9,  104,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 3100,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  961,  147,   57,  776,   32,  584, 1117, 2661,   43,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   25,   71,  176,  166,   26,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   98,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  872,    1,  460,   12,  388,  763,  415,  105, 2107,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  267,   65,  967,  277,  191,    1,    1,  600,   67, 1500,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  854,  288,    9, 1442,  342,  956,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1841,  802,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550, 1183, 1038, 2113,    9,  206,   12, 1766, 1767, 2888,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3257,   81,   32, 1505,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1,    1, 1683,   32,  949,   45,    1, 3080,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1577,  361,  612,  675, 1740,   32,   91,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  166, 2041,  220,  356,   60,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1520,   30,   79, 1180, 1395,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129,    1, 1614,  593,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    9,    1,    1,  105,  365, 2608,  361,  105,  365,  778,    1,\n",
      "            1,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,   12,    1,  542,  907,    9, 1952,    1,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3104,    1, 1288,   37, 2346,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2674, 2132, 3166, 1268,    1,  914,  220, 2613,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3356, 3357,  729,    1,  531, 3346, 3133,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  792, 3369, 2282,    1,  205,   37, 2856,  379,  792,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  200,  365, 1499,  872,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1536,    9, 1126, 1960,   28,   37,   59,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359, 1905,   37,  606, 2241,    9, 3372,  741,   98, 3339,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  398, 2151,    1, 3081,    1, 1281,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 2140,    1,   37, 1108,  453,  734,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1186,   81, 1159, 1764, 1990, 1832,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2184,  225,  218,    1,  682, 2645,   37,    1,    1,  518,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,    1,  156,  689, 1160,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,   37,  119,  340,  951,   94,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  861,    1, 1425, 3359,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1463, 2480, 1768,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  202,  105, 1090,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  872,    1,   37,  606,  947, 1942,  548,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1472,  854,  361, 2018,   98, 1171,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2406, 2864,    1,   32,   95,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2349,   81,  754,    1, 1171,  813,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1582,   51, 1251,  137,   54,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2590,  354,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  719,   37,    1, 1161,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  150,   37,  151,    1,    9,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  178,  848,  566,  912, 2285, 1597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,   45, 3349,   12, 2721,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1287,  384,  119,  340,  951,    1,   94,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   26, 1039, 2730, 2299, 1618,   28, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  214,  142,    9,  635,   12,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,    1, 1310,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,  716,    1,  163,    1,   12,    1,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  777,    1,  700,  515,  561, 2177, 1825,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,  256, 1607, 2407,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,   37,    1, 2924,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,  920,  445,    1,    1, 1627,  365,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  756,  757, 1392, 1140,    9,   80,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035, 1070,   37, 1174, 1175,  187, 1371,  187, 1610,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,  186,    1,  202,   18,   28, 1139,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  384,  501,   74,  267,  204,  967, 1658, 2804,   98,\n",
      "          166, 1339,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  460,   12,    1,   37,  764,  439, 2646,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  108,  864,    1, 3140,  193,   37,    1,   32,  531,   12,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 2797,    9, 2128,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,    1,  693,  764,  361,    1, 1112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2601, 2293,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  169,   37,  138,    9,  193,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   26,    1,    1, 2745,   37,   52, 2647, 1114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1326,   32, 2813,    9, 1383, 2027,   32,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,  37, 451,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 213,  37, 138, 438,  59,   9,  45,   1, 328,   1,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  181, 2009,   98,  487, 3222,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3015,    1,  759,   81,   37,    1,  187,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  355,    1,    1,  220,  388,    1,   29,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1971,  913,    1,    1,    1,   98,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,   12,    1,  353,  118, 1253,   32,  581,  401,  197,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3171,    1, 2615,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  439,  845,   98, 1290,  396,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  910,   37, 1539,  525,    9,    1, 2161,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  190, 1444, 1114,   52,    1,  594,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,    1,    1,    1, 1413,   32,  365,  693,    9, 1186,\n",
      "           12,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  619,  166, 1514, 2259,    1, 1079,  885,  924,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189, 1243,    1, 2758,    6,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1230, 2053,  810,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  150,   37,  151,    1,    9,  152,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1924,   32, 1065, 2027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  227,    1,  193, 2398,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3354,    1,  186,  444,    1, 1887,    1, 2262,   98,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 3310,    1, 1373,  903,    1,  182,    1,  105,    1, 1292,\n",
      "          590,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  387,  105,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  792,  440,  792,    1, 1151,   32,    9,   64,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2618,  686,  191,    1,  505,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204, 1581,    1, 1159, 2033,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1545,    1,    1,  320, 1533,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1273, 1110,   32,  170,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1200,  353,  197,    1,  846,    1,   71,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2149, 1211,    1, 3281,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1412, 2287,    1,  470,    1,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2236,  921,    1,    9,  119, 1194,  199,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3386, 1142, 2717,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1024,  551, 1024,   32,   46,   37,  151, 1026,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612, 2023,   80,    1,  210,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3259,  726,  705,    1, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2162, 1950,  384,  455,    1, 1426,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  365,  973,   37,    1,  365, 1788,   12,    1,  625,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    9, 2158,    1,  105,    1,  361,    1,   37,  885,  671,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1966,    1, 1720, 2502,   61, 2834,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  142,   37,    1,    1,  297,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69, 1784,   98,  689,  529,    1,  190,  276,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  547, 1878, 1890,  680,    1,  434,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3051, 2040,   45,  365,  356, 2024,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428,  388, 1149,  763, 2085,   63,  565, 2301,   32, 1964,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  134,    1,  444, 2144,  487, 2095, 2985,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3405, 1082,  652,   45,  596,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  460,   61,   32,   46,  220,  395,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,   12,  365, 2381,    1, 2403,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3072,    1, 1781,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2347,    1, 2748,    1,    1,   39,    9, 1517,   12, 1090,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2457, 2493, 2505,   61, 2213,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   75,  804,   51,  631,   37,  858, 1437,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1183,    1,    1, 1976,   32,  395,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2005,  907,   32,  914, 3201,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  332, 1476,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  794, 2071, 2880, 1766, 1767, 2287,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 3073,  565,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2843,  782,  247, 2482,  176,  837,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1017,    1,    1,   37,  877, 1204,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2379,    1,  253,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1414, 2497, 3155,  115,   45,  205, 2731,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2885, 2864,  103, 1624,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219, 1085,    1,   32,  367, 1010,  389,    1,   69,  122,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,  365,    1,   37,  395,   12, 2401,  202, 1027,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3271, 2714,   81,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  148, 1360,  612,    1,  647,  887,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273, 1609,  267,  790,  991, 1423,  250,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  321,    1, 1878,  166,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  374,   28, 1926, 1927,    1,  863, 1324,  157,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1520, 1380,  453,  327,   32,  166, 2301, 2012,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187, 2615,  688,  978, 3138,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3181,   37,    1, 3306,  220,    1,  432,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340,  765, 1415,   37, 1194, 2318,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3128,  304,    9,  531,   12, 3356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1353,  286,    1,  927,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  976,  459,   37,  138,  152,   37, 2743, 2596, 2372,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  952, 1262,   37, 1066, 1159, 1501,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,    1,  140,    1, 2630,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,  313,  845,  220,  340, 1251,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1178, 2023, 1117, 1525,    1, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,  388, 2341,  763, 2542,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  964,  267,  121,  580, 1698,  443,   37,    1, 1833,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2094, 1170,    1,   37,  538, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1737,  332, 1953,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1844, 2210,  191,    1,  919,  273,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1855, 2122,    1,  297,    1,    1,  934,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1258, 1473,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,  166,  389,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2212,    1,   32, 1714,  361,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1104,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  616,  439,  417,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2235,   28,  361,  472,    1,    1,    1, 1159, 2936, 2826,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398, 1082,  163,    1,   12,    1,   37,  846, 3402, 3408,  400,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1187,    1, 1435,    1,  224, 1126,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2673, 1409, 2126,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  947,    1, 2473, 2921, 1512,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1922,    1,   12,  227,  187,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  878, 1249,  903,    1, 2926,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585, 2321,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 1117,  741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,  105,    1,   45,  132, 1809,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,  493,  102, 1473,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1539,  453,  365, 2522,   32, 1314,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1906, 1579,    1,  388, 2924,    9, 3114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,   12,  553,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3399,  864,  972,   37,  360,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294, 1920, 1765,  581,    1,   32, 3376,  344, 2950,  104,  622,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1803, 1552,   32, 3118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  888,   45,  443, 1908,    1,   98,  365, 1788, 2517,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  166, 2015,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   52,    1,    9,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  365, 1729,   51,    1, 2711,  566,  384,  166, 2041,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  827, 2633,  449, 2085, 3252,   45,  166,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  121, 1666, 1539,   45, 3029,  331, 1821,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2701, 2308, 1173,    9, 1756, 1604,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2730, 2110,    1,  550, 1085,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1133, 2941, 2250,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  810,   39,    9, 1956,   32, 1512,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465,    1,    1,    6,    4,  481,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1439,   37, 2335,  537,   32, 1038,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1675, 2683,  140, 2501,    1, 2730,  856,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  428,  864,    1, 3107, 1159,  493,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  105, 1300, 2988,    1, 1370,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  514,   45,    1, 2496,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1848,  353,  118,  197,  720,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  792,  654, 1458,  848,   12, 2723, 2724,  845,    1, 1935,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1933, 1536,    9,  467,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1, 3373,    1,   32,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 1009,  884,   98, 3370,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2355, 1013,  460,   12, 1284, 1328,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1,  104,  498,   98, 1461, 1462, 2532,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  187, 1029, 1489, 1743, 1578,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1962,   37,    1,    1,   12, 1101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  551,    1,    1,   37,  306, 2587,  777, 1085,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  125,    1,  715,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  971,   37,  114,   98,  810,    1, 1232,    1,   12, 1251,  672,\n",
      "         1464,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,    1,  104,    1,   37, 2250,  176,   56,  497, 1990,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2712, 3103,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1951,   69,  396,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  233,  908,  131,   32,  301,    1, 1442, 1184,    5, 1631,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1950, 1241,    1,  862,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  422,  435,    1,  261,    9, 1213,  138,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   37,    1,  818,  819,  220, 2364,  361,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328, 1524,   72,    1,    1, 2324,   37,  125,  197,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106, 1107,  525,  256,   37, 2102, 2015,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1545,    1,   37,    1, 3158,  119,  361,  335,   98,   91,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1755,  176,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1465,    1,  140,    1,  372,    1,   24,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  168,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  609,    1,    9, 1204,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,  388,    1,   32,    1, 1291,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1545,    1,  836,  384,    1, 1135,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,   69,    1,   79,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  548,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1567,  919,  942,   37,  593, 1990, 3098,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1001,   61,  166,    1,    9,  227,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3402, 3408, 1038,  686,  191, 1656, 2596,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2106, 2409,    1,  187, 3367, 2591, 1010, 2292,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  267, 3209,    1,  321, 1343,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1773,  288,   37, 1539,  365, 1090, 1294,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2249,  548,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1559,  614,   37, 1331,   45,  111, 1107,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  754,   15,   28, 2050,    1,   32,   86,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,  197,  937, 1910,   25,  526,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   12,    1,    1,    1,  331,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2211,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  319,  297,    1,  134,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  651, 1592,    1,   98,  317, 1839,  992,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  794, 2366,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2565,    1,   37,    1,  915,    1,    1,  791,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283, 3192,    1,  640, 1194,    1,  854,   32,    1, 1463,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  829,  875, 2474,  259,   43,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1471,    1, 1088,    1,   32,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  638,    1, 2856, 2313,   98,    1,   32,  581,  667,    1, 1260,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 2649,  475, 1458, 3118,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  769,  565,   85,   32,  395,  170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  511,  951,    1, 3297,  105, 1090,  220,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1157,    1, 1975,  298, 1159,    1,    1, 1530,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,    1, 1149,    1, 1841,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,  418,   32,    1, 2075,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  288,   37,   26,   28,  187,   69,  102,  245,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   20,  872,   28,   37,  142,   98, 1821,   24,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2393,  851, 2562,  810, 1048,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,  317, 2107, 1028,  649, 1938, 3197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,  435, 1133,  365, 1994, 2095, 1506,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  978, 3138, 2225,  678,    1,  512,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  619, 2102,   98,  166,  824,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1675,    1,   37, 2560,  365, 1675, 3011,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103,    1,    1,    1,   39,    9,  914,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3311, 3310, 2930,  400,  167,   52, 1036,   37,  878,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,  403, 2926,  171, 2097,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1568,    1,    1,  551,    1, 1837,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   79,  166, 2904,    9,    1,  948,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1283,    1,  683,   51,   52,  435,  105,  865,   37, 2800,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3345,  949,    1,   12, 2804,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  314,    6,    1,    4,  187,   43, 1475,  244,  191,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 2870,   27, 3155,  716,   45,  104,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1270, 1295, 3156,   32,    1,  493, 2960,   32,  403,  395,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1670, 1018, 1285,    1,  829,  159,  756, 2690,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1178,  513,  514,   37,    1,   32,    1,  176,    1,   36,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  868,    1,   12, 1841,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1783, 1363, 1605,   98,    1,    1, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  315,  105,  183,  973, 1159,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2373, 1256,    1, 2706, 2232,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  295, 2449,  187, 1443,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1372,    1, 2072, 2107,   37, 1821,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1, 1581, 1766, 1767,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962,    1, 1401, 3218,  186,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1478, 1569,   98,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  318,   12, 1318,  255,    1, 2365,   81,  166, 1928,   98, 1034,\n",
      "           32,  166, 2925,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2162, 1665, 3060, 2827,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  649, 3105, 2827,  176,    1,   37,   52, 1683,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1093,  574,    1, 1581,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117, 1525,  700,    1, 2964,  220,  861, 1787,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 3273,    9,  449, 1056, 1867,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006, 2253,   37,    1,  163,    1,   12,    1,    1,  215, 3365,\n",
      "           32,  531,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  786, 1530,    1,   56, 2249,  187, 2529, 3121, 2097,  455,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3076,  162,  453,    1,    1,  202, 1251, 1240,   52,  845,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  475, 1682,  469,   37, 1124,  495,  361, 1633, 1278,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,  140,  741,   37, 1746, 3339, 2271,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 2236, 1866,   79,  187,  386, 2827,   32,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3297,  307,   39,   98,  129, 1684, 1625,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  579,   12, 1411,    9,  148,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2871,    1, 2238,   12,    1,  168,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  315, 1904,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  163,    1,   12,    1, 2548, 2572,   32,  531, 1450,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1662,   13,   61,    1,    9,  247, 2821,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  404, 1033,   12,    1,   37, 1192,  297,  419,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 1889,    1, 2221,  884,  105,    1,   45,  453,  248,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  674,   96,   79, 1354, 2105,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3180, 1641,  460,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325,    1,   12,    1, 1541,    9,    1,  372, 2097,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  581, 2596, 2803,   32, 2504,  463, 3133,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2160, 2049,    1, 2719,  316, 2160, 2049,  765,   98,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1645, 3160,  488,   37, 1641,   28, 3373,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1691,    1,  335, 2363, 1267,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2279,  267, 1668,    1,  105,  916,   37,   77, 1590,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3167, 1834,    1, 2110,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  223, 2420,   86,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   37, 2824,  909,  444, 3369,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2360, 2788,   45, 1509,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2292,  729,   34,  441,    1,  260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  199,  421,   37,  875,    1,  133,  134,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843,   51,    1,  920, 1167,  204,   12,  193,  590,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1186,   37,  576, 1104,    1,   37, 2924,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116,  515,    1,    1, 2375,   37,    1,  384,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1100, 2094,    1, 1456,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  429,  530,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  506, 1132,    1,  275,   37,  674, 1149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  631,  931,  548,  786,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1853,    1,  191,  868,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  105, 1989, 1990,  628,  789,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  532,   59,  754, 1589, 1273,  618,   32,  449, 2335,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   58, 1680,  197,  308,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1029,  138,  636,    9,    1,   37, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  833,  612,  804,   32,  447,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1384, 2789, 1401,   32,  411,  932,   45,    1,   12,  890,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  143,   60, 2900, 1326,   12,  197,   37,  670,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1280,   45, 2983, 1976, 1425, 1056,  440, 3009,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2615,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   85,  166,    1,   98,  105,   74,   45,    1,  341,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  548,  683,    1, 3333,   37,  856, 1751,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1183,    1, 1283,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  183, 1585,  898,   32,  403, 1447,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,    1, 1445, 2825,  431,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  927,  991, 3184,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 3285, 1787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  366,    1, 1226, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  297, 1530,  176,  121,   36,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2283,   12, 3129, 3210,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,    9,  105,    1,    1,    1,  202,  544, 1444, 1604,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  477,    1,  567,  510, 1389,  526,  737,  156,  176, 1162,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  898,   37,  665,  453,  327,  112,   28,    9,  333,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  305,  670,  187, 2163,  293,  831,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  180,  179, 2013,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2959,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1028, 1029,   79,   69,  218,   12, 1030,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1586, 3166,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  560, 1274, 1473,    1,  347,  245,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1717,    1, 2911,   76,   37,  562, 3153, 2220, 1281,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  727,  872,   98,  207,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,    1,  796,  876,  612,   37, 1313, 2271,  469,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  199,   37,  221,  760, 2542,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3109, 3094,   32,  792, 2819,  792, 2678, 1039,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  157,    1, 1620,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,   28,    1, 1499, 2549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1024, 1408,    1, 1125,    1, 2545,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,    1,   32,   37,  111, 1107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  121,  162,  673,  659,   45, 1778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1311,  193,  579,  460, 1991,   37,   52,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,    1, 1228, 2683,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2216, 2710,    1,    9, 1799,  531, 1450,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,  321,  151,  647,  232,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2534,  162,    1,    1,   32,  104,  111,  126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  395, 1500, 1184,  347,    9,  449,  199,   32, 2335,  537,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2618,   37,   92,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1006, 1022, 1023,  197,  407,   98,    1,  932,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,   60, 1276,  444,  166,   94,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2226,    1,  166,  636,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2658, 1077,   37,  439, 1559,  220, 3124,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,  429, 1018,    1, 2050,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  195,  230,    1,  267,  790, 1961,  749,  506,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1934,  267, 3341,   46,   37,    1, 1371,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  640,  241, 1034,  340,    1, 1547,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1701, 1876,  766,   12, 1935, 2294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1088,    1, 1053, 2153,   37,    1, 3401,   12,    1,   32,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   74,  176,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  292,  247, 1580, 2521,   98,  538,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  274, 1283,   32,  870,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3149, 1740, 2827,  297, 3091,   12, 2772,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  640,   81,    9, 1364, 1365,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 2222,  884,   45,  647,  159,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,  478, 1021,  125,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   79,    1,   32, 3220,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2903,  311,   12,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777, 1635, 1361, 1213,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3149,    1, 2072,   36, 3102, 1936,    1,  267,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  379, 2286,   37,   77,    1,  384,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2430,  297,    1, 1465, 3005,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3321,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  487,   22,   37,    1,    1, 1910,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479, 1337,  250,  568,    9, 1338,   45,  436,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1492, 1082,  594,  497,   37,  693, 2161,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1665,   37,  517,  618,    1,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  358, 1070,  359,    9,  138,  125,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3038, 1656, 2909,    1,   32,    1,    1, 3383,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2161,    1,   37,  443,   32, 1019,  864,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,  193, 1343,  951,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  475, 1472,    1,   98,  662,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  611, 1250,    9, 1537,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,    1,    9,  331,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3180,  168,   37, 3262,    1,  191,  388,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  183, 3272, 1296,   28,  428, 2800, 1002,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  225,    1, 2399,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  633,   84,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1240, 1343, 1602,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1024, 1458,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  140,  212,  132,    1,  566,  388,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,   66,    1,  365, 1766, 1767,  769,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,   93,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2741, 1917,  463, 2170,  748,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343,  741, 2116,    1,    1, 3363,  413, 1086, 1860,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2885,  361, 3303,    1,    9,  427, 1343, 1798,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,    1,  854,  498,   37, 1195, 2073,    1,  345,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3118,    1, 2778, 1421,  365,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2339, 1108,   12,  440,  175, 1345, 1792,\n",
      "         1001,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3276,  288,    1,  119,  220,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596, 1395,    1,   37, 2284,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1725, 1726, 1174,   46,   98,  996, 1416,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  409,   25,  605,  242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,  267,  453, 3162,  321,  920,  759,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  234, 3041,  235,    1,  234, 3041,  235, 2041, 1867,  166,\n",
      "            1,   32, 1656,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  282,    1, 2706,  288,   37,  877, 1778,  714,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2754, 3102,   32,  531,  513,    9, 1204, 1089,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3059, 1822,    1,  548,  354,   37,  519,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1213,  108,   45,    1,  384, 2062,  741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2314, 3173, 2421,   39,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  627,   32, 1820,  548, 3079, 1421,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  121, 1542,   37,  477,  444, 2095,  481,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2582,    1,    1,  220, 3358,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1604,   37,   52, 2740,   32,  199,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3278,    1,    1,  220, 3297,  590,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  395, 1441,  121,   12,  397,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755, 1749,  220,  829,    1,    1,  361,  758,    9, 2819, 2039,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2225,    1,  187,  512,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2161,  103,  121,   37,  877,    1, 2069,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  813,    1,   12, 1856,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  987,    9, 1245,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,   37, 2192,  148,  132,  168,  115, 2013,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  576, 1349,  304,   37,  923,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  715,  947,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,   12, 2129,    1,  410,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1645, 3073,  600,   37,   52, 1683,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1256,  551, 1256,   32,   46,   37,  130, 1026,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  422,  692,    1,  261,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  761,   12, 1646,   61,  680,  105, 1324,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  794,  365, 1280,   45, 2673, 2949,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  775, 2238,    1,  361,    1,  235,  931,    9,  166,    1,\n",
      "         2695,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 1117,    1, 1417,    1, 1268,  549,   45, 1099, 1453,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3100,    1,  590,    1, 2998,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1292,    1,   51,   52, 2069,    1,  454, 2663,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2859, 2955,    1, 1125,   98, 2500, 2971,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  442,   37,  184,   10,   12,    1, 2521,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  938, 1075, 1858, 1333,  191, 2751,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2104,    1,  211,    1,   32,  105, 1034,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   56, 1159, 2069,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1135,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3250, 1751,  513,  514,   37,  195,   44,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1915,    1,   37,  120,   37,    1,   59,  191,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1261, 2352, 1942,  469,    9,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  891,  286,  927,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1053,   22,  459,  131,   20,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,    9,  961,   80,  261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,    1, 2976,  861, 2454,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  385, 1424,    9,  925,  274,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,   37,   52,    1,    9,    1,  182,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1542,   37,  865,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2236,    1,    9, 3115,  914, 3201,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  324,  835,  326,   12,  466, 2359, 1131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  449,   28,    9,  365, 2936, 1831,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,    1, 1901, 2683, 2043,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  422,  267,  348,    1,  625,  297,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,    1,  163,    1,   12,    1,   37,  698, 1477, 1990, 1343,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  224,    1, 1013, 1108,    1,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2863,  884, 2956,   37,  171,  147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   20, 2767,  192, 2461,    9,  949,   37,    1,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3239,  565,  603,   37,  608,    9,  627,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1267,  288,    9, 1306,  593, 1798,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741, 3164, 3066,    1,  706, 2226,  331,  193,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  647,  721, 1707,  148,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885, 1067,   37,  166,    1, 2224,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  920,  251,    1, 2043,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  410,   98,  160, 1161,  720,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3322, 1376,    9,  449,  726,   45,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3276,    1,   61, 1762,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  942,  104, 1832,   32,   56,  497, 1990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2384,  166,  163, 1230,  163,  361, 1158,  956,    1, 2821,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  700, 1426, 1849,  895,   98,  631,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   12,    1,    1, 1368,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  479,    1, 1233,  872,   39,   45,  382, 2514,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,    1,  581,  401,  354,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   45, 3102,  213,   37,  489,   39,   45,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783, 1114, 1666,  572,  156,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,    1,  342, 1164,   32,    1,   46,   32, 2197,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3267,   37,  907,    1,   32,  581, 2069,   32, 1056, 2119,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2942,  162,  228,    1,    1, 1608,  992, 1483,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861, 2193, 1778,    1,   37,  248,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,  744, 3137,    9,    1,   46,  220, 1789,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885, 1333,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  224, 1126,    1,  176,  105,  332,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  459, 1796,  116,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,  207, 1659, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,    1,  215,    4,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3207,  967, 1298,  199,   37,    1,  810, 1425, 1918,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 1990,    1,    1,  163,    1,   12,    1,   61,    1,  453,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  572,  551,  105,   98,  196,  176,  551,  612,  170,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1061,   98,  195,  134,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  105, 2773,   37,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 2153,  697,   37,  693, 2927,   46,   37, 2707,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3132,    1,    1,  191, 2380, 1987,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,  105,    1, 2736,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  364,   98, 1383,    9, 3135,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1485,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3045,    1, 1147, 2548,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1955,   37,  335,   48,   32, 2412, 1955, 2227,  872,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  942,   12,    1,  671,  835, 2335, 1146, 1703,   48,   32, 3176,\n",
      "            1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1009,   10, 2744, 1994, 1384,   74, 1263,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  342, 2386,  829,   45,    1, 1470,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2967,    1,   37, 1668,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1411,   84, 1994, 2931,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1712,    1,   28,    1,    1,  777, 1085,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121, 2414,  176,  177, 1056,   32,   64,    1,  455,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  377,  361,  377, 1104, 2209,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,   52,  901,    9,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  615,  707,    9,  671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,   37, 1248,  439,   37,    1, 1895,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   23,  851,   37, 1054,   32, 3369,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,   12, 1313,    1, 1397, 1192,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  640,    1, 1938,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   37, 2192,  758,  388,  225,   37,  875, 2096,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  579, 1924,    1,    1,  176, 2122, 1929,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  550,   45,    1, 3001,  361,  760,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1028, 1094,   38,   66,   32,    1, 1388,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  627,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    6,  570,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1024,    1,  197,   28,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2993,  431, 2994, 3135,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   94,  654,  734,  469,  630,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1662,   98, 2534,    1, 1908, 1313,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,    1,    1, 2373,   32, 1549,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1001,  977, 1672,   32,  645, 1034,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321,  829,  688, 2102,  220,  105,  525,   45,  453,  248,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   80,  636,  443,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3147, 1550, 1583,   32, 3114,    1,  488, 1851, 2751,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  534,  765,   37, 1911,  105, 1912,  856,    9,  674,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  193,    1,    1,    1,  544,  460,  810, 1729,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3141, 1090, 1829,  316,  176, 2451,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   28,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2031,  777,  778,    1,    1,  669,   12,  822,  396,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  923, 1334,  105,    1,  115,   45,  104,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1764, 1990, 2009,   26,    9, 3253,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2257,   32,  331,  548,  170, 2552,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  424,  415,   32,    1,  384,  166,    1, 1411, 2009,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,    9,  356,    1,   37,   52,   32,  166, 1381,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2116,  211,   32, 3343, 1002,    1, 2855, 2175, 1385,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   51,    1, 1839,    1,   32, 1893,    1, 1190,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  547,  163,    1,  903,    1, 3365,   32, 3360, 1683,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1648,   37,    1,  220,  903,    1, 1447,    1,  860, 1521,\n",
      "           32, 1033,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1355,  872,   32,    1,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  160,  783,  418,  699,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2615,  186,   37,  726, 1090,  297, 3108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    6,  388,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  600, 3358,   12, 2162,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  382, 1017, 1408, 1021,  282,  838,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1623,   28,   32,   22,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2222,    1, 1658,   40,  220, 1658,  282,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  224, 1475, 1126,  636, 2320,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2960,   32, 2755, 1327, 2414, 2144,    1,  493,    1, 1610, 1389,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  487, 1386,  987,  653,    9,   37,    1, 2024,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,  798,  593, 2378, 2701, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3151,  710,  267,  474,    1,   32,  105,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947, 1348,  927,  187,  885,    1, 1531, 1523, 1552,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  719, 1857,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  585,  321,  606,    1, 1601,   98,  311,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  667, 1557,  650,   37,  726, 1708,  202,  664,  863, 1721,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105,  726,  384, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2153,  907, 1815,    1, 1119,   32, 1815, 1563,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1403,    1,   37, 1206,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1668,  619, 1735,  865,  384,    1, 2337, 1444,  321,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  852,   37, 1412,  627,  187, 2610,   15,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2685,    1,    1,    1,  928,  176,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190, 2507,   95, 1539, 1821, 2057,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2546,  833,  612,  135,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  267,  978, 2953, 1631,  846,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1186, 1550, 2179,    1,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  985,    1,    1,  365,  753,  361,  105,  736,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2384,  669,  361,  280, 3004,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3318,    1,    1,   39,    9,  166,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  574,  852,  176,  734,  591,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,    1, 3231, 1938, 2809,  191,    1,  919, 1110,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,  148, 1117,    1, 2750,  313,   37,    1, 2544,  361, 1017,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2110,    1,    1,    1, 1366,  606,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3173, 2598,   37, 2637,   32,    1, 1013,    9, 1394,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  754,    1, 1986,  898,  677,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2347,    1,    1,   32,    1, 1388,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,   37,  877,    1, 1151,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2094,   39,  166, 1280,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2993, 2994, 2995,    1, 1316,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384,    1,   37, 2773,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  223,    1,    9,    1,   12, 1708,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2673, 1220,    9,  864,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  834,    1, 1013, 1522,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1841, 2714,    1, 2772,  776,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2819,   43,  724,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2845,   85,    9, 1378, 1090,  856,   32,  718,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  695,  704,    1,  683, 1822,    1, 2748,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1803,  187, 1523,    1,   36,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3315, 1784,   37,  581,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  439,   45,    1,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,   39,   45, 1948,    1, 1724,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,   37, 1947, 1718,  528,  768,  509,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3359,   57,    1,   45, 3101, 2924,   32, 3339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766,  313,   37, 1539,    1,  220, 1411, 2273, 1935, 1825,   32,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1950,    1,  197,  407,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1574,  361,    1,    9,  224,  777, 2641,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,   28,  548, 1290,   67,  948,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  952, 1651,    1, 1563,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1622, 1009,  267, 2117,    1,   37,  576,    1, 2924,   37, 3118,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,  729,    1,  220,  163,    1,   12,    1,    5,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  865,   37, 1959,    1,  162, 1509,   45, 3332,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2102, 2668,   91,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1465, 1466,  597,   82, 1627, 1727,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  162,    1, 1217,    9, 1511,   37,   92, 1021,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  147,  640, 2819,    1,    1,  126,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3119,  459,    1,   37, 2381,  356,  132,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3285, 2761,  375,   39,  220, 2961, 3131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2024,   46,   98, 3118,   37, 1195,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3213,   37,  576,   39,  872,   45,    1,  444,  386,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  315, 1273,   33,   32,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  845,  147,   37, 2303, 1842,  400, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  333,   45,    1, 2652,  104,   14, 2338,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,   46,   37,   47,    1,   48,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 1655,   45,  966, 1791,  176, 1967,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3356, 1484,   98, 3357,   37,  439,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  986,    1,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  645, 1230,  256, 2945,   37,  453,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  307,  698,  220,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  463, 1447,  267, 1585,   32,  403,   51,  606, 1846,    1,  934,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,    1,  738,  220, 2742,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,  418,   98,  242,   69,  102,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1074,    1,    1, 3016, 1441, 1234,   12,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  282, 2367, 2695,  328, 2996,  284, 2298,    1, 2593, 1130,  918,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  622,    1,   28,  861,  115,   45, 3343,\n",
      "         1002,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  162, 1021, 1499,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1533,  384, 1762,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 1090,  951,    1, 3115,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481, 2479, 1918,   32,  691,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1090,  792, 3039,  792,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,  267, 2708,  171,  388,  972,  220,    1,  187,  446,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  314,   37,    1, 1469, 1629,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   12,    1,  210,  614,  596,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1955,  162,  166,    1, 1624,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1932,  295,   37,  125,  541,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2468,  446,    1,  176, 2950,  290,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162, 2333,  726,  187, 2367,  688,  978, 3138,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3157,  741,   32, 2823, 1002,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2540,  590,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  683,   37,  631,    1, 1027,  176, 2998,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1051,    1, 2798,  861, 1832,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1,  395, 2286,   37,    1,  297,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  777,   37, 1732, 2613,   29,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   22,   23,    1, 1077,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051,    1,   59,   32,  395,  704,  551,  705,  656,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1109,  744, 1126, 1145,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2034,  581, 1863,   45,  166, 1034,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  633,  726, 1754,   37, 1971,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2676, 2136,  736,    1,  388,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98, 2699,  220,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2616,  782, 3038, 1661,  903, 2693,   32,    1,   32,  395,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  355,    1,    1,  361,  342,  759, 1350,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947,    1, 2646,    1, 1149, 1048,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1585,   32, 3376, 2414, 2006,  249, 3133,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,    1,  487,    1,  582,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2425, 1614,    1, 2287,   37, 1523,  444,    1,    1, 2026,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  726,  105,    1,    1,    1, 2427,  335, 2017,  166,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2899,   37,   52, 2812,   98,  176,  551,  612,  613,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1663, 1603,  353,  737,  354,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  758, 1013,  614, 1273,  327,  593,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  361,  105, 2514, 1659, 1713, 1590,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 691,   1, 952, 439,  37, 214,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1966,  140,  442,  909,  444,  163,    1,   12,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1641,    9, 3042,  161,  187,  755, 1713,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1739,    1,    1,  384, 3278,  173,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  617, 1803,    1,    1,    1,  166,  777,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3281,    1,    1,  297, 3181, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1,   37,  619, 2589,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   6, 572, 197, 570,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  32,   1, 297,   1, 627,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  982,   51,  664,  183, 1889, 1232,  180,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  216,  135,    1,  217,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  415,  166, 2739,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1794,   37, 1624,    1,  372,  853,   24,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,   37,  907,  220,    1,  294, 2860,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766,  967,  183,  315,    9,  803, 1825,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1783, 2023,  662,   37, 1787,  326,   12,  596, 1085,  112, 3004,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2902, 1413,   98,  613,   80,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1585, 2668, 1619, 2597,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1,  464, 1585, 2126,  105, 2919, 1801,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,   37, 1385,   39,    1, 1021, 2232, 1841,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   45,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1774,   39, 1230, 2528,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  729,  199,   37,  439,  903,    1, 1447, 1512,   32,   46,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  938,   37,  319,  353, 1371,  176,  941,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2948,    1, 2325,    1,   32,  863,  356,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  636,    1,  104, 1108,  681,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1929, 1268,   32, 3099,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,  284, 1604,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  858, 2264, 2316,   32, 2051,  763,  547,  537,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035,  716,   37, 1038,   32,  717,    1, 1741,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26,    1,    1, 1654,  104,   26, 2545,    1,  103, 2788,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2206, 2207, 3183,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2228,   79,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  375,   61,  105, 1133, 1463,    9, 3115,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   66,   32, 2212,  861,  469,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  460,   12, 1270,  889, 1433,   61,    1,  320,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1086,  417,    1,  289,   96,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,    1,    1, 1685,  105, 1512,   32, 1513,    1, 1421, 1022,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1321,  195, 2544,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3358,   61,  729,   32,   44, 1190,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   39,    1, 1841,  220,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 1974, 2024,    1,   32, 2752,    1, 1079, 2147, 2377,   37,\n",
      "         1910,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2959,  688, 3241,    9, 1194,   73,  726,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,   66,    1, 1100,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2767,  861,  675,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018,   37, 1418, 2924,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3371,   37,   52, 3390, 1411, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   59,    1, 2974,  162, 2223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,    1, 3205,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3127, 2095, 2322,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  619, 2050,  671,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  707,   37, 2468,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1,    1, 2243, 2206,   32,  105, 1510,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   61, 2994,    1, 2051,    1,  763, 2994,    1,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1220,    9,  769, 2126,  198,    1,  267,  395,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3393,    1, 3389, 2856,    1, 2764, 2765, 1634,  437,  396,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 2254,  140,  768,   43,  444, 1361,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  864, 2431, 1261,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  794, 1300, 1222, 2359,  934,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1523, 1086,    1,  284, 1004,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  741,   76,   37,    1, 1459,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 2385,  612, 2626,  415, 1724,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  754,    1,    1,    9, 3144, 2038,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,   44,   45,  680,   12,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284,    1, 2264,  420, 2205,  220, 3068,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,  738,  156,  570,    1,   98,  983,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3178, 1086,  914,  103, 2132, 1863,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1123,  873,  733,    9,  331,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,   98, 2393,  548,  937,   45, 2416, 1260,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98,  627,  315,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106,  459,   28,    1,    9,  885,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1411,  659,   45, 1778,    9,  327,   12,   37, 2728,   32,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,   69,  102,  686,  119, 1653,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1033,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  525,    1,  321,  920,    1,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,   37, 1075,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2988,    9,  829, 2987, 2762,   61,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  853,  844, 1532, 2812,  384,  166,   81, 1311, 1821,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  169,  159,  554,   98,    1,    1,    1, 1429,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  294,  256,  278,    9,    1,  777, 2247,  325,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1244,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  103,  147,   37,  817,   32,   98,  912, 2285,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 361, 928, 176,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3010,   28,   37, 1194,   32, 3278, 1672, 2771,  357,  129, 1684,\n",
      "         1090, 1610,    9,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0],\n",
      "        [   2,  590,    1, 2486, 1042, 2906,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1676,    1, 1418,  384, 2826,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  397,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  303,  267,    1,   45,  455,    1,   15, 2177,   37,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861,  439, 2264,  565, 1658,  449,  260,   45,  750,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32,  854, 2702,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   37,   26,  242,    1,   69,  729,  289,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  293,    1,    1,   98,   26, 1039, 2876,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1, 1888,  574,    1,  647,  159,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1646,   30,  985, 1260,  629,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  108,   45,    1,  629,   45, 2095, 1450,   32,  463, 1447,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3232,    1, 1625,   37,  865,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1151,   15,   37,  686,  119,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   22,  854,  776, 1086,  548,  257,    1,  398,   37, 2303,    1,\n",
      "         1314,    1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3355, 1921,   32, 1811,  404,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2614,    1,   39, 3175,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  150,    1,  354,   98,  417,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 2741, 1940,    1,    1,    1,    1,  361,    1,  600,\n",
      "          460,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1663, 1057,  176, 3147,  622,    1,   32,    1, 3114,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614, 1421, 1451, 3171, 2559, 3132,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2408, 2165, 2438,  220,  943,   45, 2528, 1542, 1230,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  594,  497,  543,   37,  652, 1428,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1023, 1204, 2850,   28,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2801,  200,  259,  529,  617,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,    1,   16,    1,  297,   31, 1160,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3122,    1,  150,   12,    1,    1, 1631,   85,  105,    7,  183,\n",
      "         1798,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1691,    1,  472, 1103,    1, 2828, 2857, 2827,   81,  191, 2695,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  861, 2091,    9, 3360,   12, 2823,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2477,  971, 2620,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3336,  603,    9, 2187,  384, 1668,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   37,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,   84, 1415,   37, 2276,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,  682,    1,  191,  577,   65,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2550,   29, 1564,  865,  105, 1822,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  870, 1962,  108,   45,    1, 1080,  384,    1, 1273, 2866,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056, 1530,   32,  455,  187, 3121,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1, 1781,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  196,  272,   37,    1,    1, 2474,  259,    9,  453, 1074,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273, 2923, 2615,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   45,    1,  919, 1018,    1,    1,   74,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  223,  408,   76,   37, 1192,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,   48,   32,  632,   69,  633,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1044,    1, 2385,    1, 2315,  221,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,   37,  138,  331,   37,    1,  875,  573,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2265, 1314, 2357,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   45, 2249, 1178,   12,    1, 1710,  606,  277, 1013,\n",
      "          947,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  773,  565,  838,   37, 1718, 3031,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158, 2102,  215, 2590,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,   82, 1484,    9, 1580,  652,    1,  858,  973,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  794,  103,  439, 1021, 2168,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  758, 1463,  365, 2194, 1294,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    7,  116, 3017,   28,    9, 2479,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  352,   51,    1,    1,   50,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,  197, 1660,  157,  921, 1944,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1574,  969,  600,   10, 2681, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,  166,  858, 2401,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1,  921,    1, 2296,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2899,   37,  843, 1273,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2456, 2133,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2031,   37, 1291,  822,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2355, 1013,  884, 1003,  176,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  215,   12, 1247,  267,  590,  630, 2011,   98,  594,  497,  734,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,  293,  580, 1649,    1,   32,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  845,  275,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783, 1118,  453,  932,  548,  105, 2096,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  743,   12,  708,    1,   12, 2638,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1178, 1231,  220,  840, 2339, 1778, 2690,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3233,  439,  584,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2164,    1, 1850,  455,    1,    1,   32,  409,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2289, 1373,    1, 2226, 1924,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    1,  548,    1,    1,   56, 1530,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730,    1,    1,    1,  612, 1273,    9,  858, 1108,  918,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  726, 3329, 1990, 3201,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1187,    1,  248,    1,  357, 1187,  224,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2879,    1,  105,  112,   32,  463,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  741,   45, 1161,   32,  219, 3372,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1818,  147,  520,  695,   98, 3144, 1002, 1512,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  286,  940, 2407, 1791, 1630,  361,    1,  142,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  636,   51, 1348,    1,  832,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  873, 2415,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2984, 1564,    1, 2820,    1,  892,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  269, 1167,    1, 1055,  841,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  965, 1585, 2414,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  698,   28,  251,  340, 1021,  466,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2686, 2687,    1,    9, 1242,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700, 2040,    9, 3012,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3343, 1009,  680,  114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  920,  460,   12, 1051, 1039, 2690,   28,\n",
      "            9,  333,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  167, 1152,   45,  627,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  411,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 3141, 2962,    1, 1401, 1959,  608, 2307,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1902,    1,    1,  166,    1,    1, 1654,   37,  294,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2741,    1,  856,   81,   37, 2250,  220,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2103,  617,    1,    1,    1, 1080,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,   12,    1,    1,    1,   37, 2469,  378,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 2386,  104,   45, 2587, 3118,   37, 1377,   37, 2911,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2226,    1,  777, 1085,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  418,   98,  430,    1, 2046,    1,  107,   51, 1598,  568,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,  630,   98, 1461, 1463, 2824,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  197, 1784,    9,  449, 1023,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  111, 2608, 2607, 1744,    1,    1,  590,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564,  221,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2514,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  967,    1,   54, 1339,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1672, 2771,  476,   37, 1911,    1, 3100,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1236,    1, 2737,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 1377,   45,  730,  841,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  373,    6,  381,    1,  159,  720,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1191,    1,  500, 1292,   32, 1427, 2560,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2729,    1,    1,  191,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  547,    1,    1, 1976,  403,   45, 2597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  451, 1830,    9,    1,   45,  449,  104, 1168,  880,  452,  443,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,   46,   28, 2255,  801,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  571,   37,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2087,  433,    1, 1161,   32,    1, 2266,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2596, 1585, 2414,  947,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3312,    9,    1,  548, 1890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1509,  512, 1745,   37,  335,   44,   45, 2846,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  193,  466,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3403,  640,   27, 2597, 1325,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2480,    1, 1348, 2338,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  184,   32,    1,   32, 3308, 1990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777, 1702, 1718,  981, 1159,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1584,   12,  943,  600,   80,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  565,   66,   79,  105, 2589,  176,   26,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3403, 2414,   27, 2597,  947,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3192, 1956,   37, 2833,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,    1,    1,    1,    1, 1484,   39,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3124,    1,    1, 1944,   98, 1580,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51, 1334, 1400,  187,    1,    1, 2696,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1000,    1,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3297, 3089, 1090,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,    1,  889, 2826, 2030,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,   79,    1,  163,    1,   12,    1, 2053,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  447,  315,   37,  125,  259,   48,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  267,  163,    1,   12,    1,  919, 2673,    1, 1821,  970,\n",
      "         2109,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  313,    9,  103,  220,  365, 1050, 2334,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1557,    1, 3343,  863,  133,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  299,  952,    1,    1, 1001,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,    1,  311,   85,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2292,  190,    1,   32,  531,  187,  890,   27,    1, 3128,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1760, 1089, 1090,    9,    1,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2018,    1,  854,  498,   37, 1445,   26,  885, 2702,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,    1,    1, 1216,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,  187, 2565,  176, 3190,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1520,    1,    9, 2855,   98, 1915,  361, 2212,    8,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 829, 572, 156,  28, 118, 428,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 531,  69,   1,   1, 548,   1,   1,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  446, 1550,    1, 1300,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,   12, 1167,    1,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  251,    1,    9, 2580, 2851, 2544, 1958,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,   13,    6,    4,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  374,  407,  388,  763, 1394,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  700, 3007, 2679, 1912,    1,    9,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1861,    6, 1139,    1, 2237,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1008,  172,  475,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  754,   15,  120,   32,  385,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  938, 1408,  166, 1117,    1, 1480,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  882, 1111,  528,  244,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  166, 1973,    1,    1,  176, 2486,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2993, 2994,    1,  166,  593,   98,  114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  357,    1,   98, 2662,   12, 2918, 2820,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1785, 1877,   37,   77,    1, 1208,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169, 3090,  176,  455,   26,    1, 2779,  801,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  166, 1509,  191,  166,    1,   45, 1018,  661,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  446,   37,    1, 1460,  342, 2396,  424, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2504,  446, 2908,    9,    1, 2958,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,    1,  565, 1809,    1,   32, 1990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2266,   90, 2868, 1428,  190, 1527,  531,  741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2217, 2161,   12,    1, 1518,  548, 2625,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1753, 1035,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1928, 1825,  565, 2056, 2398,    1,  267,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  386,  921, 2423,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1316,  531,  187, 2529, 3373,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 3350,    1, 1550, 2884,    9, 1926, 1927, 1924,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523,    1,    1, 2876,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  627,  603,   28,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3028,    1, 2995,  388, 2341,    1,  267,  586,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2746,  167,  726,    1, 1311,   32, 1440, 2107,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   12, 1043, 1738,  338,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2586,  176,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  440, 2995,  809,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,  418,   98,  604,  605,    1, 1446,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  396,    1,  297, 1099, 1453,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 2922,    1,   81, 2722, 3074, 1215,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  811,    1,  593,   12,    1,  826,   32,  447,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  189, 1702,   81,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,  587, 1539,  477,  202,   69,  532, 2014,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3006,  688, 1178, 2112,   37,   52,  384,  104,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2256,  267, 3079,    1,  612,  877,   59,  693,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,  407,   98,  848,   12, 2371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,    1,   37, 1706,   32, 1109,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  743,   12,  277,  191,    1,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  446, 2770,   37,  764, 1403, 1894, 1064,   32, 2517,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   98,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2474,  321,  612, 1000, 2315, 2589,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3087, 2478, 1850, 1327,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  560, 1274,   71,  915, 1034,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2741,    1, 1515,  847,  176,  166,  915,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  795,  295,   82,  939,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  220,    1,   32,  166, 1013,    9, 1204,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1,  854,   37,  726,  601,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,    1,  104,  105,  106,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175,    1,  191, 3138,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  770, 1112,  176,  105,    1,  985,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 2414,  103, 3374, 2328,   13,   32, 3339,  477,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  963,    1, 1924, 2288,    1,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  745,   98,  166,    1, 2695,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2084,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,   82,   83,   37, 1540,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  398,  261, 3128,    1,   52, 2270,   37,    1,   98, 3402, 3408,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401, 1367,  297, 3241,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  197,  338,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999,   91, 1994, 2819, 3050,    1,  166,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3183, 2620,   98, 3182,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   26,  526,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  108,    1,  444, 3104, 1511,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3012, 3027,  920,  105,  331,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3253,  300,   39,  304,  220,    1,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 2673,  475,  812,  365, 2240,  220,   91,  548,   46,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 2693, 2694, 2501,  443,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  256, 1225,  414,   37,    1, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1166, 1444, 1734,   98,    1,    1,    1,  962,  361,  166,  673,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1, 1758,  176,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1787,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  382, 2514,    1,    1, 3289, 1083,  105,    1,   45, 1574,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2959,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  475,  939,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3199,    1,    1,  719,  198, 1844,  176, 2570,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  381,  604,  605,    1,  191,  215, 1852,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  911,   32,  105,    1,  297, 2997,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 2055,   37, 1399,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  155, 2412,  361,  376,  102,   32, 2759,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  729, 1121,   32,  460,  495,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190, 3327,  335,  105, 2482,    1,    1,  967, 1875,    1, 2855,\n",
      "          608,  597,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  334, 1445,    1,    1,  193, 3073,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1530,  187,    1,    1,   32,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056,  104, 2548, 2572,    1,   56, 1941, 1897, 1260,   32, 3383,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,  640, 1796,  540,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3007,  242, 1208, 1102,    1,    1,  388,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  391,  477,    1, 1094,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,    1,   37,    1,  549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043, 1993,   28,   98,  996,  753,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  566,  365, 1788, 1844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2759,    1, 1124,   32,  572,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  336, 1426, 2350,  813, 1114,   32,    1,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1335,  514,   32,  142,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,  547,  163,    1,   12,    1, 2161,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2380,    1,    1,  985,    1,    1,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  420, 2343,    1,  384,  163,    1,  903,    1,  802,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  822, 1574, 2854,  829,    1,  151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  148, 1118,  803,  112, 2750,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,   61,    1, 1013, 1681,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  828,    1,    1,    1, 2730,  302,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  684,  475,  476, 1032,   60,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2163,   69,  102,  245,  187,   64,  509,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  288,  365, 2078,  530,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 204,  12, 472, 220, 460,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 171,   1, 590,   1, 584,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  325, 2481,    1,  112,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    9,  166,    1,    1, 1624,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  167,  529,  215, 1219,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220,  567,    1,    1,  584, 1484,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,  784, 2219,  763, 1366, 2112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  733,   39,    1,  447,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2959, 2446,  902,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,   46,  220,  359, 1686,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  420,   49,   61,  686,  220,  365,    5,  396,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1908, 2242,    9, 1607, 1626,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  566,  865,   37, 1983, 2760,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2857,  682,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    4,   45,  487,  358,  482,  680, 1665,    1,    1,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2942,   37,  335,   98,    1,   32,    1, 2539,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1634, 1074, 2145,   37,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,   12,  365, 2452,   61,  810, 1616,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1771,  171, 2761,    1, 2317,    9, 1090,    1, 2451,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  430,  997,  973,   28,   69,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  614,   98,  495,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  921,   79, 1021,  279, 2232,  260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3255, 1973,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1201,    1,    9,  333,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3046,  765, 1159,  401, 3179,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1670,  166,   72,  454,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1583, 3109, 3375,   32,  717,    1,  458,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2861,  539, 1675,   28,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1625,    1,   85,  191,    1,  166, 1700,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,    1,  604,  220,  356,    1, 1039,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  129,  550,  830,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49, 1041,    1,   54,    9,  595,   37,  138,    5,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1447, 1324,  193,   66,  187,  903, 1463,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1751,    1, 1381,  384,    1, 3311,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3178,  140,    1, 3222,  548, 2347, 3168,  796,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   30,   79,  365, 1222, 2515,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2347,    1,   39,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  631,    1,    1,   32,    1,    1,    1,  163,    1,   12,    1,\n",
      "          506,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1613,  936,  365,    1, 1615,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2439,  193, 1389,   45, 1447, 1585,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1387, 1013,  361,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  404, 2295,   32,  333,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  353, 1913,  401,  207,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,   22,   23, 2392,  331, 1228,    1, 1085,  132,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37, 1234, 2294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  280,    1,   37, 2964,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  395, 1354,  756, 2910,  686,  191,  116,  861, 2298,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1366, 2047,  590,  786,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1610,    1,   32,    1,   37,    1,  138,    6,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  467,    1,  176,  393,    1,    1,  267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  660,  331,  782,  453,  913,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2350,    1,  244,   71,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  325, 1159,  934, 1499,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12, 2514, 2711,  181,   98,  785,  786,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1386, 2331, 1428, 1311, 1360,  612, 2200,    1, 1559,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1009, 3378,   37,   26, 1462,  176,  443, 2938,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2475, 1508, 1211, 2878,    1,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2225,   37, 2844, 1371,  365,    1, 2353,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  148, 1564,  915,  142,    9,  647,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3249,    1,  590,    1, 2307,   32, 2138,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3358,   12,  985,    1, 2708, 1190,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,    1,  650,  571,   37,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1243,  365, 3017,    1,    1, 2043,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200,  315,    9,  449, 1890,   32, 1021,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1934, 1583,  993,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  122,  297, 1778,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1307,  884, 1003,  176, 1792, 1871,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9, 3075,   37, 2237,    1,    1,   32,  166,  272,    1,\n",
      "         1009,  267,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1147, 2673, 1491,    1,  606,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1920,    1,  191,  166, 3088,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1440,    1, 2096,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169,  833,  612, 1306, 2890,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   56, 2341,  219, 1477, 1990, 1669,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1, 1465,  220, 3032, 1102,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1817,    1,  171,   12,    1, 1360,  612, 1343,   32,    1, 2771,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,  947,   37,  776,  563,  564,    9,   22,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2677, 1178,  386,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3303,  361,    1, 1388,    9,   59, 2497,  427, 1343, 1684,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1654,  103, 1567,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2957, 3044, 2232,    1, 1718, 2973, 1764,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  385,   15,   28,   98,  365,  280,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1898, 1994, 2275,    1,   37, 2466,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  586,  387,  196,    1,  132, 1371,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,  361,  746, 1776, 1766, 1767,    1, 1259,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2919,    1,    1, 2391, 2697,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2452,  517, 1452,  388,    1,  763,  915,  786,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158,    1,  365, 2452,  517,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,    1, 2355, 1718,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,  365, 1250,   45,  112,    9, 1151,  293,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1774,   39, 1230, 2528,    1, 2668,  220,  163,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1787,  645,    1,    1,  396,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428,   22, 2150,  105,  103,    1,    9,   10,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1509,   45, 1215,    1, 2491,   45, 1215,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 2977,    1,  513,    1,   37,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 1218,   37, 1343,   32,   72, 1131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1419, 1952,  593, 1429,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3204, 2809, 1665,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1298, 1647,   32,  903, 1447,   46,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  967,    1,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2714, 1537,  693,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  593, 2596, 2414, 1029, 2231,    1,  876,  612,    1,  176,  104,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3296, 2158, 1874, 1672,   32,    1, 1851,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2873,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183, 1985,    1,    1,   37, 2446, 1844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  978, 3138,   37,  151,    1,    9,    1,   59,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647, 2471,    1,  220,  326,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  579,  190,    1,   85, 3018,  693,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3332,   42,  284, 2753,   32,  365,    1, 2441,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,    1,   32, 2235,  537, 1185,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  551, 2860, 2373,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  936, 2975,  818,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   37, 1539,  365, 3029, 1539,    1,  424,  339,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  199,   61, 1120,    9,  375,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   12, 1043, 1738, 1518,  417,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1409,    1,  803,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,    1,   37,  168,  974,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1289,   59,    1, 2158,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2104,  952,   10,    1, 2275,  751,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1884, 2681,  187, 3101, 3372,    1, 3339, 2129,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1708,   12,  103, 2083,  924,  939,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1277,   12,    1,  105, 3023,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3176,  298, 1114,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,  647,  951,    1,  148,  724,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2662,   12, 2820,  600,   37,  946,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  144,  145,    6, 1183, 2113,  156, 1396,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,   93,  509,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1307,  459,   28,    9,    1, 1102,  841,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,    1, 2775,  361,  311,    1,    1, 1204,   61, 2177,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1273,  618, 1124,    1,  629,    1,  506,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596,  176, 2018, 3407, 3392, 2766,   56,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,  460,    1,   37, 1474,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1617,  933, 2041,  230,  548,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1187, 3229,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2080, 2771, 3276, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1283, 1074, 2312,    1,    1,  166, 2459, 3233,  606,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  237, 2357,    1, 1319, 2396,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1627,  863, 2107,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2550,   98,    1,   45,  395,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  586, 2851,    1, 2041,   37, 3018,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1056, 1349, 1867,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1769,   37,  759,   17,   32, 1018, 1015,   45, 1117, 1525,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2472,  159,  686,  119,  845,  548, 1901,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2, 342,  37,   1,  32, 400, 444, 829,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 162, 103,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 381, 197, 418, 118,  88,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 293, 420,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  847,   28,  183,    1,   45,    1, 2168,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  330,   37,    1, 2997,    1, 2898, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,  891,   46,   37,  151,  942,   12,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  361, 2275,   98, 1260,   32, 2482,   78,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056,  388,  103, 1307,  494, 2022,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  678,    1,   61,  105, 2318,    1,    1,  220, 3299,  361,    1,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,    1, 1422, 1211,  442, 1259,  220,    1,  310,  497,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    9,  219, 2579,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1501,  498,   37,  138,   37,  875,    1,  767,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2911, 1947,    5,  641,   37,  138,    9, 3283,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98,  864,   12, 2673, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1959,  951,    1, 1214,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  716, 3305, 2352,  584,  389,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,    1,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   37, 1075, 1970,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  738,  220, 2584,  379,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  409,   25,   26,  417,  104,   60,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2579,    1,   61, 2758,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2883,  908, 2251,   45,  195,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3064,  140,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1997,    1,  384,  976,    1,  851,   37, 3369,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 3054,    1,  846,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1815,    1, 1874, 1537, 1726, 2018, 2237,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1688,   37,   38,   39,   40,   41,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  440,  531,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2229,    1, 1090,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  572,  197, 1308,   37,  331,  384,  331,  187,  297,\n",
      "            1, 1149,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,  365, 2792,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3205,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1,  502,  492, 1910,  395,  934,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1957, 2712,    1, 2584,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 1557,   12,  233,  650,  796,  548,  863, 2651,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2110,  590, 2537,  320, 3257,  884,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  140, 2505,   32,  331,    1,  395,  162,  671,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3169, 1484,   98, 1345,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2289, 2385,    1,    1,    1,    1,    1,  460, 1924,    1,\n",
      "         1881,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1447,  455,  909, 1710,   52,  443,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3186,  726,    1, 1608, 2250, 1691, 1443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3186,   94, 1623,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  484,   76,  892,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1046,  215, 2095,  134,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2980,  923,  335, 1003,  176, 1273,  618,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  560, 1274,  470,   32, 1275, 1034,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   27,   98,    1,  531, 2292,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   66,  417,  187,   69, 1702,  242,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  245,    6,    1,    1,  408,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,  775, 3019,  660,  331,  220,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3209,    1, 2590,    1, 3288,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  199,  421,  744,   28,   59,  822, 1482,    1,  197, 1276,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1414,   32, 3360, 2040,   98,  949,   45, 1428, 3365,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  884,   98, 2102,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2922,    1,   37, 3323,    9, 2824,  712,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1, 2414,   32, 3155,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779, 1654,   37, 1264,  841,   32,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3308, 1947,  815,   45,    1,    1, 1411,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,   37,    1,  365,  650,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1128,  108,   98,  114,  629,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  442,  448,    1,   37,    1,  131,   32,  871,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2615,    1,  730, 2614, 1542,    9, 1090,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2960,   32, 2597, 2414,  786,    1, 2766,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3111, 2844,   32, 2162,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  538, 2469,    1, 1713, 1170,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2720, 2796,  130,    1, 3254,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564, 1499, 1064,    1,    1,    1,   39,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,  213,   37,  388, 3406,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  982, 1308,  844, 2721,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  260,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  754,    1, 3139,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  857, 1469,  439,    9,  284,  668,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1628,  550,    1,  460,   12,  227,  550,    9,   10,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  459, 1167,  455,   12,  996,  471,   61,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2275,    1,   10,    9,  397,  909, 1665,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  175,   45, 2733,  361,  440,  552,  552,  912, 2285, 1699,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   22, 1168, 1225,  288,   37,  119,    1,   93,  452,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2789,  394,   32,  926,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  475,   45,  723, 1362, 1396,  218,  332,  682,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 1725,  442,  719,    1,    1,  267,  420,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  503,  244,  688,  739,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993, 2994,  116, 2995,  218,  332,  682,   37,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2347, 1114,    1, 3274,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  868, 3339,  787,  220, 3162,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  664,  885, 2125,    1,    9,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111,  286, 1077,   51,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2275,  366,   10,   32,    7, 2482,   78,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1, 1394,   45,  518,  166, 1868, 1172,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2741,   37, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2577, 1952,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3006,  114, 2328,  176, 3101, 1223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144, 1557, 2257,   39,   45,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  715,  957,    6, 1062,    1,   48,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1625,   71,    9, 1390, 1746,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  459,    1,  132,   37, 1343,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  991,    1,   45,    1,  802,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  954,  897,  191,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2215, 3005,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  539,    1, 1159, 3295,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   58, 1500,  197,  570,  361, 1261, 1220,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,  422,  484,   98,  224, 1126,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,    1, 2758, 1530, 2764,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3190,    1, 3161,   32,  674,   45, 3278, 1669,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  365,    1,    1,  454,   37,  856, 2502,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2689,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  732,   37,   47,   35,   48,    1,  672,  734,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  121, 1666, 1539,   45,  365, 1821,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    5,  504,  696,  821,  704,  104, 1201,    1,  317,  197,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1327,  580,  477,   74,  444,    5,    6,    9,  252,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    4, 1754,   37,    1,  915,  339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1329, 1149,  562,  477,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,  692,    1,  331,    1,  599,    9, 2114,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2493,  166,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1985,  118,   45, 2527, 2946,   37,    1,  163,    1,   12,    1,\n",
      "          506,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1123, 2561,    1,    1,    1,  928,  176,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1512,   32,  531, 1221,   12,  590,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2864,  228,  537,   45, 1609,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103,    1,    1,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,  682,  548,  517, 1953,  251,  590,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1283, 3231, 2642,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26, 1039, 2366, 1271,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2144, 1530,  548,  104,  851,  298,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3186,  726,    1, 1691,  700,  427,   37, 1641, 1684, 2107, 1849,\n",
      "           26,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2300,  459, 2824,  630,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  364,  105, 1684,    1,    1,  193, 2408,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  233,    1,    1,  302,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1111,  297,  395, 1031,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  443, 2861,   37,  961,  147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3154,  914,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3363,  288,    9, 2237,   37, 2018,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2754, 2924,   37, 1910,  531, 1411,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101, 2548,  792, 2572,   32, 3339, 1585,  792,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613, 1774,   39,  365, 1615, 1775,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1641,    9,  931,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  112, 2149,  335,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2941, 1090, 3210, 1282,    1, 1352, 1022,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  183, 2960,  898,   32,  403, 1447,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2765, 1396, 3343, 1002,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  650,    1,    1,  267,  247,  808,   61,   37,    1,  365,\n",
      "            1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  879,  822, 1942,   37,  810,   17,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1127,  744, 1884,    1,   98,  234, 3041,  235, 2379,    1,  234,\n",
      "         3041,  235,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  550,  830,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   36,  433, 1242,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056,  104, 3111, 2572,   32,    1, 2433,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  726,   32,  106, 2514,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1247,  193, 1542,    9,  698,   45,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1353, 2285,   45, 1039, 2690,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1965, 2550,  782, 1534,   45,    1,  238,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  542,    1,    1,   45,  597,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  548, 2215,    1,  453,    1,    1,    1, 2858, 2665, 1108,    9,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1248, 2764, 3356,   37, 1910, 3346,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3345,  774, 1444,  606, 2572, 1485, 3102,  844,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  884,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  193,  166, 1690,   32,    1, 2717,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  596,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  952,    1,   32,    1,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  361,  104, 1822, 2446,  166, 3148,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  415,    1,  166, 2047,    1,  361, 1289,  284,  330,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  446,   46,   28, 1081, 2471,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2720, 2724,    1,  190,    1, 3265, 1857,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2041,    1, 1924, 2072,    1, 3040, 2716,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1177,    1,  857,  818,    1,   37,  553,  720,   32,  537,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,  143,  187, 1547,  246,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,  852,   37,    1,   79, 1100,  220,  365,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1056,  314,  551, 1692, 1682,   84,   85,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  858,  641,  453,  759,    1,  267, 1127,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,  716,  594,  737,  244,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  531,  443,    1,  289,   98, 2157, 2521,   37,   10,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 3039,    1,  333,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,   37,   26,   28,   37,  365,  124,   32,  395,  191,\n",
      "          439,  420,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,   37,   47, 3017, 1008,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2526,    1,  190, 2075,   81,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1375, 1243,  138,    1,  362,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1024,  884, 1003,  176,  388,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  368,    1,  102,   37, 1253,  118,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  616, 2714,   10, 1918,  220,  105,  225,  186,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2642,   77, 1340,    1,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2974, 1542,    9,  388,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  580,    1,  187,  829,    1, 3018,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   30,  590, 1184,   32, 2224,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492, 2611,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2999,   91, 1550, 1260,   98,    1, 1583,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433, 1579,  131,  750,  302,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  344, 1656, 3403, 2414,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3281,   61, 2745,    1, 1343, 1515,  931,  917,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12,    1, 2572,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 3394,  313,   37,    1, 3343,  890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  744,    1,   98,    1, 1385,  166,  593, 1787,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,  794,  210,    9, 1003,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  117, 1900,    1,    1,    1, 1937,  198, 2034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1788, 3322,  872,  420, 1169,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2576,  361,    1,  891,    1,  332,  151,   81,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1486,  353,  183,  390,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  891, 1159,    1, 1260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2339, 1108,    1,  111,  161,  133, 1551,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1412,  661,   98,  510, 2928,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1235, 1236,  297, 1241,    1,  244,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,   37, 1075,   98,   86,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,  494, 1862,  600, 1262,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3199, 2126,   32,  674,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1185,    1,    1,  582, 2925, 2158,   45, 2121,  449,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  104, 2548, 2572,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  884,    1,  191, 2050,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947, 2572,   32,    1,  176, 2459,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  491,   42,  301,  133,  134,    9,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,  136,  475,    1,    1, 2430,   98,  133,  134,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  729, 1555,   98,  105, 2771,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  639, 1988,   45,    1, 1763,   12,  663,  530, 1515,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  754,  757,  197,  418,   98, 1085,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275,    1,  297,  451,    1,  954,    1,  531,    1,\n",
      "         3118,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,    1,  193,    9,  105,  581,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311,  199,    1,    1,    1,    1,  111, 2131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1842,  271,    1,  116,   32,    1,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3251,  442,    1,   37, 3319,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1796, 1107,  441,  565,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   70,  102, 1348,   37, 1473,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  721,  261,  809,   52,    1,  187,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  361,   10,  472,    1,  361,    1,   32, 2087,  433, 2107,\n",
      "         1002,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2837,  686,  191, 1107, 2610,    1,   79,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   12, 1929,  338, 1139,   98, 1574,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2899, 1359,  614,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  896,    1,    1,    1,   45,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2991, 1380,    1,    1,  176, 1095, 2264,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2648,  580,    1, 1787,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1, 3375,  588,  132,   37,  439, 3339, 1345,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   37,  504,  384,    5, 1491, 1278,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2692,  991,   59,   32,  449,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32,  649,  851,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  628,    1,    1,   32,  525,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3194, 3195, 1800,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3371,    1,    1, 2000,    1, 2532,    1,    1,    8,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  921,  572,  570,    1,    1, 1680,    1, 1470,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  990,  838,   37, 2819,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1, 2297,  187,  163,    1,   12,    1, 1477, 1990,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  542,  176, 1477, 1990,    1,   37,   52, 2204,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  422,  267,  348,    1,  625,  297,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  980, 3144,  888,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1065, 1190,  891,  330,  601, 2113,  548,  863,  726,   32,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1411,  649,    1, 1821, 2784,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  612,  111,  884,  297,  715, 1107,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  649,  844,   13,  744, 2364,   98,   91,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790, 2134,  761,   37,    1,    1,  378,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  506, 1273,  259,  815,  641, 2895,    1,  629,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  289,   98,  310, 2527,  164,    1,    1,  193,    1, 1492,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   37, 2866,   28,  535,  656,  327,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,   46,   37,    1,  297, 2224,  317,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  413,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2250,    9, 3182,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  169,   15,   28,  699,   32, 1352,    1,  729,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,    1, 2354,    1, 2873,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  342,  952,    1,   45,  104,  211,   32,  397,   22, 1559,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2656,  275, 1346, 1752, 1962, 1149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2225,   45, 3102, 2536,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3392,    1,   32, 2018,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,  640,  365,   94,  340, 1043,  338,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  884,  105, 1917,    1,    1,   85, 1102,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2736, 1268,  651, 2396,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,   37, 1504,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1850, 2778, 1348,   46,   32,  215,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,    1,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  733,    1,    1,    9,    1,  131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,   37, 1174, 1958, 2355, 1013,   32, 2020,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2066,   69,  102,  576,   25,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,  669,   37, 1865,    4,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  844, 1727,   37, 3345,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2844,   32, 2018, 1260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,    8, 2549,   37,  582,   79, 2987,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  256,  529,   37, 2355, 1013, 1882,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  786, 1833, 3179,  565,  105,  183,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   81,  176,  460,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3152, 1348,  584, 2041, 2482,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1086,  449,  785,  786,  914,  220,  968,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,  463, 1670, 2161,   12, 2591,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  213,   37,  576, 2095,    1,   37, 1785,\n",
      "         2044,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,  997, 2638,    1, 1997,    1,   32,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  132,   37,  151,  487,  413,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1587, 2279,  162,  166,  720,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  275,  681, 1248,   10,   37,  289,   98, 2972,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708,  954,   32,  276,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,   37,  365,  687,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2929,   37, 1539, 1273,  259, 1108,   32,  179,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1419,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32, 1740,   45, 1479, 1450,   32,  531,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2982,  389,  146,   37, 2912,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3211, 3055,   37, 2613,  726,  297, 2476,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2101,   45, 1940,    1,    1,   98,  389,   28,    1,  420,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283, 1385,   28,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,  442,    1,   32, 1242,  245,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,   46,   98, 1645,   50,  333,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  183, 2537,  920,   61,   32,    1,    1,    1,   37, 2498,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 104, 376,  93,  67,  32, 581, 401,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 166, 792,   1, 792,  61,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  231, 1090, 1667, 1289,   98, 1089,   61,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1654,  557,  970,  142,  176, 1261, 1953,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1281,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233, 2104, 1458, 1859,    9, 1412,  844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  116,  437,    1,  829, 3042,  161,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453, 2145,   37,    1,  156,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  176, 2275,   12,    1,    1,  717,   61,    9,    1,    1,  111,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  108,   45,    1,    9,  645,    1, 2558,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2570,  750,    7,   37,  354,  444, 1739,  275,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1408, 2882,   26, 2545,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3323,    1,  153, 1090,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3069,   37,  576, 2172, 1346,   37,  531,   63,  356,   12,  439,\n",
      "          104,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2885,  884,  297, 3129,   12,  590,    1, 2788,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,  288,   37, 1539,  365, 1090, 1294,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1528,    1, 1194, 1843,  197,   28,  419,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283,  147, 1392, 3207,  671, 3126, 1377,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1228,    1,    1, 1111, 1434,   32,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1018, 1816, 1167,    1, 2613, 2383,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3169, 1249, 1645, 2313,    1,   37,  759,   72, 1385,  176, 2197,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  224,  155,    1,    9, 1126, 1611, 1282,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1100,  936, 1273,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3330,  729,  193,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2373,    1,  191,    1,   64,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12, 1090,   74,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  507,  539,  190,  193,  142,    9, 1933,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2677,  463, 2170, 1077,   37,    1, 1565,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3213,    1,  190, 1251,  104,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,   57,    1,    1,   37,  161, 1791, 2633,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3204, 2421,   39,   45, 2826,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  204,    1, 2349,    1,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1081,  267,  460,  476,    1,  861, 1906, 1311,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,    1,   12,  248,    1, 2158,    1, 1620,   61,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3168, 1917, 3178,   32, 2069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1, 2826,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,   37, 2099,  147, 2145,  138,    6,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,    1,  365, 1463, 2639,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1090,    1,    1,  460,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1149, 2844,   32, 1686,  176, 1325,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1081,   37, 1816,    1,    1,  171, 1340,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75, 1579,    1,    1,  261,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3231,  688,  705, 1458,   32, 2799,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1338,   45, 1647,   98, 1384,  932,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,  744,  105,  119,    9,  846,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  108,  600,  890, 1428,  997,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,  936, 1151,    1, 2174,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  387,  331,   32,    1,    6,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1645,    1,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1448, 1512, 1554,    1,  568,  176,  629,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   91,  927,    1, 1627, 2918, 2818,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1774,   39,  365, 1718, 2232, 2587, 1021, 1151,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  342,  879,  231,   45,  829,  132,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1203,  600,    1, 2687,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 716, 244,  28, 118,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 304,   1, 600,   1, 689,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  324,  132,   30,  395,   12, 1239, 1240,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1002,   30, 1986,  297,    1,  275, 1278,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2621,    1,   32, 3151, 1384,  856,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492,    1,    1,   45,    1, 2791,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2736,    1,    1, 1159, 1888,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,    1,    1, 1718,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056, 1940,  856,    9,    1,  663,  297, 3379, 1585, 2566,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  992,   37, 1598,  649,   93, 2567,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  433,    1,  233,  498,   98,  301,    5,  302,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12,    1,  267,  204,    1,    1, 2162,    1, 1322,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3121, 1554, 1530,    1, 2249,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,  640, 2755,  455,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1305,  722,  183,  787, 2856,    9, 3335,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112, 1772,  355,    1,    1,   93, 1704,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1527,  940,   61, 3340,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2479,    1,  631,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1795,    1,  391,    1,  726,  163,    1,   12,    1, 1583,   24,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  744, 1739, 1224,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  476, 3116,  922, 1031,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160,  102, 1473, 1290,  396,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  733,  159,   32, 1126,    9,  548,  672,  636,   45,  225,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  550,  551, 2415,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,   12,  463,   69,  624,    1,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2151,  531,   12,  403,   69,  532,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,  354,    1, 2216, 1299,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118, 2024,   46,  588,   37,  271,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1, 1993,  316, 1022,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  729,    1,  202,  132,   66,  972,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  220,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 2153, 1982,  807,  808,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1419,  105,    1,   45, 2976,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12,    1,    1,   37,    1, 2789,  434,  176,    1,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1051,  251, 2348,    1,    9,  829, 1872,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   31,  418,  995,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1771,  171,    1,    1,   32,  123, 1675,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197, 1137,   32,  401,    1,  202,  193, 2398,    9,  236,\n",
      "         1022,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,   28,  547,    1,   32, 2678,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  664, 1056, 2308,   32,    1, 1437, 2824,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  609,  610,   37,  257,   32,  611,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,   12, 2695,  105,   37, 2564,    1,   95, 1411, 1034,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   61, 2267,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  103, 2920,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  220, 2832, 1555,    1, 2868, 1949, 2784,   37, 2826,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2073,  328,    1,    6,    1,   48,  155,   12,  331,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,    1,    1,   32, 3288,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2729,  700,    1,    1,   98,  531, 3365,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2623,    1,   37,  949,  449, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1110,  221,   37,  321,  923,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   99,    1, 1058,  297,   31,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  386,    1,  562,    1,    1, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2924,  221,   37,    1,   32, 2751,   32,\n",
      "          403,   45,  531,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  408,  565,  365,  289,    9, 2855,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2616, 2952,    1,    1,  629,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,    1,    1,  288,   37, 1413,  596,  442, 1075, 1638,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  814,    1,    1, 1074,   37, 1154,  408,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  575,    1, 2869, 1089,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,  361, 2275, 1388,   98,  962,    1,  223, 2135,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  583, 1897, 1557,  477,   32, 1853, 1633,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2307, 3108,  688, 2087, 2614,   37, 2935,   72,   73,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885,  916,    9, 1123,   37,  875,  453, 2277,  220,  229,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,    1, 2503,  590,    1,  584,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  111,   11,    1,    1,  150,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  474,    1,  488,    1,  477,  444,  295,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2359,    1,  884,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 1385,  786,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  232, 2609,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2275, 2326,   39, 1557, 1058,   98,  443,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2208, 2402,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2503,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1997,   98,    1, 2385,  612,    1, 1103,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1137,   32, 1300,  605,  714,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2405,    1,    1, 1953,  220,  446,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,   98,  119, 1844,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12,  103,    1,    1,    1,   37, 2197,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   56, 2224,  893,  319,  297, 2113, 1523,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384,    1,   37, 2773,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3261, 1760, 1676,    1,  384, 1675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2751, 2253, 1712,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 197, 418,   1, 202, 157,   1,  88,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  60,   1, 105, 114, 680, 166,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3267,  140, 1742, 1684,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   25,   26,  417,  548,    4,   29,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  657, 1426,  660,  846, 2010,  176,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 3054, 1249,   22,  846,  119, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1796, 1592, 1835,  705,    1, 1017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2266, 2055,    1, 1428, 1346,    9,  652,  973,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453, 1682, 1599,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2249,  632,    1, 1976,    1,   27, 3367, 2640,  893, 2572,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  203,  105, 2440,    1,  167,  764, 1154, 3015,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  173,  384,  104,  793,  932,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1585,  176, 2018, 3407, 3392, 2414,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403,    1,  535,  437,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  342, 1874,  632,  432,   45, 1839, 3037,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  475, 2477, 1247,  536,  198,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3378,   98,  776,    1,   37, 2834,  105,  391,   12,    1,  105,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  686, 1653,   98,  889,  529,  533,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  511,  275,    1, 2628, 2295,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2136, 2386,   10,   45,    1, 1513,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  326, 1243,  327,   50,   12,  172,  533,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3250,    1,   37,  619,  449,   67, 1463,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  151, 1718, 2261,    1, 1608,    1, 1778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3231, 1348,  889,  442,   46,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  125,    4,    1,  860,  197,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2650,   43,   32,  166,  104,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3254, 2644,  449,   32,  804, 2824,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  978, 3138, 2872,  405,   12,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  585, 2797,    9,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1645, 1885,    1,  108,   98,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1928,   45, 3347,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  796,  103,  317,   32, 1759,  309,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3092, 1990, 3293,   37,   52,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  386,  952,  131,  388,   32, 1251,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  829,    1,  199,  421,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3261,  744,   28,  927, 1159,    1,  375,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2192, 3180,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  716,  354,   98,  525,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,  213,   37, 2089, 1064,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  424,  671,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2597,  719,    1,  388,    1,  163,    1,   12,    1,  391,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   58,  737,  156,  388,  763, 1427,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3042,  161, 2351,   28,  736,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  191, 2825,    1,    1,  730, 2614, 2222,  877,  105,  183,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800,    1,    1,   12,  533,  193,  255,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2934,   37, 1292,   32, 3010,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1404,  476, 1386,   37,    1,    1, 1580,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   61, 1718, 2595,  105,    1,  444, 3018,    1, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,   12, 1194,  142,    9, 1428,    1, 1464,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1086, 1844,   45,  197,  418,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1377,   43,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  519,    1,  634,   32,  730, 2060,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183, 2258,  205,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  430,  474,  650,  614, 2249,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885, 1641,  384,  166,  397,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  691,   12,  876,  612, 1396,  861,   32,  863,  142,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1312, 1407, 1538, 1683,   32,  531,  447,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,  218,  714, 1961,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  575,  529,  658,  996,   93,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   30,    1, 1924,  590,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3330,  162, 1913, 1918,  187, 3260,  726,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777, 2264,    1,  191,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1449,  613, 1564,  142,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  437, 1082,  876,  612, 2532,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3267, 1249,    1,   37, 2555, 1742, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965, 2982, 1000,  365,  459,   45,  238,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2523,    1,   85, 3202,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 2153,  429,   46,   98,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1444, 1445,    1,    1,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   28,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3343,    1,  104, 2548, 2572,   32, 3279,   32,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   46,  759, 2814,   45,  484, 1861,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1861,   12, 1207,  297,  487, 3102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3278,    1,  729,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1765, 3044,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1, 2897,    9, 1194,   74,  202,   66,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3332,   12, 2005, 1245,   37, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1736, 2636,  251,    1, 1935,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3369, 1625,    9,    1, 2471,  220,  316,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1429, 2109, 2567,    1, 2592,  267,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1538, 1140,   79, 1034, 1183,  477, 1651, 2104,   37, 1173, 1159,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  952, 1358,  176, 2197,   46,  220,  342, 1164,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  753,   45, 1983, 1647, 2554,  741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  286,  549,  703,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3340, 1645, 3073, 1623,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3155,  685,   28, 2375,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3112,  479,    1,  755, 1776,  956,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 1923,  787,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,  256,  388,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  267, 1221,   12,  590, 1534,   12,    1, 1447, 2399,   37,\n",
      "          877, 2673, 2108,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  183,    1, 2257,   28,  166, 2614,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3256,  632, 2598,  845,    9,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2177,    1,  972,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3372, 2591,  444, 3359, 2509,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  297,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1674,    1,    1,    1,  154,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3198, 1765,  449, 2965,   32,  395,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1005, 3298,  140,  455, 3222,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3045,   77,   28, 3038, 1450,   32, 1850,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2245,  370,  371, 1550,  898, 1832,   28,  220,    1,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   32, 1787,   37, 2278,    1,  326, 2384,  999, 2168,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3184, 1760,   12,    1, 2170, 1384,  519, 2237,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,    1,  437,   37, 2714,  647, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  558,   76,   37,  559,   79,    1, 1456,    1,  105,    1,  512,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1879,    1, 3276,  606, 1691,    1,  365, 2753,   37,  875,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 1009,    1,  413, 1708,  528, 2429,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,   25,  417,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1187,  193, 2047,  405,    1, 2022,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  245,  384,    1, 2890,   37, 2592,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1004,    1,  949,   45,    1, 2206, 3351,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2503, 2779,   37,  335,    1, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190,    1, 2230,    9,  291,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453, 1240,  606,   37,    1,  156,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3352, 2856, 3361, 2567,    9,  104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  610,  297, 2950,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1717,    1,   61,  166, 1292,  176,  453,  248,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2885,  193, 2098,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  924,    1,    1,  796,   10, 1708,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1607,  231, 1106,   12,    1,  897,   28,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1244,    1,  987,    9,    1,   59,  159,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,   37,  631,    1,   32,   22, 1697,  293,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,  794,  861, 1108,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2774, 1450, 2856, 3361,  517,    1, 2226,    1,   12, 2347,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2387, 2118,  444,  793,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  449,   67, 1705,  919,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2090,    1,  121,    1, 2268,    1,   12,   56,  569,    1, 2090,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  200,  659,   45, 1107,  525,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  700,  952,    1, 2157,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018, 1082,  736,   98,    1, 1815,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187,  734, 1757,  431,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,  395, 2396,   37, 2192, 2592,    1,   98, 2108, 1281,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,  794,  365,  517,  618,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  593,   45,    1,   32,  104,  361,   85,  680,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  200,  453,  645, 2452,    1,  257,  548,  205,  714, 2928,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  459,  331,  132,  220, 3244,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  640,  119,  340,  951,    1,   94,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 2976,  339, 1691, 2997, 2762,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3092, 1070,    9, 3066,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2031,   37, 1539,  822,    8,  777,  778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  162,   91,   12,  432,   37,  151,  647,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  612, 2577,  356, 1259,   37, 1155,  336,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 2501,    1,  400,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  324,    1,  326,   51, 1371, 2704,  327,   50,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2631,  625, 1229,   39, 2119,  220, 1987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  403, 1447,  267, 1796,  909, 1710,   52,    1,   45,  443,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2498, 1002,    1,    1,  954,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1773, 2510,  231, 1613,  361, 1087,  167,    1,  105, 1265,  357,\n",
      "         1056,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  225, 1279,   70,   71,   98,   14,   15, 1128,  801,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  323, 1057,  297, 3351,    1,   12,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3149,    1,    1, 1822,   52,    1, 2793,  632,    1, 2231,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1970,   12,  736,  967,  365,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1993,    1,   32,  633,    1,  963,    1,   61, 1194,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  671,  490,  187,   60,  338, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1987,    1, 3318,    1,    9,  356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  632, 2122,    1, 2095,  548,  851, 2421,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   28,  384,  241,  687,  951,   94,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1698, 1234, 3049,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  580, 1610,  422,  149,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  103, 2246,  403, 2926, 3272,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,    1, 2859,   12,    1, 2690,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2772, 2566,    1, 1922, 2446,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2967,    1,   37, 1668,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2838, 2562,  166,  501, 1125,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2957, 1614,    1, 2334,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,  302,  891,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,  667, 3102,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  935, 1458,    1,   22, 1787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  246,    1,   32,    1, 1969, 2891,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  153,  103, 2824,  712,    1,   98,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  822, 1879,   32,    1,  400,  103,  331,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  742,  641,   48,   32,  386,   37,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1488,  857,  763, 1745, 3297, 1784, 1159,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  176, 2413,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 1034,   12, 1586,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   28, 2078, 1499,  669,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,   37, 1403, 1107,    1, 1089,   37, 2510, 1090, 2402,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  852,   37,    1, 1778, 2580, 2851,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   37,    5,    1,  532,   37,  470,  104,    1,  342, 1057,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  531, 2705,  798,   37,   52,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1352,  163,    1,   12,    1, 1675,   15,   28,  118,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  620,  661,    1,   37,  764,    1, 1731,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106, 1345,    1,    1,    1, 2693,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  325, 1994, 2650,  669,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,   21,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 1267,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1024, 1229,   37,   52,   32,   46,    9,  985, 1671,   13,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  726,    1, 3207,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  803, 2032,  729,    1, 2738, 2032,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2994, 1488,  763,  116, 2542,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1029,   12, 1459,  267,   10,    1,   45, 2282,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1327,   12,  501,    1,   36,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,  622,    1, 1231,  220, 2282,  722,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1981,  818,  834, 1905,  410,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 2306,   32, 1123,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,   61,  697,    9,    1, 1044, 1045,   32,  959,  105,  356,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978,  769,  720,    1,   69, 1426,  105,  106,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3249,  565,  472,  220,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12,  223,    1,  187,    1, 1921,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2826, 2962,  163,    1,   12,    1,    1,  331,    1, 2939,  140,\n",
      "          671,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  494, 1599,  142,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,    1,  647, 2962,   28,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,  147, 1114, 1118,    1,  400, 2322,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1431, 1310,    1,   98,    9, 2293,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,    1,  975,  958,    1,   45,    1,  142,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3229,    1,    1, 1401, 2226,    1,  810, 2476,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  207, 2323, 2952,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  882, 1151,  475,   37,  335,  297,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26, 1039,  226, 2232,  288,    9,  949,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1645, 1113,  418,   32,  367,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  967,  590, 2177, 1534,   45,  863, 1491, 1260,  722,  420,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,    1,   38,   98, 2570,  787,   12, 2939,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 2673, 3146,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1147, 1407, 1190, 1366,  190,  193, 2192,   32,   37, 3345, 1004,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2888,  580,  228,  537,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  328, 3325, 1177,   37, 1918,  548, 1939,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  656,    1, 2547,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3207,  321,   77,  671,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,    1, 1232,  531,  770,  167,   52,    1, 3102,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  705,    1, 1417,    1,    1,    1, 2629, 1313, 1123,  469,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  353,  800,   15,  570,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  686, 1128, 2287,    1,  829, 1228,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 3381,   12,  437, 1484,    9,  949,   45, 2135, 1213,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  557,  540,    1,    1,  606,    1,    1,  163,    1,  903,    1,\n",
      "          267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087, 2614,  132, 1854,   37, 3234,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 2559,    1,  911,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 1107,   37, 1753,  111, 2633,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 1948,   61,   98,    9, 1990, 2711,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,   12, 2812,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  681, 2394,  501,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  774,    1,  193,  105, 2946,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2618, 1268, 2701,  593, 1990,  220,  726,  297,  602,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777,  686,  191,  861,  328, 2215,  126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 2433, 1030,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,   37, 1463, 2686,    1,  220, 1965, 2981, 1821,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  654,  211,  949,   45, 1975,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2244,   37,  138, 1780,  361, 2199,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  963,   60,   61,  686,  191,  340,   31,   67,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 1701, 2192, 1322,   37,  105, 2294,    9, 1935,   12,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3203, 1401,    1,  628,  191,  786,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810,   78,  317,  466,  174,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3282, 3169,  361, 3168,   16, 1515, 3136,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  573,  639,   51,  168,    1,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  121, 1025,    1, 1354,   45,   49,    5,  302,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2944, 2107,    1,    1,    1, 1509,   45,  166, 1694,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2453,    1,    1,  572,  390, 2316,  915,  356,   12,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387,  715,  954, 1239,  191,    1,    1,  419,   32,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1474,  703,    1,  549,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1523,    1,  297,  365, 2138,  261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,  579,   12, 1514,  220, 1412, 1107,  124,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2640, 1830,    9, 1539,   37, 1821, 2190,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  393, 1293,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   60, 1276,   37,  365,  340,  444,   94,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  709,  342,  442,  475,    1,  140, 1322,    9,  397,  389,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  224,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,  547,  454, 1832,    1,  361, 2885,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   74,  469,    9,    1, 2247,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 3030, 1707,    1,   45,    1,   32, 3343,  863,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1009,   37,  907,  220,  647,  494,  906,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  221,  167,    1, 1410,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790, 1579,    1, 2198,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 967,  38,  32,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 328,   1, 353, 417, 737, 197,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   22,  942, 2323, 2900,    1, 1118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,   60,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  759,    1, 2069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  105, 1918,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  755,    1,   98,  861,    8,  220,  365, 1228, 2928,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  398,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  729,  998,  247, 1737,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1149,    1,    9,    1, 1031,  176,  971,   91,    1,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  716,  449,  197,  187, 1300,  669,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  154, 2192,  562,   37,  221,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  361,    1,    1, 2472,  614,   37, 1796, 1920,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2563,  420,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1236,  111, 1688,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2498,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1043, 1086,   28,  187,  395,   29,  919, 1448,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  267, 1763,    1,  166, 1354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3285,    1, 3323, 1173,    9, 2315, 1285,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   45, 2975,   12,    1,    1, 2692,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3028,  105,    1,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 2137,   27,  104, 3150,   32, 3383,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1114,  640,   98,  166, 2041,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089,   30,  547, 1407,  863, 1149, 3340,   32,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  219, 1726,  907,    9, 2095,   46,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   69,   37,  698,  605,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1364, 1365, 1532, 1018,    1, 2927, 1159,    1, 3116, 3217,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1957,    1,  153,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1973,  957,   37,  927, 1791,    1,  182,    5,  126,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2605, 2714,    1,    1,    9, 2707,   46,   37, 1413,  342,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2716, 2465,    1, 2212,  861,  736,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1408,  383,  444,   94,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1365,   51, 1418,   59,    1,  149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   12,    1, 2385,  612, 2623, 2624,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  447,   30,   79,    1,  826,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947, 2360,  420,   45,  854, 2690, 2607,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  192,   12,  805,   98,  109,    1,  897,    1,  494,  774,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2551,  439,  119, 1090, 2041, 1044, 1045,  951,    1, 2321,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,  163,    1,   12,    1,   37, 1195,  284,    1, 1196,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  100,  920,   98,  166,  673,    1, 1247, 1373,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  157,    9,  365, 1635,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  286,  347,   71,   37,  470,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  582,    1,  843,    1,   37,    1, 2853,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081, 3109,  163,    1,   12,    1, 2003, 1213,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1278,    6,   51,  123, 1327,   12,    1, 1190,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,    1,    1,  105,  119,  118,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1187, 2851, 1389,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1685,  864,    1,  220,   91,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,  660,    1, 2581,    1,    1,  361, 2226,    1, 1456,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2734, 2372,    1,   37, 2502,  384, 1033,   37,   91,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3310, 1921,  176,  776,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,  492,  947, 2347,   32, 1994, 2095, 2625,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3227,    1, 1444,  619, 3247,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2236,    1,  187,  204,    1, 1888,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  453,    1,  582,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359, 2188, 1665,   37, 3358,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,  794, 2759, 2403,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,    1, 1820,   98,  531,  806,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2469, 2681,  938,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  744, 3055,  674,   98,  660,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  571,    9, 1668,    1,    1,   98, 1090, 2315,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228,   25,  220,    1,  571,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,   98,  166, 1314,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,  967,    1,    1,    1,  590, 1479,    1, 1976,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  111,    1,   37,  151,  903,    1, 1256,    1,  700, 2928,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  959,  288,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428, 2104,  200,    1,  652, 2362,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  302, 1710,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  877,    1,    1, 2354,  754,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1362,  213,   37,  151,    1, 2827,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,   37,    1,  236,  237,  140,   32,  385,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  702,   12, 1178,   45, 2919,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  484,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  592,  845,   69,  636,  105, 1665,    9,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  288,   37,   26,  417,   98, 2204,  156,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1001,  977, 1556,   32,  645, 1034,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,   82,  170, 1560,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3349, 2292,   61,   66,  187,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   12,  170,  315,  220, 1327,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  251,   37,  151,  989,    1,    9,    1,  372,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  636,    1,    1,    9,   64, 1080,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3033, 2905,    9, 2069, 1821, 1575,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  650,    6, 2471,  220, 3356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  197,  739,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  968,  967,    1, 1781,  453,  449, 2328, 1159, 1821,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  936, 2174,   32,    1,  769,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  677,   69,  102,  529,  715,   31,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1123,  361,  474, 2000,    1, 1563,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  477, 1148,    1,    1, 1223,  112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9, 1658, 1184,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  135,   37,  166, 1746,   45, 2573,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835, 1313,  297, 1094, 1887,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,   34,    1, 2575,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,  214,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1662,   50,  696,  848,  317,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314,   37, 1911, 2281,  134,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3191, 2827,   37, 2250,    1, 2335, 1178,    1, 2503,  187, 3312,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,   37,   33,    1,    1,    9, 2323,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,   24,   37,   92, 1718,  861,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2292,    1, 2179,    1, 1324, 3349,   12, 1625,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2206, 2207, 3183,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2992,    1, 1159,  166, 1264,  593,   45,  613,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1676,    1,   45,  346,  193,   32, 1820,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3065, 1492, 2554, 1186,   12, 1625,    9, 1675,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1100, 1625,    1,    1,  845,   93,  616,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,    1, 1848, 2243,  192, 1499, 1294,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   53,   37, 1796, 2943,  669,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186, 3340, 1527, 2664,  972, 1530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1009,   45, 3140, 1454,  247, 1833,   12,  808,   32, 1430,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1420,    1, 1579,    1,  372,    1,    1,  368,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1926, 1927,   61,   81,  716,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  156,   28,   98, 1228,   15,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,    1,  361,    1, 2704,  506,    1, 1204, 2198,  166,  116,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1187, 2017,  220,    1, 2418,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1252, 2807,  688,  501,  827, 3227,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965,    1, 2982,    1, 1159,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  402,    9, 3187,  444, 3328,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3189,   12, 2804,  338,  337,   98,  825, 2579,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3121,    1, 1064,   37, 3275, 2294, 1411,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2591,    9,  650,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1474,    1,  588,  966,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 3160,  928,   32,    1,  298,   32,  531,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  957,  108, 2476,   45,  531, 1697,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  225,   70,   71,  294, 1456,    1,  326, 1473,   32,   91,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468, 2489,   85,    1, 2226,    1,    1, 1665,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1307,   37,  693,  618,  220, 1691,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1928,   45, 3025,    1,    1,   98,  777,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2058,   32,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,    1, 1759,  309,    1,    1,  439,  844,  883,  630,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1210,  105, 1892,  424, 1104,    1,  334, 2233,   52,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  699,  242,  187,  197,  509,  470,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,  388, 1211,    1,   98,    1,    1,  187,  477, 1258,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821,   95,    1,    1,  202, 2133,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  170, 2766,    1,  485,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   60,  681,   98,   94, 1010,  342,  937,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  267,  535, 1863,  218,  388,    1,  763,    1,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187, 1628,  187,  204,  476,   37,   52,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 2334,  396,   37,   52, 1254,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314,   12,  365,  475, 1564,    1,   50,  159,   71,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,   12,  186,  884,  163,    1,   12,    1,   68,  297,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190,  829, 1564,  453, 2995, 1488,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1107, 2751,  588,   37,    1,  552,  552,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  566, 2318,    1,  813,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  755, 1809,  105,    1, 2995,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,    1, 2334,    1,  105,  119,    1,   74,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3046,  823,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 3102,   12, 2495,   37, 1198,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  365,  754,   15,    1,    1,  118,   32,  871,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 2170,  267,    1,    1, 3058,  476,   37,    1, 3342,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3304,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,  481,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1401, 2823, 2107,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  659, 1626,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  651, 1031,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343,  437,  267, 1407, 3365, 2440,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  162, 1328,  220,  163,    1,   12,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  338,   37, 1700, 1034,  340,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1043,   28,  297,  118,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2733,  321,  612, 2412, 2638,    1,    1,  147, 1373,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  462,  640, 1799,    1,   98,   49,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2163,   66,  816,  566,   98,    1,    1,  982,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  144,  145,    1,    6,  157,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  488, 3140,  220, 1378,    1,  477,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  709,    1,    1,    1,    1,  798,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  533, 2200, 1783,  156,  304,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2582,    1,    1,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  680, 2206, 2989,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1887,   45, 3375,  792,  105,  638,    1, 2502,  792, 3358,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,    1,    1,  250,   37, 1865, 2516,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  542,  151,  581,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3237, 2137,  597,    1, 3238,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  244,    9,  963,  773,   66,  677,  424,  356,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2493,  105, 1568,   38,    9,  772,  293,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1053,   12,  365,  446, 2744,  129,   74,  186, 1819,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 1988,   45, 1427, 2461,  187, 1994,    1, 1953, 2055,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1700, 2844,   32, 2018, 2596, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1420,    1,  794,  105,    1,   54,  332,  752,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2442, 1218,  459,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  390, 1348,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  306,    1, 1564,  968,  105,  366,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  361, 2275,    1,  584,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3238,  140,  590,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 2023,  365, 3044,  437,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  982,    1, 2957,    1, 1307,    1, 1181,    1, 1520,    1,  848,\n",
      "         1303,  618,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  903,    1,  507,  475,  548,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  773,  317,  800,   15,   32, 1169,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 2576,    1,   74,  220, 2808,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2912,    1,  105, 1298, 2463,  444, 3152,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2245,    1,    1,   37,  316,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1363,    1,  365,   40,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  575,    1,  600, 1338,   45,  495,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  531,    1,  322,   79, 1812,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 1190, 2386,  864,   45,    1,    1,   37,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3282, 3198,  801,   37,  395,   26, 3179,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2308,  693,   37,    1,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2729,    1, 2909, 1910,  176,  177, 1530,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123,  892,  428,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3226, 2811,  220, 1531,    1,   32, 3141,    1,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  186, 1258,  528,  863,   74,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  856,  487, 1994, 2834,  625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387, 3065, 1021,   92,  220,    1,   15,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  365,    1,  512,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066,    1,    9,    1,    1,  311, 2936,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  215,  515,   26, 1039,  166,  562, 3031,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3270,  140,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,  100,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579, 1090,    1,  844,  321,  612,  619,   79,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2018,   12,  446,  267, 2024,  220,  854,    1,   98, 1815,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,   12,    1, 3272,    1,   32, 1081,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1016,   45,    1,    1,   32,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,  420,  720,   32,  449, 1023,  197,  187,  568, 1556,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,  995,  242,  197,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2323,    1, 1095,   12, 2464,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2751,    1, 2017,  384,    1,  787,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  795,    1,    1,    1, 1618,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2839,  894, 1418, 2924,  384,  531,  191,  439,   45, 1411,  356,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2161, 2962,   28,    1,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2762,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  474,  759, 1845,  630,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777,    1,  388, 1136, 1159,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  176,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 3334,  726,    1,    1, 2498, 1917,  463, 2170,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2325, 1324,  736,   98, 1157, 1512,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   10, 1454,    1,  444, 2275,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  338,  419,   98,  570,  125,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1426,  132,   37,  151, 3287,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3264, 1458,    1,  175,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,  190,  125,    1,  191,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2629,  774,    1,  625,    1,   98,  649, 1223,  548, 3038,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3250,  688, 1497,   32, 1600,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3282,  104,   26, 2965, 3204,   32,    1,  119, 1665,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3206,    1, 1247, 2317,    9,  786, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2685,    1, 3231,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,   40, 2264,    1,  105,  365,  454,   37,  322,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1721, 1807,  720,   32,    1,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1680, 1208,   98, 1101, 1102,  931,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2900,   45,  985, 2130,   66, 1690,  481,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   47, 2507,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  727,   37,  151,    1,  728,    9,  131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1360,  612,    1,  163,    1,   12,    1, 1437,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2297,    1, 1863,   45,  166,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  565,    1,    1,   12,    1, 2181,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  297,  583,   98,  449,   74,   45, 1853,  477,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  632, 2875, 1164, 1478,    1,   32, 1330,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,   47,  159,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3315,  162,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3108,  361, 2615, 2260,  548,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3253, 1654,    1,   26, 2069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1774,   39,  241, 1778, 2580, 1626,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  792,    1,   45,    1,  792, 2867,  454,   39,   45,  539,\n",
      "         3343, 1512,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  743,   12, 1867,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,   31,  193,    1,   79,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2096, 1360,  612,  583, 1020,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,   37,  125,    4,    1,  387,    1,  987,   44,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1095,    1,    1,   37,    1, 1077,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3283, 3272, 2242,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101, 2924, 2856, 3344, 2708,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1230,    1,  744,  619,  105, 2322,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  422,    1,  837, 1369,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1425,  166, 3141,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,  456,  381,  457,  458,  285,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1230,  384, 1158,  113, 2945,  361, 1107,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,    6,  453, 1126,  636, 2320,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  413, 1396, 1158,   12, 2102,   17,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  245,  187,   69, 1784,  608,  813,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  397, 1458,    1,    1,  261,  104,  111,  772, 1281,   61, 2189,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,   15,  710,    1,   37, 1752,  136,   82,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2650, 1879,  726,  433,  432,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2499, 2658,    1,  928,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  154,  565,  972,   37,  741,  590,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   16, 1876,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 2414,   32, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1854,    1,  105, 1089, 1090,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  581, 1385,   45, 3118, 2024,   46,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1009,   12, 2789, 1401,   32,  391,  863,    1,  428,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1019, 2214, 2527, 2663, 1976,   32,  395,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1039, 3234,  690,  693,  384,  607,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,  501,  176,  424,  264,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,   32,  103,    1,   45,  365, 1537, 3192,   24, 1294,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,   71,   98,  996, 1986,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  964,  792,    1,  792, 1232, 3144, 1713,  342,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1,   37, 2505,   32,    1,  714,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2787,   12,  865,    1, 1497, 3130,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,    1,    1,   98,  644, 1527,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 1796,  909, 1710,    1,   37,  443,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1398,  612, 1584,   85, 2681,    1,  592,  475,  108,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1412, 1107,  105, 1183,  454,  384,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1557,  140,    1,   12, 3372,  890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 2446,  840,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1070,   37,    1,  573, 1197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  647,   12,  475, 1213, 1287,  247, 2924,  951,    1,  148, 1379,\n",
      "           12,  112,  499,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  743,   12,  862,  992,   85, 2007,   37,  505,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3200, 2761,    1, 2236, 2317,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1592,  973,    9,  388, 1465,  861, 1896,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2274,  357,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 1421,   79,  220,  105,    1, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1789,  794,  885,  142,   37, 1413, 1428,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1458,    1,  214,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  932,    1,    1,  150,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1088, 1920,    1,  792,    1, 2736,  792, 1684,  220,  365,  593,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2569, 3357,  650, 1530,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  691, 1312,    1, 2335,    1, 1985, 1010,    1,  157,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3355,   37, 1220,  388,  384, 3369,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  941, 2104,  267,  154,    1,  987,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   32,  455,    1,  471,   61,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1149,   45,  602,   12,    1,  429, 1479, 2357,  115,   45,    1,\n",
      "           46,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  656,    1, 2547,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  321,  612,    1, 3152,    1,  202, 3322,  429, 2588,   79,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,  361,    1, 2779,    1,  191,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,   45,  922, 1756,    1,  267,  638,  786,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3089,    1,   28,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2615,  186,   37, 2712,  730, 2614,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885, 3062,    1,  628,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  827,  726, 3252,   45,  166,  356, 2577,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  251,    1,  333,   37, 2018,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3382, 3402,    1, 1564,  870,  147,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  369,    1,    1,   45,    1, 1064,   37, 2341,  221,   37,\n",
      "          104,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1631, 3078,   32, 1971,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  105, 1298,  183, 1178,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  273, 1625,   37,  877,    1,   39,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1971,    1,    1,  444, 3250,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  794, 1107, 2610,  112,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585, 2414,    1,   32, 3407, 3392,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1480, 1975,    1,   37,  166, 1746,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3209,  186,    1,  726, 1131, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147,    1, 1702,  166,  104,   81,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1456,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  596, 1273, 1732,   15,   28,   32,  581,  401,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273,    1,   15, 1568,    1, 2053,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  726,  104,    1, 2777, 2577,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 1616,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  861,    1, 1964,    1,    1,    1,  187,    7,    8,  187,  863,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1321,  247, 2225,    9,  103,    1,  389,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,  361,  104,    1,  734,    1,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 1158,    1, 1128,  631,  327, 1889,    1, 1279, 3011,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  517, 1220,    9,    1,  592,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  113,  530,    1,  566,  430, 1302,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  301,    1, 1167,    1,    1,   12,  593,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,   37,    1,   32,  215,  361,  447,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,  267,    1,    1,  104,  182,  141,   48,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  744,  365, 2306,    9, 1539,   37, 1821, 2190,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  310, 2153, 1648,   37,    1,  903,    1, 1447,   37, 1195,   46,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2737,  580,  966, 1667,   12, 2804,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  166, 2822, 2337,  460,   12,  729, 1120,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1625,  453, 2780,  190, 2884,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1970,   12, 2764, 3210,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2055,  365, 1069,  260,   37,   92,  244,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,   37, 2000, 2028,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12, 1652,  399,  991,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    7,  365, 2741, 1675,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3200,    1,   32,  354,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  296, 1321, 1876,    9,  829,   32,  342,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,   45, 2258,   37,   18,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,  313,   37,    1, 1182,    1,  911,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,  967, 1846,   98, 3153,   12,  175,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  845,    1, 1317,  653,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 3131,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1535,   37, 1787,    1,   45,  340,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  744,   28, 2799, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,   93, 1347,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1118,  105,   12,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2275, 2471,  583,  284,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1310, 1922,   38,  176,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  275,   12,  366, 2161,  619,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,   15,  701, 1408,   25,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  645,    1, 1718,    1,    1, 1159,  522,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,    1, 1817,    1,    1,    9,  411, 2591,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  228, 3386, 1940,  514,   45,    1,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3079, 1508,  103,  712,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 2072,  105,  179,  180,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1339, 1299,  700,    1,    1,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2108,   15, 1281,  176,  166, 2363,   45,  395,  342,   46,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3034, 1345, 2819,  220,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  878, 1713,  149,  444, 1117, 2208, 1873,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  704,  551,  704,  726,  460,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,   12, 1210,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,   12,  551,  552,    1, 1279, 2405,    9,  119,    1,\n",
      "          418,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   14,   15,    1,   39,  504,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3172, 1090, 1829, 1902,    1,  951,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2009,   26,   98, 3238,    1,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  868,   85,    1,  625,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 1006,  214,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1243,  469,   37,   52,  340, 1251,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  449,  219, 2981,   32, 2918,   12, 2818,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1863, 2317,   98,  514, 1727,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2304, 1259,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,  526,   32,  857,  442,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094, 3109, 1428, 1612,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  668,  293,   37, 1753,  912,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1284,    1,  220,  258, 1013, 1522,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2807,  631, 3227,  548,  547,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1107,  293,    1,  191,  147,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  331,  551,   12,  794,  332,  752,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  954, 1754,    1,    4,   32, 1352,    1,  104,  716,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32, 1345,   32,  903,    1, 1147, 1223,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3228,    1,    1,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1423,  794, 2678,   98,  116, 2574,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  964,    1, 1820,   98,  531,  890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2855,    1,  361,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2733, 1914,  884,  985,  384,  104, 2730,  695,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1492,    1,  166,  460,  293,   12,  704,  551,  705, 1714,    1,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3181,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2807,    1,   39, 1056,  547, 2119,    1,    1, 1985,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,   28,    1,  155, 1470,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  811, 2745,  447, 1809, 1354,   45,    1,   32,  395,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1778,  593,  162, 2367, 2695, 2160,   28, 1140,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967, 1628,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  256,  365, 1928, 2759,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,  384,  687,  548,   65,    1,   29,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3053, 2477,  944,  928,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1815,   46,  439,  220, 1625,   45,  388,    1, 1896,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  137,  720,    1, 1469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  790,  195, 1196,  724,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,    1, 1048,   45,  119,  340,  951,   94,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1774,    1,   50,  582,  939, 1644, 2297,    1,  582,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   99,   94,   93,    1,    1,  113,  347,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  444, 1658, 1678,    1, 3122, 1592,  361,    1,   32,  424,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3215, 2562,    1, 2714,  176,  449,  311, 2936,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9, 2176,    1, 1158,  251, 1442, 2452,  517,    1,    1, 3011,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  505, 2727,  686,  191,    1,  229,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715,  947,    1,  722,   37, 2856, 1147, 2038,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  812, 2764, 3394, 2162,    1,  202,  476,  388,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1479, 1895,  567,  914,  570,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3330,   61,  729,    1,  361,    1,  220,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,  267,  104,  321,  612, 2884,  864, 2439,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1691, 1384, 2465,    1,   32,    1, 1120,  474,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2650, 1765,    1,   45,  116,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  342,  476,   37,  877,  116, 2440,    9, 1763,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 2243,  593,   12,  553,    1, 1616,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1363,    1,  244, 1269,    1,  158,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2476,  664, 1114,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  166,  624,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708,  446,  488,   37,  319,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  883,  406, 1353,   32, 1657,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  387,  453,    1,   50,    1,  218,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1645,    1,  557,  540, 1009,   12,  754,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 2385,  612, 1769,   37,    1,  413,    1, 1213,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  357, 1745,    9,    1, 3009,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2453,   32,  863,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1488,    1, 1034,    1,  429,    1,  845, 1625,    9,  914,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1688,   37,  288,   28,    1,   45,    1,    1,  150,  669,  112,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  595,   32, 1220, 2900, 1395,   15,  701,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1707,  219, 1004,  297, 2673, 2426,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  604,   50,   61,  680,  422,  549,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1084,  931,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  813,    1,   45, 1919,  650,  115,   45,  863,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,    1,  957,  140,  674,   45, 2487,    1,   45,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1465, 1028,   30, 2700,  167,    1,  166, 2955,   45,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   37, 1539, 2979, 2869,   32, 1657,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32,  336, 2137,  187, 3374,    1, 2299,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,   71,  530, 1146,  106,  115,   45,  107, 1953,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  232, 3167,   37,  221, 3251,   37,  316,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  963, 2949,  288,    9, 2440,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  432,    9,  365, 3283,   32,  316,  640,  105,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,  446, 2520,    1, 1521,    9,  601, 2113,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  557,  540,  622, 1202, 1260,  597, 2774,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213, 1542,   37, 2394,    1, 1514,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  232,  387,  590,  903,    1, 1447,   46,\n",
      "           63,  163,    1,   12,    1,  741,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  429,  258,  890,    1,   76,   37, 1761, 1565,   45,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,  884,  118,   45,  647,  159,  202, 1090,  193,  297,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  668,    1, 1510,  756,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  219,  437,  952, 1262,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3279,  271,   39,   32, 1430, 2649, 2791,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  657, 1958,    1, 2992, 1151,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2708,  650,    1, 3344, 2139,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 105, 590, 741,  98,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 503,   1, 220,   1,  98,   1,   1,   1, 195,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 545,  98, 166, 813,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 104, 586,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1973,  167,    1,  284,  706,  220,  726,  297,  166,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  202,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1831,  992,   85,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358, 2270,  247,  249,   12,    1, 1159,  166,  593, 1381,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   29, 1499,    1, 2043, 2962,    1,  812,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708,  344, 3403, 2414, 3095,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  311,  804,   39,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  581, 1777,   32, 1551,    9,  658, 1766, 1767, 2146,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1147, 2673, 1491,    1,  606,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 3370,  361, 1926, 1927,    1,   37, 1046,  104,  622, 1786,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  780,   37, 1539,  517, 1273, 1074,   32,  478,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1926, 1927,    1, 1877,  856, 3105,   37, 1734,  700,    1, 1928,\n",
      "          267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3211,  631,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,  421,  288,   32,  247, 1262,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  427, 1740,    9, 3303,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  603,  176,  455,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  138,    1,   59,  104,    9,  547,  104,    1,\n",
      "         2104,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3264,  389,   61, 2440,    9,  920,    1,  475,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1384,  777,  778,    1,    4, 1866, 2311,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2076, 1151,  983,   37, 1937,  816,   93,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2888,  640,  878, 1688, 1465,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3177,    1, 1813, 2448,  386,  361, 3328,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  386,    1,  325,   59, 1219,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 1070, 2018,    9, 2924,  511,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  872, 2776, 2244,   37, 1155,  105, 1488, 2707,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2170,    1, 2716,  615,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1481, 1349,   37,  221,   37,  853,  538,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  224, 2549, 1353,   98, 1331, 1017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  268,    1,  857, 1469,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1573,  166, 2741, 1096, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  338,   81,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2490,  267, 2335,    1,    1,  191,    1,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,  404, 1246,   98, 1602,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,  972,   37, 1083,  568,    1,  191,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  646,   93,  972, 2647,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1380, 2080, 1159,  166,  466, 1465,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1492,    1,  389, 2582,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   28,  220,  726,  297,  691,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,   12,  800,    1,  731,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1869, 1904, 1996, 1698,  914,   45,  522,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  433,   45,    1, 2424,  365,  301,    5,  302,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  267,  453,    1, 2334,   61,  590,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1652,  908,  152,  829,  399,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,    1,  180,    1,  627,   45,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3109,  548,    1, 2262,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 1185,  582, 2158,   45, 2121,    1, 1638,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 3194, 3195,  653, 1590,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,    1,    1,   32,  593, 1990, 2069,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  342,  221,   37,  397,  297, 1859,   37,  296,  361,\n",
      "           20,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,    1,   39,   45,  166,  984,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051,    1,  829,   32,  861, 1798,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,   21,  720,   32,  207,  156,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  479,    1,   37, 1183, 2113,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,   37,  151,    1,    9,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2448, 1179, 1761,  742,  155,   48,   37,    1,  419,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  858, 2055,   37,  413,    1,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2961,    1,    1,  488, 1821, 2190,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 2380,    1,  572,  207,  174,   28,  118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  560, 1274,   79,   32, 1275,    1, 1034,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,  708,  326, 1213,   37,   52,   82,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1481,   37,  856, 2095,  220, 2954,  279,   32, 1033,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,  519, 1248,  104,   37, 1876,   60,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1559,  297,  667, 1583, 2528,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  732,    1,    1,  187,   69,  102,   77,  677,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1442,   37,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,   12,   82,    1,  984,  238,   98,  493,    5,  423,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1273,    1,  564,    9, 3019,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,  193,   52,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  523,  190,  138,  331,   37,  875,  961,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2754,    1,   51,    1,  342,  768,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1159,  522,  176,    1, 3329,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1628,  550,  361,  227,   98, 2822, 1793,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  952, 2229,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1614,  803,    1, 2088,    1, 2382, 2320,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2422, 2428, 1427, 3098,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  952,    1,  909,   32,  149,  951,    1,  326,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3141, 1974,    1,    1,    9,  786, 1090,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1, 1707, 1789,   12, 2024,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  636,  640,  365,  845,   98,  531, 2292,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3160, 1231,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1035,   12, 1684, 1625,  335, 1328,  686,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,   52,   53,   98, 1102,  841,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1815,  336,   46,   37, 1348,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129,    1,    1,  228, 1333,  631,  176,    1, 3129,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   39,   37,    1, 1292, 3303,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2504,    1,    1,   98, 1202,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  303,    1,    1,   37,  686,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1419, 1499, 2043,    1, 1353,   98,    1, 2876,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1577,    1, 1783, 1508,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2486,  754,   15,  245,   32,   86,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    9,  786, 1034,  176,  177,    1,  273, 2853,   28,   37,  453,\n",
      "         2225,  166, 1153,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  315,   37,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  455, 2673,  700,  456, 2152,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32, 1157, 2702,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1187,  460,  810,  176,  166,  439,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,    1,  840, 2108,   37, 3369,  420,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 2523,   32, 2589,  220, 1687,    1,  631,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1380,   98,   16,  593,   12,    1, 1480, 2873,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   91, 1921,  220, 1477, 1990,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  250,   37,  877, 1805, 1021,  384, 2707,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1024,  140,    1,  364,  682,   32, 1684, 1948,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  318,   37,  582,    1,   36,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1185, 3375,    1,  548,  804,   45, 3358,    1,  753,    9,  804,\n",
      "           45,  625,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  455,   51,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2259,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 3394, 3060,  614,   98,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2596, 2803, 1700,    1,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2427,    1,   98, 2202,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,   12,  335,   98,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3322,  103,  153,   74,  548,    1,  939,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  245, 1146, 1703,   32,  105, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   69,  260, 1450, 2200,  636,   71, 2047,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2835,    1, 3140, 1937, 2271, 1898,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2834,    1,  415,  104,    1, 3101, 2537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 444,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 463, 464,   1,   1, 465,  22,   1, 191,   1, 234, 182, 235,   1,\n",
      "           1,   1, 234, 182, 235,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2315,    1,   15,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1055, 2495,    9, 1090,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1951,    1,  952,  163,    1,   12,    1, 1604, 2180,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3089, 2865,   79,  590,    1,  584,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2222,    1,  166, 1615, 1921,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676,    1,    1,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3363, 1401,   32, 3360,   12,  449, 2085,  806,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727, 1372,   37,  142,    9,  179,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2943,   61,  460,  199,   37,  335,  166,    1, 1456,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,  104, 1780,    1,   98,  310,    1, 1196,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  148, 1564, 2069,  693,    9,  647,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 2147, 1585,  193, 1634,   37,  890,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1479,  861, 2432,  788,    9,  148,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3207, 1408,  671,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   60, 1489,   29,    1, 1547,   85,  384, 2284,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1417,    1,  171,   12,    1, 1380, 2516, 1810,    1,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1546, 2771,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  358, 1949,  541,   32, 1411,  547,  257,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,    1,  356, 1691, 3088,  825,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  398, 1484, 1953,   32,  829, 1350,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  947,  271,   28,  219, 2086, 1551,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  331,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  506,  782,  460, 2664, 1161,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035,  707,   37,  717,    1, 1741,    1,  611, 1039,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2997, 2762,    1, 1778, 2580, 2851,  675,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  384,  105, 1121,  698,  424,  914,    1, 2110, 2783,  166,\n",
      "         3235,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   20,   51, 1413,  829,   32,  342, 1350,  856,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3198, 1177, 1159, 2197, 3329, 2069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,  267,  395, 2908,  297, 2949,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    7, 2171, 1675,   98,  844,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1683, 3365,   37, 2684,  754, 1371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  289,   98,    1,  187,  121,    1, 1839,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  219, 1984,  991, 1087,   12,  142,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 2213, 2814,    9,    1,   51,  361,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1092,  992, 1159, 1089, 2294,  856,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2327, 1090,  251,    1,  176, 2823, 2325,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2523,    1, 2876,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 1821, 2190,   98, 2818, 1323, 1352,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  361,    1,  693,  613,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1957, 2681,    1,  190,  698, 3141,  914,   98,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 3148,   44,   61,   10,  863,    1, 3369, 2404,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363, 1765, 3360,   12,  449,    1, 1009,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,  429,   79, 2720, 2796,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1, 2458,    1,    1, 1753,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,   12, 2877,  879, 2108,    9,  987,  469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1285,  242,  187,   69,  102,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 348, 353, 242, 737, 197,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 162, 105,   1,  45,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3238,   39,   45, 1090,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2996, 2558,   32,  282, 2367, 2695,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  384,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1932,  140, 2295, 1933,    1,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1809, 2225,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  231, 1773, 2510,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1625, 1167,  726,  190,    1,  105,  365, 1015,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   83,    1,    1,   98, 2959,   16,  600, 1143,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,  172,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   37,    1,  647, 1889,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  395, 2755,  295,  721, 1579, 1936,  297, 1056,  295,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  251, 1211,  111,   19,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2466,  952,  388,  199,    9,  622,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2679,    1, 2317,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1484, 2890,    1,    1, 2494, 1675,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  365,  506,   37,    1,    1,   45,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3221,    1, 2689, 1717,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 2170,  267,   37, 1468,  557,  540, 2024,   46,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2870,   32,    1,    1,  531, 1530,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  580,  341,    1,  384, 1793,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  479,  697,   37,  168,  166, 2025,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1426,  573,  895,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  676, 2835,    1,    1,   98, 2380,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3112,  997, 1096, 1232, 3180, 1980,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  579, 2958,  544,    1,    1,  877,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671,    1, 2525,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3354,  147, 1679,    1,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  967,    1,    9, 3227,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2827,  191,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,  952,   39,  596, 1787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2445,  315,    1,   49,  333,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579, 2406, 2885,  190,  972,   37,  774,   32,  247, 2653,   37,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  884,    1,    9,  632,   36, 3071,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1938, 2607,  382, 2206, 2989,  232,    1, 1427,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3139,    1,    9,  590,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98, 3270,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2523,    1,  449,    1, 1684,   45,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,  475,  387,  388,    1,   32, 1437,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,    1, 1380,    1,   32,  105, 1510,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683, 1086,  142,   37,   47, 1021,  112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1829, 1510, 2084,    4, 1253,  452,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2397,  267,  460,  967,    1,    1,   46,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  321,  829, 2856,  224,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  794,  224,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   49,  733,  493,   48,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,   37,   47,  824, 2261,   37,    1,  361,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  650,   90,  299, 1167,    1, 1360,  612,   52,   32,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  342, 2153,   37, 1421, 3341,  892,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  256,   40, 1228,   37, 2522,   41,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  878,  828,    1,    1,   45,   29, 2607,  176, 1688,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1435,  691,   12,    1,   37,    1,   28,  568,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3238,   37,    1,  220,   10,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066,  361, 3215, 2810,  166,  302,    9,  311,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   30,  459,   45,  275, 2054, 1424,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708, 2153,  588,   37, 2237, 3358,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  780,    1,  587,  211, 1259, 1757,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2354,  187, 2733, 2086,  776, 1268,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98, 1050,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  374,    1,  329,   28,  105,  784,    1,   12,  552,   79,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  420,  596, 1395,    1,   37, 2284,   32,  572,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 2227, 2886,    1,    1,   37, 1463, 1027,    9, 2512,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158,   82, 1564,    1,  452, 1857,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3226, 2811,  220, 1531,    1,   32, 3141,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  977,    1, 2012,    1,  506,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,  220,    1,   37, 2394,   32,    1, 2472,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,   34, 1785,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1993,   85,   98, 1931,  297,   65,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   79,    1, 1665,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437, 2770,  903,    1, 1447, 1585,  778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2918,  493,  167,  907, 3024,   12,  626, 1004,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  198,  365, 3087,  640,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2310, 2059,    1, 2310, 2059,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428,  854,    1, 1211,  442,  802,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   46,  288,    9,  395, 1211,  442,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1, 1013, 1522,    1,  775,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  275,   25,  242,  187,  657,  919,  218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481,   12,    1, 2126,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2565, 1936,    1, 2148,   32,    1,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967,  590, 2537,  220, 3269,  730, 2614,  729, 1210, 3237,\n",
      "           81,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2563, 1421,    1,    9, 2321, 1090,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2235,  398,  952,    1,  548, 1537,    1,  528,  147, 1250,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2679,    1, 2317,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1771,  398,  261, 1136,  841, 2208,  264,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158, 2102, 1398,  612, 1847,  460,   12, 1104,  199,  176,  810,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2899, 1359, 2483,  365,  912, 2285,  934,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  449, 1821,    1,  132,   98,  931,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  220, 1117,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2909,  686,  104,    1,  487, 1396,   32, 1855, 2458,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1841, 1670, 2618, 2162,  927,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1147,  437,  267,  460, 1683,  963, 3102, 2566,   12, 1841,  267,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380,   26,   37, 1903,  220,  854,   98, 1815,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 1655,  898,   32, 3369,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  590, 2354, 1638,    1,  220,  590,  261,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  625,    1, 1641,   37, 1994, 2095,  804,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035,    1,   37,  539, 1037, 1038,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  947,    1,  147,  361,    1,   12,    1, 2571,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870,  571,   37,  455,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1114,  879,  693,    9,  647,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3358,   12, 1983, 2078,   16,  590,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,    1,    1, 2567,    1, 1396, 3255,  593, 1990,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2391,  845,   69,  636,   85,    9,  105,  581,   74,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1070, 1094,   37,    1,    1,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1123,  507,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504, 1065, 1190, 1258,  220, 2237,   37,  166,  463,  528, 2596,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  120,   45, 2597, 2292, 1554, 1530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  993,    1,   98,  531,   32,  260,  220,  596,  716,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  670, 1315,  762,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1486,    1,    1,  565, 1041,    1,  331, 2021,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  848,  775, 3016,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1398,  612, 1807,    1, 2268,  405,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  790,    1,  538,    1,   98,  195,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2546,   37,  693,    1,    1, 1107,  802,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,  200,    1, 2549,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,  421,  159,   71,   98,  399,   46,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  845,    1,  492,    1, 1691,    1,  625,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1883,  835,    1,    1,  682, 1117, 1525,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2161,   12, 2472,  166,  888,   45, 2712,   61,  729,  241,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  297, 1502, 1503,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1303,  571,   37,  197,  202,  376,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  300,    1,  403,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 2860,    1,   28,  315,   37, 1527, 3375,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,  774,    1,  167, 1021, 1975,    1, 1219,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2047,    1,   49,    1, 1010, 2262,  361, 2263,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  502,  492,  491,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  471,  193, 1148, 1149,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  629,    1, 2977, 2344, 1438,   45,    1,   27, 2662,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2279,    1, 3113, 1021, 1497,   37, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  910, 1239,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1718, 2146,  682,  183, 2225,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640,   37,   44, 1159,  547, 1333,    1,  631,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3173,   32,    1, 1380,  166,    1, 1159,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,    1,  713,  361, 1937, 1992,   37, 1815, 2024,  226,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 1995,   98, 3391,  738,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  275,    1,    1, 1294, 1542,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,    1,    1, 1022,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1137,   81,   27,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  761,  315, 1463,   45,  453,    1,  195,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   33,  691,  548, 1537,    1, 1686,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  753,    9,  297, 2249,  649, 1295,    1,  232,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2158, 2963,  297,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  746,    1,  758,  759,  760,  166,  327,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1529,    1,  167,    1,  670, 1159, 2330, 1223,   32,  942,\n",
      "          103,    1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  764,    9,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,  613, 1360,  612,    1,  180, 2434,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  233,    1,  817,    1, 3104,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2539,   32, 2295,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  275,    1,   69,  361,  666,   37,  804,  616,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 1848,  494, 1046,  611,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3259,    1, 1668, 1025,    1,    1,  442,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  459,   57,    9,  993,  652,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  326, 2094,  845,  439, 2759,    1,   37,    1, 3004,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   31, 2126, 1103,    1,  104,   65,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1638,  162,   32, 2069,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1698, 3051, 2024,   46,  619,   79,   37,  105,    1,  698,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2004, 1051,   82,   12,    1, 2850,   28,  384,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  193,  320,  638,    1,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,  424,  829,  756, 2157,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3285,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,   32, 2161,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1658,    1, 2138,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1861,    1,   10,  907,   37, 2000, 3388, 2024,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2824,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2504,  358,   37,  518,  365, 1202,    1,  191,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  858, 1402,    1, 2015,  357, 1512,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1891, 2064,  774,  104, 1876,   45, 1094, 1564, 2179,  652,  105,\n",
      "            1, 2082,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2005,  907,   32,  914, 3201,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  316,   12,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1554,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2069, 2277, 1252,    1,  501,  827,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,  193,  166, 1851, 1046,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  864, 1707, 1428, 1140,    9, 3107, 3366, 1806,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1178, 1231,  220,  840, 2339, 1778, 2690,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2414, 1029, 2231,    1,  876,  612,    1,  176,  104,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  588, 2383,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2275, 2386,   10,   98,  531, 1001,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1, 3052,    1,  105,  132,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3305,    1, 1973,    9,  584,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1547, 1408,  682,    1,    1,  191,    1,  157,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2140,    1,    1,  668, 1292,  361,  709, 1009,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1672,  384,  166,    1,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   10, 1355, 2275,   98,    4,    1,  954,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1084,  841,  700,  686,  191,    1, 1260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3213, 2489,   85,  336, 1559,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2461,  437,    1,  829, 1117, 1525, 2362,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  790,   90,    1,   37,    1,  453,  378,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1408,    1,   12,  625,   98, 1171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 2257,   39,   45, 1428,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  312, 2819,    1,  478,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  905, 2166,  919, 1455,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  905,    1, 2884,    1,   32, 1956,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2470, 1070,   10,   37,  289,   98,  903,    1, 1447, 2673, 1512,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171,  957,  460,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1853,  140,   54,  854,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1955,  288,   37,  151, 2412,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2700,    1,  215,   12, 2084,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,  321,    1,  985, 2647,  975,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018, 1550,  798,   45, 1647,   32, 1926, 1927, 2884,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  107, 1372,   37,  125,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2602,    1, 1658,    1,    1,  833,  612,  907,  255,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2354,  191,   37, 2704, 2919,   45, 2820,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  528,  726,    1,  388,    1,    9,  148,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  510,    1,    1,  187,  584,    1,    9, 1913,  567,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  915,  581, 2323, 1118,  393, 1539,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2903, 1178,  384,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  179,  361,  180, 1776,  105,  131,  170,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2883,  566,  217,   32,  195, 1001, 2884,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2945,  384,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  291,  675,   37, 1468,  172,  586, 1929,   98, 1657,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,    1,  167,   52,  227,    9,  334,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1848,  361,    1,    1,  361,  877,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 398, 193,   1,   1,   1,  52,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 365, 754,  15, 245, 642, 643,  71,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  172,  593,    1,   98, 1411,   65,  475,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  992, 1159,  166, 1551,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2909, 2856, 1763,   32, 2597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2862,   12,  622, 1386, 1679, 2101, 1056, 2179, 3082, 2789,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3328,   12, 1734,    1, 2394,   37,   52,  260, 1762,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   81,   32,  183,  199,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  665,    1,   98,  429,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1411,  207, 2988,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  915,    1,    1,  187,  342, 1830, 1855,  501, 1125,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843,  748,   92,   98, 3258,  865,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  547, 1989,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   68,  953,   98,  430,  509,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  640,  183,  199,  220, 1762,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  921,   59,  813,  176,    1, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1122,    1, 1123,   32,  331,    1,  356,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1088, 2774, 3398,   32,    1,    9,   81,  351,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 2164,    1, 1850,  455,    1,    1,   32,  409,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  552,  551,  405,   37,    1,    1,    1,    1,    4,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359, 1877, 3372,  741,   98, 3339,  469,   98, 1893,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  408, 1198,  215,   31,   37,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1419,    1,  659,   45, 1778, 2580,   32, 1033,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1564,  105, 1343,    9, 1652, 2264, 2973, 1764,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  773,    1, 1595,   71,   32,  818, 1278,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   47,  593,    1,  437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1581, 2381,  356,   24,  881,  384,  902,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1607,  231,   40,  612, 1775,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3115,    1,    1,  220,   56,  356,  881,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  851,    1,   37, 2235,   98, 2596, 1665,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  691, 3397,   32,  903, 1447,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1065,  199,   51,  193,   52, 1542,    9, 1517,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  266, 2104,   37, 1173,  176, 1089, 1090,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2693,    1, 1704,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2991,    1,   37, 1095,  124,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1640, 1008,  232,   37, 1048,   28,    1,  776,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  758,   12,    1,  117,   50,   37,   26,  228,    1,    1,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2592,  884, 1370,   32,  105,    1,  220,  440, 2064,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612,    1, 1658,  741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2572,   32, 3343, 1313,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  199,   45, 1958,    9,  596, 3093,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3005, 1631,  846,  119,  384,    1,   37, 1204,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018,  190,    1,  854,    9,    1,    1, 1311,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3161,  171,    1,    1, 2479, 1381,  444, 3166,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3103,   51,  606,   37, 1594,   37,   72,    1, 3229,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2073,   12, 1009, 2940,  247,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 1114,  176,  247,    1,  754,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,    1,  680,    1,  396,  100,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   77,  340, 2395,    1,  104,    1, 1648,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56,  497,    1,    9, 1428,  861, 1906,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  144,  145,   12,    1,  765,   37, 1121,  636,  641,  187,    1,\n",
      "          682,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141,    1,    1, 1947,    1,    1,  630,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  404, 1033, 1964,    1,  176,  340,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3108, 1421,    1,   37,    1,  922,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 592,  12,   1, 267, 522,   1,  98, 104,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 610,  37, 537,   9, 133,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2,   9,   1,   1, 460,  12,  39, 220,   1,   1,  32, 220,   1,   3,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 310, 159, 410, 187,  69, 816,  27,  88,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  667,    1, 1753,  912,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 3347,    1,   32, 3376,  297,  808,   32, 1428, 3102,  949,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1181,  623,  200, 1022, 2382,  259,  220, 2177,  988, 1027,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   88,  159,   28,   98,    1,  333,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,  166, 1523, 1494,  166,  443,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1720, 2698,  565, 1176,  637,   98,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 1380, 1794,   98, 2393,  548,    1,    1,    1,   32,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2500,    1,    1,  959, 1745, 1306,    1,  506,  782,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2418,   28, 1056,  104,  441,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,   79,  220, 2977, 2334,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1794,  794, 1056,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2170, 1822,   52,    1,   32,  166,    1,   45,  166,  252,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,   23,   37,    1,  829,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  857,   16,  365, 1788, 1187,  460, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  108, 2824, 1610, 1232,   10,  140,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1450,    1,  284, 1084,  841, 2600,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2696, 1061,  297,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1407, 1538,  820,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2009,   26,    9, 2670,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   65,  929,  104,  996,  471, 1258,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129,  975,  267,  159, 1960,  187,  445,  187,  105,    1,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   71,  187,   69,  953,    1,  275, 1287,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,   15,  866,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2737,    1, 1739, 2446,  103, 2132, 1252,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  967,  590, 2763,  220, 3374,    1,    1,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3121, 2414,   32,  455,    1,    1,   32,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  191, 2825,    1,    1,  730, 2614, 2222,  877,  105,  183,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  794, 2686,    1, 2519,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,  159,  176,  365,  339, 1653,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  435,    1,    9,  864,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1125,  238,    1, 1165,  972,   37,   52, 2317,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  737,  197,  953,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089,  443,   61,  105,  271,  384,  166,  311,  856,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  845,   69,  102,    1,  104,  954,  684,  475,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2785, 2372,  240, 1527,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  384, 1372, 1039,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  746,   37,   47, 1842,   55,  844, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1458,   79, 1665,   37,  319,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   10,    1, 2275,   98,  657,  652,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1268, 2446,   98,  201,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,    1,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2755, 2170, 2064,  543,    1,  442, 2471,  220,  395,    1,  854,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   37,  846,    1,    1,    1,    1, 2444,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  654,  582, 1025,    1, 1351,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 1509,  176,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1022,    1,  678,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1056,  365,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  415, 1492,   61,  424,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2175,   37,  507,   37, 2844,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2909,    1,    1,  135,  531, 2458,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1617,    1,    1, 2572,  191,    1,  548,  166, 3096, 1090,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   98,  166,  777,    1,    1,   61,   81,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2386,    1,   45,  998, 2887,   37,    1,  361, 1861,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2612,    9,  163,    1,   12,    1,  808,   32,    1, 1637,\n",
      "          223,  408,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2708, 2328, 2414,   32, 3101, 1223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,  193,   52,    1,    1,  202,  590,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  262,  263,   12,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1460,   84, 1532,   32,  201,  529, 1116,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  864, 1358,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2257,   79,  885, 3096,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1861,    1, 3025,    1, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,  112, 2146,  162,    1,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  284,    1, 1313,   32,    1,  444, 2292,   32,  166, 2225,   45,\n",
      "            1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1648,   37, 1598, 3118, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  931,  168,  220,  803,  873,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2314,    1,    1, 1086,  914,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,   26,  699,  417,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2397, 1898,    1,   45, 2375,   37, 1220,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2494,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  166, 1357,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2418,    1,   12, 2315, 1045,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,  138, 1652,   59,  399,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1492,   12,    1,   45,  702,  361,  169,    1,  193,  837,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422, 1008,    1, 1682,   32,  133,   43,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   69, 1042,    1,  616, 1473,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1367,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1687, 1022,    1, 3008,    1,    1, 2124,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2909, 2856,  187, 3128, 2770,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,    1,  746,   32, 1766, 1767,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  342,   37, 1604, 1750, 2093,  395, 2108, 1281,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3345,   32,  531, 1211, 1312, 1538,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  326, 1614,    1, 2206, 1228, 2750, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37,  151,    1,    9,    1,  372,   87,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2528,    1,   12,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1, 2018, 2000, 1651,  934,    1, 1815,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  765,   98,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2077,    1,  971,   32, 1259,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1010,  166, 2401,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  684,  734,  102,  186,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  677,  649,  112, 1292,  686,  191,    1,    1,  131,  354,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  224,    1,    1,  729,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  481, 1017, 1773,    1,    1,  570,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1290,  396,   71,  388,  995,  763,   76,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  550,  561,  774,    1,    1,  440, 2964,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  793, 2055,  451,  541,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3229, 1240, 1306, 2486, 1090,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129, 2972,  475,    1,    1,  939,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2068,  513,  220, 1861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  596,  170,   98,  429,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  232, 2265, 1386,    1, 1532,   32,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1, 2620, 1178,   12, 2895,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  220,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  590, 1188,    9, 1087,    1,   98, 2695,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2222, 1216,  204,   12, 2565, 1492,    1,   32,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  807,    1,    1,  176, 1687, 1022,    1, 3008,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 2200,    1, 2716,  176,  163,    1,   12,\n",
      "            1, 2147,   32, 2573,  963, 2122,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1, 1955, 2654,   32, 1656, 1819,    1,    1, 1294,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  830,  104,  681,  151,    1,    1,   50,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1436, 2908,    9,    1, 2800,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  337,    1,  315,  111, 1074,   37,    1,  229,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1811,  404,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,  991,  148,   12,  214,  142,    9,  647,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1, 1695,    1,   45,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  983,  942, 1149,  288,   37, 1174,    1,    1,  847,  906,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  386,  781,  214,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  810,  566, 1594,   37, 1691,    1,  187, 3177,  571,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1898,  220,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  170,  220,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  136,   37,  138,  331,   37, 1911,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   45,  105,    1, 2540,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  215,    1, 1463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   32, 1764, 1990, 2069, 1660,  427,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  927, 1509,  454,   37, 1000,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1,   37,    1, 1792,    1,    1, 1871,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  169,  702,  132, 2420,  627,   14,  468,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  920,    1,  838,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1906, 2591,  557,  540, 2108, 3368,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  798,  403, 1383,    1, 1625,   37,  477,   69,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,    1, 1408,  289,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2476, 2536, 1530,   32, 3343,  298,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3018,   98,  429, 2191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  715,   22,    1,  669,    1,   37,  123,    1, 1153,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1285,  581,   74,   45,    1, 1990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1118,  809,    1,  804,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203,   37,    1,  105, 2829,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1354,  295, 1083,    1, 2007,   37,  529,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1, 2733, 1564,  166,  261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  437,  313,   37, 1865,    1,   45,  861,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398, 2794,  597, 1465, 1466,   82,   12,  112, 1697,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,   12,    1,  682,   32, 1428,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  365,    1, 2973, 1764,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2571,  474,   23,   66,  187,    1,  753,    9, 3118,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1658,  327,   51,   52, 2051, 2341,  763,  334, 2898,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  835,  854,   12,  627, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  244,  565,   28,  176,  654,  361,  320,    1,  460,  267,    1,\n",
      "           61,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  361, 3191, 1285,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766,   37,  877,  769,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1040,  814,  369,    1,   37,  138,    1,  599,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1109,  727,  361, 1200, 1140,    9,  365,  261,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2669, 1678,    1,  994,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1810, 2308,  125,  191, 3318,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  535,    1,    1,   45,    1,   12,  559,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826,    1,    1,  593,  119,   37,    1,    1, 3292,  671,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3187,    1,   45,   91,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  331,  104,  197,   32,  401,   98,  198,   15,   45,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2496, 1976,   32, 2646,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1704,   12,    1, 2403,   37,   52,  653, 1417,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1796,  232, 1921,   32,    1,   37,    1,    1,   12,  770,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,    1, 1126, 2290,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 458,  45, 507,   1, 929,  37, 930,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 156,  71, 202, 159, 245,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 2452, 1310,   37, 1343,  460,  838,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  315,   37,    1,  365, 1607, 2575,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1660,    1, 1998,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1367,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,  879, 2764,    1, 1281,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,    1, 3078,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,  365,  845,   98, 2046,  997,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,  582,  387,   69, 1220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2885,   90, 2843,   37,  619,   81,   32, 2482,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861, 1873, 2450,   37,    1, 2851, 2558,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  334,  674, 2102, 1380,  674,   32, 2367, 2695,    1, 2412, 3011,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  829, 2819,   43,  884, 2267,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3166, 3272,  590,    1,  273, 2171,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,    1,  326,  846,   28,  769,  220,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2798,    1,    1,  327,   15,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,    1,  738,  220, 2742,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  492,    1,    1,    1, 1010, 2966,  997,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  842,  580,  885, 2195,  187,    1, 2092, 1961,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1913,  401,  156,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2597, 2292, 2414,  176,  177,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1810, 1412, 2528, 2996,    1, 1790,   12,   61,  590,    1, 2928,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  239,  168,  613,  220,  764,   45,  326,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,   42,  220,  215,  259,   13,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1122,  853,  538,    1, 3167,   32,  331,    1,  356,  132,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2198,    1,    1,   10,  908,  301,    5,    6,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1771,  171, 1760,    1, 3134,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1, 2034, 1569,   32,  979, 2340,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  140,  105,  845,    1, 1935, 1523,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  864, 1542,   37,  843, 2390,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2319,    1,   45, 1386,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  785,  786,  429,    1,  191, 2039,    1,  735, 1281,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1680, 1741,    1, 1717, 1131,    1,  481,    1, 2689,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1757,   98, 3118,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  765,   37, 1658, 2355,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,   51, 1865,  632,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 1141,    9,    1,  865,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1338,   45, 1513,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713,    1,   32,  915,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  892,   12, 2925, 1675,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3096,    1, 1494,   81,   37,    1, 3191,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428,    1,  315,   37,    1,   32,   10,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,    1, 2222,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  292,  822,    1,    1,  552,  552, 1107,  332, 1294,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,  142,  750, 1495,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  838,    1,    1,  176, 1273,  275,   16,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  877,  166,  400,  112,  400,    1,    9, 1067,  297,  116,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1514,  837,  408,  671,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,  327,  218,  548,  105, 2338,  191, 2226,    1,  182,\n",
      "            1,  331,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   37,  125,   28,   37,    1,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2703, 1348,   37, 2816,  557,  540,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3147,    1,   39,  187,  638,    1, 2024,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,   37, 1504,  684,   12,   89, 2163, 1215,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2690,   37, 2988, 1778,    1, 2762,  920, 1300,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,   76,   37,   92, 2128,    1,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2045,   25,   71,   63,  156,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056,  583,   32, 3099, 1325, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2751,  360, 3102,  693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2871,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  151,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3296,  498,   37,    1,  922,  802,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1487,  353,    1,  367,   15,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1707, 2275,   98, 2095,  443,    1,  954,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2087,  433,  267, 1926, 1927, 1928,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  829,    1,  342, 1523,  297, 1350, 1250,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094,  580,  365,   97,  297,  861,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  566,    1,    1,    1,    1,  470, 1465,    1,   12,   74,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707,   12, 1183,  713,    9,  342, 2927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  197, 1137,   98,  983,  120,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3313,   12,    1,    1,  444,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1509,  792,    1, 1708,  792,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2355, 1013, 1681, 1245,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2980, 2954,   28,  220,    1, 3005,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994, 3153, 2220,    1, 1464,   32,  433,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2946,  335, 1130, 2100,    1,  506,  782,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303,  108,   45,  442,  448,  629,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   89,  672,  673,  448,  103,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 1648,   37,  231, 2834, 1506,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1107,  170,   34,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  167,   28,   48,   37,  187,  445,  187,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  393,    1,  469,   37,    1,  389,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  958,  885,  400,   45,    1,   32,    1, 2624,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2,  88,  28,  98, 420,   1,  28,   9, 333,  88,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 829,  12, 365,   1, 619,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32, 1102,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3241, 2192, 1214,  449,  354,  176,  754,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  880,   95,   37,  451, 1564, 2218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  733,  453,   48,   32,   22,  438,    9,  331,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 2051,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1018,    1,    9,  166, 3024,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1485, 1386,    1, 1310,   37,    1, 1255,  297, 3365,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  490,  187,   10,  431,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1497,  774, 1444,    1,  612, 1844, 2398,  915,  914,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3043,   45,    1, 2343,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2754, 1920, 3102,   81,  754,  548, 1997, 1683,   32,  531,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  380,  166,    1, 1240,    1,    1,  270,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 193, 320,   1,   1, 994,   1, 150,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 156,  71,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3375,    1, 3101, 3160, 2572,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  679, 1879,  193,  187,  845,  187, 1999,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2577,    9,    1,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018, 1126, 1568, 2398,    9, 1869,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3348,  650, 1550, 2001,  600,    1,  254, 1994,    1,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   68,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1926, 1927,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545, 1164,   32, 1987, 2107,    9, 1691,    1, 2396,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  113,  176,  548, 1520,   68, 2250,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 1432,    1,    1,    1,    1, 2495, 3175,   37,  726,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2447, 1946,  191,  242,    1,  361,  244,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1419,  384,  224,    1, 2994,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1479, 2005,  907,   32, 2835,   98,    1,  627,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26, 1039, 1228,  614,   37, 1604,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  950,  565,    1,  183,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3369, 1450,    1,  279,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3358,   12, 1404,    1,   39,  176,  379,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2540,    1,    1,  765,   37, 1909,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2017,  384,    1,    1, 2551,  798, 1110,  187,  645, 2566,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  789, 1467,   79, 3196,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1852,  267, 1099, 1453,    1,  261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1726,  319,   32, 1009, 1559,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 3111, 2905,   37,   64, 2774,  787,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1357,   45,  166,  356,   61, 2603,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1674, 1171, 2962, 2939, 1086,    1,   12, 2494,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3310,    1,    1,  606,  105, 2277,   37,  875,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  156, 1473,  176,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978, 3009,  288,   37,  168,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  582,   45,  725, 1131, 1554, 1307,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1998,  191,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2087, 2614,  361,    1,  498,   37, 1145,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   37, 1539,  999, 1892,    1, 1893,    1,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2922,   37,  221,  384, 2072,  166,    1,   37, 1267, 1030,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  140, 1350,  400,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1465, 3005,    1,   39,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162, 2116, 1784,   37,   32,   64,    1, 3349,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12, 1281,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  210, 2414,  617,  259, 2515,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2, 585, 686, 756, 757, 197,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   9, 863,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,   45, 2869, 2308,    1,  176, 1230,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1,   37, 1876, 1234, 2294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  649,  441, 1706,   32,  667,  368,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  483, 2450,   37, 1709, 3185,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1361,   12,    1,  315,  698,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129,    1,  200,    1, 1151,    9, 2261,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2993, 3056,    1, 2215,    1, 1781,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3107,    1,    1,    1,  864,  267,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,  641,  631,  297, 2275,   32,  645,    1, 1002,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 1576,   37,  875,   24,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1612, 1373,   37,  420,   37, 1604, 1602,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,   69,  393, 2751,  774,  443,   37,  698, 1893,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  197, 1249,  739,    1,  157, 1519,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  550,  369,  353,  198,  572,  244,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  187,  593,   12,    1, 1178,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  952,  467, 1942,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1100, 1151,   15, 1376,  548,  163,    1,   12,    1,  863,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2603,    1, 1357,   45,  166,  356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2672,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,  638,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1739,    1, 1024, 3062,    1,    1, 3217,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2096,   51,    1, 1821, 2057,  302,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   72,  401,    1, 1071,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579, 1232,    1,    1,  166,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2275,  162,  317,  736, 2075,   32,  863,   70,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711, 1313,  531,  443,    1, 2868, 2237,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  506,   80,  408,  810,  297,  166, 2655,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3251,  810,  202, 2626,  548,  424,  914,    1,  267,  872,\n",
      "         1009,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2376,  855,    1,    1,    1,  297, 3022,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 1447,    1, 1610,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2018, 3109, 3060,   32,  104,    1, 1585,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564,  247,  865,   98, 1602, 2539,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1711, 1413, 1994,  443,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2948,    1,  453,    1,  633,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,  123,  410,    1,   60,  242,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2357,  517, 1108,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  864,  879,    1,  297, 2162,   45,    1, 1009,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  622,  267,  967,  419,  674,   45, 3391,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   25,  439,  242,  548,  148,  132,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2193, 2018, 2751,  798, 1815, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 2592,   61,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2118,  297, 1656, 2917,   32,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1647, 2070, 2299,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613,  200, 1766, 1767,    1,  841,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  185,  631,  409,   25,  242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1229,   37,   47, 2474, 2909,   37, 1094,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   16,    1, 1234,  914,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26,   61,    1,  656,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  313,  176,    1, 2264,  220,    1, 1708,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,  413, 2450,   37,    1,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2971, 2655,   37,  764,    1,  557,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2427, 1523, 2476,   37, 1832,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1343, 1908,    1,  384, 2565,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2245,  191,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3034, 2264, 1371,    1,   37,   33, 1117, 1525, 1704,  157,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,  729,  707,   38,   32,   38,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1796,  132,   98,    1, 1196,  653,  863,\n",
      "            1,  191,  963,    1,  963, 2122,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1400, 1999,  191, 1443,    1, 3173,  415,    1,   32,    1,\n",
      "           12,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2197, 1550, 2147,   12, 1896,    9,    1, 2826,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  288,   37,   26,   28,    1,   32, 1381,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2792, 3176,    1,  631,   32, 2038,  922,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3317,    1,    9, 2637,  427,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  162,  764,  384,    1,    1,  326,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  632, 2396,   32,  166, 2069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  393,   37, 1816,   59,  159,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1855,    1,    1,    1,   37,  214,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2571,  474,  565,    1,   12,    1, 1542,   37,    1, 1515,  368,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425,  614, 1994, 2026,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12,  103,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773, 1455,  197,   28,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  968, 2262,    1,    1,   32, 2968,  927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597, 1465, 1466,   82,    1, 2430,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1909,    1,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  825,    1,   98,  224,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1033,   25,   27,  526,   98,  996,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1921,    9,  148,  361,  647,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 166,   1, 408,  45, 443,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777, 1342,  365, 1644,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2569,    1,  952,  927,   45, 1887,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,  814,   12, 1633,  616,   50,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,   28,    1,  115,   45, 1313,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1043, 1276,  118,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3123,   12,    1,  405, 2562,    1,  966,  191,    1,  542,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32, 3097,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302, 1963,  696, 1539, 1013, 1522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  396, 3370,    1,  696, 3363,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1031,   61,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  423,   32,  247, 1343,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481,  315,   37, 1865,  365,  947,    1,   37, 1664,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 2231,  267, 1405,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,  942,   37,  151, 1266, 1497,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1084,  931,    1,  361,  388,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1850, 1423,   12, 1851,    1,   37,  123,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,   25,   71,   12,  551,  552,  967, 1509,  547, 1034,  186,\n",
      "          452,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2798, 2492, 2342,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3192,    1,   81,   28,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  546, 3123,  608,    1, 2857,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1039, 2690, 1218, 2888,    1,  357, 1051,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  911,    1,   37, 3018,  211,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3199,  670,   51,    1,  180,  631,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  890,    1,  691,  190,   77, 2924,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2692, 1573,   37,  166,    1,  439,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,  361,  758,    1, 2274,   37, 1865,    1, 2417,  111,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  388, 1530,   32, 3339,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  800,    1, 1033,   25,   85,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2564,   98, 3343, 1009,   12, 1204, 1464,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1,  766,   37, 1539, 1412,    1,  220, 2080,  769,   32,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3369,  213,   37, 2035,    1,   45, 3118,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3003, 1536,  365, 1385,   45,  552,  552, 2039,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3305,  891,  365, 1015,   32,  584, 2800,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2631, 1045,  608, 2748,    9,  119,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2607,  134,    1,  444,   56,  709,  829, 1149,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12,  111,  834,    1,   32,  777,   45, 2298,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   49, 1644, 1118,  865,   37,  121,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306, 1419,  105, 1013, 1522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1326,    1,    1,  219, 1656,   45,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  531, 2905, 2731,   37,    1,  454,    9,  863,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1233,  250, 1489,    1, 1623,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  155,    1,  629,  506,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3385,    1,   45,  531, 3373, 2249,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1061,   32,    1,  133,  549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  167,   52, 3020,   12, 2249,  345,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1,  105, 1136,   32,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2343,  738,  924,    1, 3404, 2007,   32,  147,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3191,  879, 1485,  631,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   85,   98,  552,  552,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 1298, 2015,    9, 3298,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 3193, 2661,   61,   32,   38,    1,  202,    1,    1,  105,\n",
      "          855,  105,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,  936, 2069,  647,  693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649,  700,   32,   46,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  579,   61,  105, 1013, 1522,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437,  488,   37, 2856, 3365,   32,  531,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 647, 353,  72, 401, 197,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 580, 342, 389,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2579,   51,  193, 1343,   37,    1,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2871,    1,    1,    1,    1,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  798,    1,   45,  638,    1,    1,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1065, 1190,    1,  939,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1809, 1647,   32,  505,  856,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  361, 2275, 2287,   28,    9,  449,  736,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453,   37, 1124, 1633,  316,    1,   86,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1380,  225,    1,   37, 1604,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2660, 1909, 1684,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730,    1, 2905, 1545,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  220, 1009,   12, 1596,    1,  521,  663,  437, 1114,   32,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296,  288,   37, 2243,    1,  413,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,  952,   37,    1,  616,   98,  347,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,  249, 1313,    1,   12, 2108,  349,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,  747, 1508,  258, 2131,  132,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1940,   12,    1, 1575,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  252,  497,  297, 1527,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,   12,  105,    1,    1,   37,  544,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1123,  515,    1,   24, 1632,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283,    1, 2016,  386,  140,    1, 1990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  582,   37,  531, 2124, 2060,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3303,  765,   32,   98,  119, 2674, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  234,    1,  235,    1,  234,    1,  235,    1, 2225,    1,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 2407,    1,   28, 1167,    1, 3027,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  251, 2514,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  491,   37,    1,  182,  104,   37, 1504, 1356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1973, 1648,   37,  194,  493, 1649,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2822, 2879,  191,    1,    1,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,  105,    1,  384,  306,   12,  825, 1013,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2533, 1827,    1,  187, 2227,  721, 1399, 1590,   37, 1334,  665,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1,  236,  237,  220, 1402,    1, 2524,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1654,    1,  768,    1,  140, 2474,    1,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  756,    9,  282, 1108, 1779,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777, 2355,  765, 1083,  861,    1, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1, 2018, 1585,  972,    1,  191,  105,\n",
      "         2596,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3113,   12, 2545, 2658,   61,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1428, 3146,   98, 3339, 2731,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1746,    1,    1,   32,    1,    1, 1763, 1673,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,   37,   26,  417,   98,   69,  122,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  719,  372,  388,   32, 1251,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,  356,   12, 1515,   74,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1457,    1, 1757, 2493,    1,   37,  441,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  846, 1458, 2912, 1411,  221,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3094,    1,   32, 2752, 2596, 2960,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3174, 2503, 3178,   37,  759,  163,    1,   12,    1,   26, 2069,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2136,    1,  365, 1600,  261,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2679,   45, 1009,   10,   12,  538, 2653,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3253,    1, 3178,  221, 1159, 3293,   45,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  375,    1,   32,  166,    1,    1,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   46,  439,    1, 2531, 2756,   37, 1348,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   75,    1,    1,    1, 1017,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  131, 1067,  361,   29,  132,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2843,    1, 2226,  544,   37, 2876, 1404,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766, 1702, 1230, 1650,   37, 2627,  220,  365, 1027,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 217,  98,  93,  32,   1, 486,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 156, 565, 526,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401, 2755,    1,  191,  786,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311, 2936,  580,  187, 3312,   32,  166, 1354,    1, 1090,   45,\n",
      "          166,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1713,    1,    1,  293,  725,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1492,  565,    1,    1,   12,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1853,  456,    9,  885,  477,  297, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1853,  140,    1,    1, 1543,   37, 2498,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  199,    9,  104,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1352,   61, 1465,  230,  339,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 2948,   45,  585,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   12,  366,  460,  669,    1,   37, 1638,  225, 1411, 1034,\n",
      "          548,  332,  693,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2189,    1, 1054,   98, 1485, 2921,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   84, 1031,  187,    1,  213,  636,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1535,    9,    1, 1565, 2565,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2704,  388,  384,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3386,  312, 1916, 1961,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  256,  885,  726,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  142,   37, 1154,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  842,  361, 2534,   32, 1116,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  839,    1,   12,  345,   37,  574,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,  12, 572, 197, 407,   1, 118,   1, 159, 670, 328,   1,   3,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 425, 426, 729, 387,  15,  28, 118,  88,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3244,    1, 2551,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  571,  754,  187, 3200,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  125, 1085,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  232,   49,  333, 1360,  612,  805,  568,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  162, 1183,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  794,  111, 1107,  525,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  593,  442,  656,  286,    1,    1,  191, 1723,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3314, 2827,   37, 2250,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1178,  610,   32,    5,    1,  483, 1419,   29,   98, 1576,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2871,    1, 3131,    1, 2163,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  393,   37,  125,    1,    1,    4,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2418,  701,  220,  176,    1,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1043,   81,  176, 1722,   63,  800,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   28,   37,   26, 1039, 3004,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3204,    1, 3230,    9, 1194, 1684,   45,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 1343,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2528,    1,  829,   12,  365,  535,  656,  973,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1802,  839,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1095,  884,   48,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,   36,    1, 1634,   37,  365,  625,    1,    1,  459,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428,  729,    1,  804,   39,  864,  903,  469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1, 1087,    1,    1, 1017, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  619, 2966,    1,    1, 3089,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2189,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   58,  156,  388,  763, 1427,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 1082, 3375,   37, 1314,  754,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1031, 2086,  736,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,  526,  187, 1290,   71,    1,  442,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2745, 1890,  565,  297, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1010,  861,  997,    1, 3363, 1141,   37,  943,   37, 3157,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   98, 1211, 1819,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 1450,  837,  215,    1,  104,    1,   32, 2707,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  627, 1778,    1,  167,    1, 1691,   36, 3002,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1444,   55,  460, 1120, 1366,    1, 1444, 1710,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 1313,  686, 3343,  787,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390,   37, 1776, 1746,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,  396, 2133, 1463,   45,  955, 1461,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1921,   98,  199,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3361,  629, 2162,   37,    1,  166, 1530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1057,  297, 1029,  535,  625,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  204, 2850,    1,  334, 2277,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  476, 2332,   32,    1,  193,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   61,  223,  286, 1887, 1888,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204, 1249,    1,    1, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1818,  147,   37, 2303, 1842,  116,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1953, 1268,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1256,    1,  331,    1,    1,    1,    1,   15,  526,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 3091, 2827,   32,  531,   61,  820,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1618,   28,   32,  705, 1023,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 2315, 1989, 1990,  698,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  124,    1,    1,  384,    1, 1589,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  306, 1831, 2721,   45,  105, 1412, 1104,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3175, 1832,  105,   12,   32,  539,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1139, 2522, 1924, 1183,   98, 2420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,    1,  647,    1,    9,    1,  693, 1757,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1879,  619, 2941, 3136,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  550,    1, 1754,   37,    1,   45, 2894, 1273, 2980,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 1303,  387,  244,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  245,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  641,  289,   98, 2913,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  420, 1127,  697,   37,  151,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196,  132,  991,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  647,   12,  915,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,    1, 2835,  221, 1750,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1187,  193,   18,  220,    1, 1886, 2885,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967, 3200, 3130,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3232,  619, 2058,   32, 3135,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1230, 1443, 2228,   79,  444, 1158,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   20,   82,  880,  218,  471,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  732, 1831, 1216, 1366,  416,  460, 1514,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,  475,    1,    1,    1,    1,    9,  247,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 2160,   45,    1,    1, 1120,   12,  579,   12,  115,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  794,  138, 1146, 1140, 1013, 2131,  210,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,  155,  401,  361, 1698,  356,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1555,  361, 2934,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,   12,    1,  796, 2789,  317,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3152,  245,   37, 3300,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1570,  325, 1159,  395,    1, 1718,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,  388, 2529, 1230,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496,    1,    1,  116,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3185,  246,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1592, 1248,  522,  187,  163,    1,   12,    1,  847,   28,    9,\n",
      "          164, 1593,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,   10,  872,   12,    1, 1995,   98,    5, 1563,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1550,    1,    5,  798,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  177, 1530,    1, 2249,   32,  395,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1973,  650, 1082, 2397,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2028,  459,  388, 1011,  802,   32, 1890,   63, 2786,  104,  863,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1539,  365, 2522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1985,  565, 2572,   32,  298,   45, 3076,  872,  851,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1632,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 3160,    1,   56, 3006, 2572,   32, 3339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,   79,  187,    1,   29,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  484, 1822,  713,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2890,    1,   37, 1911,  617,  259,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203,   37,    1,  384,    1,  357, 1928,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  106,  936,    1,  331,  399,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2107,   98,   37, 1155,    1,    1,  725,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 1037,  850,   39,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2355, 1013,    1, 2007,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2708,  863,  191,  740,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  458,    1,    1,   93,  176,  177, 1632,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051,  325, 2348, 2544, 1873,  552,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1994,    1,  695,    1,  191,  829,  892,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  121, 1877, 2095,  856,    1,  640,  104, 1470,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2264,  753, 1095,   12,   48, 1360,  612,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1, 2497, 2774, 2827, 1147, 1223, 3133,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  443,   12,  365,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1447,  387,    1,  443, 2124,    1, 2682,  163,    1,\n",
      "           12,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,  952,    1,  220,  104,   98,  365,    5,  625,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  574,   12,    1, 1041,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2746,    1,    1,  187,  233,    1,  650,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  517,    1,    1,   60,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  503, 1321,    1,  195,  749,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741, 3255,  474, 2565,    1,    1, 1554,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,   37, 1468,  449,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468, 1454,  453,  531, 2128, 2129,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  474, 2591,   37,    1,  477, 1232,   46,  271,   85,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 2308,    1, 1536,    1,  297, 2967,  949,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,  176,    1,   45, 2875,    1, 1294,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193,  707,   37,   91,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2531,    1, 3372,    1, 3371,  187,  365,  446,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  737,  197,  388,  763, 1660,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  454,    1, 1976, 1821,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  439,  242,    1, 1946,  191,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1686,   32, 2963,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3296, 1188,  199,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2513,   32,    1, 1002,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3352, 2833,  632,   36,    1, 1936, 3365,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  732,   37,   47,   59,   35,   48,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3406,    1, 1159, 3118,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 1285, 1315,  105,  106,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,    9, 3077,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  270,    1,    1,    1, 2551,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1577,  315,   37,   47,  105,    1,   45,  247,  669,  159,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  424, 2441,   61, 1658, 2441,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1256,    1, 1256,    1,   61, 1229,   37,   52,   27,  132,   37,\n",
      "          151, 1026,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,  361, 3175,  332, 1298,    1,  361,  105,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,  705,    1,  887,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   94,    1,   69,    1,  715, 1161,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1034,   12,  211,    9,  393,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1316,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  688,  424,    9,  846,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  633,    1,  884,  674,   45,    1,  437,   12,    1,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  920,  357, 1745,    9,  903,    1, 1973,  132,    1,  267,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1795, 2279,    1,  289,   98,   20,   12,  475, 1213,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1471, 1149, 1575,   39,   32,    1,    1,    1,   46,   37, 1348,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2700,  753,   37, 1000,  388, 1199,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1231,  220, 1887,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  786,   72,   45,  460, 1132,  634,  220, 2580, 2851,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  707,   79,  166,   22,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  810,    1, 1694, 3164,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374,  578,  460,  476,  105,  808,   32, 2708,  741,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1364, 1365, 2024,  226, 2126,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  813,    1,    1,  384,  872,   12,    1, 1013,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  140,  166,   74,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2705,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  136,   37, 1046,    1,   32,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,  361,  395, 1472, 1224,  220,  105, 1239,  633,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2881,    1,  861, 2524,    9,  105, 1378, 3018, 1778,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103,  321,  612,  619,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1539,  651, 1708,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1950,   32,    1,    1,   45, 2003, 2705,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  199,   37, 1664,  166,  573, 1512,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  565,  234,  163,  235, 1691,  234,  163,  235, 1978,    1,\n",
      "           37,  576, 2215,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1449,   51,  588,    1,   45,  453,  613,   50,  159,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3300,    1,  978,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3355,    1,   38,   45, 3184,   12,    1,  191,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,    7,   37,    1, 3228,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  535, 2363,   98,  166, 1314,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,    1,    9,    1, 2528, 2146,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  647, 1913, 1843,   15,  688,    1,  187,  102,   71,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  879,  693,    9,  647,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  458,   45,  942, 2249,    1,    1, 1558,    1, 1231,  220, 2607,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  539,  455,    1, 1372,   37,   52,    1,    1, 2104,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  487,  883,  568,  338,    9,   72,    1,  339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  732,  851, 2270,   37, 1054,  176,    1, 1325,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2077,  315,   37,  791,    4,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,    1,    1,  211, 3069,  531,  630,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,  338,   37,    1, 1547,   98,    1,  191,   89,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2026,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  566,   48,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  967, 2181,  366,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  759,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1398,  612,    1,  166, 1417, 1357,   37, 3169,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   37, 1075, 1602,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1304,    1,   80, 2702,   37,  365,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  878,    1, 1713,   43,  149,  444, 2208,  441,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  733,    1,  159,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,    1,    9,  365, 1385,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2243, 1935,    1,  220, 2627,    1, 1208,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3066, 2363,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1, 1173,  176,  166,  112,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3188,    1, 2925, 2078,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  799,    1,    1,   98,  454,   37,  584,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2490,    1, 2325,    1,  544,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  810, 1425,  671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  137,  686,  191,  927, 1665,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3297,   61,  729, 1762,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  582,  539,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2140,  622, 2809,    1,    1, 1010,  926,  287,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1282, 1674, 2677,  203,  190,    1,  544,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1227, 2995,  162, 2148,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  267,  204, 1360,  612, 2192,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2190,    1,  109, 1464,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  171,    1,  590,    1, 3100,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  396,    1,  384,  647,  253,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2289,   12,    1,   32, 1820,    9, 1990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  598,  202,    1, 2827,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  266,  267,  460,  315,   37,  142,    9,  810,   45,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,  476,  104,   37,    1,    1,  806,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3333, 1396, 2179,  856, 1411,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2073,  202, 1745,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428, 2141, 3397, 1082, 1861,   37,  877,  517,  544,  388,    9,\n",
      "         2170,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1319, 1726, 1248,  365, 1705,   98,  442,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3102,  396, 2449,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1450, 3391, 2751,    1, 1527, 3150,   98,  221,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  422,    1,  612, 1584, 1469,  168, 1176, 1533,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2839,   37,  489, 2924,  384,  531,  191,  439,   45,  750, 1190,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1184, 1500,   37,  856,   31,    1,  166,   65,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  614,   98,  187,  971,  389,  125,   46, 1174,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  166, 2162,   45,  668, 2671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,   82,   45,  647,  267,  204,    1,   37, 1721,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2676,    1,    1,    1,  220,   14, 2325,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1529,    1,    1,    1,   32,    1,    1,  582,  463,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018,  868, 2856, 3094,   27, 3343, 2735,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  954, 1071,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1700, 3386,    1,  514,   45,  312, 2938,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2382,  259, 1991,   37, 2155,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2924,   37,  531,   51,   52,  125,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2427,  267,    1,   12,  211,   32,    1, 2147, 2950, 3109,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  649, 1465, 2948, 1479,  610,    9,  116, 2931,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,  786,  356,   24,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  120,   98,  626,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  861,  280,    1,   37, 2429,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1090,  297,    9, 3169,  361, 3274,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1, 2144,    1,    1,    1,  437,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  565,  288,   37,   26,  417,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1412,    1, 1465, 2876,    1,  739,    1, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1527, 2664,   12,    1, 2040,   45,  949,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123, 2415, 1332,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3362, 1484,    9,    1,   32, 3349,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   85,  419,   98,  163,    1,   12,    1,  927,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  590,    1, 2523,  782,    1,   32,  247,    1, 2482,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 2962,  405, 3291,    1,   32, 1394,  187, 2748,  140,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  294, 2161,  726,    1,  671, 1608, 1173, 2500,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1527,   37, 3349, 1428,    1,  388, 2924,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2874,   45,  166,   29,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1707,  142,    9,   13,   45,  183, 2068,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  848, 2384, 1427,    1, 1935,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  832, 1750,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1186,   12,  625,  884,    1, 2505,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1, 2720, 2796,    1, 2799,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1335,    9,  949,   45, 1056, 2476,    1, 3347, 2827, 3102,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141,    1,    1,  228,  356,   24,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  453,    1, 2899,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,  778,  294, 3102, 2572,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  287,  408, 2302,  624,  388,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,    1,   12, 3126,  920,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  198, 2571,  474,   23,  110,   32, 3118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1346,    1,  132,    9, 1390,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  694,    1, 1953,   61,  105,    1, 1343,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  954,    1,   37, 1636,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  619, 1542,    9,  906,  103, 3048, 2923,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275,    1, 2021,  440,  187,    1,   37,  631,  443,\n",
      "         1705, 2295, 2302,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  190,   77, 1796,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  207, 1704,  853, 1705,   37,   52,    1,   79,  191,    1,  844,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1013, 1522,    1, 1381,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,    1, 2270,  333,   45,   49,  886,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2800, 3213,   12,    1,   98,  166,   81,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 1965, 2982, 1000,  388,  459,   45,  238,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3369,    1,   37,   97,    1, 2794, 2117,   37,    1,  947,   32,\n",
      "         3118,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2490,   98,    1,  444, 2527,  164,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,  566,    1,   45, 2271,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,  688,  978, 3138,   37, 1334, 1675,  115,   45,  273,   32,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2838,    1,    1,  184,    1,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1360,  612,  877,  218, 1488,    1, 1367,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2193, 3362, 1314,   96, 2970,   32, 3349,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  620,    1, 2098,   39,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  872,  758,  361, 1790,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  125,    4,    1,  335,   44,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  140, 2762, 1976,   32,  829, 2232, 1228,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2279,   32,  198, 2027,   37,  726,    1,  186,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  311,  733,   59,    1,   32,  449, 1034,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  531,  729, 1176, 2342,    9,  632,  681,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  961, 1482,  458,   45, 2206, 2435,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2288,    1,    1,  729,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  581,    1,  220, 2541,   32,    1,  756,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1874,  949,   45,    1, 1682,   32, 1081,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  300,  861,  328,   37,  754, 2261,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,   45,  166,  617, 2403,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3243,  162,  501, 1125,    9, 3222, 1411,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942, 1566, 2109,   98, 1649,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  864,  267,  190, 2192,  751,   98, 2673,  132, 1371,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,  418,    1,   98,    1,  102,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3300,  913,    1,  683,   98, 2347, 1638,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1,  361,    1,  105, 1568,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3147, 3148,    1,   98,  776,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  392,  346,   93, 1347,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    4,  218, 1631,   39,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   37, 1403,  166, 2641,   37,  334,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  279,    1,  272,   11, 1056,  861,  441,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 2668, 1619, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  348,  156, 1124,    1, 1146,  332,  636,  338,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1079, 3063,  794, 2355, 1013, 2549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1050,    1, 1924,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  439,   45,  166, 2041,   61,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  773,  619,    1,    9, 1604, 1160,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1935,    1, 1294, 2070,  822, 1523,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,   37, 1021, 2973, 1764,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  931, 1173,    9,  449,  726,   32,  593, 2522,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,  636,  948,    9, 1524,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2528,    1,    1,    1,    1,  168,  613,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  585,    1,   28,  105,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2885,  884, 1003,  176,    1,    1,   74,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  166,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2560,    1,    1,    9, 1209,    1, 2802,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868, 1921,   32, 1094,   32,  645,  973,    9, 2024,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2107,  444,  199,    9, 1147,  890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3286,   30, 2885,  166, 2009,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1190, 1454, 1314,  484,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3276,   26,  220,  726,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1920, 2356,   32, 2701, 2772,  722,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  106,  936,    1,  331,    1,  399,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  619, 1994, 2086,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118, 2543, 2396,  313,   37,    1,   79, 1428,  909,  220, 2571,\n",
      "         2389,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2768,  193,  439,    1, 1444,  254,    1,    1,  774, 2700,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   22,  847,   37,  125,    1,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1925, 1583,  580,  629,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1107,  293,    1,  191,  147,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  374,    1,   12,  552,    1,  329,  810,   85,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3367, 2576, 1442,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  232,    1, 1713,  730, 1571,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2881,   98, 1718,    1, 1370,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  541, 1910,   98,  199,  176,  477,  686,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3292,   12, 3021, 1558,  548, 3185, 1463,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 3369, 1414,    1, 3396,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  489,   39,   45, 2197, 3329,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1845,  132,   32, 1895,  787,  477,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1484,    9,    1,    1,    9, 2846,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3161, 1774,   28, 2277,   98, 2570,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3220,    1,   12,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 2850,   28,  187,  510,  640,  163,    1,   12,    1,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1585,  176,    1, 1097,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   95,  161,  261,  529,  241,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1783, 1666,   72,  401,  949,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1435, 1307,   37, 1539,  297,    1,    1, 1411,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2805,    1,    1,   12,    1, 2641,   37,   52,  665,   98,  224,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2045,    1,  506, 1458, 1400,   69, 1013,  914,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  963,    1, 1492,    1,   98, 2692,  321,  612,  713,   37,  168,\n",
      "          111,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1, 1073,   39,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,  775,    1, 1108,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,   37,  588,  413, 1384,   12, 1527,   98, 3339,  469,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1017, 1825,  596,    1, 2884,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1399,   45,  227, 1215,  361, 1628,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1465,    1,  844,  170,  891,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2065,    1,    9,  873,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,  884,   98,  450,  808,   32,    1,  863, 2465,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1425,  166,    1, 1352,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  477,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  694, 1293,   32,  472,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2018,   12,    1,    1,    1, 1364, 1365,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 2371,  775,   37,  198,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,  344, 3403, 2414,  547, 1940,   45,  938, 1075,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999,   91,    1,  198,    1,   32, 2819,  443,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,   37,    1, 2108,    1,    1, 1403, 3391,   37,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,   37, 2192, 2017, 1994, 2693, 1228,   37,  893,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  872, 1118,    1,   37,    1,  548, 2162, 1665,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  503, 1505, 2657,  956,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1536,    9,  467,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1019,    1,    1, 1046,    1, 2952,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1889, 1397,  688,  739,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1306, 1022,    1, 3220,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1427,  477, 1380, 2427,   98,  103,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548, 2733,    1,    1,  162,  460,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,  387,  777,    1,    1,    1,   32,  365,  675,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1029,  155,    5,   98, 1407,   69,  441,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3394, 3060, 2572,   32, 2018, 2625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,   81,   32,  522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  103,    1,    1, 2257,   39,   32, 1742,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1,    1,  636,  423,    9,  920,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2617,  186,  297, 1887,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2427, 1348,   37,  184,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1481,  267, 1698,  333,   45,  711,  424, 2113, 2385,  612,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739,  193, 2947, 2309,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 1523,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1883,  325,    1,    1,    1,    1, 2454,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3282,    1, 2503, 3230,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  105,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1117, 1943,   15,   71,   32,  581,  401,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  333,   32,  166,    1,  187,    1,  953,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1645,    1,   37,   52,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 2924, 2856, 3006,   27, 3343, 2735,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,  315,  228,   74,    1, 1821, 2699,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510,    1, 2433, 2028,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  236,  237,   37, 1285,   28,  187,   69,  636,  953,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  511,  171,    1,    1,  105,  356,  411,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  296, 1867,   32,   95, 1273,  618,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671,  640,  356,  845,   98,    1,   45,  104,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  709, 1361,    1,  291,  494,    1, 1222, 1597, 3004,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878,    1,   51, 1281, 2244,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1191,    1,    1,   37, 1776,  956,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3263, 1281, 1056,  384,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   67,  133, 1018,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1013,    1,  361,    1, 1116,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   57,    9,  104,    1, 2338,   32, 1352,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  605,  437,  108,   45,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3184,    1, 3390,   32,  105,    1, 1009,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  251, 2264,  822, 1942,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1458,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1304,   27,  422,  132,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,   37,    1,  111,  748,  675,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3092,  877,  411,  698,   37, 3306,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1260,   98,    1, 2791,   32,    1,    1, 2572,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  376,  156,  570,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2192,    1,  105,  271,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,  741,  411, 3355,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1656,    1, 1825,  778, 1225,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2206, 2989, 1810, 1509, 1675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2572,   32,  947, 3246,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1564,    1, 2709,   32,  537,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018, 1760,    1,  548, 1656, 2596, 2414,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  938,    9,  449,  199,   32, 2218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   50,    1,  531, 2699,    1,  622,  267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2642,    1,    1,   12,   24,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,  193,    1,  642,  643, 1091,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 1485, 2161, 1810,   56, 1527, 1149, 3047,   32, 2597,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  503,  580, 1665,   45,   54,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2758,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,  765,  699,  548,  883,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3140,   12,  808,    1,  191, 1327,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  743,   12, 1690,  525,   15, 1672,    1,  419,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  912,    1, 2762,   32, 2994,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,   12, 1619,  458,  155, 1184,   67,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942, 1908,    1,   98,    1,  735,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  282,    1,    1,    1,    1, 1824,  361,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2820,   12,  183, 2050,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1081,  958, 1056, 2161, 2644, 3102,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,    1, 1896,   37, 2341, 3365,  949,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3226,  405, 3291,  571,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,    1, 1434,    1,    1,  829, 2194,  275,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  460,  389,   93,   37, 1121,    9, 1694,   45,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1116, 2896,    1,    1,  928,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  37,   1,   1, 877, 460, 449,   1,  32, 673,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 2842,   45,    1,    1,    1,   32, 1741,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3043, 2710, 3045, 2856,  249,   32, 1260,   27,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3253,   81,   37, 2315, 1262,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  811, 1564, 2333, 2784,   37,  976,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2971,    1,  321,    1,  166,  932,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,   12,  450, 1601,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  758, 1243, 2355, 1013,  315, 1079, 3063,  551, 1106, 1539,  424,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2002,    1, 2357,  686, 1633,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  197,  388,  763,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,  105, 3154, 1884,  713,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  527,  573,    1,  952,   59,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2769,  729, 2567, 2463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1783,  104,  358,  467,   37,  125,  156,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1353,  192, 1085,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1116,   32,    1, 2384,  365,   40, 1917,   32,   91,  361,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  750, 2744,  857,    9, 2206, 2207,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2192,  166,    1, 1084,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1,  191, 1855,    1,  625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  460,   12, 1133,   37,    1, 2643, 3079,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  267,  782,    1,   79,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2752, 2751, 1260,    1, 1633,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1, 2018,  498,   37,    1, 2024,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1920,   32,  451, 1867, 1894,    9, 2527,  164,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  163, 1594,  297, 1234, 1107, 1536,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2162, 1950,  384, 1094,   12, 3339, 2731,  418,   37,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786, 1567, 2398,    9, 1545,    1, 3181,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  288,   37, 1421, 1645,  593, 1990,  855,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779,    1,    1, 1758,   37,    1, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,  37, 125,   1,   4,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 422,   1, 412, 469,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1364, 1365, 2035,  631,   37, 2202,  444, 2018,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  491,    1,    1,    1,   47,  493,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,  199,   45, 1031,    9, 1149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1610,    1, 3126,  916,    9, 2942,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3185, 1655,  686,  119,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  382, 3145,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2425, 1270, 1660,  737,  983,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1269,   98,  160,  174,  420,  550,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2770,  597, 2774,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178, 1061,   32,  215, 2734, 2162, 2215,  927,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1191,    1,  500,  123,   37,  116,  668,  132,  420,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2298,  384,    1,  357,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,  142,   76,   37,  619,  413, 1876,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   12,  327,  112,   28,    9,  333,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3367,  863,  967, 1875, 2911,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,  794,  365,    1,    1, 1867, 2355, 1013,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,  321, 1389,  926,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,    1, 1085,    1,    1,  260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2473,   36,  459,    1,   24,  220,  355,    1,    1,  468,   45,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1107,    1,  565,  707,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1054,   45,    1,  313,   37,   52,  845,  275, 1568,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683, 2145,   37,  138,   81, 3103,    1,   59,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  193,    1,  600,  552,  552,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  114, 2986, 1399,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,   98, 1171,   37, 1964,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305, 1267,  186,  528,   31,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,    1,   45,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700, 1841,  893,    1,   32, 2835,  297, 1887,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2689, 1717,    1, 1045, 1086,  176,  140,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1273, 2255,    1,   98, 1978,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1221,   12, 1298,    1,   37, 3237,  484,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123,    1,  817,   32,   98, 2858,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  186,   98, 1128,   12,  157,    1,   69,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  572,  197,  338,   98,  887,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2959,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3359, 1484,    9, 1437,   45, 1583,   12, 3339, 2625,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  597, 1304, 1213,  213,   37, 1335,  514,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3196, 2405,  461, 1918,  176,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3151,  590, 2701,  922,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 3080,  820,  384,  163,    1,   12,    1, 1967,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  197,    1,   15,   71,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  921,   98,    1,  531, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  197,   28,    1,  852, 1114,  176,  845,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968,    1,  967,  638,    1,    9,  594,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1691, 3160, 3358,   61,  415,    1, 2017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   45,  531,    1,  863,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  303,  108,    1,  305,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1978, 1159,  455, 2220,  218,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2851,  105, 1822,  220, 2580,  815,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1755,  418,  187, 1187, 1950,   32,    1,    1,  361,    1,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1720,  105, 1089, 1090, 2151, 1997, 2181,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2685, 1937, 1851,  166,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3276,    1,  484,   37, 1421, 2761,    1,  967, 1621, 1467,   79,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2733,  580, 2086,  134,   32,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2708, 3352, 1211, 1072, 1235, 3340,   32, 3339, 2831,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 2515, 1901,   37, 2728, 1387, 1890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  160,  636, 1279,  387,  385,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2917, 2354, 1297, 2685,    1, 1110,   32, 1194,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1298, 1647,   98,   86,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  650,  140,  581, 2113,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1967,    1,  187, 3157, 2905,   37,  741,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2008,    1,   12,  791,   37,   91,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  200, 1626, 1106, 1013,  778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,    1, 2226, 1360,  612,  319,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1281, 1559,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  159,  756, 1039, 2690,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  116, 1085,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2828,  726, 2198,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  733,   79,    1, 1499,   50,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  142,   37,    1,  104, 1020,  195,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  593,   12,    1,    1,    1,    1, 2885,   61,  166, 3258,   12,\n",
      "           59, 1178,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  342, 1164,  498,  864, 2390, 3146,\n",
      "         3399,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,   42, 1350,  400,  220,  355,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,   98,  166,  222,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3369,  261,   39,  943,   45, 2571, 2924,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1583,    1, 2144, 2705,   32,  622,    1,   32, 3360,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2677, 1327,    1,    1,  885,  593, 1990,  670,   28,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1433,    1,    1,  168, 2401,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2308,  240,  922,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 1228,  126,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2890, 2826, 1251,    1,   54,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2427,    1,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   68,   70,  186,  297,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1558,  187, 1957,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   93, 1258,  528,   69,  636,  423,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3358,    1, 3375,    1,  247, 2494,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962,  375, 1401, 3209, 1415,   37, 1131, 1684,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2028, 1679,  885, 1156,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1796,  947,    1,   51,   52, 1370,   45,  777, 1259,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  975,   37, 2123,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  103, 2635,    1, 1654,  176, 1311,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   37,  138,    1,  131,   37,  130,  647,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   61, 3294,    1,   32,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2710, 3382,   32,  447,   37, 1937, 3358,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1092,  476,    1, 1530,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  300,  453,    1,   37,   36,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  818,  550,    1,   14,  159,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,    1, 1740,    9, 2992,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  857, 2460,   51,   92, 3280,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,  619,  885, 1333,  176,   24,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 2760,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1, 2018, 2153,    1,  365, 2240,   32, 2471,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1031,   45,    1,  176,  647,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,  681, 1937,  410,  932,   32,  486,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,  879,    1,  693,    9,  647,  636,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,    1, 1056,    1,    1,    1,    1,    1,    1, 1176, 1744,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1796,  360,  822,    1,   45,    1,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  879, 2665,  809,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  561,  794,  365, 2731,  444,  116, 2502,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  742,   12,    1,  221,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,  515,  647,  253,  388,  199,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,  361,  854,   37, 1421, 1211,  442, 1259,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  196, 2652,  887,   45,  176,  612,  613,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  119,    9,  466,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  253,  665,  654,  721,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1424,   32,   93, 2032, 2491, 1034,    9,  166,   94, 2060,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2495,   37,    1, 1425,  316,  705,    1, 1417,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2823,    1,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  831,  548,   74,  832,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,  794,  517,   32,  215,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2789,  891,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,   25,  554,  187,  615,    1,   10,   12, 1445,  863,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2942, 3062, 1524,  671,    1, 1909, 3126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2906, 1635,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  577,  548,  403, 1447,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3033,  190, 2286,   37, 2324, 1821, 2190,   22,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   52,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2523,   81,   32,    1, 1569,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  680,   97,  115,   45,    4,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  378,    1,  193,  415,    1,    1,  254,   32, 2826, 1381,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118, 3396, 2301,   32,    1, 2198,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1642,  166,    1,  951,    1, 3169,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 2984, 1521,    1, 2918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1631, 2481,  176, 1687, 1022,    1, 3008,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1007,    1, 2962,    1,  919, 3117,  297,  166, 3260,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  613, 1182, 1508,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2596, 1665,  155,  861,  122,    1,  167,  288, 1628,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  754,   15, 1473,    1,  118,   32,  367,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  447, 1401, 2468,   32,   65, 1990, 3295,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 3032,  639,  794, 2678,   98,  864,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,   14,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884, 3190,  389,    1,  220,    1,  562,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  179,   37,  125,    4,    1,    1, 1541,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1334,  220, 3233,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  686,    1,  528, 1313,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  300,  993,  302,   37,  299,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  320,  583,  191, 2836,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3167,  190, 1140, 1593,    9, 1218,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  158,    1,   98,  225,  469, 1031,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  163,    1,   12,    1,  894,  606,    1, 3361,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  938,  765,   37,    1,  941,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160, 1278,   28,    1,  118,   32,  871,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1487, 1275,    1, 1690,  525,   15,   28,  419,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,    1,  674,  675,  321,  194,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  612, 1273, 1310,    1,   32,   91,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    6,  570,    1,  225,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  947,  973,    9,    1,  278,   98,   17,  259,    1,  116, 1879,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   71,  329,    1,   12,  552,  176,  339, 1653,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   79,   37,  365,    1,    1,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   12,  446,  267, 2343,    1,    1,    1,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3087,   32,  455, 2414,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   41, 2250,   81,   37,   36, 2242,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1861, 1310,   37,    1,  531,    1,   32,   91,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1037,    1,    1,    1,  977,   37,  764, 1344,  365,  326,    4,\n",
      "         2928,    1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777, 1635, 1361,    1,   37,  289,   98, 2355, 1560,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,  996,   93, 1044,  128,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  733,   56,  493,  725,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3167, 1118,  741,   37,  221, 3251,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1737, 1722, 1944,   45,  579,  719, 1336,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1074,   37,  123,  191,  465, 1657,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   12,   18,   81, 1421,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   51,    1, 2104,  297, 3153,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  487, 3397,    9,  464, 1585,  778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2676, 2007,   37,    1, 1159, 2275,   32, 1819,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3020, 1532, 2990, 2472,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2569, 1533,  917,  650,    1,   85,  947,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  167,    1, 2982,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2004,  829,    1,  220, 1643,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2605,  184, 2305, 1477, 1990,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,  829,   37,    1,  388, 1346,   32,  854,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2047, 3181, 1805, 2872,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,    1,    1,    1,    1, 2171, 1699,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  542, 1210,  388,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1861,    1,   37, 2033,  548, 2596,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1230,  361,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 199,  39,   9,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  49, 924,  12,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  195,  932,    1, 3021,   61, 2317,  191,  247, 2193,  872,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  863, 1555, 1090, 1258,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2049,    1,  365,    1,  195,    1,   32,    1,  506,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2612,  593, 1659, 1222,    9, 1609, 1116,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 1542,   37, 1642,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,    1,   32,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,  271,    9,  615,  417, 1469,   98, 1279, 2575,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843,  140,  361,    1, 2753,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2857,    1,    1,   39,    9,  547,  257,  548, 1857,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  632, 2640, 1445,    1,    1,  176, 1821, 2190,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1701, 1753,  116, 1662, 2633,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3140, 1542,    9,   46,  220, 1094, 2198, 2915,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2152,    1,  501, 1805,   45,    1, 2165,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1702,   98,    1,  220,  148,    1,  440, 2264, 1900,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1666, 1300, 1996,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035,  146,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  917,  920,    1,  460,   12,  193,  227,   37,   52,  166, 2959,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   11,   81,  612,  111,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  403,    1,   37,   47,    1, 1084,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175,  656,    1,    1, 3265,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3190,   12,   10,   37,  698,  176,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2275,    1,    1,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2548,  726,  917,   37,  487,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,    1, 1128,    1,  657,    1,  361, 2278, 1413,   37, 1835,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2838, 1421,    1,   37,  786,  356,  132,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  976, 3109, 1791, 2764, 3394,  893,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1854, 2489,  220, 2171,    1, 2880,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2213,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  197,  418,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,    1, 2094,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1442,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1663,    1, 2135, 1518,  531,  285,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1632,  105, 2210,  914,  105,    1, 2146,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   26,  417,  657,    1,   69,   25,   85,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2528,   45,  596, 2691, 1388,    9,  987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178,  162, 1204,    1,    9,  552,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1078,    1,  389,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12,  957,  582,   37, 1253, 2728,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2869,    1, 1719, 1021,   32, 1658,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1930,    1, 3378,  776,    9,  339,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,   51,  720,  453,  647,  142,  417,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123,   12,  221,   37, 1122,  288,   28,  191, 2929,  132, 2928,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,   37, 1406,   32, 1081,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  232, 1082,    1,    9, 3118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1557,  650, 1082, 2517,   97,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,  260,   28,    9,    1,  164, 1593,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1181,  623,  200,  593,   12, 1637, 3146, 1151,    9,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  166, 3226, 3263, 2811,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  116, 2542,    1,   37,  365,  218,  332,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2557,    1,    1,  176,    1,  275, 1929,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  514,   32, 1833,   12,  449,    1, 2819,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2531,  379, 1174,   46,   98, 2673,    1,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1542,   37, 2394,  105,  402,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,    1,  715,  954,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   33, 1658,    1, 1323,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2864, 1194,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2420,  384, 1970,   12,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1647,   32,  104,  358,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,  953,  548,  303,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422, 1458,  225,  218,  261,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1572, 1414,    1, 2029, 1619, 3391,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3256, 1674, 3116,    1,    1, 1798,    1,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  305, 2482,  417,  187,   10,  113,  166,  631,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1676,    1,  487,  947,  271, 2189, 1228, 1551,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2214,    1, 2827,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1, 1481,   98, 1445,  863,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  361,   91, 1980,   37, 1814, 2096,   98,\n",
      "          644, 1859,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171, 1535,  861,  655, 2572,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2028, 1419,  176,  177,   56,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,  894,   52,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1815,  166,  873,   61,   81,   32,    1,  147,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  224,    1,   72, 2789, 3034,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  302,    1, 2609,    1,   45, 1186,   12,  730,  259,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2184,    1,  140,   72,  553,    1,   32,  963, 2218,  361, 2437,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1712,    1,  191, 1718,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1313,  205,   32, 2890,    9, 2868,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1123,   37, 2286,   37,    1, 3251,  221,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  461,   32,  984,   98, 1251,  672,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1864,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3200,    1,    1,   32, 1600,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2962, 3175,    1, 3256,   37,   27, 3220,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,   91,    1,  562,  864,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  506, 2471,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3184, 1557,  650, 2356,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2426,    1, 3356,   12, 1876,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2734, 2134,  111,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3178,    1, 2540,    1,  176,   26,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3079, 1152,   45,    1, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  494,  577,   98,  460, 1278,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  346,  347,    1,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  822, 1469, 1289,   37, 1902,  900,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  334, 1719, 1366,  321,    1,   17,  361,    1, 1001,   85,  105,\n",
      "            1,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  550,    1,    1,    1,  334, 1445,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 1922,  569,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1599, 1771,  171,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878, 2213, 2321,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  550, 1778, 1901,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,    1, 1167, 2580, 2264,    1, 1108, 1779,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,  37, 151,   1, 669,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  39,   9, 166, 914,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,   56,  356,  881, 1632,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2658,  859,   37,  804,  381,  220, 1018,  368,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  442,  448,  490,    1, 1290,  396,   28,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3155,   46,  271,   85,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1795,  197,  407,   98,  460,    1,  880, 1220,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993, 2994,  460,   61,  829,  951,    1,  111, 1659,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  104, 2161,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106,   12, 2610, 1108,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2106,   12, 1178,  140,    1,  411,  932,   32, 3367,   16,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  463, 2571,   46,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  100,    1,   33,    1,  199,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,  159,  670,  548, 1585,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1403, 2226, 2969,   37,   91,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,    1,  302, 1963, 2745,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1711,    1,  191, 3279,   32,  404, 3114, 1428,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  669,  829,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2321,    1, 2719,  943,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 1739,    1,  403, 1739,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 3369,  213,   37,  226,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  259,  437,  582,  939,  548,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1414, 1539, 1995,   98, 1147, 2751,   32,\n",
      "         3383,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,    1,    1, 2810,    9,    1,    1, 1090,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1962,   37,  109,  572, 1294,   37,  196,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,  986,  331,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  947, 1816,    1,   45,  103, 2985,   32, 3379, 1585,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1034,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 2604, 1294,   12,    1,    1,   61,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1364, 1365, 1648,   37,  693,  388, 1876,   37, 2046, 2024, 1896,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2628,  952,  562,   37,  151,  164, 1593,  384, 1407, 2616,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1533,  384,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  512,    1, 2317,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1411,  221,   32,  166, 1778,  951,    1, 1718, 1523,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,  176, 2890, 1675,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  154, 1947,  221,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  503,  167, 1673,  384,  749, 2039,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2452,  517,  614,  548,  166, 1230,  288,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  244,   71,    1,  155,  157,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   69,  102,   71, 1010, 1622,  509,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  491,  200,  182,   32,  315,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178, 3348, 3382,    1,  396,    1,  115,   45, 2095,  776,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2206,    1,  171,    1, 2922,  288,    1,  119,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  716,   59,   32,    1,    1,    9,   72,  401,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  886,   12,  365, 1151,  313,  760,  617,  618,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2171,  745,  469,  190,  504,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,  544,  357, 2844,  698,   32, 1090,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  475, 1213,   12,    1,    9,   93,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  987,   98, 1994, 2650,  700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  146,   37,  403, 1447,   37,  168,  115,  220, 2673,   46,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2615,  631, 3216,   32, 1090,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614, 1025,  693, 1451,   24,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  691, 2393,   98, 1081, 1260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  559,   37,    1,  726,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  245,   98, 1256,    1,  552,    1,  485, 1948,  361,   69,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2701,  922,  315,   37,  168,   98,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,  632,  655, 1710,    1,   32,  166,    1,   45,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3187,  920,    1, 1684,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,  134, 1954,  548, 3134, 2811,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2677, 3232,  951,    1, 3260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2682,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   69,  640,   98,  430,  109,  997,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  169,    1,  702, 2123,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  644,  686,    1,   32, 2646,  187,    1,\n",
      "           27, 3346,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  547,  487, 2548, 2572,   32,  531,  344, 1260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1484,    9,  531, 1002,  211,  529,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  934, 1707, 3042,  161,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98, 3285, 1959, 2489, 1488,    1,  202,  729,    1,   39,\n",
      "          140,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  864,  267,  460,  967,    1,  493,    9, 2673, 3366,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,  225,  616,  242,   32,  411,  802,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,  971,   37, 1835, 1736, 1975,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 2694,    1,   98,  777,  552,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3268,   37,  930,  678,    1,   12,  590,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2748,    1,  590,    1,  584,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1819,   98,  166,  116, 2126,    1,    1, 1592,  774,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  361, 2028, 1421,  442,  802,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1147, 3125,   37, 1211,  104, 3091,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938,  422,   32,  149,  951,    1,  941, 1663,  597,   82,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 442,  29,  16, 885, 119, 448,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  39,  45, 460,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  203,  501,  565,  215,    1,  605,  315,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,    1, 1189,  379,   37, 2000, 2673, 1816,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3115,  247,  454, 1159,    1,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  374,  375,   37,  151,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3397,    1,   45, 1994, 1645,    1,   32, 1094,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  365,  617, 1151,   37, 1021, 2979,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  187,  584,    1,    9, 2073,  183,   64,    1,  166,   95,  891,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1268,  822,  856,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3129,    1,    1, 2226,  331, 1284, 1488,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303,  954,    1,  284,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359,  267, 1542,   37,    1,  220,  365, 2708,  650,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192, 3192,  691, 1408,    1,    1,  297,  854,  844,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  548,  284,    1,  270,    1,    1,  967, 1479,  595,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1469,    9,  157,  412,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2800,  411,  400,   45,    1, 1080,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  750, 2104, 2744,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  312, 1149, 3047,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2485, 1380,    1,   98,  793,  590, 2354, 1638,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3064,    1, 3230, 2963,   32, 1674, 3282,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  539, 1401,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1739,    1,  566, 2696,   12, 2107,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,   37, 2460,   79,  593, 1990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2844,   32, 1260,   98,  104, 3150,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1992,   37,  531,    1, 2321,    1,  163,    1,   12,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   80,    1,   32, 1051,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,  725,    1,    1,  402,    1, 1956,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3407, 3357,    1,  698,    1,   32, 2375,   32, 2597,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3003,  546,  365, 1385,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   60, 1564,  682,  444,   94,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2238, 1749,  220,  848,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2676,    1, 2343, 2582,  590,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  350,    1,    1, 1599,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  187,  449,  736,  431,    1, 1443,  588,   37, 1403,  531, 1159,\n",
      "          289,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2746,  311, 2537,  163,    1,   12,    1,  550,  593,  420,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  680,   97,  176, 3313,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3371,  140,  191,  863,    1,  920, 1065, 1190,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  632, 2224, 1458, 1259,   98,  651, 1031,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   94,  654,  253,   81, 1633, 1124,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,    1,  463, 2170, 1758,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,   12,    1, 1921,   32,  976,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2024,    1, 2917,   98,  463, 2490,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232, 1717,    1,  105, 1178,    9,  810,    1,    1,    1,  245,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   24, 1624,    9,    1,  927,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3245,   76,   37, 1343,  388,    9, 2307,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1082, 1094,   37,    1,  454,    9, 2708,\n",
      "          741,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   26, 1039, 1900, 1587,   45, 3042,  161,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  698,   37,    1,  863,  155,    1,   32,    1,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  694,   12, 1567,  619,   81,   98, 1171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  136,  256,    1,   55,    1, 1402,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2603,    1, 1357,   45,  166,  356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3322,  153,    1, 1600,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,   37, 1539, 1622,  793,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3375,    1, 3101, 2572,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3373,   32,  581,  632,  880,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  220,   69,  102,   28,    1,  460,  167,   52,  105, 1183,  889,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  200,  241,  160,  623,  280,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1232, 1223,  991,   39,    1,  460, 1822,   52,    1,  914,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,    1,    1, 2468,   12,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  328, 1883,   37,  151, 1117, 1525,    1,  669,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  933, 2642,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32, 2206,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  515,   26, 1039,  166,  168,  115,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1191,    1,  361, 1542,   37,  168,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  202,  284,    1,  596, 1793,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1749,    9,  845,  846,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  621,   37,  877,  142,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,  321, 2000,  881,   45, 3366, 2836,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2136,  614,  384, 2491,   37,  449,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  864,  251, 2673,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  994,    1,  150,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2743,    1,   37, 2579,  455,    9,  449,  199,  220,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2528, 1128,   12,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  766,  140, 1876,    9, 3016, 1935,  384, 1662, 1701,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,   74,  320,  445,   98,  166,  260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1757, 1552,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2547,   37, 1539, 2977, 2328,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1585,    1, 1056,  537, 2248,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843,  603,    9,  247,  449,  726,   32,  455,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   55,    1, 2775,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1778,    1, 1876,   37,   18,  176,  636,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3129, 2523, 3325,  193, 2494,  872,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 2239, 2166,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 2911,  707,  111,    9,  550,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,  267, 1327,   12, 1428, 1058,  190,  583,   91,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2415, 2922,    1,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  438, 2122,    1,  952,    1,    1, 1074, 1244,   37, 1192,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2466,    1, 1450,  187, 1209, 1268,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  515, 3175,  105, 1198,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  639,  952, 1203,   45,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004, 1968,  292,   40,  220, 1766, 1767,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  777, 2264,    1,   37,  207,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3279,   63,    1,   12, 2237,   37,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1106,  779,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3352,    1, 3192, 2671,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   85, 1114,    9, 1834, 3209,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  959, 1762,  163,    1,   12,    1,  140,    1,  671,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1317,  704,  104, 2659,   37, 1334,    1,   32,  821,  112,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,   10,    1, 2275,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  794, 1377,  444,  342, 1994, 2143,  695,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1597,  681,    1,   28,   37,   26, 1039,    1,  202, 1574, 2449,\n",
      "         1379,   12,  112,  499,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2956,  991,  454,    9, 1273,    1,  389, 3017,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384,  914,    1,  361, 1090,    1,   37,    1,    1, 3228,  361,\n",
      "         1497,  565, 2954,   37,  688,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3096,    1, 1554, 3176,  105,   19,  841,  187, 3316, 1774,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  954,    1,  191,  119,  845,   69,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  446,  859,  121,  190,  907,   69,  569,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   27, 1684,  548,  183, 2457,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   10, 2275,    1,  190,  583,  954,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181,   12,    1,    1,  191, 1461,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  801,   37,  163,    1,   12,    1,   26, 3295,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  872,   12, 1280,    1,    1,  361,    1,  247,  454,   37,\n",
      "          105, 1383,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1268,   32,    1,  400,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3231,    1,    1,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   20,  361,  296, 1388,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,  636,  490,  608,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   78, 1822,  125,   22, 2150,  191,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790,    8,    1,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1711, 1827,    1,  191,   64, 1046, 2053,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2580, 2851,  515,    1,   37, 1605,   37, 1718, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  311,  664, 1737,   98, 3316,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 1877,   37, 1334,   32,  531,  548, 3102, 3395,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  461,   12, 1509,  914,    1,  267, 3196,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  364,  884,  180, 1990, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  632, 3102, 1223,    1,    1, 1755,  176,  964,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  936, 2979, 2869,  636,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1308, 2942, 1333,  176,    1,  813,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1716,    1,  988, 2759,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3260,  631, 3209,    1, 1632,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1,  267,  105,   65, 1009,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   98, 1965,    1,  590, 1204, 1724,    1,  202, 1744,  978,    1,\n",
      "           45, 2162,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390, 1737, 2640,  587,  498,   37,    6,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  842,  159,  245,   98,  104,  195, 1641,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303,    1,    9,   60,  190,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  228, 2572,   32, 2764, 2765,    1,   32, 3376,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,  928,  176,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  111,    1,    1, 1117, 1943,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  835,  647,   32,    1,  182,  132,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1444, 1398,  612,  606,  105, 1357,    9,  460,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  794,  327, 2177, 1027, 1013, 2549,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1654,  722,   32,    1, 2607,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2871, 1971, 3252,    1, 1240,   52,   39,    9,  914,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1116,   32,    1,  572,  197, 1137,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2421,   39,   45,  186,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  528,    1,  802,    1,  803,    1,  804,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  600, 1340,    1,  754, 1844,  119,    1,  193,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2994,   32,  166, 2884,    9, 1146, 1703,   45,  166, 2995,  218,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190,  424,  214,  469, 1594, 1159,  671,    1,  166, 1868, 1172,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3144,  446, 2682,    1,   12, 2484, 2282,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1,  193, 1724, 1542,   37, 1413,   94,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3241,  688, 2463,   37,  439, 1826,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   37,  138,   59,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1023, 1204,  820,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  961,    5,  639,  967, 1711,   32,    1,  127,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428, 3160, 2347,   32, 1388,  220, 3362,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984,  884,  449,  123, 1680,   45, 2820,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 1236, 1791, 1228, 2633,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1869, 2757, 2094,    1,   37,  166,   16,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  251, 1251,    1,    1,    1, 2759,    9,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  958,  121, 1542,    9,  365, 2024,   46,  220,  455,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2308,    1,   37,  606,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3108,    1,   37,  698, 1090,   98, 1139, 1694,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,  267,  190,  506, 3354, 2362,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  174,  897,   98, 2079, 1228,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2195,    1,   79, 1245,   12,    1,  698,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,  147,    1,    9, 2764, 2765, 1634,  722,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1360,  612,    1, 2111, 2898,   45,  166,    1,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    1,    1,  400,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  447, 1625,    9, 3102,  949,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1022,    1, 1993,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1663,    1,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  187,    1, 2565,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  393,   12,  597,   82,   37,  335,   28, 2163,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  500,    1, 1191,  872,   28,   98,  858,  668, 2568,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428,   46,   37,  231, 1166, 2342, 1793, 2055,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1774,   39,    1, 2750,  517,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  600,  903,    1, 3165, 1237,  942, 2147,   32,  395,  535,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 1147, 1414,  698,  365,  221,  444,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,  166, 1411,  183, 1265,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  474,    1, 2878, 1388,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1900,  661,    1,  886, 2013,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1373, 3310,  590,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  709,   20, 1644,  513,  514,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,   37,    1, 1021,  191,    1, 2670,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1147,  437,  488,   37, 2856, 2249, 3091,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993, 2994,  116, 2995,  218,  332,  682,   37,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,   21,    1, 1104,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  203,  361, 1433,    9, 3132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307,  267, 1339,  627,   61, 2474,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,   25,  504,   98, 1565,   45,  479,   12,  156,  157,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2757,  105, 2859,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1661,  331,  353,    1,  572,  244,    1,   15,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  507,  539, 1360,  612,  142,    9, 1933,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  733,    1,   45,  761,  195,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1458, 2381, 2169,  627,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,  437,   37, 1539,  104,  111, 1107, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  304, 2264,  357,    1,   28,  112,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2153, 2714,  420,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2747,  166, 2925, 3188, 1573,  187, 1103,  187, 2330, 3284, 2085,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510, 2414,   32,    1,    1, 2405,  539,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2414, 3160,   32, 2018,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492, 1539, 1663, 2884,    9,    1, 3060,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043,  242,  191,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  421,   12,  157,  590,  567, 1724,  187,  592,  108,   98,\n",
      "          433,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1955,  765,   32,  176, 2412,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  102,    9,   69,  245,    9,  705,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2593,    1, 1620, 1935,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3227,  132,    1,    1,    1,   37, 3182,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386, 1070,  147,   37,    1, 1495,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  173,   45,  829,   12,  365,  535,  656,  973,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,   72, 2789, 2997, 2976,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3104,  267, 3046,   12, 1074,    1,  864,  220, 2673,  210,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  618,   37,  619,   40, 2589,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2663,    1, 1000,    1,    1,   32,  395,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  410,    1,  275, 2054,  162,    1,   92,  187,   69,  102,\n",
      "           27,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2, 602,  32,   1,  54,   1,  47,  79,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 163,   1,  12,   1,  69, 297,  98, 889, 529, 509,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1833,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 1087,    1,  220,  932,   45,    1,  207,  956,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788, 1236, 1785, 2044,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  880, 1220,    1,  460,    1, 1795,  197,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  787,  924,    1,    1,  195,  400,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 1564, 2149, 2237,   37, 3369,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  821,  525,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3247,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,  60,   1,  27, 687, 115,  45, 517, 907,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 805,  45,   1,   1, 428,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  253,    1,    1,  829,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496,    1,    1,    1,  681, 2387,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,  147,  991,  454,    9,    1,  458,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,  104,    1, 2572,    1,  774, 3157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  449,  149,    1,  444,  116, 2650,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  729,  162, 1990, 1569,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  964,   12,  365,  132,    9,  121,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   37, 1539, 1718, 1851, 1021, 2168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1766, 1767, 1671,    1, 1067,    1, 1089,  361,   29, 2973,\n",
      "         1764,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  648, 3155, 1918, 1822,  606, 1147, 1046,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1848, 1216,  636, 1336,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1675, 2773,    1,   90,   45,  247, 2586,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3108,    1,  191, 3132,    1,  590,  454, 1160,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707, 1713, 2107,  785,  786, 2462,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,  156,  420,   30,  117,   92,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3177,    1,   32, 3187,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1718, 2146, 1967,   61,    1,  579, 2639,  719, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3138, 1827,    1,  951,    1, 3132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3365,  820,  384,  632,   36,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,  147,  958,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2158,  166, 2773,    9,  463, 2170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  200,  449,    1, 1273,  259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  422,   66, 1809,  224, 1126,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1268,  756,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   39,   45,  862, 1787,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187,  776, 1268,    1, 3382, 1988,   32,    1, 3389, 2694,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3370, 3043,   32,    1, 3363, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1412,    1, 2188,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2514, 1841,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  148,   12,    1,    1,   98,  225,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  104,  358,    1,    1, 2092,  792,    1,  792,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  954,    1,  308,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 1390, 1025,   37,  125,    1,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  954,  321,    1,  105,   71,   32,  347,    1,  774,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  790,   90,  761,   37,  489,    1,  378,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  155, 1184,  347,    9,  449,  199,   32, 2335,  537,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,  963,    1,  669,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   27,  845,  951, 1547,  548,  389,   29,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3369, 1386,    1,    1,  463, 2751,  543, 2024,  191, 1837,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1977, 1176,    1,  600,    1,  315,    9,    1,  270, 1379,   12,\n",
      "          112,  499,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  845,  147, 1360,  612, 1709, 1107, 2285,  400,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  799, 1396, 1817,    1,  404,  540,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  219, 1477, 1990,  872,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   31,  361,   93,   98,  837,    1,  202,  448,  105, 2537,    9,\n",
      "         2707,   12,  954,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,   32,    1,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497,  619, 3344,    9, 1844,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  335,   28,    1,    1,  361,    1, 1316,  166,  163,    1,\n",
      "           12,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2413, 1545,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  582,   45,   20,   12,  750,   50, 2260,   37,    1,  495,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  936,  469,    9, 2128,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1027,   37,   92, 1211, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2692,    1, 2744,   98,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  474, 2591,  193,   37,  477,  444,    1,  551,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2486,  921,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2328, 1539, 1961, 2191, 2020,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,    1, 3044, 1159,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  340,    1, 2088,   39,    1,  156,  570,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  327,   32, 1691,  282,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  804,    1,    1, 2577,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3099,    1, 1054,    1, 1192,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2708,  863, 2306, 2297,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2695, 2223,  437,  315,  365, 2522,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3303,    1,   39,  294, 1456, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129, 2246, 3303,  140,  427, 1343, 1684, 3324,    1, 2578,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1174, 2819, 1995,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  295,  354,    1,  131,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2615, 2935, 1194,   73, 2764,  404, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   69,  218, 1111,   98, 2091, 1588,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  171,  237, 1116,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1497, 2497,  436,   45, 3155,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  768,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  524,  525,   15,  245,   32,  645, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3209,  661, 2872,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741, 2962,   28, 2522, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,    1,   45, 2093,  356,  963,  713,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1373,   37,  138,  152,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2737,  927,  894,   52, 1300,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,    1,  191,  784,  211,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  727,   12,  613,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   37,    1, 1839, 3037,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3369,   12, 3118,   98,  166, 2041,   37,    1,    1, 1428,  108,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885,    1, 2523,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,  744,  453, 2364,   98,  803,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2820,   98, 1970,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  130,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 2347,   32, 2137,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  520,  333,   45,  327,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1120,   12,   37, 1658, 1507,  223, 2135,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,  884,  297,  413,  647,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  474,  488,   37, 2035,  430,  477, 1232,  957,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  289,   98, 2974,   12, 2790,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2557,   32,  147,    9, 3153,  663, 1900,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 384, 105,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 204,  12, 416, 460,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  968,   12,  442,    1,   61, 2084, 2085,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,    1,  475,    1,  517, 1931, 2013,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   60, 1946,  191,    1,   69,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 3006,   98,  166, 1844,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  191, 3131, 1987,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3001,    1, 3230,  288,    9, 1764, 1990, 2069,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  105, 1487,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1712,  829,   37, 1463, 1106,    1, 2603, 2283,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  256, 1768,    1,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  518, 2153, 1664, 2095,  394,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   25,   71,  548,   65,   67,  423,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  288,    9,    1,  682,  444,   94,    1, 1547,   63,  389,\n",
      "          420,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2125,    1, 3285, 1188,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1990,   45,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  617,  259, 2718,   37, 1604,   98, 1273,  844,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  738,  647, 2552,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  148, 1114,  879,    1,  693,    9,  647,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1797,   92,   37, 3118, 1527, 1705,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2140, 2122, 1386,    1,  217,    9,  604,  693,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1583,  267, 2335,    1, 2751, 2572,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,  365,  650,   32, 2849,   45, 2292,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2696,  476,   37, 1281,  333,   45,    1, 1089, 1675,   37,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2998, 1586,   28, 3194, 3195,  791,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1584,   85,    9, 2087,  424,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1458, 1140,    9, 1855,    1,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2998,  147, 1707,  620, 2208, 1787,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  726,  166,    1,    1, 1684,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  537,  548, 1405,    1,    1,   37,  365,  261,  897,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1720, 1056, 1752,  786,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  251, 2677,   45,    1, 2232,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,    1,    1, 2911,   32,  736,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  422,  475, 1082,  299,   37,    1,   37,  721,   98,  809,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  877,    1,  220, 1087,    1, 2560,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  922,    1,    1, 2362,  191, 2308,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2155,  640,  215,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3061, 2809,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361, 1755,   32,  803,  632, 1223,  548, 3071,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2427, 2963,  163,    1,   12,    1, 2161,   32,    1, 3163,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1498,  837,    1, 1446, 1501,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2342, 2988, 1396, 2987, 2762,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3225,  103,  712,    1,   32, 2171,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1013, 1522,  166, 1417,    1,   45, 1013,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  314,    1,    1, 2290,   98,  721,    1, 1010, 1629,   12,  839,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1564, 2069, 2390,  693,   37,  864, 2283, 3399,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2942,   98, 1171,    9, 2674,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 1976,   27, 2893,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1366, 1463, 1027,  848,   12, 2371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 3365, 1623, 2619,  191,  105,    1,  786,  339,   98,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,  596,    1, 1359,    1, 1360,  612, 1046,  134,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  218, 1518,  143,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  809, 2867,   37,    1,  542,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1584,   12, 1709,  460,    9,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1773, 1680, 2510,    1,    1,  837,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537,  147,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3129,    1,   12, 1684,  142,   61,    1,  176,  166,  915,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3378,    1, 2410, 2509,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  794, 1260,   98, 3025, 1730,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1728,  845, 2395,    1, 2145,   37,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  561,    1, 1099, 1453,   32,  927, 1039,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,   37,    1, 2741,   12, 2789,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2779,  801,   37, 1447,   26, 3293,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  142,   37,    1,  989,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,    1, 2977,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2335, 2827,   32,  722,   37, 1260,    7,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  582, 2565,    1,    1, 1530,  176,  166,  823,   45,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  232, 2167,  790,    1,    1,  220,  749,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1, 2572,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,    1,  294, 2548,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2965,  967,  195, 1894,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2498,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1844,    9, 2708, 1009,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,    1,   81,   32,    1,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1789, 1550,    1,   32,  597,  163,    1,   12,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 1585, 2803,  176, 2147,   32, 2197,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  273,  730, 2614, 1421, 3224,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1357,    1,  191,    1,  861, 2454,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2220,  155,  455,   12, 1625,   37,   92, 3081,   67,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1, 2707,  498, 1145,   45, 2927,   46,  342,  232,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  746, 1713,  166,   80, 2789,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479, 2414,    1,    1, 1228, 1294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  383,   39,   45, 2320,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1019,    1,  167,   52, 2500,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3161,    1, 1159, 1739,  361,  884,  166,    1,  191,  166,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 1656, 2596, 2414,   32,    1,  379,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3354, 3073,  840,  129, 1184,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2414,   32,  531,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3048, 2923, 2175,  906, 2539,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  653,    1,    9, 1058,   98,  596, 1793, 3037,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  619,  357, 2192, 3034,    1,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,   61, 1239, 1018,  328,   98,  224,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2486,  113,   79, 3119,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1809, 2869,  535,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1,    1, 2565,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  102, 1473,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,  163,    1,   12,    1, 2872,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,    1, 1467,    9,    1, 1804,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  552,  551,  517,  353,  242,  197,    1,    1,  157,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1,  449, 1273,    1, 1140,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1, 2909,    1,   71,   45,    1,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1238, 2932, 2286,   37,    1, 2333,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  437,    1,  297,    1,   37, 1476,  574, 1682,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  567,  510,   12,    1, 2497, 2732,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  952,   37,    1, 2471,   37,  942,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1691,    1,    1,   39,   45,  199,    1, 3124, 1800,    1,\n",
      "         1470,   45,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 2685,  480,    1,    1, 1144,  182,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  196,  733,  284, 1541,   37,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1326,  284,  861,  681, 1677, 1176,  445,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2371,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   96, 1425,    1,  356,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361, 2977,  798, 2334,  593,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2511,   37,   47,  535,   50,   37,    1,    9,  152,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,  60, 338,  63, 303,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 323, 805,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2104,  387, 2978,  541,    1, 1371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,   98,  486,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,   27,    1,  395, 1441,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  566,  331,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  112,  987,    9,   10, 1708,    1, 1576,    9, 2275,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  268,    1,    1,  857, 1469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  942,    1, 2949,    1,    1, 1794,  927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12, 2975,    1, 2692,  614,   98,  333,  176,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  964,  531,  729, 1176, 2342,    9,  632,  681,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273,    1,    1,  829,  361,  151, 1018, 1158, 1230,  460,  272,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  409,  159,   71,  202,   69,  509,  817,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2472,    1,    1, 2827,   32, 2890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1645,  522,   32,  557,  540,  105,    1,    1,  267,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  338,   98,  459,  954,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1057,  297,  195,   25,    1,  374,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  908, 1193,   69,  209,   37, 1194,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  596, 1793,    1, 2822,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1614,    1, 2690,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  449, 1023,  354,  703,   98,    1,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  361,  166,    1,   45,  105, 1190,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 3144, 1619,  863, 1984,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1443,  439,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   13,  190,  317,  453,    1, 1463,  932,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593, 3009, 2712, 2618,   12,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3358,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,  105, 1298,    1,  191,  247,    1,\n",
      "          714,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  487,    1,  200,  469,    9, 1972, 1821,   95,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1117, 1525,  852,   55, 2819,   37,  284,    1, 2928,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 2834,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2142, 1022,    1,    1,  608, 2906,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  215, 2593,  365, 1397,    9,  116,  259, 2264,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226, 1210, 2310,    1,  844,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  428,    1,    1, 1360,  612,   52, 2175,   81,   37, 3296,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  290,  396,    1,  475,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1110,  421,   37,    1,    1,  640,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  794, 1106, 1107, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  842,  361,    1,  159,    1,  191,  230,  122,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  803,  441, 1292,  187,  218,  418,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  592, 1563, 1091, 1980,   37,  498,   98,  734,  591,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3183,  498,   37,   24, 1145,  220, 3252, 3229,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  459,  220, 3271,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3328,  361,    1, 1523,   37, 2250,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1087,  716,   71,   32,  737,  244,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777, 2232, 2549,    1,  256,    1, 1876,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  107,   32,  590,    1,   37,  125,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,   12,  996, 1135,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1793,   51,   52, 2051,    1,   32, 1619,  163,    1,   12,    1,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  830,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3361, 3060,    1, 2548,  254,  288,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2143,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2993, 1310,   37,    1, 2994,  270,  220, 2215,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,  197,  384, 2512,   12, 1358,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1487,  197, 1784,    1, 2025, 1034,  696,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3053, 2477,  944,  928,  176,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  166, 2349, 2273,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 3358, 1572,  191, 1861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1, 384,   1, 428,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 413, 773, 159, 245,  98, 702, 169, 132,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1280,    1,    1, 1976,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1471, 1149, 1267,    1,  187,    1,  138,   46, 1348,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  395, 1550,    1,  606,    1,    1,  424,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226,  852,   37, 1017,    1,    9,  105, 1376,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  548,    1,    1,    1, 1018,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  948,   37, 2702, 3361,    9, 2343,  776,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  547, 1530,   32,    1,    1,   32, 3360,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147, 2450,   37, 2709,  352,  399,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1454, 1789,   12, 1689, 2108, 1907,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1395,  844,   15,   66,    1, 1411,  356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3096, 2671,    1, 1921,   32, 2028,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,  196,    1,    1,  590,    1,  483,    1,  762,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,  365, 2759, 2287,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,    1,    1, 2070,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   98,  736,   74,    1, 2676, 1408,  105,  340, 2395,  361, 2136,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2197,  315,    1,  333,   45,    1,   32,  411,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  861,  981,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1173,   37,  754, 1675,    9,  471,  548,    1,  698,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3360,   12, 3363,   32, 2018,    9, 2095,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,  102,  245,  699,   98, 1488,   68, 1588,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1348,   37,    1,   32, 1183, 2921,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   39,   32,  829, 1350, 2322,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3277,   90,  386,  334, 1822,  688, 1545,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2332,   32,    1, 2192, 3081,   37,  365, 2829,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  753,    1, 1258,  951,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993,  794, 3056,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2222,    1,  917,    1,   98,  166,  917,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 2729,    1,    1,  947,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3332,  361, 3311,    1,   37,   16, 1492,   61,  166, 1488,  872,\n",
      "          650,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,    1, 1564,    1,  714,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3006, 2856,   32, 1256,  551, 2196,  115,   45,    1, 2237,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1319,   12,    1, 1745,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  579,   12, 1167,    1, 1123,   12,   81,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3020, 2096,    1,  284,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 1334,   98,    1, 1638,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1051,   34,  572,  207,  174,    1,  983,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1145, 3380, 1178,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  619,   59,   32,  768,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  580, 3308,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1, 1982, 1183, 2113, 3107, 3366, 2199,  232,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2308,    1,    1,  365, 2362,   37, 3151,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,  681,    1,  777, 1085,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  954,   32,    1,  187,    1,   18, 2007,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903, 2605,  335,  388,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   75,    1,  777,  618,  384,  171,  804,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,   12,  401,  198,   15,  800,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   61, 1691,  671,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2205,   81,   98, 2741,   12,    1,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  597,  695, 2789,  267, 2602,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  792, 1938, 2607,  382,  792,  640,  124,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2328,  851,  140,  152, 2223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  919, 2388,  275,  260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1567,  696,    1, 2035,  922,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649, 1732, 1091, 1572, 1151, 1424,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2868,    1, 1750, 3148, 2669,   32, 3118,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1236,  169,    1,    1,  460,   45,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  552,  551,  405,    6,  284, 1693, 1049,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32, 2702, 2291,   27,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1629,   37, 1844,    9, 2696,   32,  365, 1788,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,  385,   31,    1,   85,   37,    1,  384,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1178, 1179,  958,  142, 1992,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1741,    1,  275,    1,   28,  282, 2367, 2695, 2334,  191,  959,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1294, 2695, 2334,    1,   28,  959,  118, 3011,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  852, 1542,   37, 2354,  978, 3138,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  294,  372,  388,   32,  529,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1025,   39, 2119,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1011,  468,    1,   98,   32,  163,    1,   12,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219, 1477, 1990,  872,  571, 3286,    1, 1750,    1,   85,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1658,    1,   12,    1,   98,  334,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  515,  562,   37, 1361, 2355, 2750,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1796, 3048,  927, 2699, 1685, 1118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1559,  997,  297,  661,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1028, 1181,  623,   93, 1071,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878,  477,  640,    1,  197,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2862,  267, 3341,   46,   37,    1, 1371,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1149,  439,  477,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  386,   22,   51, 1188,  388,   32, 1251,    6,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2334, 1167,    1, 1159,  105, 2186,  415, 1056,    1, 2088,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,   28,  384, 1034,  687,   98,  163,    1,   12,    1,  341,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1401,  902,  608,  153,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1426,  449,    1, 2579, 2069,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  529,    1,  606, 1846,    1, 1159, 2375,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1390,  475,  267,  199,   61,  472,   39,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2753, 1394,   37,  631, 2486,  297, 2906,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453,  986,  166,  636,   45,  672,    1,   37, 1173, 2440,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  166, 1215,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018, 3372,    1, 1065, 1190,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 2924, 2905,    9,  531,  221,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2275,  716, 1270,    1,  331,   32,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,    1,  104, 1714,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,  247,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2262,  686,  531,   12, 3391,  176,  698,\n",
      "           45,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  303, 1398,  612, 2047,  104,    1,  734,    1,  754,  102,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,   74,   79,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   37, 2432,    1, 2232, 1411, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2944,    1, 1940,   12, 1684,  220,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2862,    1,  936,  469,    9,  388, 3082, 1419,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2528,  166,    1,    1, 2474,  259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  824,    1,  351,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,    1, 2614,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1559,  297, 2539,  541,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2206, 2989,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,   37, 1539, 1411,  659,   45, 2366,   98, 1332,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2751,    1, 1056, 2909,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3248,   98,    1,   45, 2222,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1028,    1,  297, 1850,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1051,  696,    1, 1155, 2706, 1542,  725,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 1625,    9,    1,  531, 3102,  949,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2004,  844, 1151,  669,  162,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  166, 1089,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  636,    1,  119,  813,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  719,   37,  693,  388,   37,  903,    1,\n",
      "         1447,  861,  420,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1022,    1,  952,   72,   73,    1, 1684,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  903,    1, 1447, 1585,  193, 2439,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 2386, 2275,   45,  365,    1,   98,  531,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1048, 1049,  538,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2565, 2331,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  298,    1,   37,    1,    1, 2762,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  142,    9,    1,  596,  892,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  500,    1, 1191, 2274,   37,  693,  111,    1, 3031,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2554,    1,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  140,  395,   26,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  934,  313,   37, 1835,  201, 1021,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   26,  178,  777,    1, 2544,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3115,    1,   39,  220, 3288, 1987,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  591,  902,  219,  332,  682,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1855, 3365, 1683,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144,  729,   32,    1,  528,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2615,    1,   37,    1, 3131, 1857,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  980,  888,   45, 2712,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,  884, 1003,  176, 1230,    1,  202,  453, 1273,    1,  193,\n",
      "          187,  227,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2703, 2816,  557,  540, 1010,  555,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  792,  510,  166,    1,  792, 2705,  361,    1,   45, 1714,\n",
      "           32, 1080,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  113,    1,    9,    1, 1887,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2762, 1976,   32,    1,  756,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,    1,  524,  879,  192,  973,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   89,    1,  218,  187,   60,  640,  105,  241,  340,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1584, 1125, 2230,   98, 1266,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  869, 1658, 1944,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  177, 2844,  187, 2178,  880, 2421,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  835,    1, 1022,    1,    9,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1516,   12,  836,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  409,   25,  245,   60,   28,  444, 1547,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   61, 2506,   98, 2334,  977,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1431, 1268,  105,    1,   37, 1089,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1312, 3365, 1683,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  597,  654, 1009, 1143,  267,   83, 1924,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  221,  193,  105, 2050,   37,  258,    1,  542,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,    1,    1,  166,  171,  113,  453,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790, 1579,  815,   45, 1151,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3017,    1,  191,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  456,   39,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1955,   37, 1155,    1,  250,   32,  511,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  794, 2102, 1107,  525,   32,  942,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1369,    1,  565,  837,   45,  422,    1, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3249, 1025,  114,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1249,  968,    9, 1674,  671,   32,    1, 2800,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160,  102,  245,  187,  493,  408,  720,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1778, 2580, 2851,  328,    1,  193, 1018, 2613, 1747,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1298,  551,  624,    1,   37,  151,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3399, 3385,    1,  968,  759,  630,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,   37,  270,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,   32,  331,  573,  399,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3095, 1599, 1461,  595,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3144,  555,  509, 3123, 3096,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  176,   38,   32, 1422, 2893,  776,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 2388,    1, 2206, 2207,  171,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2339,   45, 1230,   12,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  321, 1089, 1675, 2595,   52, 2797,    9, 2292,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2527,  267,  872,  792,    1, 1441,    1, 3240,    1,  792,  947,\n",
      "          231, 1928,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2193, 2800, 3115, 1878,    1, 1463, 1724,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1685, 1686,  187,    1, 1687,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  782,   16, 1366,  254,  917,   37,  856,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,  640, 2275,   32,  736, 1376,  142,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,   45,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  605,  390,  176,  649,  700, 2175,   37, 1125,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  304,   37,    1, 1346,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  412,    1,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12,  125,   85, 1778,  288,    9,  388,  616,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  355,   82,  166,  669,   51, 1046, 1133, 1215,    1,  156, 1396,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  882,  353,  449,  197,  276,   32,  228,    1,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  758,  325, 2215,  698,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1583,    1,  352,  138,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  754, 2261,    1,  220, 2298,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  491, 1213,  201,  529, 2190,   32, 2016,   61,  415,  166,  698,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  443, 2938, 3060,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144,   37,  606,  581, 1385,   45,  863,    1,  232,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2321,  167,  664,    1,    9,   28,   37,  105,  339,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593, 2153,  753,    9,  241,  698,  220,   10,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 1896,   37,  838,  954, 2567,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  782,  365, 1678,   32, 1537,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  515, 3322, 1198,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2977,  475,  580,    1, 1574,  176, 3089,  297, 1610,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2103,  617,  441,  245, 1010, 2244,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   51, 1598,    1,  493,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  385,  389,   93,  143,  763,   76,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   28,   37,    1,   32,    1,    1,    1, 1492,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  715, 1379,    1, 1226,   98,  845,   69,  102,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 2962, 3188,  140, 3212, 1523,  187, 3244,    1, 2807,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1017, 2541,    9, 1037,  992,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 1665, 2070,   22, 2393,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 2659,  342, 1778, 2109,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  837,    1,   37,  856, 1393,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2617,  736,  166,  230,   45, 1646,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1492,   12,    1,  384,   26, 1039,    1,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1061,  176,  903,    1,  904,    1, 1325,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1,  679,   69, 1588,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  786, 2572,   32,    1,    1,  458, 1450,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3365, 1229, 2572,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  141,  132, 2598,   32,  166, 1046,   45,  121,   12,  901,    1,\n",
      "            9,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,   37,  439,  202,  204,   12,  193,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3363,  304,  297,  229,  442,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61, 2289,  357, 2385,  612, 2289,    1,    1,  515,    1,  166,\n",
      "            1,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3175,  361,  730, 2614, 2260,  548, 1700, 2799,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2498, 1272,   51,  759,   81,    1,  537,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,  597, 2789,  475,   96,  680,  433, 2263,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  193, 2398, 1198,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,   26,  242,    1,  104,   60,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1512,   46,  176, 1390,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1100, 2071, 1331,    1,  504,    1, 1876,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1617,    1,  103,    1, 3382,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  584,    1,  384,  567, 1582,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  324,  958,   46,  220, 1479,  460,  669,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  420,   49,   37, 2199,   68, 1588,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1855,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1008,    1,  929,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1166,  166,    1,  738,  166, 2229, 2041,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  813,    1, 1018,    1, 2017,    1, 1018,    1,   37,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  388,  585,   51,   52,   98,  454,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  780,    1,  189,  619,  183,  179, 1495,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1021,   32, 2069,    1,  202,  176, 1797, 1251,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2802, 1177,   37,    1, 3098,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   94,    1, 1464,   37, 2200,   93, 2007,   37,    1, 1384,  218,\n",
      "            1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  147,  400, 1018, 2564,   37,    1,  253,    1,  267, 1076,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37,  423,   69, 1069, 1208,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  284,    1, 1314,   32, 3348,    1,  715,    1,  444,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1579, 2144,  129, 1649,  605,  315,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1902,    1, 2017, 3244, 2467,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785,  947, 2856, 3043, 3384,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  348, 2749,   28,  187,  453,   15,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  913,    9,    1,  357,    1,   32,    1,   12, 3273,   37,\n",
      "         1046,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1557,    1,    1, 1559,  187,  204, 2216,  691,  957,    9,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  733,  163,    1,   12,    1,    1,    1,   50,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  565, 1936,  166, 1357,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1829, 1510,  299,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2072,    1,  455,  395, 2471,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  502, 1525,  353,  499,  331,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,  873,   45,  114,    1, 1608,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1,    1,  267,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,    1,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2751, 2856, 3361, 2567,    9,  104, 1583,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307,   12,   81,   98,  103,  166, 1868, 1172,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1446,   98,    1,  217,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  815, 2549,   37,    1, 1011,    1, 1116,   30,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1596,   45,    1,    1,    1, 1464,   37,    1, 1755,  297, 1038,\n",
      "          949,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1431,   12, 2498,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,    1,   37,    1,  453, 1377, 1160,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  183, 2050,  191, 1537,  721,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115,    1,    1,  162,  979, 1217,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962,    1, 3296,  877, 3209,  713,    9,  404, 1684,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,  744, 1757,    9,  864,   37,    1,   37, 2673, 1057,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  548,  105, 1183,    1,    1,  226,    1,  105, 3022,   61, 1696,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1062,    1,   37,    1,  612,  111,   32,  332, 2434,    1,  752,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  978, 2953,    1, 1718,  103, 2933, 1638,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,    1,    1, 1865, 1352, 2050,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1411, 1778,  659,  837,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  953,  680,  187,  104,  109,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  861,    9,    1,    1,   45,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 2414,    1,    1,  356, 1691,    1,   32, 3339,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2528, 2080,    1,  844,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,    1,   28,    9,  166, 2063,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  920, 2046,    1,  166,   69,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12,    1,  396,    1,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  915, 1734,  191,  166, 1497,  750, 1494,  454, 1176,  411,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1094, 2414,    7, 3374, 2596,   13,   32,   22,  477,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3103,  713,   39, 2925,  226,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  590, 2613, 2082,    9, 3194, 3195,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741, 1188, 1515,  183,  564,   37,    1, 1931,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,    1,   85,   32,    1, 1125,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  877,  914,  714,    1, 3152,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3129, 2885, 2934,    9, 1194, 3258, 2579,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,  379,   37, 2237, 2597,   37,  588,  949,   45, 3073,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 1096, 1090,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2222,    1, 1603,  127,  187,  507,   12,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  342, 1527,  475, 3067, 3353,   45, 2135,  940,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2504,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2325,    1,  992,   37,  105,  365,   10,    1,  662,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2323,    9,  829,    1, 1994, 2819, 1017,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 193,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 384, 166, 749,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,   81,   28,   37,   98,  163,    1,   12,    1,  889,   25,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 2754, 2548, 2844,   32,  531,    1,  298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  332,    1, 1552,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497, 1508, 2787,   37,  881,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   51,  832,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3297,  953,   81,   37,  590,    1, 2072,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3012, 2699,    1, 2684,  176, 1821,  656,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280, 1625,   37, 1844,   32, 2592,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3069,  267,  320, 1533,  320,  227,   98, 1674,  861,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  884,  885,    1,  176,  777,   98,  844, 2928,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   65,  575,    1,    1,   32,   86,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3303,  884, 2135,   45,    1,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3311,   12,  365,  808,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2265, 3102, 1683,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 2084, 2339,   32,  166,  225,  218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  829,    1,  166, 1718,  768,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  914,  297,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  205,  388,    1,   32, 1332,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,   45,   81,   37,   36,  623,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2047,   45, 2292,    1,  182,    1,   98,   74,   45,  350,  868,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3215,  894,  698,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3279,   32, 2646, 2253, 2024,  142,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2962, 3237,    1,  730, 2614,   37, 1194,   73, 1918,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1009,    1,  754,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1428,   98, 1430, 2471,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283, 3175, 3186,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  727,    1, 1159, 1842, 1681,  220,  365, 1017,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,   37, 1638,   98, 2235,  225,  269, 2013,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  105,    1,   28,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962,    1,  640, 1194, 2907,    1, 3117, 2923, 3260,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2295, 2321, 1421, 3229,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2873,    1,  203,   37, 1844,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1033, 2211, 1273,    1,   32,    1, 1651, 1597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,    1,    1,   12,  671,    1,   98, 1377,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   33,   39,  166,  593,   12,  366, 1410,   98,  224,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,    1, 1327,    1,  447,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  328, 3184,    1, 2741,  535, 1281,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,  774,  104,    1,  753,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  458,   45,  942, 1554, 1184,  347,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  773,    1,  166,    1,  226,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  388,    1, 1827,   32, 1420,  475,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   79, 2383,    1,  150,  105,    1,    1, 1013, 1522,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  198, 2164,    1,    1,    1,  590, 1479, 1080,  898,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597, 3127,    1,   96,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  879,  832,    1,  163,    1,   12,    1,    1,    1,  395,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  815,    1,   37,    1,   79, 3059,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  982,   37, 1155,  617,  618, 1159,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,  923,  815, 1117, 1525,  161,   37,  504,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2774,    1,   57,  439,   37, 1345,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  287,    1, 1418,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1341,    1,  197,  570,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035, 2055, 1038, 2113,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  179,    1,  180,    1,   28,  182,  104,  613,  170,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3058, 1240,  588, 3342, 2251,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  176,  989, 1277,    1,  170,   32,  422,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  990, 1297,  517,   52,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  140,  147, 1523,  297, 2162,   32,  487,  611,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1467,    1,    1,  361,    8,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  441,    1,    9,    1,   68,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,   37,   36,    1,   81,   37,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2678,    1,    1,  116,    1,   32,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  314,   51,  606,   37,  125,    4,  187,  156,  276,    1,  615,\n",
      "          774,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497,    1,  405,   61,  105,    1, 1569,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3095,    1,  294,  726, 2376,    9,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1670,  607,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1215,   32,   69, 2432,    1,  193,  105,  916,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,  614,   37,  166, 2918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328, 3204,   39,   45,    1, 2630,  220,    1, 1987,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,    1,  829, 1994, 1718,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  691,  335,    1,   32, 2073, 1463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3401,  123,   37, 1002, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1710,   52, 1628,    9, 1580,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,    1,   37,  166,  519,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   37, 2389, 1398,  612,   16, 1880,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115,  179,   37, 2056,  698,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  581, 2318,    9, 1691, 2873, 2821,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  195, 1988, 2659,   81,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  885, 1333,  176, 1668,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1457,    1,  700,    1, 1717,  191,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  715,    1,  570,   93,  190, 1121,   32,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,    1,    1,    1,   82,  943,   28,   26, 1039, 3004,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1983, 2078,  205,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  319,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  590, 2230,   37,  754,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1774,   39, 1230, 2528,    1, 2668,  220,  163,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  647,    1,   81,   37,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1258,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2374,  550, 2908,  297,   10, 2681,  724,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1926, 1927, 1928, 2182, 1096,    9, 1785,  555,   98,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2814,    9, 2925,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2893,    1,  162,  356, 1038, 2113,    9, 1898,   37,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1293,    1, 1720, 3130,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 1114,   32,  166,    1,  187,  667,  863,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   85,  220,  657,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  353,    1,  737,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  858,  261,  166,  116,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233, 1579,  182,  301,    5,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  297,  631,   32,  667,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2753, 1394,  187,  166, 3218,  688, 3119,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  294, 2619,   98,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  721, 1707,  148,  693,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  647,   12,  597,  475,  267,  204,    1,   37, 1721,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,  102,   71, 1750, 1714, 1146,  106,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  119,    1,  140,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,  365, 1788, 1215,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,  37,  47,   1,  50,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 166,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1140,  247,  248, 1593,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,   12, 1481,  697,    9,  601, 2113,  548, 1833, 2591,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  631,  166,  365, 1173,  183,  404,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,   37,    1,  372,   32,  285,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2411,   37, 2192,    1,  357,  664,  671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1060, 2827,   32,  632,   36, 2572,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993, 2994,    1,    1,  829,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  780, 1478,    1,   45, 1178,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1360, 1700, 3141, 1241,  220, 3113,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3237,    1,  247, 2848,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,    1,    6, 1126,   37,    1,   59,  159,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1569,   98,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739,    1,    6,  570,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1718,   32,  957,   32,    1,   45,    1,    1,  957, 1718,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1693,    1,    1,    1, 2579, 3201,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  794,  853,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3387,  548,  216,  176, 2936,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1447,    1,  191,  104,    1, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 3211,  856,   81,  444,  691,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1463,  546, 2673, 3085, 1461,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2676,  416,  164, 1333,    1, 3404,  774,    1,    1,  985, 1816,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  468, 1362,  251,  365, 1273,  861,    9, 1273,  618,  361,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3163,  726,  162, 2942,   72,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,  193,    1,  202,  729,   32,    1, 2135,    1,    1,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2596, 1396, 2597, 2696,    1, 2572,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1190,    1,   39,    1, 1563,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2708,    1,  240, 3358,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3376,  344, 3403, 2766, 1312,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  105, 1811,  404, 2410,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  608, 1617,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  215,  398, 1405,    1,  321, 1046,  163,    1,   12,    1,  776,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  648,    1,    1,  148,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1360,  612, 2446, 2349,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,  565,   98,    1,  439,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  579,   12,    1,    1,    1, 1987,  357,    1,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 1321,    1,   37,  342, 2770,   32, 1256,  551, 2196,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  785,  786, 3196,  140,   32,  395,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433, 2104,  162, 1133,   98, 2650,    1,  552,  552, 2086,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 1051, 2274,   98, 1074,  412,  861,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1509,    1,   37, 1075,  906,   12, 3048, 2923,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  503,    1,  220,  749, 1028,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  242,  142,    9,  647,    1, 2552,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  755, 2593,  453,  248,    1, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   37,    1,  460,    9,    1,  626,  633,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  803,  681, 2139,  187,   69, 1137,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  682,    1,  187,  590,    1, 3161,  921, 3161, 1022,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  183,  978,  794, 1298, 2759, 1510,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,   61, 2506,   45, 2319,  651,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1366,    1,    1, 2021,  440, 1176, 1183, 3380,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2414,    1,   12, 2068,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   32, 2388,    1, 2081,  897,  297, 2184,   12,  970,   45,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1227,   37,  439,  726, 2196, 1876, 2198, 2851,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  666,    1,    1, 1258,   37,    1,  584,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 3403,  640, 1619, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  215,  947, 2263, 1051, 1039, 2690, 3060,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2379,    1,    1, 1250,   32,  166,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  669, 1203,    1, 1125,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325,  207,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1899,   12,    1, 1946,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  217,    1,  218,   98,  119, 2098,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  190,  686,  166,  985,   45, 1739,    1,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090, 1667, 1289,   98, 1089,   61,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1260,   98, 2650,  894,  168,  981,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  539, 1037,   32,  105, 1882,   37,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2045,    1,  267, 3402,    1, 2596,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,    1,  105,  288,   45, 1013,    1,    9, 2993, 2264,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  492,    1,  162,    1, 2948, 2223,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2452,  517,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   75,  475, 1566,  613,  170,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  375,  801,   37, 1183, 1253, 3179,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,  292,  365, 2474,  259,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  669,   37,   64,  218,  220, 3044, 2168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2590, 1987,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2095, 1450,   32,  531,    1,  176,    1,   10,   12,    1,  964,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  176,  612, 1380,  617,  259,    1,   98, 2441,   15,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   30,  590, 2047,   98,  357,   79,  166, 2498,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1630,  580, 1084,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1366,    1, 1439, 2764, 3394, 2892,    1,  267,  864,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1273,  259,    1,    1,  629,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37, 1377,    1,   45,  453,    1,  768,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3054, 1426,  119,   45, 1270,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1060,   45,  912, 2285, 2039,    1,  444, 2733,    1,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1364, 1365,  688, 2018,  191, 2202,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3123,  168, 1985, 1394, 1048,   32, 1717,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  253, 1947,    1,    1, 2928,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1407, 2541, 1921,    9,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  865,   37, 3329,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3102,    1,    1, 1004,  760, 1147,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  236,  237,   25, 2346,   98,    1,  144,  145,  157,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3237, 1297,  886,  544,  247,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  729,    1,    1,  777,  778, 2141, 2911,   37,  877, 2309,   98,\n",
      "         2823,  863,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  119,    1, 1260, 2733,   32,  691,    1, 1167,   61,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2218,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2963,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  105, 2482,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868, 1401,  365,    1,  384,   10, 2224,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1361,    9, 2613,  726,   32, 2941, 3201,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  585,  540,   37,  726,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  166, 1411, 2273,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1566, 1377,   45,  397,    1,  695,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2004,    1, 2055,  365, 1151,    1,  108,   98,  156,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178, 3382, 1231,  297,    1, 3389,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1926, 1927,    1, 2849,  297,  225,  218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  337, 3358, 1921,   32,  447,    9,  351,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  488, 2039,  297, 1718,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 1674, 2472,  187, 3280, 1042,   39,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2144,  104, 3111, 2572,    1, 2335, 1941,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1709,  400,   98, 2285,   45, 1107, 1536,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  387,  572,  932, 1315,  572,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3329,    1,   37,   77, 1684, 1625, 2793,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  204, 2582,  810,  917,  765,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  637,   85,    1,   32,  141, 1611,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2292,  686,   32,    1,   32,  443,  420,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1050,  957,   37,  771,    1,    1,   37,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  963,    1,    1,    1,    9, 3302,  593, 1863,   45,  166,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1355,  224,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2136,   10,    1, 2343,  345,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1015, 2153,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  942, 1073,   85,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1290,  396,  720,    1, 1196,  686, 1653,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 1514,    1,    1,   32, 1821, 2190,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1569,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,  444,  166, 2497,   98, 2127,   31, 1397,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175,  606,  284,  845, 1625,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  361,    1,    1,    1,   32, 2597,    1,    1, 2967,\n",
      "          361,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  675,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1429,  251,    9,    1,    1,  217,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2547,  726,  176,  103, 2948, 2015,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1757,    1,   37,  802,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1060,    1, 2408,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  742,  641,   48,   32, 1178, 1179,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  315,   37,   26,  187, 1744,  187,  104,  124, 1411,\n",
      "          356,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2922,   12, 1755,  600, 2961, 1045,    1,  297,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2476,  686,    1,    1,  818,  914, 1268,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2800, 3186,  726,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  936,  365, 2657, 2639,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37,    1, 1835, 1151, 1017,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196, 1408,    1, 1834,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3253,  140, 1377,  444,  487,    5,  695,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 1803,  155,  915,    1,    8,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1684,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2702,  288,   98,  114,  191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  582,   45,  882, 1151,   50,  939,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2062, 1009,  267,  204, 1360,    1,   37, 2449,   32, 1021,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,   32,  104,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  729, 1625,   37,  875,  220,    1,    1,  710,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3343, 2751,  469,    9,  890,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  137, 2370,   97,    1,  720,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,   37,    1,  597,    1, 2965,    1, 3139,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3270,  307,    1, 1383,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1359,    1,  365, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106, 1013, 1626,  193, 2788, 1106, 1013, 2603,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   87,  910,   37, 1463,  365,  124, 1167,  837,    1, 2161,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228, 2234,  408,   37,  554,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2321,  230, 2805, 1247,   39,    9,  914,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 2827,  191, 1994, 2095,  947,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,   12, 1043, 1738, 1518,  417,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3119, 2151, 1022,    1,    1,   12,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1106,  361,    1,    1, 2035, 1467, 1013,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1683,  384, 3127, 1054,   32,  754,  611,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  912,  767,  444,  923, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1877,  193,   37,  865,   37, 3141, 2920,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  746, 1268,   28, 1766, 1767,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2142,  171, 3272,  590,    1,  511,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  215,  669,   37,  151,    1,    9,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3068,    1,    1,  774,  575, 1937,  166, 1125,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  487, 1113,  640,  365,  356,  340,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 1462,  475,  884,  754, 1804,  384, 1537, 1583,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 1992,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2056, 1011,  633,  716,   72,  401,  682,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  356, 1844,   32,    1, 1086,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1425, 1033,   12,  616,    1,    1, 1033,  335,  166,  631,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  820,  384,  611,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101, 2224, 1579,  797,    9, 3339,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  103,  548, 2148,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1939,  176, 3358, 3336,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,    1,    1, 3277,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  792,  227,    1,  792,    1,  220,  365, 1537, 1386,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,  812,    1, 2868,  101,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1211, 2461,  437,  936,  391,    1,   45, 1718,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1463,  167,  631,   37, 2227, 1747,  220, 2512,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1292, 1021,  120,    9,  853,  538,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503,    1,    1,    1,  159,  504,   98,  505,  506,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  470,   32,  310,  442,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2161,   12, 2630,  967,    1,  627,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3117,  959,    1,  548,  885,  354,   37, 3296,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1212,    1,    1,  454,    9,  310,  442,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  459,  132,   37, 1155,    1,   98,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  202, 2557,  361,  997,   45, 2177, 2585,  565,  166, 1690,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  139, 1950,    1,   32, 1010,    1,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785,   69, 1190,    1,  191,   69,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359,  469,    1, 2024,   46,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   88, 1002, 2275,  392,   10,  631,   37, 1394,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  168,  115,    1,  877, 2310,   74, 2966,    1,    1,    1,    1,\n",
      "          320,  227,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800,    1, 1366, 1822,   77,  255, 2405,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1395,    1, 1768,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3229, 1249,  590,  220,  886,    1,    1,   45,    1,  665,\n",
      "          460,   85,  187, 1018, 1691,  234,  182,  235,    1,    1,    1,  234,\n",
      "          182,  235,    1,    3,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1084,  702,  887,  640,  169, 1084,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1, 1924,  917,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   12, 1447,   32,    1, 2673, 1916,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3046,  640,   81,    9,  854,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1414, 2596, 1147, 2751, 3113,  967, 1002,\n",
      "         1931,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2013, 3320, 3262,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1023, 1204,  713, 2055,    1,   37,   52,  105,  713,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  282, 2367, 2695,    1,   45,  166, 1034,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   26,  417,  548, 1290,  396,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   22,    1,   32,   85,   37,    1,   46,   98,    6,  220,\n",
      "          453,  359,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3207,    1,  671,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,  947,    1,  331,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1024,  551, 1024,   37,  138,    1,  131,    9, 1026,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1366,  810,  167,  335,  105,    1,  384,  730, 2614,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3235,  688, 2206, 2435,   12,    1,   61,   98,  166,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  633,  669, 1228,    9, 1994, 2650,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1061,   32, 1791,    1,    1, 2596,  722,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  166,  433,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3213, 1874,  386,  927,   98, 1691,    1, 1011,  856,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   45,    1,   32, 2499,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3315,   81,   32, 2331,    1,  548,    1,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,  267,  163,    1,   12,    1,   12,    1, 1447,\n",
      "          443, 1675,    1,   46,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1773, 1009, 2489,   85,  848, 1732,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1140,    1,    9,    1,   37,    1,    1, 2041,  826,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1628,    1,  361,    1,  176,  166, 2826,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  168,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2164,    1, 1850, 1327,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671,  640,  356,  845,  310,  159,  504,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2676,   37,  877, 2237,   37,    1,   98, 1517,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2114, 1713, 2723, 2724,  437,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  612, 1273,   32, 1766, 1767,    1, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,   55,  105, 1628,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  114,  688, 3206,   32,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  147,  246,  450, 1393,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  458,   45,  507, 1536,    9,  797,   32, 1047,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1458,    1,  221,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3257,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545, 1917,    1, 1863,  748,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3343,  863,    1,    1, 1159,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  147, 1707,  205,  793,  662,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3369,  719,  764,   37,  439, 3118, 1512, 2835,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91, 3067, 3379, 2950,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  597,    1,    1,  513,  514,   32, 2154,  161, 2607,  400,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2822,    1,  488,  249,    1,    1, 2321,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  284,  773, 1996,  111,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2547,    1,   37, 2162,  191,    1, 1537, 2702,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  667,  159,  439,  699,  242,    1,  640,  241,  119,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2238,    1, 1998, 2677,  220,    1,   12,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 506,  32,   1, 967,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 529, 408,   1, 732, 244,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  716,  118, 1124,   32,   72,  401,  244,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   37, 1706,  131,   32, 2336,    1, 2168,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 1177,   37, 1383,    9,    1, 3222,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1380, 1768,    1, 1159,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,   28,    1,   37,   47,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2958,    1, 2731, 1069,   32,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   26, 3230, 2951,    1, 3173,  614,  582,   37,  582,  220,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  267,  792, 1284,    1,  792,  220, 1512,   32, 3118,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1050, 2262,  207, 3387, 2985,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1018,    1,    9,  323,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1162,  315,   37,    1,   23,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1633,    1,    1,  151,    1, 1501,    9,    1,  372, 2097,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1720,    1, 2489,    1,  460,   12,  199,   37,  335, 1318,   45,\n",
      "          166,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 1203,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1770,    1,   12,    1, 2385,  612, 2567,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101,    1, 2414,   32, 3339, 2791, 3133,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1252,  275,   12,    1,  879,   24,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   10, 1408,  841,  187,  475,   45, 1346,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162, 1950,   32, 3118, 2517,   45, 3369,  167,  759,    1,    1,\n",
      "          163,    1,   12,    1,  232,  267,  963, 2122,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1680,  992,   28,  192, 1896,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  104, 2841,  872,   12,    1,  916,    9,  671,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 849, 132,  66, 972,  88,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 108,  45,   1,   1,   1,   1,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  219, 2005,  619,   81,   98, 1171,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2047,  361,    1,   98,    1,  836,  384, 2170,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596,    1, 3149,  861,   23, 2803,  548,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  396, 1465,  846, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  462,  162,  168,  115,    9,   49,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340, 3212,    9, 1909,  199,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  530,   98,  430,    1,  517,  509,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 1252, 2540,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  272,   32, 1647,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  980,    1, 2053,  569,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  405,   12, 1594,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,  102,  670, 1315,  105,  106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3405, 1702,    9,    1, 3114, 2024,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  730, 2614, 2651, 2615,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3345, 2253,   37, 1594,  297, 2135,  475,   37, 3381,   12,  437,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  280,   84,  460,   28,  105,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1913, 1843,  207,  418,    1,   98,    1,    1,   15,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   98,   74,    1,  105,    1,   45,  888,   32, 2468,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,    1, 2284,  548,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3169, 1632,   37, 3295,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779,  879, 2315, 1045,   32,    1, 1787,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2620,  765, 1850,    1,    1,   85, 3106,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  224, 2995,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  193,  105,    1,  173,    9,    1,    1,  225,   85,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1940,   12, 3208,    1,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3232,  877,  460, 1056,   73, 2198, 1018, 2561,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  551,    1, 1332,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2697,   12,    7,  365, 2741, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  716, 1534,   45, 2095, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094, 3057,   46,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1194,  395,   22,   16,   37,   26, 1411, 1034,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3367, 1830,   37,  168,   37,  806,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  555, 1414,   69,  102,  242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  286,  441,    1,   32,  927,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  544, 1228, 2264, 1188,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,  105,   84, 1415,   37,  647,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1877,   37,   71,  384,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1216,    1,   12, 2312, 1442,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1430,    1, 2764, 2765,  722,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  683,   12,  199,   37, 2230,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151,   37,    1,   39, 2308, 2283,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3079,  360, 1364, 1365,    1, 2362,   37,    1,   46,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1411, 1821, 2107,  680,  454,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1711,   45, 2455, 1960,  786, 1357,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3048, 2923,   76, 2697,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  971,  515, 1656,    1,    1,   32,  347,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1086, 3168,   12, 1684, 1625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1856,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1445,  459,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,   98, 2001,  384,   91,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    6,    1,  636,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  665, 1019, 1183,    1,    1,   32,  453,  913,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1509,  151,   37,   47,  176,  612,   12,  116,  259, 1108,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2546,  733,  547,   59,    1, 1632,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1, 1396, 3006,   32, 3391,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  667,  493, 1125,  972,    1,  607,    9,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  202,  190,    1,  501, 2056,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,  167,  664,   72, 1674,    1,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,  26,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 162, 411, 432,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1539,   45, 3101, 2968,  853, 1464,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  251, 1797,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1009,   12, 2789,  140,    1, 1002,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2324,  820,    9,    1, 2232,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  147, 1392,  400,   45, 2895,    1, 1920,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1957,  686,    1, 2597,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2774,  437, 1542,   37,    1,   63, 1663,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2704,  477,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2005,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1188,    9,    1,  866,  781,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   47, 2307,    1,  721, 2456,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550, 2851, 2659,    1,    1,  967,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   32,  336,    1,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,    1,   39,  803, 2075,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  181,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  121, 1421, 1651,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  470,  384,  356,  845,  202, 2449,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  775,    1,    1, 2706, 2232,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  105, 1023,    1,    1,    1, 2162,   45,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2595, 2745, 1120,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1156,    1,   37, 1844,   32, 2708, 2823,  863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26, 1039, 1564,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1118,    1,   95,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1406,  600,    1,    9,  749,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   32, 2789, 1819,    1, 1861, 1216, 2179, 1251,   45,  531, 2958,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  698,   45,  597,    1,  475,   12,  776, 1961,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1228,  187,  105, 1108,    1,  636,    1,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2227,   64,    1,  455, 3222,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3110,    1,  453, 1744,    1, 2337,    1, 3194, 3195,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,    1,  581, 1023,  197,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  547, 1262, 1017, 2094,  249, 2444,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2916,    1,  542,    1,  187,  163,    1,   12,    1,  640,   81,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  671, 1078,  615,    1,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2778,  912,  767,  297,  863,    8,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  590, 2338,   98,  531,    1,   10, 1877,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  474, 1149, 1575,  176,  960,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1736, 2636,  251,    1, 1935,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3110,    1, 3166,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2956, 3017,  791, 1563,  884, 1601,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2987, 2988,  640,    1,    1, 3005,  123, 2072,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  596, 1151, 2287,   15,   66,   85,    1,  118,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1497, 2497, 3384,    1,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1934,   12, 1065, 1190,   61,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   77, 1658,    1,   39,   45,  460,    1, 3335,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  189,    1,  963, 2281,  927,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  204,   12, 1997,    1,   37, 1957,  190,   81,   28,\n",
      "            1,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1100,    1,  365,    1,  469,    9, 1151,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220,  365,    1,    1, 2885,    1,   32,    1,   45, 1194,  726,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  857, 2828,  868,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810, 1292, 1090,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2349, 1176,    1,  229,  726, 1876,   32,    1,  506,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  741,   32, 2823,  890,    1,   76,   37,  726,  581, 2113,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  535, 1523,    9,    1, 2577,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  638,   74,    9,    1, 1123,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  177, 1530,   32,  121,   36, 3071,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1127,   37,  693,   40,    1, 1962,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3172, 1090, 1829,    1,  176,    1,  275,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3257,  682, 3329,  913,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2565,   61, 2098,  261,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  204,  583, 2349,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  306,    1,  829, 1753,  923,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3252,    1,  234,  190,  698, 1517,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1006,   30,  459,   45, 1019,  238,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111, 1013,    1,   61,    1, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1625,   37,    1,  103, 1505,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1,  546, 2828,   37, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1718,   61,  105, 1665,    1,  460,   51, 1719,  102,    6,\n",
      "          361, 2051,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1, 2171,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1645, 1009,    1,  593,   12,    1,  826,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1798,  297, 2673,  315, 1489,  863,  855,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3375, 2047,  388,   45,  166, 1690,  548,  104,  890,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  794,  365, 1230, 1774,   39, 2610,  124,   32,   91,  551,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1432, 3207, 2226,    1, 2310,  985,   39,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2476, 2506,   37, 1911, 1370,   45, 3393,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  342, 1189,   46,   98,    1, 2673, 1816,  729,   98, 1171,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3118, 2751, 1066,   98, 2024, 2467,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  751,    7,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,    1,    1, 2253,  863, 1860,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3064,  683, 2963,   32, 2106, 1990, 1343,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465,    1,    1,    1,  131,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1971,   26,  220,  726,    1,  297, 3250,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  581, 1023,  197,  418,   98,    1,  887,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1879,    1,   51, 2760,   32, 1056, 2119,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,   37,  588,    1,  138,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2243,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   37,   92,   15,  176,  104,    1,  773,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3235, 3248, 1121,   85, 3260,   44,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2057, 1670, 1300,  615,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   12, 1033, 1443,  429, 2673,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1465,  418,  548,  207,  388,  763, 1660,   98, 1230,   15,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1900,  337,    1,    1,    1,  383,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1035,    1, 1070,    9,    1,   12, 2488,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1576,  912, 3402, 3408, 2118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159,   71,   98,    1,  195,  562,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  326, 1380,  861,  176, 1658,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3252, 1810,    1,  979,  228,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   69, 1226, 1114,   98,  800,  163,    1,   12,    1,    4,   29,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203,   37,  877,  166,  917, 1140,   98,  617,  315,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,    1,  384,    1,   12,    9,  105,  152,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1640,  782,  228,  365, 2165,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  686,  424,  829,    1,  224,  288,   37, 1046,   79,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2068,   45,  597, 1212, 1009, 1976, 1530,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2511,   37,   81, 2487, 2723, 2724,  361, 3016, 1935,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1194, 2132, 2748, 2097, 2160, 2049,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962,    1,  571,    1,  919, 1668,   37, 1918,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938, 1282,   12,    1,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1101, 1102,    1,   32, 1613,   12,    1,  612,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1065, 1190, 1481, 1445,    1,   32,  691,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  716,    1,  954,   61, 1793,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  794,  224,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  203,   37, 1116,    1,    9, 1013, 1522, 1299,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,  681, 1330,  365,  809,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  361,    1,  477, 2355,    1, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3382, 2352, 2646, 2024,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 2142, 2540, 2142, 1022,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  193,  810,  492,    1,  565,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1529, 2164, 2668,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2427,  606,  590,  509,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2779,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   25,    1,  417,   98,    1,  425,  426,   15,  739,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,    1,  696, 1876,  567, 2372,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,    1,    1,  632,    9,  810, 1425, 1674, 1684,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  105, 2623, 2624,  400, 2493,    1,    1, 1867, 1000,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 2925, 2954, 2935, 1131,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 342, 908, 148,  12, 142,   9, 647,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 779,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  920,  357, 1745,    9, 1850, 1423,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2483,  810,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1656,    1,    1,    1,    1,  778, 1225,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   47,  493,  725,    9,    1,   54,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  726,  176, 1485, 1990,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1064,  138,   79,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  978,    1, 1445, 1421, 1417,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116,    1, 1046,  365, 2026,  126,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  476,    1,   37,    1, 1992,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    9,  327, 1494,  220,  284,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2580,  861,  328, 1961,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325,   48,   32,  632,   69,  700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2328,   13,    1,  804,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1162,  315,   37,    1,   23,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  766,  884,    1,   37, 2082,   32,  768, 1388,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  915,  916,    9,  864,  297, 2673, 1757,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  597,    1, 2965, 3139,   37,    1, 1796, 1920,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1780, 1308, 1985, 1178, 2792,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1317,   37,  123,   28,   37,  124,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,  186,   98,  800,    4,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1340,  140,  119, 1909, 3235, 3212,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284, 2746,    1,  166, 2789,  894,  619,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1149,   32,    1,    1, 1947, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3287,  530,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2676, 1554, 2611,  548, 1867,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2817,    1,   32, 2140,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,   12,    1,  220,  105,    1,   12,  985,    9,  691,   12,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  737,  197,  338,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  216,  898,   32, 2936,  548,  304,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1809, 2498, 2701,  813,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   37,  764, 2702,  463,  464, 3053,  191,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2528,  669, 1009,  113,    1, 1953,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1822, 2394, 3304,    9,  317,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1827,   32,    1, 2160,   45,  799,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1061,    9,    1, 1656,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  597, 1405,    1,    1,   61, 1231,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187,  535, 1648,   37,   77,    1,   32, 1381,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  657, 1949,  469,   37, 1237, 1412,  844, 1151,  218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  854,  877,    1,    1,   32,  449, 1463,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 900, 721,   1, 475,   1,   1, 774, 587,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 105,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,  271,    1, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2853,   28,   37,  247,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  931, 2365,    1,  361,  460,   12, 1284,  857,  411,    9, 3231,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2476, 1414,  477, 3155,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2016,  386,  140, 1479,  922, 3096, 3154,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2855,    1, 2099, 1771,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,  368, 2003,  114, 2162, 1950,  418,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3258,  708,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  561,    1,  136,  597,   82,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  103, 2087, 2614,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2881, 1484,  861,  105, 1745, 2093, 1523,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  338,   37,  339,  340,   98,    1,  341,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,    1,  441,    1,  365,  977,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  978,  769,  439,  417,    1,  425,  426,  246,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176, 2087,  433,    1,   10,  361, 1861,    1,  973,    9, 2708,\n",
      "          171,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  381, 1205,  297, 1405,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1499,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1676,    1, 1048,  548, 2596, 2716,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3101,    1,   51,  619, 1038,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3334, 2579,   51,   52,  653,   79,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,  147, 1707, 2932, 1377,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  268, 1077,    9, 1092,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398, 1579,    1,    1,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035,   37,  698, 1038,   32, 1352,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,   12,   26, 1039,    1,  920, 2812,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1100,    1,   98, 1647,    1,    1, 1434,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  730, 2614,    1,  191,  978, 3138,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1648,   37,  815, 1193,   69, 1356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2441, 2852, 1205,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1107,   15,   98,  166,  777,   37,  686,    1,  496,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  640,  187,   49,    6,  395,  109,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  550,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 2950, 1450,   98, 3391, 2165,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2031, 2606,    1, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1022,    1, 3008,  967,  553, 3087,  452,  465, 1352,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  998,   28, 1103,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111, 1107,  525,    1,  459,    1,    1,  421,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  567,  640,    1, 2921,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  655, 3395,    1,  104,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2256, 2373,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1867,  955, 1461,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3207,    1,    1,    1,   37,   77,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,    1,    1,   61,  590,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  382,  387,    1,  354,    1,  159,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993, 3056,    1, 1117, 1525,    1, 2812,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  744,  949,    9, 3018, 1455, 1294,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2960,  640,  531, 1407,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3363,   12,  472,    1, 2726, 3343, 2003, 1585,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  879, 2522,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,  207,  197,  388,  763, 1660,    1, 1178,  105,   92,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1118,    1,  557,  540,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1189,    1,  287,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    8,  116, 2542,  861,  328,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1891,  593,   12,    1,   37,   10,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,    1,    1,  365, 2217, 1277,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  455,   82,    1,    1,  475,    1,   37,    1,  176,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1672,    1,  166,    1,  187,  331,  551,   12,  832, 1258,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  199,   98, 1964,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 2694, 3148,   32, 3369,   12, 3118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3097,  741,    1,  191,  133,  134,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340,    1,    1, 1857,   98, 1827, 3265,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  183,    1, 2682,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1585, 2478, 2597,    1,    1, 1999,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962,    1, 1938, 2809,  696,  931,  688, 3296, 1114,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  976,    1,   37, 1344, 1429,    9,   69, 2054,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2227,    1,  705,    1,  105,    1,    1,  304,   98,  166,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  193,   37,   52,    1,    1,  758,  256, 1117, 1525, 2759,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  996,  157,    1,  105,  784,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1445,  376,  156,  837,   98,  567,  396,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  463, 2170, 3159, 2602, 1853,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  381, 1205,  297, 1405,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 3185, 1063,   37, 2360,    1,   12,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1741, 1519,  223, 1639,    9,  597,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,  402,   37,  224, 2995,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  375, 1236,    1,  297,  229,  798,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  502, 1525,  738,  284, 1396,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2658,   45,    1,  166, 2069, 1435,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,   12, 1043,  640,  105,  786,  339,  340,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,  267, 1585, 1370,   45,    1,    1,  934,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   65,  379,  470,   68,  122,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2196,   12,   32,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  221,   28,   32, 2771, 3154, 2522,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006,  729,   32,  674,   45, 2646, 3346,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,  65,  66,   1,   7,  67,   1,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1,   1, 197, 418,  88,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788,  951,    1,  166, 2832, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12,    1, 1886, 1822,  631,   37,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2427, 1722, 2522,  220,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3330, 2034,    1, 1185,  590,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2662,   32,  730,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   45,  166,  593,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1520,    1,  104, 2419,  218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1938, 2607,  382,   66, 2098, 1675,   15,  119,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  213,   37,  221,    1, 3396,   37,  230,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  920,    1,    1, 1594,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,   39,   45,  730, 2060,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2231, 1042,    1,   44,  444,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1159,  105,  979,  808, 2198, 2330,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,    1,  187,  383,   69,  102, 1344,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  251,  297,    1,  182,    9,    1,  596,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  619, 2016,   12, 1217,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2882, 1898,   37, 1050, 2095,  617,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1, 2040, 1147,  890,   98, 2462,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  861, 2091,    9, 3343,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  595,   45,  166,  294,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  939,  187,  104, 3030,   37,  386,  497,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1366,    1, 1584,  168,  424,  199,    1,  267,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3115,   26,   37,    1, 2407, 2777,    1,    1,  361,    1,  606,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 2164, 2372,    1,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  129,    1, 1563,   32,  166,  272,    1,  267,  942,   12,    1,\n",
      "         1190,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  444,  166, 2402, 1433, 2208,  833,  612, 1604,  361,  579,\n",
      "          334,  321,  544,  600,  460,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1759,  309,  159,  123, 1298, 1382,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    8,  197,  304,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1009,    1,    1,    9, 2315, 2376, 2024,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 2352, 1861,   12,  228,  402, 2024,  469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2314, 1963, 1082, 2275,   37,    1,  863, 1450,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  999,    1,  388, 2529,  327,  529,  617,   61,   98,  166,  454,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  747,   12,  196,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 1656, 2909,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2881,    1,   98,  627,    1,    1,   98, 1718,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  250,  190,  243,  581, 1119,    1,    1,    4,  191,  257,\n",
      "          439,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,  868,   80,  802,  220, 1842,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  795,  295,    1,  359,  759,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,  361, 2254,  875,   39,   45,  147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  353,    1, 1913, 1843,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1086,    1,   12,  914,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3244, 3159,    1, 2072, 3188, 2631,    1, 1879,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1773, 2510,    1,  227, 1160,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1891,  922,    1, 1982,   97,   98, 3140,   37,  319, 1430,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3253, 1564, 1139, 1604,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1602,   12, 2764, 3210,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  627,   45,  166,  777,   61,   98,  166,  221,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  891,    9, 2217,   12,  365, 1277,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   74,   32,    1,  187, 3251,    1, 1343, 2069,  754, 1090,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  716, 1083,  365, 1574,   98,  790,    1,   45,  195,  230,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 3160,  513,  514,   37,    1, 1147,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1065, 1190,   12, 1574,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1035, 1070,   37, 1642, 1175, 1371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100, 2067,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  683,  801,   37,  395,   26, 2069,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  442,  475,  952,    1,  271,  788,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  208,   37,  211,  182,  734, 2434,  693,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283,    1,   39,    9,  914,  220, 3265, 1987,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   32,   12,    1,  584,    1,  311, 1104,    1,  729,  840,  198,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 2915,   46,  220,  104,   98, 1031,   45,  316,   12,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  159,   85, 1969,  594,  156,  932,    1,  104, 1393,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,   12, 1167, 1620,    1,    1,   61,    1,  220,  166, 2836,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1773,   37, 1539, 2510, 1090, 1294,   32, 1169,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  303,    1,  104,    1,   37,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  782,  160,  783,   28,  105,  784,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,  721,    1, 1143,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,    1, 1535,   37,    1, 2819,  384, 1712,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  117,   15,    1,   93,  176,  316,  317,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,   12, 1230,   61,  105, 1568,    1,   98,  818,    1,    1,\n",
      "          424,  356,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  315, 2866,   28,   45,  535,  656,  327,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  224, 2229, 2641,  630,   61,    1,  449,   84,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  355,  884,  166,    1,   39,   45,  236, 1022,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2183, 1428,  223,  232, 2682, 1663, 1659,  297,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3332,   98, 3311,  204,   12,  105,    1,    1,    1,    1,\n",
      "          105,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428,    1,  167, 1937,  388, 3118, 3396,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 2962,    1, 1879, 2712,  365, 1788, 1497,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1123,  548,  537,    1, 1123,  571,   37,  316,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3186,  688, 3176,    9,  449,  199,   32, 1312,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,    1,   32, 1411,  356,   12, 1764, 1990, 1022, 1385,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1821,  176,  166, 2190,  187,    1,    1,   28,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3181,  304,   37, 3116,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  198, 2799,    1,  361,  166, 1110,  243, 1515,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3276,   81, 1810,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 3286, 2230,   32,    1,  854, 2579, 3201,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1855,    1,   32,  531,    1,    1,    1,   30,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 1447,  376, 1184,  347,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1585,   32, 3339,  754,   45, 3374, 1178, 2414,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 3350,  903,    1, 1447,   51,   47, 2439,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,  176,  539,    1,  187, 2565,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  352,   51,    1,    1,   50,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1361, 2715,  506, 1821,  341,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1700,    9,    1,  187,  365, 2036,  470,   37, 1918,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676,    1, 1292,  928,  548,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1191, 1561,   28,  378, 1083,  160,  122,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,    1,    1,   37,  651, 1259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  369,    1,   37,  151,  104,  223, 1085,  441,    9,   59,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2997, 2454,  167, 1762, 2026, 2574,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056,  610,   37, 2162,    9,    1,    1, 1260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,  421,    1,  755,  875,    1,  133,  134,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 2996, 2306,    9, 2355, 1013, 2549,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  427,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2218, 1214,    1,    1,   32,  449, 1056,  176,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1966, 1070, 1899,   37,    1,   59,  104,  458,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1352,  996,   29,  410,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  497,   37, 1496,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3129, 3303,  140,  119, 2674,  593,  427, 1343, 1684,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  251, 2492,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1414, 2555,  582,   45, 3043,  531, 3384,\n",
      "          617,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3358, 1572, 3375,  202,    1, 2024, 2813,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,    1,  191, 2789,    1,  187, 3358, 1216, 1809, 2958,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1652,  353,  197,   88,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2266, 1458,  104,    1, 3369, 3146,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2,  69, 640, 365, 119,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 328,   1, 387, 417, 572, 156,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2800, 3296,  542, 1822, 2047,  105, 3317,    1,   39,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  719,  228,  388,    1,   37,  798, 2522,  726,   32,  854,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1918,  986,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2464,   37,    1,    1,    9, 2098,  261,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3120,    1,   98, 2347, 1638,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1827,  967, 1532,  166,  810, 1292,  872,  547, 1215,\n",
      "            1,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  310,   25,   71,  187,   69, 1042,  384,  119, 1955, 1401, 1758,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708,  650,    1,    1,  943,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  854,  167, 1982, 2018,   12, 1815,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  475,    1,   37, 2059,   12,  589,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  187, 3151, 1756,    1,   98,    1, 1875, 2272,  979,   37, 1835,\n",
      "           32, 2308,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 2615, 2651,  730, 2614,  335, 2522,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  967, 1844,   32,  220,  947,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,    1,  384,  749, 1992,  365,  229,  220, 2557,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  109, 1913,  401,  156,  720,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2161,   32, 2948,  619, 2363,   92,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1229,  105,  807, 2095,  837,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  375, 1236,    1, 1359,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2, 920,   1, 166,   1,  64,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 105,   1, 458, 572, 197, 418, 118,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1326,    1,   37,  693,  853,  538,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3125, 1648,   37,  288, 1796, 1211,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 1707, 1926, 1927, 1928,    1,  640, 2275,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2902,   80, 1108,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  667,    1,  744, 3192,  813,  854, 1401,  191,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,  361,    1, 1174,  792, 1084,  841,  792,  259, 1916,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  593, 2522,  967, 1846, 1533,  384,  105, 2848,  628,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1956,  277, 1154,    1, 3192, 2579,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1985, 1283,   37,    1,  691,  854, 3192, 1463, 2522,\n",
      "          844,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,    1,  732,    1,   12,  776, 2191, 1332,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1417,    1,  624,    1, 2914,    1, 1345,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273,   12,    1,   98,    1,   45,  449, 1684,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  166,  454,    9,   26, 1039,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,  313,    9,  118,   45,  777,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 236, 237, 729,   1, 224,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  150,  716,    1,  120,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727, 1372,   37,  142,  920,    9,  179,    1,  178,  774,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,  166,  645,  550,    1, 2111,    1,  424,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3390,   32,  187,  365, 3104,  475,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1227,  629, 1634,   37, 3081,  339,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  491, 2257, 1346,  384,   69, 2517,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  216,  837, 1853, 1557,  186,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  334, 1851,   47,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1100, 2355,  769, 1285,  115,   45,  657,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 2751,  288,   79,    1,   32, 1815,    1, 1530,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307,   12,    1,  313,   37,    1, 1431,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2483,  388,    1, 2115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  698,   28,    1,  619, 2276,   33,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220,  354,    1, 2643, 2715,   98,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  709,    1, 2565,  302,    1,  928,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  702, 1008,    1, 2166,    1, 1751,  475, 1213,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1043, 1086,   85,  118,  548,   29,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1680,  572,  197, 1784,  118,   98,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1013, 1522,    1, 1381,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2563, 2551,  317, 1090,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 2579,  202, 3124,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  441,  634,   37,  907, 1757,   98,  172,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  420, 3151,  193, 1044,  187,  445,  187,  460,  396,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,   52, 1041,    9, 2089,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   98,  730, 3022,   45, 1204,    1,  978,    1,   45, 2162,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  183,    1,    1, 1141,  444,  861, 2429,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1554, 1849,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  491,  456,    1,    1,  388, 2007,   37,  430, 1313,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  267, 1352,  104,   15,   71, 1387,   37,  570,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  176,  590,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2514,    1, 1426,  166,  439,   45,  166, 2227, 2041,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   45, 1778, 2580,    1,    1, 1108, 1779,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 328,   1,   1,  42,   1, 400,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 305, 186,  98, 720,  32, 367,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  550,  778,  686,  191,  412, 2298,   32,  395,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081, 1536, 2834,  134,  444, 3382,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  179,  361,    1, 1237,  132,   37,   26,  613,    1,   32,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  295,    1,    1,   45,  800,    1,  361,  340,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  104,   69,   27,    1,  109,  997, 1119,   37,  430,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3053,  678, 1185,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2322,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,   22,   23,   37,   52, 3344,  220,    1, 3055, 3162,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,    1, 1419,    1, 2693,   98,  618,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   37,    1,  597,    1, 3289, 3139,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1699,  105,    1,    9,    1,   28, 1658,  327,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  544, 1604,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1011,  472,  340,    1, 1821, 2190,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169,   32, 1505,  115,   45,  104,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1293,   98,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1610,  861,    1,   66,  176,  755,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1831,    1,  166,   97,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1751,  132, 1710,    1,  611,  199,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  295, 1373,   37, 1594,  297, 1168,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  678,    1, 2423, 1073,   85, 2640,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  686, 1619, 2646,  548,  163,    1,   12,    1, 1450,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1933,  295,  515, 1443,  105, 1333,  176, 2295,  218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2313, 1231,  297,    1, 2693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1716, 1972,  327, 1220,  897,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 361,   1,   1, 166, 116,  96,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 104,   1,  98,   1, 865,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 2845,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   12,  193, 1960,  247,  913,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  715,  471, 2126,  800,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3113,   12, 1277,    1, 1023, 2068,   12, 1684,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788,  614,  323,    1,  162, 1253,   98, 1531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2656, 1412,  538, 1822,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  395, 2003, 1585, 2414,    1,  753,    9, 2986,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1550, 2936, 2909,  254, 1634,   37,  531,  443,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1987,  997,    1,  297, 3176,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  507,  111,  716,  720,   32, 2819,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614, 1568,    1,  202, 1914,   12,  977,  984,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3182, 3183, 1090,    1,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   75, 1380,  429,   98,    1,  259,  347,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1583, 2097, 3006,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  596, 1793,    1,    1,  658,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1210,  412,   37,    1,  741, 2116,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2648, 2801,    1,  326,    1,  657,  872,   37, 2341, 1273,   41,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  176, 1364, 1365,    1, 2414, 1056,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1243,   45,  327,  112,  333,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   82,   45,  294,  295,  108,   45,  388,  389,    6,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,  924, 1268,  700,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1430, 2764, 2765, 3060,  928,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1051, 2471,  829, 1872,   37, 1658,  259, 1294,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1786, 3127, 2304,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  103, 2635,    1, 2963,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181, 1564,  999,    1,  841,    9,  617,  618,  327,  593,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1987, 1414,    1,   39,   45, 2142, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1771,  171,    1,  590,    1, 2388,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2236,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1, 1230,  220, 1656,    1, 3011,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2144,  356, 1281,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3178, 1152,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1613, 1766, 1767,    1,  841,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1309,  614,  548,    1,  710,  138,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1485, 2924,   37, 1334,   32,  531,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2877,   37,    1,  531,  863,   32, 3113,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  794, 1362, 2995,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,  765, 1836,  220, 3153, 2220,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 3115, 1493, 1131, 1684,  191,    1,  297, 1110,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  270,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3298, 2479,  103, 1569,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1794,   37, 1073,   85, 2949,  538,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2, 350,   1, 574,  37,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 166,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1640,    1,    1, 1438,  650,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3075, 2864,  350,   27,    1, 3346,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1570,   37,  949, 1718,  659,   45, 2473, 2367,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1390,   12,  627,  176,   48,   32,  474,  943,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  138,    9, 1361,   12,    1,  407,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   14,   15,   85,   32,  367,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  773,   51,  606,   37,  544,  284,    1,   37,  619,  575,   81,\n",
      "           32,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,  547,    1, 2308,    1,   32,  136, 3217,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 197, 418,  98,   1,  15,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  515, 1959, 1918,  297,  316,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,   98, 2018,   12, 1926, 1927, 1896,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1985, 1215, 1056,    1,  786, 3076, 3289,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  477,  411,  444,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3358,    1,  187,    1,  897, 1813, 1404,  361, 2179,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2694, 1299,  443,  444, 1230,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  872,   28,   37,  804, 1972,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1465,   61,    1,  415,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   69, 1069,    1,  187,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835, 3109,  228, 2985,  297, 3393, 3389,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2525,  220,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1610, 3327, 2657,  167,  805, 3190,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  361, 1361,  469,    1,   37,    1, 2532,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  626, 2221,    1,    1,    1,   37,    1,   32,    1,  283,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  632, 1149,  186,    9,  242,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  396,    1, 1007,  920,  593,   12, 1354, 2529, 2334,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  584,    1, 1079,  103,  147,   37,    1,  131, 1080,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12, 1273, 1182,  837,    1, 2013,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,  613,  200,    1,    1, 1671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2922,    1, 2764,    1,   98,    1,   12,  809,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  105,    1, 1007,    1,    1, 1185,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,   51,   52,    1,   45,    1,  625,   32,  903,    1, 1256,\n",
      "            1,  428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3209,  186,   37, 2712, 3271,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  217,    1,    1, 1469,   37,    1,  220,    1, 1443,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,    1,   30,  932,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  458,  739, 1032,   93,    9, 2065,  310,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1486,    1,  155,  197,  570,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  224, 2995,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1181,   37,  949,    1,  259,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597, 2977, 2664,  513,    1,   45, 1792,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 2005,  608,  634,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2680,  256,    1, 2215, 1942,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1043, 1276,   85,    1, 1547,  246,   98,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3120,  872,  420, 1169,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3235, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2372,   45,    1,   36, 1939,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  596,  496,   30,   45, 2064, 1210, 2275,   32, 2087,  433,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671, 3126,    1, 1204,    9,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1818,  147,   37, 1709,  400,   98, 1842,  187,  116,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1066,    1,  105,    1,   45, 1809,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  105, 2313,  808, 2876,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1727,   37,  949, 3340, 1527,  475,    1,  191,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  224, 2355, 1013,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1,  455,  726,  397, 1876,    9,  442,  909,   98,  104,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,   76,   37, 1947,   46,  220, 2707,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1554, 1090,  220, 1987,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1, 2238, 2436,    1,    1,  662,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 1821, 2190,  472,  340,   98,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   50,   37,   92,    1,  983,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1,  570, 1010,  459,   45, 1424,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  512,  176, 2136,    1,    1,    1, 1612,    1,  149,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  315,  658,  336,    9,  660,    1, 2581,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  388,  104,    1, 1041,    9,    1,  225,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169,  140,    1, 1990,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  121, 1008,  365, 1821, 2190, 2640,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3297, 2132,  601,   32, 3278,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  162,  105,  389,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  638,  836,  384, 2890, 2202,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1461,  640, 1656,   32, 3339,    1,  176,  177,  786, 2708,\n",
      "         2572,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2881,    1, 1718,  582,   98,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 3164,  507,  696,  163,    1,   12,    1,  221,   98,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  799,  167, 1910, 2048, 2198, 1021,    1,  284,    9, 2119,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2737, 1243, 3279,  220, 3311, 3310,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  111,    1, 1281,   61,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3253,  167,  865,    9, 1764, 1990, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,  562,   12,  182,   32,    5, 1631,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,    1, 1401, 1894, 1537,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2496,   45,    1,    1, 2548, 1976,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2162, 1950,   32,  310, 2164,  139, 2424,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3231, 1285, 2642,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2090,  702, 1342,  365,  475, 1213,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1086, 3038, 1850, 3339, 2731,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  449,    1,    1, 3343, 1009, 1082, 3361,   37,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380,  267,  163,    1,   12,    1, 1822, 2653,    1,   45, 2834,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,  764,    1,  505,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424,  356,   12, 1110,  603,   55,  915,  914,   12,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  619,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3051, 2725,   98, 1428,  637,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,    7,   31, 1279, 1071,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,  421,  197,  338,   98,  822, 1482,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 3344,   37,  166,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,  458,  475,   46,   28,   60,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  885,    1,   45,  104, 3047,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790,  267, 1544,  191,  230,   45, 1812,  229,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  420, 2173,    1,  136,  759,  895,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1479, 2164, 2478, 1157, 1633,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  715, 2488,    1, 2559, 2235,  225,  269,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,   12,    1,  267,   37, 1046, 1107,  293,  927,   32,  163,\n",
      "            1,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  396, 2397, 1542,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,  450,   95,  384,  104,   37,  451,  452,   61,   98,  453,\n",
      "          454,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2910,  335,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  664, 2347,    1,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,   75,  908,  261,    9,  258,  259, 2015,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,  131, 1763,  176,  629,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1652,  919,    1,   98, 2608, 1499, 2043,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,    1,   28,  803,  112, 1699,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  437,    1,    1,  267,  460,  967,  132,   37, 1154,  487, 3222,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    6,  503,   12, 2316,  105,  731,  191, 1056,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  596,  616,  219,  159, 1269,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  384,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  546,  176, 3045,    1,  105,    1, 2596,   32, 3356,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481,  140,  601, 2113,   32,  667,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1236,    1,    9, 2086,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  737,  197,  738,  739,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   39, 1048,  855, 1452,   63,  736,  891,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3388,    1,   51,   52, 2714,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2751,   23, 2752,  681,   37,  123,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  774,    1,    1,   51,  193,  865,   32,  424, 1204,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,   25,   71,   32, 1034,   12,  551,  552,  682,    9, 1194,\n",
      "         1034,   32, 2144,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  664,   37,    1,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  473,  741,   37,    1,  477,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,   37,  480,    1, 2400, 1021, 1129,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2334, 2107, 1618,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   66,  417,  187,   69,  113,  530,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3323,    1, 2583, 2317,  191, 2925,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  900,    1, 1860,  888,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  647,  475,   12,    1,    1,  187, 1389,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3116,  922,  437, 1417, 3315,    1, 1413, 3191,  187,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1763,    1,  105,  365, 1421, 2829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053, 1109,   12, 1854,  267,  805,   45,  824, 1484,  905,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1198, 1324,  297, 1675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 2449,   32, 2755, 1206,    1,    1,  220, 3175,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,  361, 2275,  619, 1542,    9,  915,  844,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  105,   60, 1167,   12,  383,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2227,    1,  880, 1450,   36,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2942, 1564, 2315,  865,  176,  593,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  884, 1013, 1273,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  353,  354,  202,  387, 1647,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  389,    6,   71,  981,   32, 1332,    1,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1569,   32, 3293,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2024, 2223,  105, 1103,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1537,    1,    1, 2889,    9, 1204,  548, 1894,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1445, 3109, 2673,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2691,    1,  220,  885, 1204,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  669,  495,   66,   28,  384,  356, 1490,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3051,  232,    1, 2571, 3406,    1,  612,  110,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3038,   74,   32,  531,  344, 3403, 1450,  294,  361, 1147,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 620,   1, 361, 166,   1,  60,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  12,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3343,    1,    1, 1426,  119,  845,    1, 1428,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3250,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1229,    1,  365,    1,   32,  903,    1,\n",
      "         1447,   46,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,    1,   74,   15,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1306,    1,  171,   12,    1,   37, 2553,   39, 1090,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   31,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1240,  698,  444, 1879,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1818,  147,  484, 2156,  297,  912, 2285,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1,  980, 1512,    9,   91,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1461, 2414,  786,   32, 3339, 2791,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1353, 2285,   45, 1039, 2690,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2571, 2153,  360, 1407,    1,   32, 3118, 1816,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,  315,    9,    1,  660,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  238,   98, 1965,  202,  193, 1204,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  644,  114, 3162,  176, 3339,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1136,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  364,  156,   71,    1,  907, 1944,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2558, 1398,  612,    1,    1, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  964,    1, 1931,  297,    1,   45,  531,  806,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1137,   98,  689, 1167,  667,    1,  190, 1594,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,  442,   16,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2031,  387,  105, 1298,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3394,  313,   37,    1, 3343,  890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2009,  729,   26,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3006,  729,  429,  649, 3365,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1557, 1484,    9,  885,  477,   32, 1853,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   32, 3369,    1,  590, 1048,    1, 1813, 1891,  361, 2571,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1,   27,    1,  395, 1441,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   49,  159,   71,   98,  142,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  484,    1,   32,  400,   45,    1, 1920, 1231,  220,    1, 2059,\n",
      "           37,  163,    1,   12,    1,  963, 2122,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2449,   32, 2941, 2107,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  605,  781, 1353,    1,   45, 2695,    1, 2193, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  437,    1, 1604,   98, 1994, 2819, 2461,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 1090, 1829,    1,  176, 1531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1273,  259,   15,  729,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  600, 1934,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  506, 1898,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  166,    1,   45,  105, 2312, 1691,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  936,  356,   93,  469,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,  421,  225,  967, 2012,   37,   71,    1,   12,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,    1, 1828,   45,    1,   76,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1971, 1054,    1,    1, 3310,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  795,  359,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,   12,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  551, 1035,    1,  901,   37,    1, 3254,  551,    1,\n",
      "         2594,  551,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  784, 2580,    1, 1288,  590,  636, 1500,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1405,  133,  776, 2055,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1538,  477,   37, 1313, 1108,    5,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  442,  448,  590, 1389,    9,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  812,    1, 1918,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   98, 1383,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1735, 1343,    1, 3250,    1, 2715,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  735,  681, 1046, 1797,  133,   43,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2767,  613, 2759, 1671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  912,  605,    1,    1,  765, 1836,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,  260,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  160, 1278,   28, 1969, 1014,  276,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,   74,   98,  236,  237,  187,   69,  636, 1042,    1,  374,\n",
      "          801,    9,   72,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3297,  765, 1159,   72,  913,   32, 3278,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,    9,  938,   37, 1540,  247,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1712,   37,    1, 2020,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,   11,  129, 1286,   12, 1521,    1,  112,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  325,    1,    9, 2943,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3290,    1,    1,   39,    9,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2977,   37, 1776,  365, 1280,   45, 2983,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  798,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  520,    1, 3343, 2784,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1028,  326,    1,   37,    1,  327,  218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2764,    1,    1,  331,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  398,  261,  399,  400,   26,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2801,   37,  693, 2311,    1, 3085,  517,  618,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  612,    1,    1,  384,  124,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1433,   10,   61,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1509,    1,   32,  166,  433,    1,  612,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2179, 1394,  446, 1936, 2135,   45,  112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,   37, 1155,  617,  618, 1159,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   65,  475, 1301,  223,   45,  104,  217,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1060,   45,    1,    1,   37, 1789,    1,  686,  191, 1797,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3143,  992,   28,  861,  187,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1670,   37,    1,    1,  657, 1008,    1,   82,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2784,   37, 1423,    1,    9,  284,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  774,  994,    1,  150,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2999, 1994, 2819,  877, 2518,  193, 2819, 1108, 1781,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800, 3281,  688, 3316,    1,    1, 2537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  682,    1,  365,    1, 2148,  308,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,    1, 1861, 1816,  937,  297, 2292,   32, 3369,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  111, 1107,    1,   51,   52,    1,  191,    1,    1,    1,  829,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1425,  166,    1,    1,   51,  865,   37, 3175,    1,   39,    9,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2062,  650,  140,  741,   37, 2035,    1,  232,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3177,   98,  247,  454,   37, 1691,    1,  187,  386, 1083,  142,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3257,   37, 1046,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,  459,   28,    9,    1, 1225, 2549,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  906,  176,  166, 1477, 1990,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 1229,    1,   49,    1,  333,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  135,    1,    1,  967,  505,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968, 1594,   98, 2304,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3319, 1073,   39, 3231,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,    1,    1,    1, 3358,   61,    1,   37, 1694,   98,  539,\n",
      "          458,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3251, 2712, 2685,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2440, 2969,   32, 1778,  696, 2324,  579,    1,  460,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  268,    1,   32, 1092,  524,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567, 1193, 1527,  288,   28,   32,  584,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1363,    1,  615,  191,    1,  158, 2013,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  822,  856,    1,  644,  734,  748,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,  813,   32,   91,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260, 1348,   44,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  223, 2420,   86,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   58,  197,    1,  157,   28,    1,  225,   85,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  228, 2572,    1, 1700, 2347,  191,    1, 2751, 1897,    1,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711, 2249,  384, 2504, 1223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,    1, 2414,  187, 1428,  232,  108,  199,  193,    1,    9,\n",
      "          806,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2551,    1, 1110,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  548, 2250,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2733,    1,  297,    1, 2931,  674, 1563,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   79, 1515,   81,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1421,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1041,    1,    9,    1,  730,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,   29,    1, 1632, 1013,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   75, 2678,  167,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2595, 1187,    1, 1305,  361,    1,   37,   52,    1,  193,\n",
      "            1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 381,   1,   1,  32, 399,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  69, 636, 640,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  258, 1601,   45, 1933,  533,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,  657,  872,   98, 2474,  613,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1448,    1, 2050,  636,  125,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2746,  798,   10,   12, 2075,  190,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  573,  574,   45,  365, 1788, 1536,  149,  444,  503,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3325, 2463, 1385, 1924,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3375,  469,  890, 1387, 1890,   37,  712, 3358,   12,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  437,  288,   37,  865,   37,  329,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,  162, 1697,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363, 2783, 3343, 1002,  726,    1,  413,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  758,    1,   37,  619, 2589,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3132, 1415, 2007,   81,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,    1, 2249,  187, 3121,    1,  640, 2433,  455,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1022,    1, 3008,  406,   51,    1, 2960,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  793, 1070,  147,   37,    1, 1384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1170,  853,  459, 1481, 1349,   37,  356,  895,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    9,  166,  119,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   94, 1426,  365,  845,  444,  166,  104,   60,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1317,  315,   37,  123,    1,  124,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1,  903,    1,  464,    1,   32,  594, 1134,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2310, 2494,  967,   18, 2848,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  134,  606, 1846,    1,   32, 3141, 2811,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   25,   71,    1,  202,   69,  490, 1114,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   63,    1,    1,    1, 1658, 1778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  460,    1,   55,  105, 2494,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2501,  861,   37,  619,  242, 2395,  650, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1503,  931,   32,  207,  861, 2716,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2272,   32,  166,  449, 1841,   45,  112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  852,   37, 1636, 1778,  176,  754,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,   34,    1,   37,  365,  119,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2322,  288,  548,  829, 1443,  319,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,  190,   77,    1,  102,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2994,   12, 1215,  117,  857,  187,   59, 3049,   27,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,    1,    1,  773,  774,  590,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 3347,    1,  140,    1, 1684,   32,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2283,   12, 3129, 3210,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  182,  754,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1877,   37, 1604, 2177,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3343, 3345,  288,  365, 1757,    9, 1428, 3365,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3323, 1878,    1,    1,  827,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  131,  961,  448,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1450,   98, 1778,  327,   12,    1,   32,  449, 1023,   45,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3369, 1407, 2924, 1844,    1,   45,  957,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  242, 2247,  102,    1,    1,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1037,    1,   85,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  356,   32,    9,  535,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3003, 1236, 1107, 2633,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  225,  616,  186,   98,   65, 2509,    1,  417,   69,  102,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  313,    9,   56, 2403,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,  947, 1013,    1,  735,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1894, 2846,   32,    4,  631,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  762,  951,    1, 1639,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  107,  967, 2411,  104,    9,   69,  764,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 3345,  774,  957,  213,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  593,   12,    1,  826, 1268,   32,  447,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2651,   32,    1, 1564,  104,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328, 1105,  787,  267,  857,  818,  583,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,  854, 2572,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  727,   37, 2035,    1,    1,   37,  436,   45, 1700,    1,   78,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3190,  891,  914, 1166,  460,    1,    1,  176,  590,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,    1, 1078,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1640,   37, 1114,  588,    1, 2251,  384,  455,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  119, 2101,   45,    1,  898,   32,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,   45, 1943, 1236,  422,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,   51, 1079,    9,  562,   37,  125,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,  180,  132,  943, 2070, 1057,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777, 1008, 1644,  548,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1625,    1,   98,   46,   32,  121, 3102,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2592,  787,    1,  297,  829,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1, 2275, 2673, 2362,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 2012,  176,  166,    1,   45, 2890,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,   29,  791,   37,    1, 1532,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1009, 1579,  535,  625,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2083, 1470,   32, 3358,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2265, 3082, 1988,   45, 1997, 2764, 3394, 1098,    1,   32, 1038,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,  980,   37, 1918,   32,    1,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,   12, 1481, 2864,  601, 1002,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2161,  508,  798,   37, 2268, 1763,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  659,   45, 1643,  112,  786, 2812,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974, 2326,  798,   37,    1, 2223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3256, 2939, 1654,  220,    1,  187, 3055,  674,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   12,    1, 1151,  293,  719,  105,  469,  182,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3204,    1, 3257,    1, 3169,  726,  176,    1,   26,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965, 1924,    1,    1,    1,  774,    1,  202, 1924,  460,    1,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 409,  25,  26, 417,  60, 242, 428,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 105,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1309, 1009,    1,   39,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  967,  416, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  487,    1,   32,  531,  738,  220, 1557,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1936,    1,   98, 1139, 1694,  590,  183,  132,   37,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2, 462,   1,  37, 142,   9,  49,   7,  69,  50,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 615, 240,  65, 221,  98, 347,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1043,   28,  419,    1,  978,  769,  186,   98,   29,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,  232, 2476, 2518,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1283, 1499,  633,    1,   53,   37, 1429,  669,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 1194, 1880,   45,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  326, 1353, 2229,    1,    9,  112, 1749,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1040, 1310,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158,    1,   45,  166, 1107,  218,    1,  586, 1070,  321,  460,\n",
      "           77,  460,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612, 2776,  453, 1183,  608,   37,    1,  453,   27,\n",
      "          627,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 1594,  417, 1114,  187,  186,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  295,  972,   37,    1,  573,  315,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  852,   37, 2022, 2240,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3051, 2024,   46,   26,  220, 2096,   98,  861,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1051,   12,    1,    1, 1125,    1, 1463,  932,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   37,  804, 1970,   98,  148,   12,  142,    9,  647,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1713, 2826,  671, 3126, 2525,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1523,    9,  169,  702,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  561,    1,    1,  851,  298,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  673,  659,   45, 1778, 1036,    9,  121,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  493,  636,   28,   27,    1,  105,    1,  496,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496, 1727,   37, 1154,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3010,  580,  590,    1, 3190,  220,  566,  361,  453, 3130, 1849,\n",
      "           26,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1849,  163,    1,   12,    1,  290, 1159,    1,    9,  223, 2135,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  459, 1312,  356,  132,  220,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  420,   98,  463, 2926,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2057,   32, 2835,  948,  452, 1450,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453, 1991,    1, 2089,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  224, 1126, 1464,   37, 1000,  932,  460, 2156,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,  631, 3209,  548,  547, 2799,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,    1, 1085,  669,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  146,  342,  695,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  854, 2506,  191,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1942,    7,   37,  550,  104,  221,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2321, 3229,    1,   37, 1306, 1694,   45,  914,  220,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087,  433,    1, 1154,  220,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,   52, 1584,  168,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 3302, 1760, 3306,  481,  548,    1, 1894, 1463,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,  176,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  344,  155, 2360,   45, 2218,   12, 1950,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,   32, 1134,   37, 1198,  166, 2769,  220, 2507,  726,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1690,  724,  176, 1105,  787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  758,    1,  614, 1273,   98,  180,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3199, 1654, 1377,   45,  402, 1780,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  715,    1, 2155, 1736,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1459, 3090,  480,    1, 1877,   37,    1, 2423,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777,    1, 2798, 1718,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2614, 2408,   12, 2162,  155, 1574,   98,   23,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,  759,  915,   32, 3308, 1990,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1469,    9,  157,  412,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   32,  885,    1,    1,  657, 2414,    1, 1151,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1851, 1008,  606, 1382,   32, 3278,  126,   45,  105, 1294,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  503,  387, 2051,  197,   32,    1,  159,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147, 1579,    1,    1,  394,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3374, 1550,  450,    1,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2048,   37,  854,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  506, 2780,    1,   39,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  726,  449, 2522,   98, 1537,    1,   32,  537,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  654,  515,  449,  158,   71,    9, 1700,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2658, 1040, 1454,  247, 1944,   98, 1580,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1117, 1943, 1215,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707,    1,  297,  342, 2927,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2685, 2303,  166,  199,   61,  917,    9,  105, 1842, 1074,   45,\n",
      "         1515,  248,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1851,    1,    1,    1,   37, 3184,   12,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  191, 1100,  190,  460,    1, 1023,   45,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2158,   39,    9, 1517,   12, 1090,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1841,   12,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  950, 2034,  332,   45,    1, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2076,  575,    1,  220,  111,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537,  275,    1, 1403, 2698,   37, 1604,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,   12, 3359, 2386, 1533,  917,   45,    1,  443,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2576,  551,    1,  449, 1023,  197, 1556,  187,  445,  187,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   39,    9, 1411,  547, 3308, 1990, 1675,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  148,  647, 1523,    1,  191,  147,  695,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   10, 1562, 2275,   98,  223, 2135,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,  223, 1801, 2202, 1264,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1716, 2232,  218, 1258,    1,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  977, 1594,    1,   98,  596,  244,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  544,  334,  335,  987,    1, 1084,  357, 1151,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,  593, 2965,    1, 1401,    1,  186,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1163,   12, 2742,   37,   84,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1064,  166, 1230,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  799,    1, 1817,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1191,  354,  703,    1,    1, 1192,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1674, 3282, 3289,    1,    1,   32,  449, 1385,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32, 1585,  176, 2597,  947, 2190,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  475,  387,  596,  275, 1278,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  409,   25,  417,  176,  857, 2305,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  744,  810,  199, 1423,    1,  119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700, 1198,    1,   98,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 1151,  475,  920,    1,    1, 2115,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3228, 2712, 3290,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3284, 2795,    1,  105, 2133,  914,    9, 3103,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121, 2321,   85,   98, 1796, 1938, 3197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  744,  119,  187,  347, 2284,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2373,    1, 2403,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,  467, 2070, 1783,  156,  304,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  924,  267,    1, 2768,  193, 1847,  600, 1463,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1017,  867,  794,  449, 2039,  444,  668,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,   32, 2662,   12, 2227, 1551,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 1739, 2540,  365, 1212,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183, 1042,   32,  166,    1,    1,  202,  670,   32,  605,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1019,    1,   79,  166, 2904,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,   22,   23,  607,  162,  257, 1038,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  395, 3121, 2162, 1950,  418,   37,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  770,    1,   28,   32, 3099, 2930,  927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1876,    9, 1094,    1,  652, 1896,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3353,    1, 2576,    1, 1890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  140,  183,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,    1,   32,    1,  942,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2871,    1,   37, 1306, 2119,  187, 1987, 2842, 1258,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  484,   74, 1921,    9, 3213,   37,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  947,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1064, 1434,    1, 1419,  449,    1, 1510,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  894,  720, 1281,   98,    1,  116,    1,    1,  593,  442,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  429, 3180,   32, 2046,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3260,  631,  931,  548, 1312, 2799,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  617,    1, 1017,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1186,   12, 1861,   37, 1220, 2383,  384, 3369,   98, 3118,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1236, 1485,    1,  297, 1047,  283,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1527, 2664, 2827,   32,  531,  513,    9, 1922, 1204,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299, 1070,  422,    9, 1476,  574,  506,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1151,   13,    1,  353,  354,   98,  134,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280,    1,    1, 2394,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  236,  237,  193,   11,   14,   12, 1986,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  374,    1,    1,  329,  682,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1421,    1,    1,    1,   37,    1,  132,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  365,    1,    9,    1,    1,    1,  191,   38,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   12,  552,  441,   37,   16,   93,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2445,    1,    9,    1, 1839,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 2596,    1,    1, 1585,   32, 2018,    1,   90,    1,\n",
      "           37, 1911,  274,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,    1,    1,   32,  871,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3213,  288,    9,  183, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,  220, 1018,  723,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2751, 1229, 2572,    1,    1,    7,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1404,   12,    1, 1727,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  563,  593, 2965,  968,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2107,  322,   32, 1705,  509, 3013,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2065,    1,    1, 2800, 1089, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,  187,  753,    1,    9, 2249, 1295,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  422,  839,    1,  437,   50,  297,  589,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3149, 2751,  693,   59,    1,    9,  964,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  853,  595,  640,  858, 2264,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2964,  815, 2931,   37,  837,  829, 2987, 2454,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1966,  992,   28,  861,    9, 1319,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,    1,  112, 1501,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   52,  166,    1,  914, 2085,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181, 1616, 3154, 1280,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2932, 1835,    1,   37, 1000,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1738,  745,   76,    9, 2021,    1,   61,    1, 1039,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  744,   28, 1388,  220, 3257,   32, 2197,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,   12,  572,  156, 1473,   98,   15,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  487, 1273,  259,  700,    1, 1500,  983,  570,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  180,  572,  197,  418,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1, 1022,    1, 1249,    1, 1022,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  415,  105,  123, 1140,    9, 1415,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2771,    1,  193,  320,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3259, 2523,   32, 2205, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  647,    1,    1,  648,  187,   82,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  437,   37, 2303, 3073, 1623, 1371,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3226,    1,   39,    1,  220, 3265, 1987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089, 1675, 1594,  995,   37, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   61, 1542,   32,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   45, 2505,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  324,  958,   46,  220, 1479,  460,  669,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1617, 1216,    1,   94, 2927,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3342,   12, 2059, 1231,   32, 2282,  722,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,    1,    1,    1,  166, 1381,  220, 1090, 2315, 1333,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   39,  103, 1499,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  819,  619,  411,  818,  698,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2102,    1, 2102,    1,  612,   19,    9, 1423,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  952,   37,   47,    1,    1,  297,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  921, 1463,  748,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708, 2153, 1248, 3140,   37, 1334,   39,   45,  890,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1209,    1,  105,    1,   45,  781,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  564,    1,   98,  464,   22, 1202,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  715, 2693,    1, 1231,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2822,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1757,    1,  297, 3369,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,   12,  103,  147,    1,    1,   45, 3359,  400,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3240,    1, 1096,    1,    1,  384, 3226,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1226,    1, 2646, 2024,  132,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1186, 1625,  361,    1,    9, 3102,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  287,  686,  189,   37,  877, 2664,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  750, 1576,  774,    1,  220, 3378,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1530,  187, 2702,  338, 1159,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2741, 1176,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,  856,   37,    1,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  811,  640,   39,  176, 1663, 1659,   12,    1,   32, 1811,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,  267, 3369,    1, 3148,   32, 3118,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3042,  161,    1, 1385, 1056,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1938, 2607,  382, 2206, 2989,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  393,    1,  359,  474,  498,   37,    1, 1907,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  191,  111, 1260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 3270,  140,    1, 1938, 3197, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,    1,   37,  552,  552,  681,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3128, 1301, 2379,    1,    9, 2924,    1,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1968, 3007,    1,   28,   40,    9, 1273, 2798,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2596, 2414,  487, 3160,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,  102,  838,   79,   32,  367,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  176,  166, 3143,  166,  915, 1265,  166, 3141,  110,    9,\n",
      "         1515,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144,  863, 1984,    1,  297,  915,  932,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  365, 2109,   98,    1, 1196,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  707, 2025, 2799,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3228, 2035,  726, 1045,   37, 1675,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,    1,  326,  815,    1, 2670,    1,    1,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,  267,  810,  675,  168,    9, 2371, 1539,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2077,    1,  479,   37, 1706,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  524,  525,   15,  670,   32,  645, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596,  518,  519, 1360,  612, 1584,   69,    1, 1986,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  415,  786,    1, 2249,  384, 2741,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,  510, 1648,   98, 1549,  540,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2275,  267,   10,    1, 1677,   98,   69,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  615,    1,   32,  225,   12,  270,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 393, 716,   1, 737, 354,  88,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 865,   9,   1, 166,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 1447, 1458,  163,    1,  903,    1, 1953,   98, 2103,\n",
      "          617, 1116,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447, 1458, 2266,   98, 2189,  531,  443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1481,    1,    1,    1,   79, 1002,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 2292, 1258,   32, 3339,    1, 3375, 2572,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  582,   45, 1795,   12,    1, 1131,   37,  930,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 1231,  220,  133,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32, 2824,   74,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   79,   37, 2056,  698,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,   37, 1421,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  872,  942, 1625,   37,    1, 2087,    1,   32,  593, 1990,   45,\n",
      "         2701,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1,   37,  151,    1,   12,    1,  604,  700,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1658, 1762,    1, 1456,  327,  327,  593,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  424,  166, 1034,  166, 2631, 1045, 1086,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,   12,    1,  171,  731,  969,   37,    1,    1,   12,  551,\n",
      "          552,  267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3084,  580,  365, 2180, 1574,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  626,  159,   28,   98,  214,  943,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  872,  132,  167,  764,  487, 3222,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1853,   61,    1,   37,  970,  885,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2605,  736, 1228, 2351,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  584, 1818,  147, 1392,  400,   98,    1,    1,    9, 2895,    1,\n",
      "         1920,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2841,    1,  105,  410,    1,   45,  535,  774,    1,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  718, 2838,  872,  420,  367,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1877,   37,    1,   37,   60, 1563,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  220,    1,  967,  223, 1639,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821,    1,    1, 2191, 2978, 2361,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1304,  256,   37,   80, 1108, 3004,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,   45,  166, 1034,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2807,    1,   37,  606, 1857, 2283,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3190,  167,  429,    7,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  790,   37,    1,  273, 1609,    1,  250,   87,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,    1, 3138,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  127,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,   56, 1159, 2158,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2868,  267,  190, 1604, 2177, 2191,  204,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1627,  160,  777,    1,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1223, 2061,  171,    9,    1,  977,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   21, 1253,   32,  845,  275, 1196,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1442,   37, 2929,    1,  150,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  212,   37,    1, 1116,   32,  854,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1720,  460, 1494,   37,  166, 3220,    1,  166,  388,  166,    1,\n",
      "           61, 2310,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 1245, 1421, 1211, 2256,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  284, 1147, 3045,    1,   32, 2375,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437,  365, 2741,  193,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  779,  780,  781,  734,  748,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2294, 1421,   45, 1215,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3140, 1585, 2414, 3374, 3384,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  323,    1,    1,    1,   32, 1619,  878,    1,    1, 1406,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  377,    1, 1824,   98, 2051,  763,  105,   74,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,    1,   32,    1,  505, 1857,  548,  823,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,   51,  125,    1,   12,  731,    1, 1159,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2067,    1,    1, 2016,    1, 1366,    1, 1846, 1221,    1, 2740,\n",
      "         1167,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3361,    1,    1,  332,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1022,    1,  515,  931,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3386, 2930, 3060, 2399,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3285,  489, 2017,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,  565, 3344,  220, 1161,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2511,    1, 2863, 2341,    1, 2943,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3177,   39,   37,    1,  166,  183,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,    1,    1,  140,    1,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,  197,   98,    1,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12, 1048, 1444, 1847, 1492,   37, 1140,    9,  764,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1786, 1190,  288,   37, 1776, 1183,    1,    1,  484,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2175, 1371,  845,    1,  844,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  103,  632, 1273,    1,    1, 2845,  331,    5,  302,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537,    1,  614,   39,   32,    1,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2863,  431,  365,  207,  259,  802,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3244,    1,   32, 3284,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2004, 2634,    6,  118,   45,  163,    1,   12,    1, 1604,   23,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1380,  861,  176, 1658,    1,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,   46,  220, 1256, 1256,  297,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2774, 1900, 1860,    1,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,  176,  861,  220, 1768,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708,   12, 2162,  744,   79,    1,   45,  839,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2457,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204, 3205, 3169,   32,  163,    1,   12,    1,   26, 2069,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3175, 2728,    1,   37, 3251,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  765, 1159,  166, 2886,   12, 1311,    9, 1965, 2982,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1817,    1,  460,    1, 1673,    1,    1,  384,  666,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  267,  160, 1161,  600,  166, 1690,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1804, 1133, 1463,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1343,  460,    1,    1,    1,    1,    1,  176, 3320,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,    1,    1,    1,    1, 1569,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  645,    1,  149,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1117, 1525, 1943,  951,    1, 2325,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1576, 1140,   98,  163,    1,  903,    1,   37,    1,    1,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3227,  707, 1632,  284, 1769, 1215,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  669,  289, 2535,  166,    1,   37,  793,  244,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2266, 1458,  104,    1,  342,  973,    9,  522,   98, 3118,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1013,    1,   32,  224,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  669,   42,  134,   98,  977,   53,   37, 2548,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1673,  187, 1645,   26, 2965,    1,    1,  176, 2197, 3329,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  957,    1,    1, 2756,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1531, 3079,  872,  420,  385,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2042,  113, 1994,    1, 3136,  477,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3089,   12,    1,  738,  220, 3103,    9,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  258,  512,  246,   32,   98,    1,  815,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2077,    1, 1645,  469,    9, 2210,  621,  475,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2819,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1528,   27,  132,   98, 1405, 2039,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  331, 2919,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 2924, 2856, 2708, 3065, 3133,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  105, 2162,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2217, 1277, 1082, 1833,   37, 1000, 1351,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1963,  951,    1,  166,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1547,   81,  680,   97,   69,    1,    1,  343,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  420, 3101, 1583,    1, 2414,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1530,   32, 3339, 2831, 1345,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  365,    1,  444,  617,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2899,  315,   37,  693, 1273,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  154,    1,   39, 2308,   32, 1384, 2096,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  200,  365,  659,   45, 1106,  844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  296,   12,    1,   37,   52,  621,  624,  475,    1, 1504,    1,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,  453,    1,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  749,  480, 1908,    1,   37,  761,   12, 1646,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654, 1458, 2723, 2724, 2294,    9,  453,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1717,    1,  716,  449,  400,   45,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  846,  631,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  219, 1990, 2315,    1,  928,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2591,   32, 2823, 1002,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1362, 2185,  207,   85, 2092,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 1707,    1,  693,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 105, 260,  32, 166,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 136, 708, 326,   1, 678,   1, 187,  82,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   98,    1,    1,  288,   37, 2354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1372,    1, 2072,  457, 2107,   37, 1821,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2359,    1,  619,    1, 1217,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  295,  267,  388,  389,    6,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,   91,    1,  562,    1,  864,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1237,  105,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1643,  716, 1253,   32,  572,  983,  361,  197,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3254,    1,    1,  220,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  190, 1694,   32,  863,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,  267,    1,   37,    1,    1,  469, 1822,  439,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3245,   37, 1306,  581,   73, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   96,   28,    1, 1245,   32,    1, 2748,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3361, 2816, 1345,   32,    1,  191, 2203,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  200,  365,    1, 2168,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,   12,  822,    1,   74, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 1037,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428,  396, 1338,   45,  622,    1,   32, 3118, 2517,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   81,   37, 1604,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1362,  387,  572,  983, 1315,  572,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   22,  868,  686, 2764, 3155,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1092,    1, 1236,  829,  297,    1, 1090,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,   37, 1463,    1,    1, 1017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   66, 2410,  417,  187,   69, 1784,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2677,   74,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  726,  515,    1,  807, 1285,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  640, 2381,  339,  687,  951,   94,    1, 1547,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  632,    1,    1,  884,    1,   45,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715, 2313, 2430,  297,    1, 1465, 3005,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  590, 1211,    1,   32,  348,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1126,  384,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,  147,  597,    1, 3289, 3139,  321,   52,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   37, 1075,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2193,    1,  166, 2151,  361,  166,  943,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640,    1,    1,    1, 1006, 3009,    9, 2463,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2476, 1376,   37,    1,   39,  726,  297, 1617,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3113,    1,   37, 1752,  596,  275,  650,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  929,   98,    1, 1780,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1378,    1,    1,  903, 2718,  629,  730,  841,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   25, 1838,   28,    1, 1158, 2806,  105, 1198,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  868,    1,    9,    1, 2741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2206, 2435,  960,    1,   39, 1612,   32, 1384, 2096,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973,  671, 3126,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  871, 1097,   57,    1,  739,    1, 1224, 1071,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  449,    1,    1, 2983, 2083,  255, 2604,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   96,   37, 1755,   32,    1, 3070,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  515, 1845, 1322,   37,    1,   12, 1503,  142, 2013,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2508,    1, 2168,  384,  215,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  657,  378, 2175,   37,  105, 2186,   27,  334,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1971,    1,    1,   37,  698,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267, 1411, 3151,  914,  483,  176,  629, 1603,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,  365, 2933, 2232,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1147,    1,    1, 1897,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3190,    1, 3278,  590,    1,  429, 3161,  590,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  534,   12,  294, 2494, 1628,    9,  615,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  503,  894,  606,    1,  749,   32,    1,  506,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3241,  913,    1,   98, 2347, 1638,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2685,   51,  712,   28,  597,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374,    1, 2572,   32,    1, 1633,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1733,  884,  297,  395,   12,  103,  622,  389,  384,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1008,  112, 1501,   32,  442,  533,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  885, 1918,    9, 2802,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 1908,  410,    1,   32, 1327,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  721,  123,   37, 1322,  105,    1,    9,\n",
      "         1933,  295,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1712,    1, 1130,  631,  878, 1705,    9, 2103,  617, 1116,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2663, 1976,   32,  395,   51,  168,   81,   59,  537,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2388,   12,    1, 2422,  682, 1161,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  627,   45,  342,  768,    1,   32, 1820,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2579, 2689,  447,   37,  698,   98, 1645, 2921,    1,  168,\n",
      "         1632,  602,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  395, 1021,  288,   37,    1,  225,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 3015,    1,    1, 2699, 1176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  938,  992,   85,  187,  941,   82,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1760,  487, 2800, 1465, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 2597, 2909, 2414, 1763,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   83,    1,   98, 1734,    1,    1,  166,    1,   45, 1143,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,    1, 3021,    1,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1140,    9,  388, 3118, 3406,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  176,  612,  613,    1,  365, 1107, 2610, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2326,  845,    9, 2741,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1317,  704,  104,  353, 1455,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2102,    1,   32,  215,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2009,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1266,  267,   22,  942,   51,  151,   28,   37,  644,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1234, 1484,    9,    1, 1592,  176, 2949,  290,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  988,    1,  453,  454, 1750,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  388, 2205,    9,  842,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  890,   37,  221,   25,   32, 1139, 2113,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  572,  932, 1946,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1,  159,  245,  419,   98,  104,  927,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  581,  401,  197,  338,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237, 1036,    9, 2305,  186,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  686,  365,  845,  361,  388,   37,   18,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  268,   51, 1083,  693,    9,  413,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,  597,    1,  952,    1, 1159, 3084, 2180,  966,  927,  420,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    1,   24,  384, 1307,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2472,  197, 1042,    1,  157,  125,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1766, 1767, 2094,  858,   37,    1,  316,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  720,  384, 1056, 1034, 1653,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  619, 1133,  365, 2887,  625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110, 2192,   28,  917,   37,    1, 1340,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2018,  267,  113, 2985,  330, 1479, 1450,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2334, 1114,  396,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018,  176,  177,  249,    1,   32,  344, 1656, 2596, 1260,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485, 3102, 1810, 2572,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  709,  829, 1149, 1231,  220,    1, 1228,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885, 1631, 2523, 2210,  356, 1001,  119,  220,   72,   73,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2753, 2315, 1844,  187, 2615,  335, 2522,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,    1, 1380,  463, 2170,   32,  559,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158,   37,  480,    1, 2400, 1871,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  720,    1,   25,   71,   98, 1125, 1378,  818,  605,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2689,    1,  726,    9,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,  386,    1,    1,    9,  152,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2102, 1353, 1159, 2335,  388,  219, 2064, 3011,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  795, 1288,   37,  427,  116,    1,   98,  453,  248,  778,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  323,  805, 1821,  927,  313,   37, 2809, 1159,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1475,  453, 1126,  636, 2320,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3280, 1631,   85, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1,  355, 1291,  219,   25,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   64, 2162, 1950,  640,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 1190, 2726, 3040, 1260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  420, 1861, 2506,   45,  531, 1803,   32,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1647,  109, 2728,    1,  220, 1821, 2190,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  395, 1562,    1,    9,    1,   98, 1789,   12, 2225,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1060, 1314,   32, 2752,    9, 2024,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  859,   37,  125,  448,  187,  517,  387,   93,  762,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1262,   37, 2709,  199, 1813, 1880, 2424,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  138,    6,  176,  386,   12,    1,  669,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1147, 3373, 2249, 1428,  639,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  116, 2264,  193,  187, 2440,  111,  187, 1444,    1,    1, 2932,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510,    1, 1750, 2732,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158,   12, 1230, 2524,  163,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1107,   37,    1,  715,  434,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  379,  402,   37, 1677,   45,    1,   98,\n",
      "         1891, 3093,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  524,  525,   15,    1,  645, 1034,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   77, 1658,    1, 1073,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  565, 2741,  542,  565, 2319, 1515,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2154, 1585,  176, 3379, 2147,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,   98,  495, 2784,   37,  854,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1364, 1365,  810, 2789, 2024, 1320, 1268,   37, 1860,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  794,  365, 2474, 1075,    1,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  834,    1,  150,  105, 1628, 1183, 2113, 1429,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299, 1707,  365, 2673, 2375,  977,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2605,    1,  384, 2226,  540,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2330, 1099, 1453,    1,   28,   37,  422,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1017,  261,   32,  593,   45,    1, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2144,    1, 1683,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  848, 2767,  845,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2871, 2477,    1,   28,  180, 1948,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2925,   12, 2847,   45,    1,  321,   52,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708, 2572,  191, 3101,  114,   32,  539,  458,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  153,  913,    1,   98, 2347, 1482,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,  686,  220,  241,    5, 1220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1617,    1, 2937,    1, 2942,  431,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2591,   37,    1, 1351,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   51, 2358,    1,  353,  417,  197,    1,   15,  245,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,    1, 2111,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    9,  512,    1, 1621,  105, 1782,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3054,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   68,   69, 1518,  530, 2091,  889,  109,   61,   66,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2185, 2194, 2146,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  305,  417,    1,   69,  509, 2010,  832,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   74, 1394,   37, 2141,  724,   37,    1, 3358,    1,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  871, 1278,  641,    1,    1,   28,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,  913,    1,  683,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1317,  704,  104,  217,   98, 1560,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1982,    1,   45, 1185,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 2201, 2003, 1585, 2414,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700, 2572,   32,  403,  404,  854,  187, 2774, 2292, 1258,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2774, 2782,  891,   37,    1, 2752, 1633,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1298,    1,    1,    1,  355,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  522,    1, 2691,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26, 1039,    1,    1,   44,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1186,   12,    1,  634,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1074,  861, 1051,   37,  130, 1074,    1,  700,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962, 3120,    1, 2290, 3259,    1, 2959,  688, 3241,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2499,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1666, 1539,   45, 2080, 2056,  880,   37, 1970,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  228,  583,  187,    1,  851,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,    1,    1,    1,  994,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1306,    1,    1,  187,  582, 2565,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2163,   37,  470, 1381,   98,  137,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  356,  881,  972,    9, 2924,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2613, 1918,    9,    1,    1,   32, 3293,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2920,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   26, 1039, 1659,    1,  600,  829,   12, 3042,  161,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403, 1447, 1550,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3113,    1, 1247,  865,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  719,   59,  388,   32,    6,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2551,   38, 3059,  449,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   98,    1, 1434,  220, 1107,    1,  297, 1234,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2873, 1297,   85,  542,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2094, 2580,    1, 1228,   37,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3102,  590, 1861,  580,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129,  105,    1, 1477, 1990,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1257, 1536,    9, 2240,  467,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  213,   37,  352,  290,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  108,  228,  142, 2458,   37, 2446,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1486,  333,  155,    1,   45,    1,  214,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  193,    1, 2588,  297,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  292, 1228, 2568,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  782,  365, 1030,   32, 1228, 2086, 1523,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3207,    1,   37,  429,  247,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 2123,  220,  365, 1788,  669,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  761,   12, 1646,  919,  985, 1260,  629,   32,  776,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   64,   12, 1950,  418,   37,    1,   32, 3349,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  151,  140,    1,  562,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1261, 3370,    1,   32,    1,  595,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1989,  162, 1638,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  936,  197,    1,  225,  490,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,    1,  746,  288, 1568, 1569, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[2, 1, 1, 1, 1, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,\n",
      "         0, 0, 0, 0, 0],\n",
      "        [2, 1, 1, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,\n",
      "         0, 0, 0, 0, 0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3180, 2919,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   37, 2192,  152,    9, 2117,   23,   32, 3118,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,   37,   77, 2924,   32,  531,  528, 3102, 1936,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1962, 2078,    1,   12,  297, 1273,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,  265,   45, 1292, 1021,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,  388,  146,    1,  444, 1674, 3126,  932,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  693, 1176,  227,   37,    1, 1006,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  220,  142,    9,    1,  524,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  942,    1,   98,    1,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3301,    1, 3239,  619,    1,   32,    1,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2925, 1090, 1829,    1,  827,  176,  316,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1539,  645,  973, 1159,  160,  616,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3144, 1443,  562,  741, 1511,    9,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  439,    9, 2650,    1,   45,  829,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3157,    1, 2162,   45, 3060,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2982, 1013,    9,  365, 1831,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1775, 1921,   32,  104,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  185,    1, 1295,  764, 1043,   71,    1,  419,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1718,  279,    1,   98,  166,  454,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3225, 1012,    1,  187,  365,  512,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 2640,  744,   79,    9, 1821, 2190,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  995,  242,   98, 1269,   32,   69,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1147, 2038,   12,    1, 3340,    1,  220,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,   12, 2715,   45,    1,    1,   39, 1409,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2531,  854,   46,   98,    1,    1, 2198,  630,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284, 1912,  114,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1059,  105, 1298,  784,   81,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2733,  794,  750,   32, 2730,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  686,  105,  106,    1, 1608, 1267,  105, 2338,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,    1,  715, 1161, 1298, 1382,  328,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3005, 2393,  418,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1951,  398, 1337, 2251,   45, 3387, 2985,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1811,  404,    1,  187, 1065,   93,  218,    9,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  387,   15, 1124,   32,  385,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  531,  991,  734,    1, 1268,  454,    9, 1527,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2832,  588,    1,  548,  114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  737,  354,  703,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  273,   32,  472,    9, 2472, 1916,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2648, 2801,    1,    1,    1,    1,   32,  517,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1458, 2017,  384,    1,    1,    6,    4,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284,  195, 1091, 1000, 1167,    1,  565,  227,  112,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2530, 1542,    1, 2981,  162,   28,  123,   37, 2662, 2918,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  852,   37,  335,   98,    1,    1,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2912, 2297,  512,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1592,  345,  284,  229,   37, 2313,  344,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  113,   27,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   61,  917, 1166,  204,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1503,  129,  253,  562,  214,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  459,  460,  132,  220,  461,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  395,   26,  631,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1721,  774, 2106,  952,  674,   45,   69, 2054, 1632,   49,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3206,    1, 2475,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390,  587,   23,  365,   46,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  310,    1, 2506,   45, 1665,  384,  651, 1031,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1227,    1, 1158, 1330, 1107,  176, 1273,  259, 1091,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  567,    1,   51, 1641, 2454,   32,  104,  954,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1076,   32,    1,  372,  332,  142,    9,  671, 1078,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  614, 2071, 2880,   98, 1766, 1767, 3011,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236, 1022,  288,    9,  682,  187,  185, 2905,    9,  186, 2013,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   71,   98,  720,   32,   69,    1,   65, 2001,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  381,   12, 2511,    1,    1, 2434,  353,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1475,    1, 2187,  636,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  315,  777, 1953, 1108,  884, 1003,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,  686,   56,  356,  340,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302, 2794, 3032,    1,   37, 2449,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  597, 1123, 1292,   12, 2162,    1,  195,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  468, 1362,  879, 1994, 2693, 1228,   37, 1273,  218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3086, 2548, 2684,   32, 3369,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  693,  916,   37, 1358,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  386,  295,  387,  388,  389,  390,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12,    1, 1123, 2308,    1,  488,   37,  168,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1459,  140, 1029, 1743,  232,  932,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  829, 1542,   37,    1, 2348,  663,  297,  166,  116,    1,\n",
      "         2973, 1764,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  388,    1,   37,    1, 1204,   98, 1965,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968, 1290,  338,   37,  339,  340,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  459,  903,    1, 1447,    1, 1461, 1463,  105, 1406,  163,    1,\n",
      "           12,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 2319, 1434,   98, 2336,  315, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3247,    1, 3323,    1, 2138,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1,   37,  130, 1017, 1085,  700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  738, 1787,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,  123,   32,   98,  132,  220,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  671, 1078, 1377,   37,  269,   98, 1076,  142, 1464,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275, 1774,   39,  223, 2135,  117,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,   37, 1075, 1970,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,  460, 3188,  361, 1902,  631, 3244,   37,  885,\n",
      "         2651,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  344,    1,  792, 1542,   37,  477,  792,  121,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1035, 1070,   37, 1642, 1175, 1371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1930,  804,  912, 2285, 1228,  822,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 1044,   37,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1622, 1384,  474,   37, 1267,  477,  187, 1903, 1686,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,    1,   45,  365, 2915,    9,  949,   45, 3365,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 793,  25, 866,  98,   1, 157,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  875, 1786,  927,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485,    1,  856,   37, 1154,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3133,  163,    1,   12,    1,    1, 2596, 3155,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1958, 1894,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  176,    1,  628,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2217,   61, 1194,  310, 1833,   37,    1, 2527,  164,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2217,   12,  365, 1277,  571,  384,  395,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  565,  800,    1, 1347, 1120,   37, 1334,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,  37, 817,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 746,  51, 125, 388, 763,   1,   4,  88,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  303,  967,    1, 1886,    9,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,   12, 1349,  387, 1735,   93,    1,  340,   31,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  828, 1210, 1725,   37,  973, 2862,    9, 1511,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2266, 1874,  147,  484,    1, 3398,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1357,    1,  191,    1,  861, 2454,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1530,  187,   64,    1,  455,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2765, 1347, 2827,   32, 3113,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1442,  880, 2598,  862,   37, 1841,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,   12, 1230,  614,   37,   36,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,  898, 1530,  548,  176,  177,  547, 1957, 2809, 1159, 3376,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3175,    1,  105,   12,    1, 1151, 2017,  176, 2764,  539,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  849,  213,   37,   52,    1,    9,  332,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  324,   32,   46,  220, 1479,  460,  669,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,  200,    1,    9, 2510, 2869,  772, 1294,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1095,   12,    1,    1,  150,  349,    1,  220,  629,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,    1, 2052,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1643,  251,  365,  861, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  315,   59,   29,  656,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1089,    1,  774,  959,  810,  365, 1675,  565,  331,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  718,  267,  736,   92,   37,  954,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2235,   69,   85,   37,  977,  335,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,  413,    1,    1,    1,  202,    1,   81, 1590,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  265,   45,  434,    1,    1,   32,  367,    1,  548, 1568, 1014,\n",
      "          361,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2722, 3074, 3231,  872,  420,  385,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  352,    1,   98,  968,  934,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3276,  877,  166, 1879,  138,  361,  726, 1515, 1194, 1090,   32,\n",
      "          105, 1559,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  837,   12, 1059,   32,  166,    1,    1, 1657,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  640,  365, 1653,  530,  105,  106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1178,  610,   37, 1204,    9,  903,    1, 1973,    1, 2772,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1114, 1160,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3192,    1,  577,  600,  786,   74, 1505,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2551,  913,    1,   98,    1,  949, 1700, 2308,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    1,  191,   56,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  361, 2018,  498,   37,    1, 2024,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1641,    9,  458,   17,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  138,    1,   37, 1915,  218,    1,  460,  681, 1373,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2578, 2850,  449, 1385,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2929,   37, 1539, 1273,  259, 1108,   32,  179,  132,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3358,   12, 2162,   51, 1403, 2024,   37,  465,  404,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1, 1052,  572,  354,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,  854, 1708,    9,    1,   12,  949,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3287,  186,   37,  688, 3241,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  619,    1, 2017,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   12, 1013,    9,    1, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1534,    9,  238,   98, 1965,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1, 1908, 2264,  454,   32,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  615,    1, 1001,  176, 2759,  698,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1654, 1377,   32,  942,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  754,  757,  197,  921,  308,   98,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  261,   39,  531, 2161, 3082,  949,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 1310,   37, 1073,   85,  259,  312,  847,   32, 1994, 2931,\n",
      "         1708,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3150, 2625, 2414, 2018, 2924,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  397,  908,  909,  951,    1,  163,    1,   12,    1,   32,  442,\n",
      "         1559,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1674,  932, 1970,    1,  367,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  468,   45, 1407,    1,    1,  938,  104, 2332,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,  735,    1,    1,  798,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  758, 2996, 1056, 2558,   32, 1525, 1294,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1033, 3343, 1428, 3345,  240,  949,   45, 3370,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 195,   1, 191,  13,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 530,   1, 104,   9, 166, 449, 199,  32, 388, 763, 105,\n",
      "         234, 182, 235,   1,   1,   1, 234, 182, 235,   1,   3,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  786, 1530,  548,  593, 1990,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  375, 1236,  582,   45,    1,    1, 1355, 1590,   37,  335,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1368,    1,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2620, 1380, 1684,    1,   28, 1030,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,   37, 1539,  999, 1892,    1, 1893,    1,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129, 1462,  103,    1,    1, 3371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  597, 3235, 1292,    1, 1530,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   93,    1,    1,   45,  612,    1,    1,  162,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1585,    1,  220,  903,    1, 1447,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  245,    1,  236, 1022,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2045,  232,  104,  358,    1,  562,  644,  815,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  352,   51,  193,    1,    9,  531, 1604,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1494,  754,  415,  115,   45,    1, 2242,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3124,  267, 2658,   61, 1691,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  833,  612,    1,  193, 1573,  435,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398, 2694, 1899, 2810,   37, 1734,  776,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1110, 1673,  885, 1641,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043, 1268,  242,   98,  996, 1986,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  990,   32,  399,  220,  669, 1167,    1,    1,  777, 2165,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978, 3138,  688,  705, 2796,   32,  915,  913, 1523,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612, 2589, 1167,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196,   12,  572,    1,   93,   34,  983,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2650,  220,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  493,    1,  462,   37,  335, 1370,   32,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1902, 1205,  191,  422,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  794, 1895,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1658, 2332,  565,    1,  334,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  560, 1274, 1556,  915, 1034,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  915,    1,    9, 3251,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2873,    1,    9, 3015,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1461, 1463,  190,  193,    1,    1,  226,  220,  854, 2531,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  843, 1243,   45, 1019, 2853,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   28,    1,  361, 1227, 2193,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12, 1447,   37,    1,  381,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1023,   45,  968,   12,  306,    1,    1,  506,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1725, 1579,   46,  220,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3330,   37, 1306,  698,  220, 2693,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,  123,    1,   45, 2662,   12,    1, 2918, 2820,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2328,  794,  365,    1,  853,  384,  584,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1354, 3095,    1,  477,   98,  864,    9,  920, 1002,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  220, 2333,  250,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2672,    1,  167,   52,  901,    9,  914,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  716,  774,    1,    1, 1026,  170,   66, 1387, 1034,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307, 2744,  517, 1074, 1437,   37,    1,   32,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    9,  920,    1,    1,    1,    1,  220,  105,  365,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1717,    1,    1, 1764, 1530,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  326, 1419,  365, 1718,    1, 2079, 1228,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,   97,  104,   25,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,  108,  864,   98, 2673,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,    1,   98,  485,    1,    1,   69,  716,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,  868, 2856,  163,    1,   12,    1, 3160, 2572,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  602,  477,  132,   98,  531,  734,  322,   79,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  942, 1249,  104,    9,  671,    1, 2618, 3062, 3077,   32,   56,\n",
      "          497,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  338,   98,    1,  333,   44,  550,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  941,   37,  335,  331,   44,    9,  767,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425,  251,  471,  675,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,   25,  123,  417,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3345,   32,  531, 1211, 1312, 1538,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1671, 1976,   98,    1,  880,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  232, 2162, 1950,   66,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2227,    1,  162,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 1568,    1, 2199,  730, 2614,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  216,    1,    1, 1324,  297,  903,    1, 1447, 1039,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  103,  460, 2958,   37, 1911,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2924,    1,   32, 1256,  551, 2196,   37, 1174,  892,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1009,    1, 2224,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 3151, 1756,    1,  590,    1,    1,    9, 1479,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  953,  951,    1, 1547,  187,  303,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1988,  515, 1534,   32, 2282,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  166, 2896,   45, 2971,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  947,  927,    1, 3392,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  622,  193, 1953, 3102,    1, 1004,   37,  949,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  147, 3205, 3398,   12, 2457,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  365,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3388,   51, 1114, 1752, 1479,  163,    1,   12,    1, 1816,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,   12,    1,  580,  709,  391,   32, 1422, 2823,  806,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  344, 2596, 2414,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2484, 1268,  631,    1, 1774,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1574,    1,  443,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1075,   39,  157,    1, 1120, 1494, 3056,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  620,  741,  706, 1248, 1064,   37, 1294,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   94,  953,  548,    1,    1,   60, 1489,   29,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  877,    1,    1, 1398,  612,    1,   39,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1594,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  122,  600,  889,  973,   69,   37,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1187,    1, 1210,  388,  384,    1,  763,  195, 2274,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428,  108,   45, 3343,  195,  171,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  519, 3229,    1,  501,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3282,  447,  884,  631,   32, 1764, 1990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    5,  290,  640,    1,  159,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,  940, 2758,    9,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   74,    9,  121,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1100, 2035,  662,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  459,    1, 1084,  630,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1620,   45,  270, 1094,  868,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 1739, 3205,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  150, 1042,  548,    1,  983,  837,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  272,   37, 1021, 2910,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2466, 1209,   51, 2004, 1198,   25,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 2592,  187,    1, 1494,   85,   98, 2890,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2648, 2801,  794, 1766, 1767,  517,  617,  259,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652, 1536,  885,  829,  149,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,  338,    1,  218,    1,  395,   12,  221,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2817, 2856,   32,  395,    1,  590, 1584,   28,   32, 1881,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  711,  475,  939,  115,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1702,   81,  949,   45,  453, 1411,  659,   45, 1778,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  938, 1075, 3160, 2572,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,  744,    1, 1074, 2285,  261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3252,   81,  288,   37,  698,    9, 3232,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,  267,  222,  649,    1,  792, 1851, 1232,    1,  792,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3168,    1,    1,  759, 2033,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  529,  408,   51,  193,   71, 1897,  818,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  912, 2285, 2165, 1976,  193,    1,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3216,    1,   81,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  558,   61,  123,   37,    1,    1,    9,    1,  131,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  481,    1,  442,    1, 1813,  104,  361,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159, 1269,   98,    1,  157,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1317,  792,  704,  792,  104,  353,  572,  197,    1,   15,  245,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220,  984,  889,  115,    1,  242,  529,  408,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401, 1739,   37,  726,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  936,    1,    1,   98,  166,  168,  105,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1188,  105,    1, 1429,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,   28,  187,   69,  102,  470,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  550, 2964, 1413,    1,  861, 1705,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3196,  546,   28,  166,  542,   32,  968,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  140,    1,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713,  311, 2936,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  356,  560,  347,   71,   32,  645, 1034,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,  267,  463,  967, 2673, 2108,    1, 1707,   46,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  412,  162, 2219,    1,    1, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  882,    1, 1234, 1863,  640,  166, 1171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3363,  872, 2331,   45, 1918,   32,  449, 1385,   45, 2208,   32,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2427,  489,   39,   45, 2018, 2498, 2701,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2076,  829, 1249, 1570,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994, 2749,   28,  777, 2995,  593,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3375,   37,  288, 2306,    9,  890,    9, 3358, 1351,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2737,  297,  166, 2918,  548,    1, 1361,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  166, 2498,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  476, 1509,  539,    1,  872,   37, 2579,  691,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1821,  550,   91,   12, 2918,  927,    1, 2977,   12, 3054,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1118, 1901,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98,  166,  389, 1167,  416, 2017,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  733, 2725,  280,   50,  152,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1340,  670,  187,    1,    1,   69,  186,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1631, 1632, 2501,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  984,  202,    1,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1373,  193,   37, 1543,    1, 2855,  384,  365, 1250,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3144,   12,    1, 1484,    9,   62,   98,    1,   45, 1002,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  359,  759,  895,  220, 1390,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3270, 2094,    1, 1415,   37, 1684,  220, 1088, 1938, 3197,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  105, 2225,  388,  224,    1,  901,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3060,  344, 2596, 2414, 1147,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  931,  951,    1, 1497,  401,  191,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  177, 1530,   32, 1537, 2702,    1,  844,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1527,    1, 1619, 2228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1774,   39, 2366,  918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2551,  688,    1,    1,  221,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1191, 1635, 1299,  475,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  754,  546,    1,    9, 3088, 1731,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  393,   12,  484,   98,  467,   76,  892,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971, 2257,    1, 1101,    1,  117,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,  365, 2876,  685,  682,  176, 1691,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1019, 1292,    1,   51,  402,   37, 2500,    1,  506,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  572,  105, 1361,   12,    1,    1,   98,  166,  669,   12,  460,\n",
      "         1085,  315,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3306,    1,   37, 1936,  229,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1448,    1,    1,  162,    1,   54,  170,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  113,   27,  845,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  936,  932,   45, 2823,  890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  395,    1,   37,    1, 2471,  220,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1103,    1,   32,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2190, 2640, 1585,   79,  384,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3363, 1260,    1, 3343,  863,  997,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  878,   12,  856,   98, 1649,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 596, 604, 994,   1, 150,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 992,  85, 187,   1,  82,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 111, 112,  53,   9,  59,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  32, 531, 105, 183, 112,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  649,    1, 3340,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878, 1236,  829,    9, 1350,    1,    1,    1, 1114,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  545, 1035,    1,   37,  717,    1, 1741,    1, 1038,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  251,    1,    9,    1, 2931,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2881,   42,   98,    1,    1,    1,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,  108,   45, 1239,  673,  910,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   11,    1,  515,  334,   92,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1952, 1725, 1953,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  605,  437,  108,   45,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  327, 1220,   34,  657,  156,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   75,   37,  771,  613,  412,   98, 1202,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  996,   93, 2051,  763,  570,   32,  572,    1,  102,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1401, 3191,   37, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1024, 2437,  187, 1863,   37,  289,   98,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   98, 2780,    1, 2325,  361,  166,  116,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12, 1352,  361,  460,   12,  199,    9, 3220,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1700,  440,  310, 1182, 1505,    1, 1273,  662,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2676, 1514, 2309,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  506,  782,    1,  220, 1744, 1975,  582,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  246, 1189, 2673,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1802,  957,  288,   37,    1,  949,   45,    1, 1156,   32,  395,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1167, 2055,  220, 3009,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147,    1, 1921,   32,  864,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  849,  515, 1641,  191, 1641,  420,   45,  333,  226,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1444, 2595,  544, 1027,    9,   16,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1716, 1100,    1,  118,    1,  332,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  344, 3035,    1,   37, 2856,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2222, 2257,    1,    1, 2093,    1,    1,    1, 1844,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  297,  375,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321,  334, 2047, 2349,  920,    1, 3031,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1492,    1,  166, 1398,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   32,    1,    1,  163, 1594,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  693, 1211,  207,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1864,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1212,  947, 2317, 1897,    1,  927,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,  446, 1112,  204,  190,  193,   52, 1425,    9,  885,  863,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2308,    1,  542, 1046,  134,   32, 3141, 2811,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,  655, 1231,  220,    1,    1, 1159, 3065,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1431,    1,  517,    1, 1273,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  952,  103, 1013, 1569,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  456,  365, 1149,   39,   45,  573,  469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  462,   37,  142,    9, 1069,   50,   45,   49,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  597, 1087,  710, 1713,    1,  721,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2819,  384,    1,   37,  301, 1529,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2651, 1554, 3132,  631,  176, 3266,  504,  674,  220, 1844, 1194,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  961, 1498, 1210,  388,   29,   63,    1,  365,  503,  888,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,    1, 3154,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965, 2918,    1,  384,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  431,  365,   64,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1647,   98, 1796,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3178,  921, 3173,  683,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1, 1363, 1413, 1414,   37,    1, 1273,  259, 1228,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  746,   51,  125,  388,  763,    1,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   32, 1328, 3137,    1, 1407,    1, 2684,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  669,   37, 1527,   32,  211,  926,  927,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2266,  267,  593,  590, 2219,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  403, 1447,   46,   51,   52, 2566,   45,  104,  806,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468, 3109, 1194,    1,   32, 3043, 2596,  722,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  550,    1, 2026,    1,  686,  166,  207,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  476,    1,  593, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147, 3384,  437,    1,  792,    1,  792, 2606,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715,    1,    6, 2460,   32,    1, 2357,  905,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  921,    1, 1662,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  352,   37,    1,    1,   50,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 2767, 1468, 1416, 2232,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1232,  334,    1,  994,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   85,   37,  112,    9, 3311,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  567, 2372, 1046,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,    1,  359, 1195,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  542,  565,    1,    1,  548, 2685, 2282, 2689,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2859, 2955,  167, 2346, 1125,   98, 2500, 2971,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1520, 2414,    1,  279,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962, 2184, 1249,    1,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273,  173, 1021,   32, 1658,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  154,    1,   45, 2851, 1424,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  186,  251,  964, 1876,  297, 3102,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  597,    1,  710,   37,  138,    1,  331,   37,  875,  134,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   68,   69, 1784,  530,   32, 1033,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  397,  342,    1, 1859,  271,  442,  261,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2110,  147,  261,   98,    1,  333,   45,   49,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   64,  799, 1554,  388,  763, 1530,   32, 3349,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861,  681,    1,   28,  327,  593,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  256,    1,  230,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  626,  459, 1909,   24,  220,  395,  129,    1,   69,  369,\n",
      "            1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  782,    1,   98,  166,    1, 1638,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310,   25,   71,    1,  420,  919, 1043,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275,   26, 2069,  339, 1452,   32,  987,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868, 2440,  548,    1, 1897, 3349, 2237,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1081,   98,  845, 2393,  548,  667, 2147, 1585,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   37, 1198,  442,  909,  444,  104, 1010,    1, 1931,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3313, 2827,   37, 2250,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2976,    9,  829,   12, 2851,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3254,  884,  786, 2847,  631,  176,  219, 3329,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3297,  361, 3161, 2260,    9,  590,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  108,   45, 1718,  396,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49, 2590,  885, 2195,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2692,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843,    1,  315,  112, 1775,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2468, 3123,  688,    1,   37,    1,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,  794,  517, 1108,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  547, 1428, 1149, 2644, 3102,   32, 3376,  565, 1683,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128, 1203,  331, 2400, 1129,    9,  114,  629,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  755, 1458, 2017,  384,  829, 2194,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1471,  395,   15,  245,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1309,    1,    1,    1,  166, 2009,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  310,    1,    9,  453, 1021, 1151,  973,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3251,    1, 2685,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964, 1454, 3367, 1563,  176,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2838, 1183,    1, 1910, 3236,    9,  385,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,    1, 1994,  926,  872,   37,  927,    1, 3023,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  268,  251,  331,    9,  413,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  614,  548,    1,  792, 2819, 1468,  792,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1821, 2728,  884, 1918, 2365,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  147,   37,  231, 1369,  695,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2658, 2269, 1550,  716,   45,  845,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,    1, 1899, 2145,   37, 1734,  776,    9, 2772,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1128, 1203,    1,   59, 2871,    1, 1129,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2658, 1550,  204,   61,   39,   45,   84,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  218,  332,   32,   29, 2759,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1145,   16,  384, 2890,  105,  270,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  766, 1236,    1,   98, 1102, 2351,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2308,  474, 1822,  100,  920,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1131, 2522, 2871,    1, 1216,   37,    1,  815,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3231,  774,    1, 1360,  612,   52,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,   42, 1370,   45,  633,  573,   43,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1039, 2321,    1,   37, 1421, 3284,    1, 2719,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2563, 2563,    9,   98,   72, 2622,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 2262, 2095,    1, 2572,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1834, 1287,   37,  103, 3231,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1813, 2047,  361,  753,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2499, 2104, 1770, 2707,  342,   46,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3349, 2705,    1,   32, 2970,  339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1327,  686,  191,    1,  477,   45, 1149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,    1, 2737,  459,  220, 1691,  872,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,  146,    1,   37,  359,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98, 2901,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1829, 1510,  864, 1877,   37, 2446, 3366,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  764,   12,   98,  166,  454,    9, 1628,    1, 1704,  617,  259,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  700,   37,  508,   79,    1,  187,  156, 1374, 1010,  927,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885, 1765,  449,   59, 1178,   32, 3129,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  355,    6, 1183, 2113, 2034,    1,    1, 1396,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1786, 1360,  612, 2446,  166, 2819,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1718,   51, 1719,  636,    6,    1,  377,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178, 3384,  162,  537,    9, 1606, 1260,    1,  598,   45,    1,\n",
      "         1585,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1566, 2410, 1537,  250,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984, 3062,    1,   32,  810, 1922, 3098,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2578,  396, 1684,  176,    1, 2335,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   92, 1766, 1767, 2320,  191, 1146, 1703,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  718,    1,   37, 2613, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296, 1249,   20,   37,   54, 1250,  384,  340, 1251,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1821,    1,  288, 2364,   98,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,   12,   39,   37,  665,  105,    1,   98,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69, 1298, 1382,  187,  104,    1,   76,   37,  907, 1220,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  176,  163,    1,   12,    1, 3160, 1939, 1941,  531,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1364, 1365,  759, 2069,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,  361, 2821,    1,  176,    1, 1313,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  200,    1, 2355, 1013,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   12,  156,  388,  763, 1427,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  854, 1463,  546, 2673, 3085, 1461,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  147,   57,    1,   37,    1, 1791, 2633,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    4,    1,   12,    1,    1,    1, 1456,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 2153, 1152,  444, 1002,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 1301,    1,    9,  317, 1527,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  846, 2264,  221, 1159, 2241,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   19,  166, 1593,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,  985,    1, 2070,    1,  736,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,    1,  114, 1631, 2078,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3128, 2770,  854,    1,    1,    1,   98, 2108,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,    1, 1827,  803,  615,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  729,  603,    9,    1,   32,  531,  548, 1665,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  694,   12,    1, 1542,   37, 1664,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   98,  105,   74,   45,    1,   62,   32,  531,    1,  736,   98,\n",
      "          863,  211, 1258,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  403,  464, 3396, 1237,  463,  464,    1,   32, 2592,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2255,  852,   37, 1296,   28, 2355,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  190, 1188,    1,   45,   28,   37,    1,    1,\n",
      "          990,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  461,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3277,  967,  590,  997,    9,  119,  151, 3177,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398, 1297,  793, 1978,  209,    9,  285,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  496,  782, 1412,    1, 1810,  961,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282, 3230, 1308,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  166,  114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 2366,   26, 1039,  949,  729,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2606, 1297, 2264,    1,  166,  730, 3022,  384,  754, 1821,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    1,  928,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  507,  111, 2559, 1273,  911,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1877,    1,    9,  647,   17,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   33, 2094, 2149,    1,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   25,  526,    1, 1340,  245,  115,   45,\n",
      "           65,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  602,  578, 1119,   98,  531, 1563,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   12,  365,  327, 1013, 2549,   51,    1,  762,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   32, 1523,   45,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  155,  570,    1,  225,  338,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,   50, 2424,  413,   32, 1186,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  395,  719,   37,  544,  388,   37,  674, 1278,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  590,    1,   37, 1573,  220, 2523,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2596, 2766,   32, 2755, 2490,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  765,   37, 1636, 2971,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,    1,    9, 1099, 1453, 1216,  122,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,  829,  132,  155,   26,  756, 1574,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2676, 2137, 2275,    9,    1, 2001,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 2506,  297,   20, 1859,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  205,  971,  389,    6,   32,   91,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018,    1,   32,  388, 1726,    9,  365, 2224,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  261,    9, 2127, 1001, 1900,   32,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1140,  656, 1085,   98,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2236,  729,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1935, 1320,    1, 3016, 1935,    1, 2636,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1606,  524,  387,  449, 1023,  197, 1253,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018,    1, 1876,    9, 1815, 1389,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  176,  365,  845,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  197,  418,    1,    1,  191,  333,   45, 1033,   48,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  947,  619,  563,  564,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3003, 1536,  365,  912,  605, 2039,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   49,  321, 2728,   69, 1010,    5, 2096,    1,  121,    1,  267,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,  180,    1,  170,   61,  199,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1481, 1401,    1,  297, 3322,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  951,    1,  584,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 1734,  776,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3402,    1, 1988,   45,    1,    1,  361, 2772,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  657, 3007,  365,  673,    1,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,  658,  659,   45,  660,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  469,  509,  828,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3209,  688, 3260,    1,  288,   28, 1834, 3135,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1707, 1448, 1749,  693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2059,   12,  589,   98,  132,    1, 2266,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  621,    1,    1,  170,  943,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112, 1161, 1276,   32,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,   45,  599,    1, 2150, 1042,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1662, 2086, 2039,    1,   32, 1440,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1492,   12, 1411,    9,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2767,    1,    1,  931,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1858,    1,    1,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  639, 2051,  763,  649, 3079, 1827,   32, 1264,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  548,  537,   32,  611,    1,    1,   45,    1,   61, 1211,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   37,  927, 1229,    1,  531, 2439,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3236,  688, 3256,   37,    1, 2916,   39,   45,  449,  913,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2343,  379, 1916,   37, 1174,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  565,  410,   98,  120,   32,   69,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   94,  654,  225, 2317,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,   37, 1636,   29,    1, 1316,  593,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  361,  620,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  720,  187, 1256, 1256,    1,  626,  159,  817,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  114,    1,    1,  967, 3265, 1857,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  284, 2360,  846,   45,  657,  475,  302,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3386, 2161, 1585,  312, 1916,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1965, 2982,  271,  199,  297,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129,  838,   38,    1,  321,   52,  103, 2887,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1,    1, 1680,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,   12,  449, 2918, 2699,  431, 2818,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2962,    1, 2202,  297, 3227,  187, 1110,  726,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3051, 3118, 2751,  222, 1527, 1259,    9, 3396,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 1500,  347,   37,  838,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374,  114, 2328, 1159,  399,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  584,    1,    9,    1,   64,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  191, 2882,  535,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  619, 1253,   98, 2321,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189, 1443,  838,  157,    9,  613, 2287,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  733,  327,  112,   37,  649,  437,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,    1, 2741, 3192,    1,    1,  307,   39, 1897, 3023,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  500,  387,  306,    1, 1935,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1734,   79,  614,   98,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  799,  408, 1001,    1,  199,  176,  584,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1221,   51,   52, 1204,   39, 1221,  548,  810,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275, 1398,  612, 1406,  600,  275, 2928,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  207,   85,    1,    1,  156,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3181, 1831, 3281,  418,  530, 3314,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2419,  218,   32,    1,    1,  716, 1716,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428,  146,    9,  949,   45, 1149,   32, 3360,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 2361, 2024,   46,  220, 2755, 2751,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  864, 2098, 2673,  132,  220, 2339,  778,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,  713,   37, 2225, 1517,   12,  979, 3229,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1092,    1, 2446,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2977,  162, 1799, 1124,    9, 1821,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1414,   64, 3391,    1, 2909,  135, 2597,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,    1,    1,   79, 1443,    1, 1475,  102,   98,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  631,  176,    1,   12,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3404, 3041,  164,  187, 2617,    1, 3358,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2591,   37,    1, 1351,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 1063,    1,    1,  331,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  187,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,    1,   98,    1, 1823,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,  603,   37, 2918,  361,  760,    9,  627, 1821, 1967,   32,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  557,  540,    1,   32, 2426,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2819, 1277, 2145,   37,    1, 2650,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1079, 3063,    1,  777, 2937,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1340, 2424,   98,   74,   79,    1, 1293,   32, 2340,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1638,  108,   45,    1,  659,  674,  629,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401, 1110,  297, 3285,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 1707, 2170, 2128,  693,  176, 3118,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1327, 1386,  288,   37, 1174,  219, 3341,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  966,   61,   37, 1096,  267,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  293, 1931,   20,    1, 1795, 1539,  872,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2814,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   30,  453,  792,    1,  792,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2208,    1, 2249,    9, 1717,    1,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3018,   37, 2684,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1, 1790,  872,   98,  207, 1085,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1151,   13,  315, 1208,  423, 1010, 1424, 2047,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   61,    7,    1, 2825,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  565,  388,  585,    1,   37,  596, 1793,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   26, 2679,  197,    1,    1,  225,   85,  548, 2074,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3204,    1, 3230,   32, 2490,   26, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,    1,    1,   95, 1478,   32,    1,  548, 2596, 2716,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2843, 2523,    1,   61,  943,   45, 2921,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  506, 1380,   86,    1,    1,  176,  131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,  882,  327,    1,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3068, 1542,    9, 2487,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  121,  744, 1611,    9,   69,  633,   49,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  477,  384, 1602, 3163,  868,   51, 2535,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   61, 2213, 1010,  105,    1,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3045,  837, 1147,  947, 1530,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,    1, 2043,  759,  365,  784,  769,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   28,  548,  163,    1,   12,    1,    1,   29,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  323, 1806,    1, 2162,    1,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2593,    1, 2760,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  982,   37,  130,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  561, 1013,    9,    1, 2249,  384,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2932,  877,    1,  985, 1000,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 1974, 1751, 1056, 1675,    9,  195,  400,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2498,  220,  846,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233,  735,    1,  498,   98,  790,  302,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   85, 3018,  729,  251,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1378,    1,    1, 2952, 1183,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1019,    1, 2663, 1976,   32,  395,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375, 1140,    9, 2024,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1782,    1,   79,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1380, 1836,   54,  214,  142,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2563,  565,    1,  885, 1641,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,    1,  660,   32,    1,   45,  440,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  409,   25, 1269,    1,  289,   98,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  513,    9, 2453,  916,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1284,    1,  760,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043, 1268,  242,   98,  996, 1986,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1227, 1702,    1,   39,  166, 2009,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  459,  881,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  198, 2164,    1,    1,  686,  455, 1530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75, 1831, 1458,  196,    1,  613,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   22,  477,   98,  531,   12, 3391, 2414,\n",
      "         1056,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1718,  884,  105,   84,  105,  803,  786, 1750,\n",
      "         2355,    1, 1160,    1,  150,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  919, 2468,   37, 2654,  247, 1764, 1990, 2494,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3232,  665,    1,   32, 2602,  171,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  418,   98, 2187, 1625,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  334,  774,  334,    1, 2423,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2164,    1,    1, 2856, 1056,   32,    1,    1,  903,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299,  123,   37,    1, 1281,   98,  116,  412,  962,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3358,  105,    1,  104,    1, 3101,  595,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006, 2856, 3025,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  271,  384, 1663, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1173,    9, 2056,  698,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 2946,   45,    1, 2952,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2388, 1022,    1,    1,    1, 1022,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,   32, 1698, 2760,    1, 1542,   37,  168,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  142,    9, 1428, 1311, 1735,    1, 2868,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  661,  166, 1938, 2223,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230, 2540, 3257,   32, 3329, 1990,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,    1, 1022,    1,  921,    1,    1,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087,  433,  802,  220,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3278, 1523,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,   51,   44, 1167,  523,    1,   37,  615,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1444, 1398,  612, 1982, 1167,  105,    1,   32,  968,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  635,  197,  338,  191,  187,  445,  187,  225, 1042,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2533,    1,  220,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1204,  286,   61,  824,    9,  920,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2666,   32, 2147, 2950,  691,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1284,  105,    1,   45,  105, 1935,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2,  69, 640, 187, 163,   1,  12,   1,  68,  25, 832,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 422, 476, 388,   1,   9, 616,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2056,    1, 2706,   37,  860,  116,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,  253,   37, 1982,  467,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1585,  176,  947,  317,   32,    1,    1,  547, 1530,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,    1,   37,  104, 1046, 1400,  713,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2089, 2537,  176,    1,  167,  211,    1,    1, 2092,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,   37,  741,   98, 3339,    1,    1, 1094,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 1471,    1,  715,  474,  562,  138, 1806,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2090,   69,  636,  919,    1,    1,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  596,  616,  510,  850,   69,  242,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1955,   37, 1155,  250,   32,  795,  511,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1, 2255, 2639,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1983,    1,  782,  590, 3307,   98,    1, 1039,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  884, 1194,    1,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1005,    1,   12,  157, 1018,    1, 1167,    1,  833,  612, 1188,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1178,  386,  162,  142, 1992,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1771,    1, 1149,   51,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  298,   27, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2206, 2207, 3319,  872,  420,  385,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,  952, 2924,   37, 1496, 1428, 1346,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964, 1484,   98,    1,    1,    1,    9,  105, 1358,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1479,  922, 1123,  550,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2218,   98, 1515,  175,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1962,  108,   45, 2537,  220, 2522,  618,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  880, 2421,   32,  942,    1, 1312, 1530,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,   30,    1,   32,    1, 2026,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   95,  473,  474,    1,  477,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,   12,   49,    6,   69,  568,  570,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2890, 1675, 1509,   45, 1676,  608,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  786,   32,   56, 2527, 2946,   51, 2844,   39,  424, 2350,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  388,  734,  591,    9,  594,  497,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   22,   37,  125,  138,  118,    9, 1354, 1149,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1994, 2693,  700,  108,   45,  365, 1273,  259, 2693,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 3012,    1,  415,  203, 2342,  565,  453,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   32,    1,    1,  166, 3312,    1, 1031,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  968,    1,    9,  671,   32, 2161,   12,\n",
      "         3096,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1018,  367,    1,    9,   31,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,  446, 1484, 1193, 1953,  297, 3091, 3102,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,   37, 1155,  613, 1074,    9,  627,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   15,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  885, 2997, 2762,    1,  885,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1877,   37, 1806, 2673, 1699,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  656, 1061,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,  562,   12,  613,  207,  412,   98,  541,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  938,   61, 1231,  220,  133,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1436,    1,    9,  211,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2950, 2414,  176, 2018,    1,  186,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  420,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,  213,   37,  138,   59,   37,  875,   43,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3348, 3382,    1,   37, 3358,   12,  175, 1010,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   74,    1,    9, 2695, 2223, 1821, 1333,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2501,  861,  475,  939,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2345, 2390, 1867,   32,   12,    1, 1447,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  884,  105,  638,    1,    1,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  468, 1362,  251, 1211, 1273,  861, 2389,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,    1,  342,    1,  220, 3374,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2459,  614,  613,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3108, 1285, 3266,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  857,  237,    1,   37,    1,    1,  698, 2013,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,   37, 1454,   65, 1990, 1684,  176, 2069,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   98, 1514,  175,   45,  166, 2088,  978,  260,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779,  580,    1,    1,   32,    1, 2470, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2867,    9, 3149, 2751,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3348, 1896,   37,  949,  487, 3102,    1,  932,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1128,   37,    1,  453,  449,    1, 2686, 2687,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12, 1048,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1423, 3006,    1,  114,  562,  705,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1494,   32,  581,   32, 2161,   12, 3292,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1904,    1,  297, 2196,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2883, 2924, 1997,    1,    9,  531,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1988,  104, 3400,   37,  420,   37,  622,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  632,    1, 3272,    1, 2325,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3048, 2923,    1, 2697, 1232, 2599,  565,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 2767,  449,    1, 3044, 2232,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  632, 2981,    1,    1,    1,    1,  220, 1663,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   63,  166,  862,    1,  418,   98,  157,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  964,  267,  121,  580, 1698,  443,   37,    1, 1833,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,  947, 2833, 2048,   45,    1,    1,  384, 2839,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1795,   37,  335,   44,   98,  147,  484,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1, 1787,  944,    1,  436,   50,  333,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1844,    1,   32, 2069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,  520,  413, 2362,    9, 2448,  386,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  656,   45,  661,   45,  666, 1564,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 2160,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  147,  261, 1968,    1,   98,    1,  768,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3326,    1,   39,   37,   92,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788, 1760,  186,  444,   10,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187, 2769,  868,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  680,  422,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,  556, 3384,  836,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3380,  193,    1,   98,    1, 1583,  317,  104,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1034, 2512, 2227,  872, 1813,  395,  361,  455,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1354,    1, 1876,    1,    1,    1, 1002,  782,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3303,  765,   37,  166,  103,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  315,    9,   22, 1484,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  218,  640,  183, 1011,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  954,  256, 2196,    4,   32,  367,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267, 1398,  612,   47,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1739,  729, 2963,  191,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2912,  928,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3357, 1554, 2646, 3346,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  551, 1751,  872,   28,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  539,    1,    1, 2018,   37, 1388,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1420,    1, 1149,  384,    1,    1,  187,  510,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1645,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  510,    1, 1632, 1951, 1549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   26, 3204,   12,    1, 3282,  744,  166, 2146,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2266,   12,  317,  176,  166, 1428,   51,   52,  176,  629,    1,\n",
      "          379, 2047,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3175, 1334,   32, 2884,  220,  726,  297,  105,   12,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  750,  232,  488, 3140,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  894, 2595, 1406,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  750, 1494,   28,  183,    9,  590,    1, 3110,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  469,    9, 2397,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1607,  231,  848, 1303,    1,  105, 1775,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  827, 2720, 2796,  872,  420,  385,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 2580,  973,    1,  520, 3018,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  550,  561,    1,    1,   98,  116,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2757,    1,    1,    1,    1,    1, 2405,    9,    1,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  288,   37,    1,  395,   98,  442,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  387, 1332,    1,  104,   15,   28,    1,  419,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1,   79,  706,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  366,    1,   85,    9, 1194,  339,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,    1,   98,  651, 1031,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232,  565,   85,  361,  588, 1198,  384,  542,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  121,   37, 1155, 1821, 1539,    1,   32,  463, 1447,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1426, 1845,   59,  399,  220,  234,  182,  235,    1,    1,\n",
      "            1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   98, 1995,   44,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1320,   37,    1,  624, 2456, 1813,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2663,   45,  638,    1,    1, 1976,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 1002, 1463,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  235,    1,    1,  187,  227,  187,  460,  162,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 3121, 1554,  228, 1530,    1,   56, 2249,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  365,  142,   37,    1,    1,  957,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,    1, 1622, 1920,   12,    1, 1175,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1235,  636,  504,  807,  763,   76,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2685, 2192,   28, 1700,   32,  449,    1,  321,  612, 2139,   81,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   20,  140, 1250,  384, 1053,    1, 1464,   37,   47, 1117,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 2700, 1403,  201, 1975, 1415,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1899, 1231,  220, 2772,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,    1,   98,  568,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  590,  750,  444, 1778,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  312,  821,  456,  667, 1325,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1542,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340, 1310,   37, 1048,  247, 2225,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1128, 1614,  340,  439, 2232,  260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  743,   12,  244,   28,   98,  198,  163,    1,   12,    1,   15,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428, 2699,  300,  622,  872,   37,    1, 1345,   32,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  945,    1,    1, 3404,   37,  166, 1009, 2572,   98,  454,\n",
      "           37, 1604,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 1874,  121,   12,    1,   45, 1839,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  446,  936,  315,    9,  161,  931,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  434,  220, 1095,    1,    1,  191,    1, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203, 1617,   61,    1,  191,  166,    1,   45,  228, 1479, 2064,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1680,  142,    9,    1,    1,    1,  325,  199,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2924,   64, 2597, 3392,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  764,  260,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,  313,   37,  631,  116, 1697,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  191,  365, 1787,  220, 2846,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3241,    1,  105,    1,   32,  354,   37, 3263,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,  715, 3329,  191, 2847,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  754,    1,  437, 1025,    1,    9,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,    1,    1,   37,  273,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181,    1,  848, 1508, 2019, 1259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 191, 224,   9, 705,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 365,   1, 820,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2317,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  359,  176,  393,  335,  327,  125,   32,  138,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  952,   48,   32,  649,  458,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2308,  997,  677,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2999,   91, 2257, 2819, 1345, 3050,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  580,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1523,  297, 2606, 2653,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  316,    1,    1, 1167,   12,  166, 2225,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1414,  798,  429,   45, 3155, 1387, 1056, 1890,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260, 2712, 1110,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   37, 1075, 1602,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,   45,    1, 2980,  640, 2474,  618,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  293,    1,    1,   98,   26, 1039, 2876,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  267,    1,    1, 2336,    1,  782,  454,   37,  243,  885,\n",
      "          331,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1548, 1831,  744, 2364,   98,   91,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  351,  837,   61, 1976,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  200,  469,   37, 1211,   28,  218,    9, 1656,  436,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  954, 1032,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1951,    1, 2414, 1056,  961, 2878,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2744, 1766, 1767, 2287,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1247,   12,    1, 1360,  612, 1251, 1590,  389,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1568, 2854,   45,  166,   74,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  203,  321,    1,  361,    1,    1,   52,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   30,  365, 3365,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1123,  892,  428,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  102, 1343,    7,  808,   32, 1128,  156,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3359,   37,    1, 3339,    1,   37,    1, 2789,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   68,   69,    1, 2174,  813,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  503, 2151,    1,   54,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  375,   81,   98, 3130,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   42, 1056,  183, 2659,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196,    1,  176,  551,  612,  613,    1,  176,  551,  612,  498,\n",
      "           98, 1085,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  125,    1,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2378,  823,    1, 1910,  105,    1, 2290, 1316,  166,  795,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  636,  921,  679,  109,  340,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  186,   98, 1194, 1856,   45, 1537, 2874,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1200,   12,    1,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545,   61,  920,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,  754,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  220, 3190, 2800,  872,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2305, 2581,  571, 1809, 1821,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196,    1,   28,  176,  612,  613,  887,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2347,    1,  167, 1306, 3135,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  828, 1140,   98, 2087,  433,   37,   81,    1,   45, 1281,   98,\n",
      "         1995, 2375,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1178, 2827,   32, 2741,   32, 1051, 2690, 2607,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390,   12,  721, 1579,  105, 1746,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,   66,  187, 2084, 2886,   45,  557,  218,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1829,  236,  237,   12, 1479,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  700,  162, 1056, 1147, 1495,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1846,    1,   45,  857,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   83,  776,  891, 1445,  654,   12, 1143,  797,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2945, 2480,    1,    1,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1159,  613,  777,  220,    1,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700, 2496, 1976,   32, 1056,  437,    1,   32,  455,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,  105,  354,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 2414,  103, 3374,  650,   32, 3140,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  393,   22, 1426,  132,   98, 1858,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  738,  739,   32,  572,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1423,   32,  142,   37, 1000, 1527, 2664,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3274,   76,   37, 1306, 2882,   26,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1707, 2614,    1,  459,  220, 1110,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  741,   32,    1,  890,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  224, 2976,  365, 2454,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32,    1, 1260,  176,  649,  845,   36,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101, 2572,   32,  717,  458, 1939,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  974,  975, 2593,  365,    1, 1211, 1607,  260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2073,  328,  711,  475,  796, 1010, 1033,  331,  551,  105,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1555,    9,  478,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,   44, 1750,  105,  106,    1,  102,  120,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2415,    1,  400,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 382,  15,  66, 383, 384, 385,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1,  32,  26,   1, 428,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1355,    9,  141,  475,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2197,    1,    1,  384,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1461, 2766, 3339,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  335,    1,   37,  365, 1722,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  288,   37, 2728, 2229, 2232,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1509,   45,    1,  550,    1,    1,  361,  760,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  104,  684,  734, 2010, 1822,   52,  969,  424, 1034,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  288,   37,  335, 2933, 2545,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1785, 3030,  267,  388, 2924,  110,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481, 1830,    9,    1,  863,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,  903, 1447,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25, 2075,   81,    1, 1572,  191,  185,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  683,    1, 3103,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 2308,  365,  693,    1,    1,  125,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,  297,    1,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2656,  267,  460, 1924,    1, 1159,    1,  724,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  597,    1,   37,  764,  220,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203, 1691,   61,  166,    1,  454,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1824,    1,  384,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  815, 2978,   37, 2324, 3015,    1, 2977,   61, 1373,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2685,  151,   39,    1,   12,   24,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3202,    1, 1208, 2242,  176,  449,  395, 3141, 1090,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1174, 2673,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2837, 2789,   28,  105,   64,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  132,    1,  122,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1, 2797,  187,  302, 1271,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  786, 2638,    1,    1,   32,  395,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1412, 2521,    1,  334,  894, 1847,  600,    1,  861,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  593, 1660, 2101,    1,  759, 3293,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  733, 2481,    1,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,  535,  656, 2367, 2030,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  826, 2317,   32, 2795,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1773, 2510, 1090, 1863, 1908,    1,   98,  455,  714,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3094, 1439,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  215,   37,  588,   10, 1876,   98,  517, 1964,  569,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2246,  942,   12,    1,  641,  247,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3094,   45,  116, 2502, 2985,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2246,  104, 1249,  104,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1629,  315,   37, 1753,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 2702, 1085, 1195,  548, 2291,  778,  598,   45,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3144, 3372,  267, 1844,   79, 1002,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  744, 1893,    1,    1, 2306,    9,    1,    1,    1,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 2317,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  297,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   71,   45,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105, 2154,    1,   32, 2208,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 2864, 2933,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2961,    1, 1071,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,  99, 113, 347, 816,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 479, 919, 197, 739,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  721, 1098, 2297,  929,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  410,    1,    9,    1,  314,  475,   12, 2022,    1,  220,  591,\n",
      "            1, 1057,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3358,   12, 1983, 2078, 2845,  297,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12, 1619,  458,  267,  172, 1294, 1620,    1,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  155,  158,    1,  197,  570,  159, 1253,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   25,    1,  191,   69,   12,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2415,    1,  901,    9,  914,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  845,   69,  636, 2007,   37,  109,  997,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  547,  454,  132,  123,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1591,    1,  640,  237,  472,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  411,    1,    1,  168,   37, 1611,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  992,   28, 2943, 1499,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  665,   98, 1658,  730, 1777,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  803,   25,  631,  166,  454,   98,  236,  237,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  818,  834,  162,   79,   37, 1121,  698,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,    1,    9, 2383,   37, 2464,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1480, 1656,    1,  934,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3038, 2708,    1,  114, 2134, 1094, 2625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   91,  927, 1921,  176,  166, 2918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  515, 2176,  105,  271,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1273,  215,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2944,  315,   37, 1418, 2924,  384,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1808,   30,    1,    9,  111, 1107, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3255,    1,    9, 2551,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1973, 2161, 2365,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2943, 1499,  675,  361,    1,  105, 2529,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2, 914,  45,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  32, 400, 334, 254,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  709, 1228,  655, 2430,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 1292,    1,    1,   32,  312, 1995,  776,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  511, 1414, 1776,  183,  504,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  337,    1,  876,    1,  952, 1281,   98, 2970, 1089, 1675,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  420, 1440,  686,  191, 1938, 1723,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   90, 2264,   37, 2432,  365, 2558,   32, 1778, 1160,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  314,   37,  836, 2281,  134,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  410,   98, 1162,    1,    1,  937,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,   12,    1,  477,  460,  252,  220, 1126,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2573,   12,    1,  315,   37, 2354,   37,  395,  191,    1,  420,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  266,    1,  131,    9,  752,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   13,   32, 1512,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2615,  631, 3216,   32, 1090,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  625, 1296,   28,   61, 2030,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 193, 320,   1,   1, 994,   1, 150,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 485,   1, 372, 326, 486, 132,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1545,    1,    1, 2590, 2961,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3280,   37, 1844,  365, 1788, 2472,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2948,   91,  927, 1478,   98, 1965,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  941, 1201,    1, 1318,    1,  562,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  511, 1021,  140,  695,   98, 1116,  506,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,   69,  102,   51, 1121,  104,  954,    1, 1360,  612, 1389,\n",
      "            1, 1592,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2778,  588,    1,   32,  451,  736,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  207,  412, 2175,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  921,  922,   45, 1117, 1525,  923,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 2347, 3265, 1071,    1,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  147,   37, 1982,   49, 1727,   98,    5,  302,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  670,  187,  197,  937,  817,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   26, 1039,   12, 1411,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  144,  145,    8,  197,  304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  493, 2152,  110,    9,  903,    1, 1117,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2236,  162,  247, 1333,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2889,    1, 2789, 1484,    9, 2024,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938, 1489,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 3155,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  251, 2334,    9,  333,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  509,  297,  863, 2095, 1665,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  147,  261,   49, 1822,  138,    1,  131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  669, 1178, 2572,   32, 2597, 2292,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9, 1610, 1090,  698,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  747,    1,  746,    1,  349,   45,    1,    1,  150,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2765, 1810,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2,  60, 640, 365, 340, 444,  94,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 220,   1,   9,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1028, 1300,    1,    1, 2179, 1021,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3285,    1, 1971,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3037,  765,   37, 1496,  310,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226, 2233, 1851, 1540, 1232, 1366, 1980,   37,  877, 3179,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  160, 1161,  338, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089,   37, 1935,    1,    1,  327,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2754,    1,    1, 1098, 1465, 2086,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,   42,  400,  444,  896,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 2107,   32,  455,    1,  968,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,  940,   30, 1662,    9, 1211,   37,    1,  706,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  321,   52, 3298,   12,    1,    1,  267,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885, 2297, 1863,   45,  166,  356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 857, 818, 686, 524,  15,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1,   1,  37, 875, 134, 428,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2530,  631,    1,  636,  948,   32, 1352,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035, 2301,    1,  475, 1213,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359,   12, 3339,  469,    1,   98,  741,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683, 2745,  220, 2505,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1988, 3400,  288,   37, 1046, 1583,  776,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1184,  347,   37,   71,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3276,  726, 1194,   73,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32,  531, 1656, 2950,    1, 3279,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1638,   32,  104,    1, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1,  182,    1,  105,    1,  637, 1133,    1,   37, 2308,\n",
      "            1,   32, 2811,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1122,  538,    1, 1107,  111,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984, 2418, 2662,   12, 1841,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158,  794, 2627,    1, 2627, 1230, 2528,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1486, 1680,  570,  548,  198,  401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   22,  942,  998,  669,  716,  572,  354,   45,  331, 2007,   37,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1562,   10,   12,    1, 1563,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2135,  940,    1, 1919,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2165,   63, 1104, 2928,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1902,  515, 1367,    1,   45,  247,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1940,   12, 3134,  872,  884, 3077, 3126,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2939,   98, 1434,    9, 1427,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1586,   28,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  572,  105,  730, 1777,  710,   46,   45, 1355,   37,   26, 1039,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   98,   40,    1,  111,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  164,  165, 1463,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2629,  588,  797,    9, 2673, 1867,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1968,  884,  365,   40, 2436, 2311,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2372, 2126,    1,  176,    1,  778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  195,  669,   42, 2163,  133,   44,    9,    1,   59,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1385,   45,  166, 2355, 1013,    1, 3154,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  799,    1, 1159,  166,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1367, 2712, 3218,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1099,   82,   51,  193,    1, 1787,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790,  908,    1,    1,    9,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  550,  369,    1,   32,    9,   12,  551,  552,  221,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3102, 3025,    1,   32,  365, 1089,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  447,  267, 3358, 1983,  912,  321,   52,  820,   37, 1841,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  410,   98,  645,  646,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   67,  423,   66,  187,  961, 1482,  738,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  572,  197,  338,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1408,  219,  159,  242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3290,    1,    1, 1751, 2073,  914,    1, 3318,    1, 2805,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  636,    1,  365, 1406,   32, 1582,   12, 2160,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  237, 1241,   28, 1242,   15,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2652,    1, 1375,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 3172,   37,    1,    1,  549, 1602,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1100,   12, 1273,    1,  884,   98,  657,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171,  172,  173,    1,   98,  174,  175,    1,  176,  177,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   28,    1,  190,   92, 2974,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1127, 1373,   37,  125, 1251,   45,  847,   37, 1443,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2718,  588,    1,    9, 2544,  861, 2043,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1786,    1,  735, 1576,  736,    1,  625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1222,   12,   54,  333,  155,  389,  361,  230,  122,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,   12, 3359, 1877,   37,    1, 3358,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  636,    6,    1,  215,   15,   45, 2975,    1, 1892,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,   12, 1350,  149, 1394,   37,    1,  756,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  613,  768,  149,  729,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1308,    1, 1022,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  395, 2164,    1,    1, 1219,    1,  590, 2705,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3313, 3270,  140,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1790, 1419,    1,    1, 1907,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  943, 2707,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  910,  315,  365,  124,    1,  176, 2161,  297,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,    1,   10,    9,  439,   45, 1995, 2375, 1281,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  854,  200, 1563,   37,  764,  877, 1833,  116,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1, 1401,   37,    1,  182, 1369,  354,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3267,    1,    1, 1758,   37,  136, 3217, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226,    1, 2941,    1, 2758,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2171, 1863,    1,    1, 1187,  857,   16,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,   22,   23,  232,  610,   32,   20,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  717,    1, 1661,    1,  405,    1, 2104, 1458, 2953,    1,   32,\n",
      "            1, 2693,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2366,   37, 1539, 1169,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   60,  338,  548,   65,  423,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2226,  331, 1658, 1656,    1, 1398,  612, 1584, 2349,\n",
      "            1,  334,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,   84,   28,   97,   98, 2646, 2751,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,  511, 2055,    1,   32,    7, 1090,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  215, 3102,   32,  637,   45,  365,  437,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  794, 1107,  525, 1626,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614, 2872,  105,   12,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,  856,  342, 1228, 2351,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  957, 1822,  335,    1,    1,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178,  947,  774, 3379, 2147, 3403,    1,  191, 2971,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  294,   37,  508,   79, 1149,    1, 1737, 1202,  548,  365,  354,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3020, 2096,    1,  284,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3244, 1046,  581, 1034,   45, 1884, 2462,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2300,  480,    9,  326,    1, 1129,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1537,  957,  765,   37,    1,   69, 1242,    9,  575,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447, 3145,  444,    1,   32,  531, 3102, 1512,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    9, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  636,   45,   69,  980,   79,  119, 1653,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,  458,  818,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  544,  365,  229,    1,  606,   37, 1251,  320,  445,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3196,    1,  754, 2242,   32, 2760,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190, 2192,   28, 2127,    1,    1,    1,   32,  132,  220,\n",
      "          553,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  539, 1037, 2097, 3166,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2713,  384,  487, 1583,   32,    1, 2172,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  409,   25, 1838,  417,    1,  104,   60, 1226,  444,   94,    1,\n",
      "         1547,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 1420,    1, 1660, 1661,  207,  197,    1,    1,   88, 1275,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2877, 2694,    1,  804,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1308, 2942, 1333,  176,    1,  813,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1527,   95, 1961,  548,  851,  640, 2624,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  885, 2615,  730, 2614,    1, 2522, 2861, 1159,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  711,  475,    1,  796,    1,   37, 1910,   32,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2160, 2049,  113,   79,    1,    1,  171,  140,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,   12,    1,  861,  207,    1, 1057, 1810,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  315,  777, 1953, 1108,  884, 1003,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  727,  613,   37,  151,    1,  728,    9,  131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  947, 2681,  444, 1887,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3213, 1408,    1,    1,    1,    1,  600,    1,   98, 1517,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2204,   98,  395,  442,    5,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  631, 2936,   26,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,   30, 2056, 1224,   45, 2319,  593,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2868, 1562, 2265,  446, 2309,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  711,   37, 1334,   32, 2882,  637,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3318,    1, 1025,   39,    9,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3336, 2489,    9,  449,  199,  452,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3001, 1249,    1,  176, 1022,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3309, 1360,  612, 2192,   28,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3118, 2751,  774, 1021,  132,  449,    1,    1, 2248,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,    1,    1, 2910,  619,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  603,  176,  141,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447, 2352, 1147, 1929,  190,   52,    1, 1851,    1,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1674,    1, 2942,    1,  776,  288,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1310,   37,    1, 2471,  220,    1,  507,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32, 1575,   45, 2121,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2596,    1,    1, 3150,   37, 1731,  447,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2153, 1413, 3358,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,    1, 1159, 1821,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  963,    1,    1, 1077,    1, 2022,  384, 1674,    1, 2630,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2314, 3358,    1,   32, 1645, 2611,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,  440,  229,   51, 1083,  985,  762,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  991,  148,   12,  142,    9,  413, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  709, 2227, 3289, 2682,    1,   45,  487, 3222,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  375,   37,  151,    1,   32,  152,  132,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,    1,   37,  319, 3339, 2831,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  374,  375,  624,    1,   37,  151,    1, 1201,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  721, 1707,  469,    9, 1485,  170,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2206, 2435, 1606, 1756, 1086,   46,   37, 1348,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1414, 1758,  115,   45, 3391, 1995,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1264,    1,    1,    1, 1152,   98,  932,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   64,  183,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2679, 2853,  111,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2003, 1585, 2414,    1, 2803,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  908,  233,    1,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,  739,    1,  983,    9, 1194,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  694,   12, 1090,  469,  860,  499,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1088,  147, 1707, 3398, 1377,   45,  926,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  852,   37,    1,  453, 1294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  724,   45,  105, 2350,    1, 1654, 1194,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   27,  526,    1, 1406,  297,   69,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   60,  338,  995,   98,  996,  997,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676,    1,    1,  796, 1675,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1429,   32,  457,    1, 2498,    1,    1,  191, 1300,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  267, 2239,   51,  606,    1, 3012,  298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2826,  395,    1, 1323,  187, 1354, 2529,   23,   32, 2601,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1238, 1247, 2321,    1,    9,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2878, 1013,  190,    1,  756,   32,    1,  927,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3046, 3205,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  729,    1,  134,    1, 1232, 2330,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  610,   37, 2162,    1, 1130, 1156,  297,    1, 2950,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3121,    1, 2097, 1850, 1789,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492,    1, 3348, 3006,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,  200, 2355, 1013,    1,  884,   98,  829,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340, 3212, 1624, 2806,    1,   32,    1,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  857,  818,  686,  524,   15,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2857, 1389, 3176,  857,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1625,   37,  917,  166, 2728,  176,    1, 1171,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  361, 1790, 1776,  105,  956,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  646,  193,  638,    1,  202,    1, 1735,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2744,    1,  122,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,   12,  365, 2759,  675,  335,   98, 2278,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1523,    1, 1813, 2999,  361,  923,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,   12,    1,  190,  877,    1, 1274,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  680,    1,  187, 1107, 2015,  418,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094, 2625,    1, 3339, 1219,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,  786, 1890,  361, 1463,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2974, 2137,   79,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1782,  760,    1, 1008,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   66,  526,  187,   69,  102, 1473,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  150,  325,  207,  259,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  731, 1013, 1522,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1394,   32,  864,  342, 2673,   46, 3399,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1312, 1538, 1683,   32,  531,    1,  447, 1489, 1357,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   32, 2818,    9,  197,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564,   54, 1973,  887,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3323,    1,   32, 2138,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1293, 2808,  187, 2968, 1740, 1910,  438,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1066,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,    1,   37,   62,  997,   45, 1610,  225,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 647, 721,   1,  37, 943,  37, 148,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 104, 116, 117,   1,  28,   1, 118,  37, 119, 101,   1,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2941, 1625,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  405,    1,   12, 2840,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1631, 2743, 2472,  119,    1,  140, 1940,   12, 2107,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1278,  526,   32,  367,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  705,    1,    1,   98,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3258,  894,    1,    1,    9, 1472, 2579,  931,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,    1, 2071, 1331,  660,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  289,   98,   65,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1237, 1658, 1117, 1525,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   42,  149,  297,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3244,    1,    1,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1474,  556,  412,   37,  778,    9, 2311, 2911,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  125,    4,    1,  825,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375, 2905,   37,    1, 3358,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2903,  857, 2250,    9,    1,  951,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232,    1, 1367,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3221,  252,   32,  247,  248,  454,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2285,    1,  105,  466,  825, 1638, 1821,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  621,  353,    1,  572,  197,   93, 1680, 1698,  356,  157,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537, 2122,    1,  964,    9,  695,   39, 1428,  861, 1906,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  410,  420,    9,    1,    1, 2948,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1, 2634,  693,    1, 2759, 2639,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  711,  986,    1,  636,   32,  105,  152,  225,  752,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,  112,    1,   39,  996, 2521,    9,  365, 2178,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  973,  115,   37, 2035,    5,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 1417,    1, 2629,    1,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,   72,  401,  156, 1253,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   26,  294,    1,  187, 3230,    1, 3253,\n",
      "          168,   39,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3251,  872,  420,  385,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  766,   37, 1505,  526, 2104, 1616, 1597,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1235,  102,  720,    1,  442,  910, 1052,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2644,    9,   36, 3071,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  336,  216,   32, 2755, 1094, 2856,    1,    1,  388,  763,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2021, 2277,    1, 2300,  547,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1545, 1249,    1,    1,   32,    1,   37, 2035,  631,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117,    1,  163,    1,  288,   37, 1198,  909,    9,  920,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1867,  858,  844,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  387,  983,  530, 1944,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 2873,  815,   37,  120,    1,  191,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1726,   37,    1,  673,  261,    1,  588,  105,    1,   94,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1202,  686, 3381, 3045,   32, 3391,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2936, 3329, 3198, 1249,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1237, 1658, 1117, 1525,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1294,  707,  810,  620,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2217,   12,    1,  578,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  776,  288,    9,  365,  356,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1123,  892,  428,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12,  730,    1, 1718,   37,  289,   98, 2798,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  354,  703,    1, 1944, 1315,  237,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75, 1679,   80, 1108,  384,  171,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  288,   37, 1638,  187, 1371,  187,  906,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994, 2995,    1, 2542,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1380, 1245,   98, 2579, 2153,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  136,  672,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2819,   81,   98,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3238,  162, 1194,  187,  730, 2614,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  425,  426,  572,  156,   71,   98,  242,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   45,    1, 2266,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  487, 2924,   51,   52, 1866,   37, 2597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,  147,    1,  544,  193, 1140,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2882,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  977,    1, 2012,    1,  506,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2984, 1976, 1056, 1298, 2662,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426, 1627,  166,  111, 1107,  525,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   26, 2679,   37,  130,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  347, 1719,  439,   45,  340, 1184,  408,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 2614,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  515, 2427,  411,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1765,  105,  650,   45, 1940,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  367,  442,  910,  640,  182,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,   12,  299,  140,  806,   32,    7, 1068,  171,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2193, 3093, 1313,   32,  864,  682,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1364,    1,  673,  566,    1,  682,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3336,    1,  361, 3098,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3358,   12,  223,    1,    1, 3404,   32, 2197,  774,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3025,    1,   37,  764,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1766, 1767, 3022, 2420,    1,  412, 1394,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  612, 2384, 1117, 1525,    1, 2492, 1671, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  258, 1132, 2745,   37, 1937,  534,   12,   81,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   28,  166, 1245,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,  61,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 590,  37,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3287,    1, 1902, 1765,  105, 2742,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,    1,    1,   32,    1, 1821,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  386, 2562,  365, 1757,   37,    1,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283, 1110,  190,   77, 1340,   32,  166,    1,  388,  537,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  572,  551,  105, 2893,  776,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2768,  166,  449, 2476,   18,  384,    1,    1,    1,  691,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  792,    1, 1117,  792, 1480,   37,  166, 2918,   61,  415,\n",
      "         1385,  166,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,  746,   51,  125,  388,  763,    1,    4,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   34, 1766, 1767, 2320,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,  387,  417,  572,  983,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1821,  927, 2421,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1762,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3249,  260,   28,   37, 2277,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  947,    1,    1, 2382,   32,    1,    1,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2762, 1412, 1450,  815,    1,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,    1, 1056,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3310, 2386,    1,   45,    1,   98, 1404,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 3220,    1,    1, 2872,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1039, 2942, 1270,  686,    1,    1,    1,    1, 1463,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111, 1900, 2072,    1,   45,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1081,    1,  650,   98, 2884,    9, 1726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169,    1, 3274,  759,  271,  402,   32,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  782, 2558,   32, 2580, 2851,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2802,  140,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,  190,  100,   98, 1547,  682, 1232,    1,    1,    1,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  950, 1685,    1, 1463,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3358,    1, 1584,  104, 1847, 1433,  204,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2427, 2872, 2522,  220, 1844, 1918,  297, 3211,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2702, 2291,   32, 2140, 1554, 1530,    1, 1941,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2572,   32,    1,    1,  443,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   32, 2451,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1357,   45,  166,  356, 2603,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  657, 2336,    1,    1, 2041,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128, 2650,  484,  902,  365,  468,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3144,   12, 2823,  863,  891,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925,   12,  198,  886, 2465,    1,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  519,    1, 1061,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1788,  200,  915,    1, 1509,  142,   37,  504,  166, 2826,\n",
      "           32,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  321,  612,   18, 1805,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1006, 2753, 1394,    1, 2463,    1, 3268,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  842,  325,   48,   32,    1,    1,  328,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2751,   32, 2752, 2856,    1,  187,  166, 1633,    1,  105, 3071,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2596,  850,   28,   32, 3339,    1, 3101,    1,  178,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1509,   45,  356, 2452,  517,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,  242,   60,   28,  444, 1547,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,   98, 2992,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1123,    1,    1, 3260,   37, 2522,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1229,   37, 2856,  176, 3043, 2765,  778,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3352, 2856, 2183, 1147,    1,  232,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,    1,  657,    1,  829, 1539,  777, 1085, 2146,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1656,    1,  829,   32,  166, 2886,   12, 1311,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2502,  921, 2736,   12, 1819, 2521,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   66,    7,   37,  215,    1,  627,  420,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  979,  105, 1245, 2842,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2596,    1,    1,   45, 3155,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868, 2489,   28,    1,  858,  809,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  730,    1,    1,    1,   32, 1549,  540,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1554, 1778,    9,   26, 1039, 2639,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  382,  293, 1236,  297,  878,   22,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,   82,  387,  198, 1838,   37,  356,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962, 1340,    1,  754, 1844, 2174,   32, 1110,  726,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 2925, 1292,  514,   32, 1404,   12, 2162,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1245,   98, 2826,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  957,    1,  798,  103, 2343, 2431, 2827,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  299,  315,    1,   98, 1099, 1453, 2089,    1,    1,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,    1,   12, 2059,   61, 3187,    1, 1603,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3161,    1, 1739,  275,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  974,  975, 2647,  157,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   58, 2145,   37,    1,  163,    1,   12,    1,   59,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2045,  420,    1, 2889,  384, 2841,   32,  163,    1,   12,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2618,   37,  865, 2126,   45,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1763, 1941,   32, 1260,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  537,   98,    1, 2372,  729, 1555,    9,  797,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1718, 2355, 1518,   32,   98, 1778,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3227,  588, 2925, 2966,   98,  845, 1480, 3115,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  331,  551,  612,  458,  353,  242,  572,  197,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  551,    1,  840,    1,   48,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    5,  302,  640,  632, 1273,  700,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3051, 2774,    1,  267, 2024,   46,  606,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  669,   12,  572,  354,  703,  187,   15,  670,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  147,  400, 1552,  297, 1395,  768,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  216, 2856,  176,  177,   32, 3339,  787,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  854,  439, 1044, 1045,  220,    1,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 1065, 1190,    1, 1057,  600,  354,   45, 1168,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  176,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,  884,    1,  808,  176, 1319,    1,   32, 1966,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  266,  353,  354,   98,  134,  744,  372,  752,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1398,  612, 2047,  116,    1, 2043, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  612,    1,    1,   12,    1, 2218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1920,  884, 3365,  176,    1, 1097,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1774, 2017,  384, 1652,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  782,    1, 1945,  297,   10,  361,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  375,  924,  396,    1, 1924,    1,  191, 1171, 1292,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,  251, 2492,    1, 2215,  361, 2679, 2665,   98,\n",
      "          166,  168,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  225,   70,  816,   63, 2014,   45,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3186,  429,   79, 2838,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1123,    1,  218,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   36, 1339, 1760,    1,  334,  321,  612,  899,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2511,  369,    1,   82,  267,   11,    1,   37,  838,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1158,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1497, 3252,    1, 1494,   28,  183,   32, 3201,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3132, 3294,  162,    1,    1,  351,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  706, 3041,  730, 1125,    1,  762,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1463,    1, 2953,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  167, 1173, 1159,    1,  815,   45,  229,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,  105,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1447, 1988,   45, 1769,   37,  211,   46,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1110,  104, 2951,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  742, 1680, 1178, 1179,   48, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  909,  444,    1,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3332, 1310,   37,  665, 2748,    1,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2736,   47,    1, 1107,   37,  542,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 1855, 3365, 1683,   32,  531,  639,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2844,   32, 2597, 2292,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3003,    1, 2171, 1107,  802,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  190, 1844,   32,  628,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2577,   59,    9, 1805,  626, 1021,  250,   32, 1817,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  588,    1,    1,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2765, 3060, 1631,    1,    1,   32, 2018,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  218,    1,   27,  730, 2228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  384,    1,    1, 2800, 1218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1043, 1738,  765,   32, 2091, 2320,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 1518,   98,  105,  845,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,    1,  328,    1,    1,    1,   32,  198, 1220,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  705, 1458, 1012,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3260,    1,  566,   98, 1739,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   32,    1, 1313,  297,    1,  114,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2322,  288,    9, 3226, 3240,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1523, 1813,  148,  361,  647, 2344,   37,    1,  147,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    4,    1,    5,    6,    7,    8,    9,   10,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1231,   32,   91, 2095,  927,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3167, 2206, 2435,    1, 1834,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1606, 1149, 1997,    1,   39,  176, 1985,  960,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   32,    1,    1, 1194,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  517,  476,  388,   69,  568,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  105, 2775,   45, 1056,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1918,  980,  997,  297,  442,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094,   34,  861,    9, 3359,    1, 1130,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1684,  590,    1,    9, 3169,   32,  316,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3286, 1710, 1982,    1,  187,  219, 3164,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   67, 1500,  191,   65, 1604,   32, 1056, 1262,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3343, 3345,  907,   98, 1623,   45,  163,    1,  903,    1, 3365,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,   12,  597,   82, 2430,   98,  133,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1218, 1042,    1,  290,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 2717,   45,    1,    1, 3073,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  398, 1707,    1,  191,    1,  297,  815,   45, 1674,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  187,    1,  580,  163,    1,   12,    1,  622,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,    1, 1564, 1811,  404, 1460,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2893,    1, 2919,    1,  191, 1485,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  647,   85,   98,    1,    1,  570,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1607,    1, 3004,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,    1,  199,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181,    1, 2118,  220, 3308,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3369, 1800, 1665,   45, 1428,  909,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   41,  612, 1273,  602,    1,    1,  361,    1, 1107,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  199,    9,  105,  730,  841,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128, 1205,    9, 1791,  596,   15,  768,  966,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1366,    1,   37, 1575, 1700,   59,  537, 1490,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3331,  429,   98,  444, 3241,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2494,  914,  267,  461,   12,    1,  940,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1585,   32, 2531, 3392, 2414,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  212,   12,  572,  156,   28,   98,   15,   93,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  190, 1982,    1,   37, 3117,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1005,  321,   52,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  374,  375,   37,  151,    1,    9,  152,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1364,    1, 2886, 2827,   32,  531,  267, 1924,    1, 1103,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1412,    1, 1348,   37,  664, 1737,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  364, 1383,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3309,   61,  943,   45,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   96,   37, 1087,   37,    1,  285,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   61, 2567,    1,  104,  267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3262,  288,    9,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2800,    1, 2226, 2233, 1154, 3306,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764,    1, 1450, 2856, 1312,  104, 3111,    1,  104,  622,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  845,   69,  102,  686,  395,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183, 2978,    1,  193, 1610,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  195,  700,  159,   32,  701,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2682,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3115,    1,    1,  220,   56,  356,  881,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3178,    1,   28,   37,  105,    1, 2196, 1918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,  37,  47, 829, 279, 613,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 129, 550, 830,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  132, 1610, 1371,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,   95,  384, 1759,  309,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   56,    1,    1, 2153, 2844,   32,   22,  298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230, 2450,   37, 1096, 1987,    9, 1764, 2712,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2049, 1149,  125,   79,    1,   45, 1327,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1802, 2591,   32,  123, 1002,    1,  289,   98,  388, 3093,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2004,  166,    1,  967,  416, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2942,  140,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  894,    1,    1,   32, 2161,   12, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3236,    1, 3266,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3151,    1,  474,  865,   37,    1, 2601,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  967,  590,    1,  469,   37, 1413,  517,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2026,  126, 1396,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 3108, 1468, 1378, 1209, 2789,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  157,    1,   98, 2487, 2621,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3095,    1,    1,   45,    1, 3374,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2957,    1, 2334, 1684,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,    1, 2019,  210,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1061,  176,    1, 1314,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,  125,  190,   52,   59,    1, 1146,   74,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  619,  183, 1631,   32,  365,    5,  302,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1658,    1, 2280,  209, 1197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1641,    9, 3042,  161,  187,  755, 1713,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  484,  199,  915,  916,    9,    5,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  676,    1,    1,   15, 1347,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  326,   12,  327,  112,   28,    9,  333,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1773,  733,    1, 2510,    1,   32,  449, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870,  313,   37,  194, 1568,   22,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1084,    1,  286,  533,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1492,    1,  997,  297, 2500,   37, 2500, 2527,  164,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,   63,  299,  600,  286, 1506,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3381,  437,  396, 2877,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   12,  957,  582,   37, 1253, 2728,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  439,   37,  976,  909,   98,  342, 2521,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  615,   32,   84,    1,  148,  765, 1415,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1,   46,   98,    1, 2673, 1806,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1465, 1466,    1,   82, 2520,   93,  315,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2657,    1,    1, 3038,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1, 2274,    9,    1, 1013, 1522,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671, 1078, 1586,   28,  104, 1876,  444, 1076,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1783,  251,  411, 1888,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 1845,  562,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  370,   37, 2446,    1,  183, 1395,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2177,   37,    1,   32,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1478,  103,  389,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537, 2728, 1683,  548,  116, 1842,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 2951, 1638,   45,  103,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  535,  656, 2367, 2489, 1103,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2024,  221,   32,  296, 1859, 1523,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  640, 2255,    9,  617,  618,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2871, 2954,  606,  105,   12,   98,  846,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 2257, 1149,  384, 3343,  787,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393, 1635, 1663, 1299,  700,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1921,   32,  121,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  168, 1412,   37, 1171,  378,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2235,  269, 1707,  715,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  863, 1820,  187, 1428, 1346, 1079,   37,  489,   39,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2658, 2269,    1,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458, 1484,    9,    1, 1511,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  489,  166,    1,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  660,  331, 2071, 1331,  769,    1,  590,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3342,  353, 1368,   37,  439,   12,    1, 2170,  433, 2263,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 1234, 1863,  218,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  777, 1360,  612, 1584,  957,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  323,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2857,  123,   32,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1386, 1500,    1, 1291,   32,  945,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  810,  227,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3134,    1, 3332,  782,  247,  365, 3311,  187,    1, 1408, 1245,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  345,   37, 2936,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2063,  565,  105,  686,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  706,  686,    1,    1,    1,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2822, 2378,   37,    1,   32,  478,  424, 2350,    1,    1,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187, 1718, 2367,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1117, 1525,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2875,    1,  829,   12,  645,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   10, 1458,  198,   60,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1656, 2950, 2766,  597, 2224, 1190,    1, 2414, 2886,  361,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   12,  551,  552, 1426,  317,  845,  402,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  155, 2393,   32, 2597,   12,  501, 2060,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1527,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  315,  365, 1506,  444,    1,  663, 3006,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3010,   12,    1,   32,  166, 2060,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999,   91, 1086, 2819, 1345, 1708,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3151, 1949,  810, 1292, 1981,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  818, 1697, 1804,    9,    1, 1211, 1480,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  938, 1075,    1, 1140,    9,  215, 2128, 2129,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2473, 1294, 1396, 2474,  618,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2226,  331,    1,    1,    1,    1,    1,    1,  166, 1131, 2522,\n",
      "          162,  590,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,  619, 1542,    9,  105, 2873, 2874,    1, 1428,  420,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1266,  475,   37, 1910,  669,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497,  168,  220,  726,  297,  153,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  649,  957,    1, 1789, 2362,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  409,   25,  439,  242,    1,  104,   60,  417,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1062,  458,   12,  475,    1,  103, 1213,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2579, 2689,  447,  894,  149,    1,   12, 1443,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3213, 2489,   85, 2308,  336,  856,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,   25,  686, 1034, 2284,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1652,    1,  957,  943,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  638,  273, 2472,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,  497, 2809, 2843, 2751,  187,  241,    1,    1, 1364, 1365,\n",
      "         2024, 1625,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  820,  384, 1440, 2611,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2623,    1,  459, 1675,    1,  132,  220,  654,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   72,  401,  197,  418,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  938,    1, 1322,   10,  565, 2333,    1,  202,  193,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230, 2726,    1,  202,  193, 3204,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,  330, 3019,   55, 1589,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  777,  819,  818, 1278,   28,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  765,   37,  166, 1030,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1391,  310,   25,   69,   85,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   25, 1473,  187,   69,  338,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1668,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2854, 3376,  537,  548, 3370, 2712,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  875,  133,  134,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1389,   45, 3358,   12, 2162, 2353,    1,    1,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2204,    1,    1,   37, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  915, 1140,    9,  615,   37,  142,   98,  224,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2562, 1144,    9,  949,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2994,    1, 1220,    9, 2157, 2995,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  365,    1,    9, 2543, 2177, 1825,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3188, 1631,  119,    9, 2381, 1880, 1675,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3257,  852,   37, 1348,    1,   45, 3204,   32,  104,   26,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3035,  542, 1827,    1, 1623,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3086,    1,   37,   52, 2399,    9, 1791,  808,   32, 3148,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  397, 1579,  909,  444,  163,    1,   12,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3226,  856,  220, 3263,  542,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2942,  140,    1,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3303,    1,  650,   32,  463, 2170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1617,  146,    9,   62,  548,    1,    1, 1086,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1085, 2054, 1279,  953,   32,  385,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2377,   45,  531,  443, 1530,  837,   10,   32,  378,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123,  321,  612,  429,   39, 2330, 1400,   98,    1, 1816,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1645, 2830, 1687,  529,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1807,  105,  311,  104, 3141, 2494,  872,   32, 2592,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1185, 2889,    9, 1204,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  612,   32,  931,  415, 1724,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2,  25,  37,  26,  28, 115,  45,   1,  29,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 107,   1, 297,   1, 109,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  220,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092,   12,    1, 2959, 2928,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 2447,  449,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  217,   98,  132,   37,   47,    1,    9,    1,   54,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  421, 2297, 1110,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1245,    1,   37,    1, 1316,  507,    1,   91,  506,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  596, 1766, 1767,  412,  132, 1564,  593,  613,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  689,    1,  943,   45, 1545, 1512,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  848,    1,   37, 1835,    1,  552,  552, 1108,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 1454,  161,  931,    9, 1186,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,  859, 2532,   98, 2708, 1002,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1821,    1,   32,  453, 2069,   74,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1186, 2331,   45,  125,   32, 3343,  195,  568,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1487,    1,   28, 1412, 1107,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3244, 2035,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   25, 1473,  187,  148,  132,  919,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  615,    1,  191,  915,    1,  224,  765,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  421,   37,  698,  444,  166, 1497,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1583, 2257,   81,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340,    1, 1110, 2368, 3209,  726, 1045,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1940,   12, 3096,  872, 2554,    1,  220,  105,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,    1,    1,    1,  276,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  163,    1,   12,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1583, 3164, 1236,  163,    1,   12,    1,   37,  222,  531,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  190,   52,  166,  449,   37,  168,   98,  776,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1891,    1, 3101,  872,  580,   28,   37, 3309, 3328,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2777,  967,  915,    1,   98, 3250,  187, 3115,  860,   37,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3117,  599,    1,    1,  786,   74,   12,  138,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3105, 1377,   37, 1147, 3125,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267, 2193, 3149,  778,  972,  190,   52, 1073,   85,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  386,   78,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1277,   61,   39,  220,  105,    1, 2771,  920,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  236, 1022,    1,  157, 1571,  218,  220,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3268,   37,  930,    1,   12, 2101,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  204, 2126,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1479,  647,  253, 1066,   98,  148,  132, 1160,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,    9, 2347,    1, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  177, 1530,   32, 2140, 2817,  361,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3192, 3170, 2810,    9, 1463,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,    1,  104,  469,   32, 3360,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3161, 1774,  297, 2570,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790, 1579,    1,  161,  769,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   69,  246,   98,  159,  187,   60,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  455,   12, 3087, 1080,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3238,  515,  730, 2614,  593, 2522,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1214, 1414,    1, 1090,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3212,    1, 1509,   32, 1255,    1, 2764,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3250,  688, 2563,   98,  183, 2489,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,  921,  829,  220,  365,  327, 1013, 2549,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  439,   27,    9,  121,   12,   49,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1056, 2007,   32,  147,   98, 2107,  134,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3318, 1046, 1133,    1,  220, 3244,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,  200,  365, 2108,   32, 2278,  443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  896,    1,    1,  384, 1476,  574,  293,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  411,  270,    9,  463, 2170,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12, 1652,  399, 1360,  612, 2716,   79,  342,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1861,   12,  543,   98, 3377,  509, 1922,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584,    1,  441,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1789,  616,    1,    9, 3121,  541,    1,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3013,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051,    1,  829,  826,  861,  910,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  705,    1, 1417,    1, 1118,  741,   98,  365, 3251,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1074,    1,    1, 2278,    1,  861,    1, 3004,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1239,    1,   98,    1,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  165, 2493,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 2707,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3384,  598,   45,    1, 3389,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  952, 2241,   48,   32,   12,    1, 2170,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  294, 1414, 2122, 1159,  166,    1, 1551,   45, 2646,   12, 1691,\n",
      "          787,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  398, 1360,  612, 1947,  647,  399,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  200,  453,  365, 1013, 1522,  176,  915,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1583,    1,    1,    9, 3075,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  477,  833,  612,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37, 1539,  365, 1013, 1522, 1017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  381, 1205,  297, 1405, 1634,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  493, 1738,  921, 1146,    1,  496,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  968, 1809, 1647,   98, 1228,  970, 1027,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   37,    1,    1,    1,    1,  191,  439,   45,  356,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2339, 1108,    1,  111,    1, 2502, 1551,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2327, 3113,  190,  193,  168,   85, 2198,  105,  856,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,    1,   37, 1250,    1,    9,  878, 1021,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,   98,  898,  219, 2673,  693,   37,  864,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3347,    1, 1056, 2476, 3340,  187,  531, 3102, 1512,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  169, 2667,  105,    1,   37, 2187,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 425, 426, 385,  15,  28,   1, 118,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 507, 932,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2198, 2889, 1740,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  463, 1383,    1,    1,    1,  612,  166,  449,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3297,   12, 3278,    1,    1,    1,  202,  460,  321,  612,  798,\n",
      "          105, 1133,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 3147,    1, 3114, 2004,    1,  178,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  199,   37,  335,   81,  227,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,   37,  652, 2212,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2122, 1419,  365,   81, 2009,   37, 1013, 1522,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1718,  218,  697,    9,    1,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  486,   12,  805,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  943,    1, 1494,   81,   37,  312,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3255,    1,   37, 3164, 2792,   32, 1169,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   41, 2250,   81,   37,   36, 2242,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,   21,    1,    1,   37,    4,   29,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204, 2471,  813,    9,    1, 3179,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  203,  460,  272, 1059, 2691,  885,    1,   98, 1515,  593,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2114, 1662,    1, 2029, 2723, 2724,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3039, 3040, 1090, 1908,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1706,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3073,    1, 1159,  166,  656,   45,  166,   64,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  415, 2286,  460,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2493,  105, 1280,  100,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 1280,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2862,  267, 3341,   46,   37,    1, 1371,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 1414,   64, 1147, 1223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1346, 2324,  110,  176,    1, 2606,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3356, 3006,  442, 2108,    9,  987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  681, 1634,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,    1,   45,  166,  736,   32,  447,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3013,   12, 2236,   37, 1594, 2193,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3227,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   93,   32,  163,    1,   12,    1,    1,  219, 1108,    1, 1071,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,  379,   33,   98, 1611,   45,  365,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2170,    1,    9,  388, 2141,    1,    1,    1,    1,  977,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 2874,  792,    1,  792,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,  649,   31, 1042,  995,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  811, 1921,   32,  976,    9,  449, 2085, 2237,  191, 1645,  582,\n",
      "           45,  171,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468, 2565,  580,  549,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  528, 2651,    1, 3297, 2126, 1913,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  256, 1106,  844,  116,  551,  535, 1863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  747,  197, 1042,    1,  613,  408,  619,  284, 1096,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  871,  568,   28,    1, 1844,  658,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  326, 2334,  103, 2132, 3044, 2402,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1171,  361, 2498,    1, 2242,  387,  105,  104, 2872,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  420, 2628, 1635, 3301,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2802,   37,   52, 2466,    1,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3192,  166,    1, 1366, 1445,    1,    1,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545,   12,    1,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2601, 2701,   61, 1176,  905,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  198,    1,    1, 2433,  455,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  511,  176, 3297,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1512, 2599, 2507,  342, 3341,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 491, 682, 331, 384, 333,  45, 493,  48,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 596, 616,  94, 980, 384,   1,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  104,  560, 1274,   71,   32,  645, 1034,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3332, 1408, 1245, 1762,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3173, 1426,  601, 1385,   45,  163,    1,   12,    1,   26,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1401,    1,  176,  632,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3226,  405, 3291,   76,   37,  168,   98, 2347, 1638,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  105,    1,    1, 2694,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12,    1, 1844, 1211,  548,  671, 3126,  590,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  407,  297,   98,  889,  529,  509,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018,   37,    1,   81,   23, 1425, 1223,   27, 3343, 2735,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,  947, 2263,  395,  945,   69,  475,    1,    1,  446,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    9,  258, 1244,    1,  193,  445,   45,  105,   92,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,  503,  475,    1,    1,  176,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  434,    1,   37, 1821, 2978,    1, 3033,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,   37,   52, 1689, 1090,    1, 1167,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1545,  879,  119, 3158, 1844,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3261,  859,   59,   37, 2734, 2372,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  224, 1353, 1013,   37, 2355,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   25,  640,  365,  119, 1653, 1279,  530,    1, 1394,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1054,   45,    1,  313,   37,   52,  845,  275,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1317,  704,  104, 1052,  354,   98, 2332,  704,  104,  333,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3190,   12,   10,   30, 3193, 2409, 1505,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  872, 2627, 2934,    9,  388, 1674,  270,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2292, 2070,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1688,    1,  220, 1689,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,  166,  698,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1536,  767,  297,    1,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788, 2615,  872,  420,  385,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2791, 1260, 1056, 3006, 2572,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2161,  877,  803,    1,   32, 1090,  293,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387,    1, 2608, 1512,  111,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  810,  112,   98,  424, 2784,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  460,   98,    1, 3132,  838,   79, 2614,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  217,  720, 1876,   45,  142,    9,  632,   69,  633,   12,   50,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,   98, 2213, 2321,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2634,    1, 2957, 1505, 1605, 1597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  957, 1822,  100, 2198,  211,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  857, 1084,  841, 1879,  686,  356,  340,   32, 1014,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  650,  967, 2999,    1,  166,  923,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3354,    1,  104,  129, 1061,   32,  365, 1788, 2596,  722,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1019,    1,    1, 1991,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  242, 1230, 1828,   37,   92, 1158,   12,  572,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564, 2333,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1774,   39,    1,    1, 1907,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 3250, 3290,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3358,   12, 1983,  912, 2845,  297,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  321,  612, 1731,   28,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2137,    1, 2887, 1450,  798,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  434, 2983,   61,  105, 2809,    1, 2821,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3347,   37, 2884,    1,  443,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2844,  187,  531, 2292,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   98,  486,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938,   37, 1540,  384,  941,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1, 2123,   37, 1505,  593,   12,  553,\n",
      "            1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2531,    1,  105, 1298,    1,  744,   32,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  129,  922, 1110,  135, 3260, 3117, 1878,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  166, 1381, 1005,   83,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1494, 1632,   32, 2025, 2799,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  851,  298, 2372,    1, 1534,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  718, 3224,    1, 1333,   98,  872,  336,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1918,  894,  606, 1846,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2229,  741, 1297,    1, 2476,  712, 1009,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,   46,   32,  430, 1229,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3143, 2811, 1720,  847,  271,   85,    1, 1221,   12, 1803,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  497, 1044,  593, 3136,  856,    1,  420,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  386,  587,  588,   28,   37,  131,   32,    1,  573,  589,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37,  138, 1417,   59,   37,    1,  170,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   25, 1376,   98,   14,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  605, 2387,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2984,   12,  449,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  103,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  977, 1632,  411,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  625,    1,   81, 2095,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1472,  203,  166,  207,  272,   26,   37,  810,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 2683, 2043,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228, 2844,   32,    1, 3339, 1345,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  792,    1,   81,   37, 2611,  792,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2677, 3262,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1950,   61, 1530,   32,  645,    1,   45, 2292,   32, 3349,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,  671,    1, 3077,   32, 2161,   12,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3300,    1, 3206,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275, 1484, 2249, 3373,  786,   45,   10,   12,  638,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   28,   98,  157,    1, 1610,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2693,    1,  289,   98, 1521,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3363,   12,  183, 1002,  631,   30, 3343, 2169,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1577,  387,   15, 2148,  308,    1,  159, 1253,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3310,    1, 1920,   12, 1727,    1, 2488,   16,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1139,    1,   10,  186,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  315,  365, 3146,   98, 3118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437, 1354,    1,   47,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2714,   37,  166,  858,  593, 2973, 1764,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978, 1151,  376, 1183, 2113,   93, 1396,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  224, 1996,    1,    9,  432,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   79,    1,  522,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,  167,  606, 1846, 2349,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1183,    1,    1,  640,  166,  215,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  294,    1,    1,  361,    1, 3340,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  953,   37,   72,  548, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 3108, 2712,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 1210,    1,    1,  202, 1444, 2233,  713,  361, 1937,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2873,    1, 2598,   37,    1,  453,  248, 1021,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2795,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2735,    1, 1353, 1768, 2937,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2658, 1040,  476, 1583, 1942,  176,  502,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2700,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1232,  148, 1458,   79,    1,  647,  167, 1376,  918,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  506, 1117,  112, 1889,    1,   98,  166,   71,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984,    1,  515, 1298,  550,   98, 2820,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1583,  580,  105,    1,  384,  166,  917,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1433,  968,   61,    1,   37,   22,  453,    1,  608,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  260,   28,   37,  741,   98, 1459,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2040,   45,  399,   32,  342,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,   37, 1636,  219, 2102,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129, 1286,    6,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2941, 2677,    1, 1568,  730, 2614,    1,  105,   12,  907,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   55,  105,    1,    1,    1,    1, 1564, 3120,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1359,   45,    1,    1,    1, 1530,  176,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3002,    1,  176,  829,   71,  995, 2425,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  910,  197,   79,    1,  387,  388,  525,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1, 1210,  166, 2043,   37,   52,  105,\n",
      "            1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2254,    1, 1361,  875, 2252,  182,   43,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  218, 1034,  810,  566,   98,  303,  361,  166,    4,   29,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   61, 1472, 3238,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523, 1564, 1844,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3120,    1, 2920,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2117,    1, 2024,   46,   98, 3118, 1512,  288,   37, 1195,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  335,   98,  166, 1305,   32, 1989, 1990,  628,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  459,    1, 2657,  132,  220, 1081,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2617,    1,  365,    1,   98, 1178,   12,   81,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3132, 3159,  730, 2614,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  809,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2688, 2572,   32,  531,   12, 2433,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2547,  726,    1,    9, 2948,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375, 2785, 3358,    1,   63,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  765,   37, 1110,    1, 2410, 2009,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1913, 2318,  726,  810,  202, 2783, 1990,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1629,  868, 1114,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187,  386,  439,  214,   46,  220,  742,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2018, 1542,   37,  843,  622, 1527,   37, 2752, 3371,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1834,    1, 3341,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1060,  186,  444, 2834,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   12,  964,  261,   39,    1,   37, 3149, 2751,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  782,  105,  389,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,  191, 2971,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  551,    1, 1893,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  387,  105, 2219,  507,    1, 2337, 2275,  387,  105,    1,\n",
      "         2485,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  159, 1374,   98,  572,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1788,    1, 2197,  877, 1675,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   30,    1, 1912,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 2926,   12,    1,  598,   37, 1343,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 511,   1,   1, 513, 514,  37,   1, 388, 763, 234, 182, 235,   1,\n",
      "           1,   1, 234, 182, 235,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  61,   1, 220,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,   46,   37,  151, 1933,    1,  420,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  958, 1796, 3102,   32,  531, 3395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2527,  164, 3115, 2572,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2578,   12,  198, 1838,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2883, 2751,   51,    1, 2024,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2871, 3132,    1,  967,    1,   32,  354,   37,  405,   12,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  177, 1530,   32, 2597, 1585,  187, 3155, 1345,  614,   98,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1,    1,    1,   98,    1,  880,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3052,    1,  294,  865,  384, 1821, 2190,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2266, 1707, 1484,    9,  247, 1596,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2659,    1,    1,  506,  782,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1178,   37,    1, 3334,    1,  361,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,   45, 2869, 2308,    1,  176, 1230,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  384, 2691,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  338,   37, 1739,  275,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  381,   37,  151,  449,  294,  458,   32, 1739,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,  105,  913,   32,  640,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213, 1366, 1445,    1,  191,   94,  595,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  238,   98, 1965,  388,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   51, 1371,   52, 2430,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1341,   12,    1,  333,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1771,  171, 2565,    1, 1346,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1412, 2287,    1, 1729,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2602,    1,  424,  414,   61,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   81,    5,  302,  444,   49,   61,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2705, 1083,  997,  297,    1,    1, 1857,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  364,  140,    1,  159,  631,  220, 3199,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1528,  572,  156,   71,  995,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1712,  292, 1228, 2463,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3332,    1,  551,  729,  183,  629,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  667,  159,   81,   32,  119,    1,   98,    1, 1565,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  361,    1,  683, 3299,  973, 2685,  608, 3251,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2583,  476,   37,  271, 1211,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,    6,  102,   98, 2798,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  506, 1789,    1, 1053,  631,  876,  612,  111,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159,  720,  197,   51,   52, 2051,  763,  570,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 2185, 1994, 2819, 2146,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1732, 1091,    1,    9,    1,  674,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  253,  254,  255,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,  159,  439,    1,   98,    1, 1936,    1,  800,  714,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2980,    1,  210,    1,  187, 1994, 2819, 3050,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1, 1463, 1894,    9, 2889,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 3069,    1,  342,    1,  176,  629,  297,    1, 2985,\n",
      "            1,    1,  108,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  942,  546, 2565,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2685,  565,   98,    1,   45, 2825,    1,  187,  273,    1,   39,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61, 1658, 3017, 2225, 1997,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  534,   12,    1,   98,    1,    1,    1,   92,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  666,   37, 1251,  131,   37,  131,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3199,    1,    9,    1,    1,    1,   39,   45,  180, 1990,  631,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,    1,  297,  568, 1124,  187,  567,    1,  531, 1450, 1198,\n",
      "          102,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1640,  144,    1, 2004,  429,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123,  195,    1,  928,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1972,    1, 1159, 1821,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1568,  977,   61,  105, 1560, 1167, 2559,  595,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2391,  132,  105,  139,    9, 3192,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3110,  407,  228, 1669,   37, 1524,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1157,  379, 1377,    9, 1663,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  462,  721,   51, 2000,   49,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359,  267,    1,    1,   51,   52,    1,  402,   32, 3388,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885,    1, 3371,  429,   46,  548,  854, 2018,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  579, 1366,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783,  353, 1913, 1843,  354,   98, 1794,   24,   44,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1706,   32, 2053, 2198,   11,  105,  754,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   89,    1,   91,   98,  996,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2994, 2995,  696,  334,  877,  166, 1354,   45, 1658,  199,  111,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,    1, 1361,  875, 2255,  768, 2096,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147,  446,   12,    1, 3340,    1, 1046, 3026, 1665,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   30,  365, 3365,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  777,  721,    1, 1564,  105, 2225,    9,    1, 1160,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169,  640,  103, 2287,    1, 3168, 1177,   98,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2028, 1679,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  108,   45, 2212,  861, 1064, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3102,    1, 1258,  187,  885, 3395,  770,   61, 1976,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  332,  693,   37, 1083,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  933,   26,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9, 2723, 2724,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3175,    1,   28,    1,   32,  726,  297, 3132,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 2744,    1, 2336,  769,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   32, 1966,    1, 1224,   45, 1786,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  220,  755,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1920,  928,   32,    1, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  389,   93, 1258,  202, 1113,   67, 2126,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2803,  886,    1,   51, 1306,  547, 2741,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3309, 2471,   28,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2680,  256,    1, 1117, 1525, 1942,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,    1, 1159, 1230,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   75, 1579,  858,  297, 1021,  260,  261,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267, 1151,  190,  771,  844,   98,  617,  618,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1983, 1261, 1998,   92,  384,    1, 1228,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1848,  494, 1046,  611,   32,    1,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2414, 2105,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  761,  108,   45,  762,  384,  453,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  234,    1,  235,    1,  234,    1,  235, 1988,   45,    1,\n",
      "            1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1748,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2596, 2803,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,   98,    9,  628,  772,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,    1, 1151,   37,  815, 2051, 1021,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   35, 1715, 1259,  220,   22,  438, 2443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1450,  125,  531,   12,   69,  532,   32, 1023,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,    1,   37,  907,   98, 2283,  220, 3089,    1, 1013,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  352,   51,   47, 2245,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 1447,  267, 2768, 1609,    1, 1463,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  197,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1619,  458,   34, 1184,  347, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3253, 1321,  384, 1183, 2921, 3023,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  613,  861, 1787,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1202,  686,    1,  187,    1,   27, 2646,\n",
      "         3346,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,  119,    1,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1523,    1,  297,  878, 1649,  804,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2160, 2049,    1,  220,  726,  297,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1277,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1, 1658,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2949,    1,    1, 2317,  384, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  879,  631,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3225,   77,    1,    1, 2861,  754,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713, 3231,    9, 1056,  537,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  852,   37,  166,  116,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3233,  584,    1,   61, 2222,  297,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  506,  957,   29,  905,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105, 1002,  193,  320, 2056,   98, 1571,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1537, 3348, 1659, 1239,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1479,   84,   32,  166, 1523,    9,  785,  786,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1661,    1, 1007,    1, 1914,   61,    1,    9,    1,\n",
      "           45,    1, 2308,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1013, 2405, 1750, 2798,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  585,  335,   98, 1833,   12,  590,    1,  750,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  385,  389,   93,  143,  763,   76,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1880,  458,   37,  151,  365, 2741,   14,  458,    1,    9,    1,\n",
      "          131,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  262,  263,  353,  354,    1,    1,  983,  570,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  794, 1106, 1107,  282, 2264,  729,  193,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  501,    1,    1,    9, 2523,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051, 1008,    1, 2264,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,   37,    1,    1, 2641, 1772,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  437,    1,    1,   37,  581, 1023,  354,   98,  134,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,   12, 2102,    1,   37, 2464,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3012, 2699, 1625,  565,  845,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3175,    1,  166,  910,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  140,    1,  695,  297,  111, 2131, 1563,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2425,   37,  130,   48,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  381,  731,  125,  191,  373,    1,  159,  245,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  758, 1564,  105,  132,  220,  166, 2594, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,   12,    1, 3062,  671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  242,   98,  531,  548, 1884,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,  163,    1,   12,    1,  442, 3368,   98,  976,   32,\n",
      "            1,    1,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 1559,  488,  103,  342,  770,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 3102,  952,  439,   37,  582,    1, 1281,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1033,  365, 2292,  640,   12,    1, 2490,  548, 2024, 2950,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325,    1,  118,   48,   32,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  698,  190, 1527, 3103,  865,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3091,  176, 2363,   45,    1, 1559,   61,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  593,  458,   61, 1542,   37,  574,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3367,   37,  429, 2823,  863,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  658,   33,    1, 1639,  810,   45,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1018, 1816,   32,    1,    1,  686,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  425,  426, 1408, 1690,  525,   15,  157,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,  908,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3298,    1,  187,  461, 2660,  785,  786, 1684,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  166, 1690, 2775,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3096, 2565,    1,    1, 2572,   32, 2291,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1360,  612, 1584, 3006,    1, 3343, 1002,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3271, 1009,  852,    9, 1876,  176,  104,    1, 2498,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,  545,    1,  460,   12,  199,   37,  544,  199,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  224, 1991,   37,    1,  686,  361, 1844, 2566,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  572,  156,   28,  118,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2682,    1,   12,    1,   37, 1195, 2024,   46,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  317, 1384,   74, 1278,    1, 2275,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  491,    1,    1,  493, 2498, 2055, 1604,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1824,  854, 1917,  691,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1417,    1,    1,    1,  552,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  997,  167,    1,  365,  625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 2538,   32,  105,    1, 1560,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,   37,  693,    1, 2549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  600, 3358,   12, 2162,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3274,  361, 3169,  271,   28,    1,    1,    1,  315,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3230,   37,  631,  163,    1,   12,    1,  444, 2468,   32, 1764,\n",
      "         1990, 2069,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  199,   63,    1,    1,    1,  232,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1133, 1215,  115,    9, 1151, 1091,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  142, 3165, 2845,  297,   37,  649,  947,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  982,  737,  156,   71,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1024,   61,  449,    1,    1,    9,    1, 2579, 2630,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  756,  757,  315,   37,  125,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  458,    1,    1, 2509,   98,  104,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1431,   37, 1155,  331,  104,  613,  535, 1074,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3342,  205,   37, 1910,  754,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1008,    1,  187,  475, 1213,  332,  636,  948,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3331,  913,    1,   98, 2347, 1638,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1773,  267, 2510, 1675,   37,  714,   32,  455,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  686,  191,   69,    1, 1340,   28,   98,  800,    4,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  458,   45,  507, 1380, 2225,   98,    1, 2522,   45,  273,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  449,    1, 2630,   32,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1,   59,  486,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1685,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3190,    1,    1,    1,  168,    1,   37,    1,    1,  428, 1002,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 2649,  475,  267, 3369,    1, 2751, 1822,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3314, 1249,    1,    1,  614,  581,  913,   32,    1,  922,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  606,    1,   37, 1947,  166,  365,  219, 1984,  872,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  409,    1, 3043,    1,   45, 1796,   32,  531,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755, 2612, 1003,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,    1,    1, 2495,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  290, 1710,  764, 2341,    1,    1,  267,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3369,  361, 3118, 2751,  713,    9, 2117,   46,  484,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  696,    1, 1844,  608,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,  517,   61, 1254, 2876,   37, 2306,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358, 1841,    1,  297, 1983, 2078,   45, 2708,  650,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   37, 1539, 1013, 1522, 1167,    1,  220,  224,    1,  758,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98, 1568, 1311,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3124,  361,    1,    1,  854,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1420,    1,  368,    1, 1124,  548,  395,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2977, 2700, 2040,   45,    1, 3012,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1215,    1,    1, 1346,  741,   37,   77, 2471,  220, 1056, 1603,\n",
      "         1223,  437,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  447,    1, 2468,    1,   98, 3387, 2985,    1, 2263,    1,  437,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   12,  695,  299, 2789,  140,    7,  171,  863,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  393,  580,    1, 2082,   32,  283,  734,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  193, 1340,    1,    1,   16,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 244, 331, 105,  74,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 829, 861,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  552,   37,  552,    1,    1,  365,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  327, 1074,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,  365, 2240,    9,  597,  348,  475,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3194, 3195, 2161, 1054,   32,  917, 1569,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3084, 1550,  241, 2180,  396,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302,  515,  828,  412,   37,    5,  571,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  632,  622, 2572,   32, 3367,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1599,    1,  100,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2547,  665, 1688,   98, 1095,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  975,  716,  417,  156,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3292,    1,  140, 1194, 1267,   45, 2579,   45, 2468,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  632,  109,    1,    1,  220, 1821, 2190,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,    1, 2500,  663,   32,  395,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1918,    9,  938,   32,  104,  147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993,   12, 2994,    1,  166, 1411,  183, 2995,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  288,    9,  417,   26,   69,  343,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1746, 2954,    1,    1,   45, 2140, 1177,  139,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  335,   81, 1311,  187,  166,  785, 2058,   32,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3113, 1065, 3060,  297, 3374,  686, 1638,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158,  225,  744,   56,  356,  845,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2345,    1,  753,   32, 3339,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 1008, 1708,  512,   37,  582, 2466,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  166,  443,    1,  202, 1396,  810,  166, 1690,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1665,   37,  691, 1258,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181,    1,  631,  220, 1545, 2250,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1390,  159,   28,  187,  132,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,  952,  365,    1,  220,  104,   37, 2653,  596, 1793,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  964, 1550,    1,  315,    9,   49,    1,  202,  171,  681,  321,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596, 1793,  967,    1, 2822,  506,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1550,    1,  297,    1,    1,  631,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   36, 3071, 1223, 1830,   37,    1, 1530,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3340,  667,    1,    1,  191,  224,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 3029,   37,    1,  220, 1821, 2190,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   79,   37,  105,  198,  698,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1614,  523,    1,  199,  421,    1, 1309,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  463, 2170,   12, 1076,  671,   37,  142,    9,    1,   37, 1865,\n",
      "          593,  650,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,  395,  155,  131,   32,  332, 1996,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  202,  590,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  668, 2786,   45,  166,  351,   45, 3348, 2161,    1, 1018,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1718,  697,    9,  221,  384,   29, 2363,   37, 2355,  420,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1140,   37,  611, 2893,    9, 2144,  537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2095, 1705,   66,    1,   98, 2597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2235,  225,  269,  566, 1033,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141, 1090, 1829, 2110,  176, 1717, 3219,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  921, 1412, 1107, 2577,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1419, 2495,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3095, 2856, 3375, 1072,    1, 3047,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1022,    1, 2296,  288,   37, 1624, 2974, 2695, 2223,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,  354,   37, 2594,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  864,   12, 1818,  650,  108,  104,  600, 2646, 3071,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273, 1609,  614,  834,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  148, 2767, 1479, 2706, 2232, 1901,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785, 2044,   37,    1,  104,    1,  182,   98, 2657, 2545, 2658,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2954, 1343,  449,    1, 1090,   32,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144, 2409,    1,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  112,  802,  105,    1,   45,  811,   12, 2592, 2784,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2246, 2885,    1,    1,    1,  884,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  400,   45,    1,    1, 1110,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1809,  166, 1354,   45,  914,   12,  183, 1055, 1230,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  224, 2479,  705,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2308,    1,  861,  509,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1206,    1,  573,  574,   37,  423, 1093,  574,  325,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  719,  388,   69, 1208, 1063,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1585,  176, 2729,    1, 2414,  176,  177,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,  716,  118,   71,   32,  572,  197,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   91, 2272,   85,   98, 2189,  532,   45,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2319, 1046,   45,    1,  275,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2275,    1,  680,  114,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092, 2659, 2189, 3049,  191,    1, 2168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2826,  125,  460,   39,    1, 2192,  460,   81,    1,  838,  166,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  632, 1497,  298, 1387,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2203,   69,    1, 1554,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   15,   45,  327,   12,    1,  932,  176,  829,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1009, 3090,  480,  741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,    1, 1848,  872,   28,   37,    1,  192,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  506, 1256,  551, 1256,    1,    1,   61,  187,    1,  187, 1857,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2371, 1402, 2758,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2236,    1,  820,  356,  548, 2162,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  276,  995,    1,  202,  159, 1269,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  560, 1274,   71,  915, 1034,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  935,   37, 1539, 1821, 2057,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1256,  551, 1256,  744, 1224,  220,  182, 1026,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 2355, 1013,    9,  282,  680, 2657,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1559,    1, 2791,    1, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1985, 2258, 1366,    1,  424, 1034,   32,  166, 3141,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  288,   37,  349, 1084,  841,  669,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,    1,  479, 1083,  163,    1,   12,    1,   15,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  321,  612,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1412,    1,   12, 2525,  361,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2130, 1887,    1,    1,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  576, 1110,   37,  105, 1918,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,   98, 1448,  986,   79,  183,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1243,  365, 3017,    1,    1, 2043,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2871,    1,   37,   47,  118,   45,    1,    1,  971,  913,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2339,  312, 2853,   45,  845, 1480,    1,    1,   32,  166, 2642,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  634,  220,    1,    1, 2650,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  907, 2153,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,   89,  267,  590,  629,   45, 1520,  104, 1424,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089, 1090, 1091, 1882,   37,  987,   32,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  537, 2248,    1,  105, 2267, 2423,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  381, 1226,   98,  373,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3375,    1,  104, 1119,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 1493,    1, 2777, 2577,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3207,  113,   98,   37, 1674,  810, 1385,  671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089,   30,    1,   45,  455, 3102,  777,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  656,    1, 1564, 2821,   45, 1936, 2017,  754, 2202,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  865,    1,    1,  411,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1123,    1,  140, 1194,  671,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  593,  616,    1,   98,    9,  105,  104,  863, 1578,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056, 1645, 3073, 2249,   32,  531,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  255,    1,  608,  105,  582,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,  493,  102, 1198,    1,    1,  197,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  316,  317,   12,    1,  318,   37,  319,  320,  204,  321,  322,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  717, 1417,    1,  777,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  633, 1838,    9, 3188,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1818,  147, 1360,  612, 1709, 1107, 2285,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3266,    1, 2615,    9,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1401, 3023,   45, 3116,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  197,  418,    1,  155,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,   37,    1,   37,  342, 2673,  693,    1, 3399,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773, 2510, 1090, 1863, 1564,  198,  455,  714,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,  119,  687,  951,   94,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  491, 1391,  682,   32,  219,  159,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1082, 2892,   37,  713,  176, 2646, 1712,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3190,   12,  366, 1178,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3369,    1, 2282,  722,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  952,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  741,    1, 2764,  712,  515, 3238, 2007,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325,   48,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2650,    1,   37,  335, 1601,  740,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  469, 1494,  680,  114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,  331,    1,   98,  105, 1151,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671,    1,  176,   27,  356, 1653,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   14,    1,    9,  834,  914,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1237, 1658, 1117, 1525,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596,  403,   45, 2597, 2414,    1, 2766,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273,  772,  884,   79,   32,  854,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2942,  162,    1, 3126,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1707,  219, 1004,   37, 2199,  903,  275, 1027,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  120,   98,    1,   10, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,  942,  469,  162, 1217,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   45,  602,   61,    1,  191,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12, 1404,  680,  114,    1, 3279,  220,    1,  519,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  942,    1,    1,    1,  297, 1610,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1051,   12,  365, 2575,    1, 2206,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  108, 1730,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  229,    1,  344, 1634,    1,    1,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3370,   12,    1,   45,    1, 1464,  844, 1463,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  560, 1274, 1556,  915, 1034,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2963,  176, 1022,    1,    1,   26,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3183, 1421,    1,    9,  537,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,   12,   83,   37,   84,   85,   32,   86,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777,   37,  151, 3028, 2232, 1699,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2923,  190, 1403,  105,    1,    1,   37,  166, 2918,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2, 241,   5, 396, 686,  49,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  49,  50,  51,  52,  53,   9,  54,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,   81,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  502,  361, 1361,  662,   37,  221,    1,    4,   37,  854,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  393,   12,    1,    1, 1931,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  342,  293,  475,  108,  444,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1, 2274,   98,  593,   12,  449, 1766, 1767,  236,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  612,    1, 1369,   51,   52,  824,    1,  202,  590,  786,\n",
      "           11,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2944,   12,    1, 1065, 1190, 1822,  713,  105,  339,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3328,    1,  512,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  815,    1,    9,  764,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2202,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 176, 612, 613, 353, 417, 197,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1, 176, 654,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  970, 2830,   37,  404, 2170,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649,  650,  476,    1,  651,    9,    1,  652,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3117,  619,   92,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,   48,   32,  121,   12,  141,    9, 1270,  131,  104,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  758, 1213,   37,  582,   28,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1572, 1414,    1, 1850, 1147,  787,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  915,   74,   45, 3116,  922, 2058,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   76,   37,  103,  105,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3192,  691, 1504, 1854,  220,    1,    9, 3211,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  245,   98,   69,    1,  374, 1086, 1315,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  170,  167,   52,   81,   98, 2056, 1171,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968, 2963,   32,    1,  395,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  709,    1, 2572,   32,  298,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  588, 3144, 2666,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2518,    1,  357, 2310, 1841,    1, 1433,    1, 2881,  833,  612,\n",
      "          619,  460,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   89,   37, 1334,  176,  684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1970, 2305,  188,   98, 1602,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1567,  919,  942,   37,  593, 1990, 3098,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  878, 2458,    1,    1, 1753,  829,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325, 1499,  669,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1203,    1, 2938,  951,    1, 2839,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3105,    1,   98,   37,  105, 2501,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  529,  617, 1273,  259,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1070,  942,   37,   38,  297,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1883,  779,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2170, 2153,  588, 3118, 2024,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2246, 3202, 1401,  411,  810, 1292, 2208,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2386,  326,   45,    1, 2465,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1759,  309,  890,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746,   37,  815,    1, 1074,   37, 2035,  196,  759,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  729,    1,   32, 3117,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  882,  200, 1935,    1, 1167, 2489,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  829,  197,    1,   15,   71,  187,   93,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  813, 3349,   12,  645,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  743,   12,  155,  158,    1,  159, 1473,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1360,  612,   52, 1542,    9, 3276,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275,   98, 2482,  171,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  434,    1,  176,    1, 1325,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2522,  967, 2562,  104,  284,    1, 1123,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2594,    1,  176, 1140,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  989,    1,  605,  120,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878,   61,  449,   37,    1,  617,  259, 2101, 2387,  625,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1, 2835, 2434, 3080,   32, 1421,   45,    1, 2471,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  327, 2177, 1027, 1353, 2293,  361,  846,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  864, 1707,  342,  221,   37, 2199, 2673,  315,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2197,    6,   22,  447,    1,   48,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3103, 1154,    1,  384,    1, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  513,  193,  514,   32, 1887,   45, 1404,   32,  871,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1, 1316,  395,   37,  813,  455, 1260,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2729, 3030, 1240,  865,   37, 1094, 1371,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2425,   12, 2980,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2224,   45, 2265,  446,    1,    1,  939,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  539,  458, 2708, 3065, 1333, 1530,  191, 3101,  114,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1138,    1,  967,  105,    1,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2868,    1, 1796,  588, 1262,   37, 1814,  403,  464, 2673, 1512,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2488,    1,  182,    1, 1417,    1,    1, 2262,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3035, 2856,   32, 2440, 2060,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 2609,   98, 3015,    1,    1,    1, 2977,  475,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  517,  519, 1543,    1,    9, 1273, 1107, 2568,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,    1,  191,  163,    1,   12,    1,  315,   37, 1418, 2924,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   37, 1847, 2349,    1, 1847, 2310, 1230,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 2468,    1,  105, 2249,  345,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2431, 2582,    1,  600,    1,    1,  290, 1373,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870,  190,  151,   81,  225,  384,  507,  111,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2663,   45,    1,   32,    1,    1, 1976,   32,  395,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  867,   37, 1642, 2039,   98,    1, 2168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160,  102,  720,    1, 2053, 2055,  554,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  103, 2132, 3190,  113,   81, 2906,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640,   81,   37,   77, 1485, 1625, 2793,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  764,    1, 3159, 3315,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  823,    1, 1000,  251,  803, 2050,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1408,  979,  389,  220, 3183,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,    1,  619, 1018, 1901,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  754, 2522, 2540,    9,  854,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  502,  492,  491,  716,  156, 1427,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2496, 1976,  176,    1, 1212,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066, 2917,  187,  311,    1, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1529,    1, 2249,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   12,  551,  552,  267,   51, 1901,  180,   37, 1429,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  162, 1126,  168,  115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1710,   55,   37,  865,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,    1, 1089,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,  952,  581,  913,   32,  455,  220,    1,   45, 1239,  517,\n",
      "          218,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,  704,    1, 2226,    1,   37,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  716,   72,  401,  932,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3340, 2804,   45,    1,    1,  820,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,  381, 1682,   51, 1046,   12,    1, 1117,    1, 1417,    1,\n",
      "          134,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3330, 2814, 1921,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2587,  193,  415,  105, 2549,  202,  105, 2549,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  437, 1679,  104, 3091, 3102,   32,  531,  844,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2065, 2064,  588,    1, 1067,   32,  592,    1,  593,  458, 1513,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1403,    1,   98,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,  105,  730, 1777,  710,   46,   45, 1355,   37,   26, 1039,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  159, 1150,  548,    1,  570,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2638, 2548,   32, 1030,  260,   45, 1681, 1316,  593,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2264, 1000, 1176, 1744,    1,   32,  166,  116, 2288,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,    1, 1391,    1,   71,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3300,    1, 3079,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2516,  750,   98,  361,   79,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3121,    1,  396, 1700, 2853,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,    9, 2789, 1945, 1010,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1780, 2589,  361,  168,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2689, 1717,    1,  424,   61,    9,  810,  166,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2016, 2037,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3174,    1,    1, 1758,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2410,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,  300,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2999, 2659, 2819,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1419, 1961, 2210, 1421,   98, 1607,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1024,  551, 1024,   51,  151, 1026,    9,  131,    1,  249,  774,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  587, 1313,  365, 1600,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  256,   56,  454, 2232,   37,  365, 2226, 1607,  260,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  180,    1,  727,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612, 1070, 1232,  829,   61,  166, 1509, 2355, 2309,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,  136,  475,  513,  193,  514,   37,  133,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   15,   28,    1,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2386,  105, 1093,  574,   45,  225,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1046,   79,   32,  772, 2826,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043, 1268,  242,   98,  417,   69,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1307,  353,  720,   32,  572,  156,    1,   15,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1632,   32, 1742,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,   37,  138,  331,   37,  875,  133,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1, 2759,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   28,    1,  951,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1654,    1,  220,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2700, 1000, 3038,    1,   45,  164, 2693,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2879,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  204, 2233,   52,   81,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2296,    1, 2578,  890,    1,  593, 2522,  877,    9,  105, 2181,\n",
      "         1890,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2388,  171,   12,    1,   39,  220, 3131, 1987,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  315,  787, 1849, 1766, 1767,  191,  439,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  348,   42,  220,  422,  297,    1, 1888, 1907,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  760,    1, 1456, 2056,    1,   98,  166,  311,  403, 1383,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1424, 1414, 1744,   37,    1,    9, 1604,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1384,  108,    1,   98,  711,  333,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  597,  136,  475,  513,  193,  514,   37,  133,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,   32,    1,  186,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  352, 1809,    6,  176,  634,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  387,  777,    1,    1,    1,   32,  365,  675,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1090, 1372,    9, 2975,  424,  356,  161,   82,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 3037, 2825,    1,  191,    1, 1512,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,  227,    1, 1628,    1,    1,    1,  361, 1452, 1488, 1739,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1, 1052,  572,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  612,    1, 2902,  125,  102,   98,  116,   19,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  227,    1,    9,    1,   32, 1092,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   66,  187,  366,    1, 2409,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175,  726, 2775,   45, 1675,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,    5, 1178,   51, 1526,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   88, 1564,    1, 2084,    1, 1153,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1480,  450,  384,  531,    9,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2142, 3225,  872,  420,  385,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  215,   12, 1861,   37,  665, 2170,  176,  985,   45,  166,  517,\n",
      "         2521,   32,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2806,  756, 1039, 2690,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,   37,    1,    1, 1410,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2700,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   39,  384,  342, 1984,  260,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  125,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2634,    1,  766,   16, 2869,  529, 2727,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  839,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1555,   98, 1377,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 2344, 1434,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,  698,   45,    1,  183,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  542,    1,  176,  439,   45,  593, 2522, 2769,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2171, 2800,  420,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,  951, 3333, 1720,  105,    1, 2421, 1159,  105,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  430,  430,  587, 1140,   79,  477,  548, 1194,    1, 1386,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226,    1, 1658,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  429,    1,   32, 1178,  386,  627,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,  908, 2103,  617, 1116, 2915,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2673,    1,  796, 1708,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 2404, 1070, 2835,   37,  764, 1746, 3101, 1941,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2479, 2759, 1499, 1873,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1113,    1,   69,  550,   77,   25,  410,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  511,  275,    1, 1037,  275,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  765,  115,   98,   10,   12,  469,   37,  865,   37, 2918,\n",
      "            1, 1965,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3376,    1, 1377,  680,  454,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,    1,   69,   37,    1,    1,  996,   93,  191,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1109,   30,    1,   45, 1204,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1461, 2414,  786,   32, 3339, 2791,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094, 1353, 2625,  220,   22,  477,   27, 3339,  787,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1017,  641, 2429,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 3103, 2844,  548,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018, 1028,   45,  829,   12,    1,  768, 1274,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3298, 1177,   37, 2674, 1796, 2227,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2898,   63,  334,    1,   37, 1911, 3002,  361, 2574,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3002,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  153, 3229,    1,    1,    9, 1517,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1861,  288,   37, 1046,  587,    1,  187,    1, 2058,   79, 1952,\n",
      "         1929,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  574,  420, 1633,  437,    1,  453,  823,  220,  105,  857,   93,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1796,    1,  548,    1, 2856,  176,  177,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1603,  357,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1788,  778,  967, 2006,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  614,  384,    1,   37,  105,  671, 3126,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2238,   61,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 1100, 1539,  166,  466,  116,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3305,  105, 2556, 1178,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359, 1114,  488,  522,  444, 3358,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  854,  267, 2774,  475, 2572,   32, 1815,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1298, 1382,    1,    1,  889,  341,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  596,  382,  230, 2461,   98,  454,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1751,  696, 3250,    1,   85, 2563,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1926, 1927, 2886,    1,   32,  449, 3127, 2322,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   81,  176,   98,    1,    1,  889,  997,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  476, 1032,  790,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3102, 1404,  513,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  167,   52,  266,  887,  837,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  458,  710,  996, 1269,   61,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1861,    1,    1,    1,   32,    1, 2180, 1559,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868, 1949, 2890, 2237,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3380, 1145,   46,  220, 2406,  504,    9, 2024,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  814,  733,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1938,    1,    1,  891,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,   37,  606,  985,    1,    1,  190, 1642, 1913, 2113,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1765, 1452, 2051,  105, 1211,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  233, 1118,    1,    5,  625,  788,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,  411,  221,  220,    1, 2056,  698,    9, 3303,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  297,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  187, 3374,    1,  886, 1159,    1, 2433,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,   81,   32,  147,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2753,   56,  187, 1212,    1, 1022,    1,    1,   32, 3275,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1789,    1,    1, 2471,  220,    1,   32,    1,   37,  395,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49, 1682, 1910,  121,    1, 1801,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  120,   98,    1,   10, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2802,   12, 2315, 1045, 1086,  176,  547,  187,    1,  140, 2080,\n",
      "          517,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962, 1110,  186,    9,  183,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,    1, 1639,  220,    1,   32, 2087,  433,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  231, 1708,  518,  777, 2165,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428,   10,  190,  877,   22, 2150,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,    1, 2990,    1,    9,  472,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2583, 2297, 2741, 3255,  474, 3164,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2615,    1, 2720, 2796,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   22,    1, 1737, 1414, 2497, 1147, 3357,\n",
      "          353,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3181,  475, 1366, 1445,  917,   37,    1, 3306,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117, 1525,  126, 2489,   98,  104,  890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2648, 2801,    1,  196,   37,  345,   32,  517, 1339,  112,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2527, 2946, 1976,   32, 2140,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1893,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321,  166,  219,    1, 1259, 1878,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2176,   51,    1,    1,  647, 2515,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  180,    1,  727,  288, 1483,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3235, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  756, 1149,    1,  221,  297, 1120, 1494, 1955,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  198,  698, 1639,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1680,   37,  151,   39,  395, 2274,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1537, 1583,   37, 1174, 2924,    1,   32,  854,    1, 1815,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2193,    1,  166, 2151,  361,  166,  943,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1555,    9,  591, 1010,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810,   45,  105,    1,    1,  166,    1,  852,  105,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3180, 2286,   37, 2035, 3158, 1844,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  590,  315,    9,    1,  531,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2745,   37,   52,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2562,    1,    9,    1, 1663,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1361,  744, 2364,   98,  340,  439,  218,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  804,  884,  105,  686,  187, 1327, 2659,   81,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1249, 2801,   32,  207,  617,  259,    1,   93,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1157, 1386,   37,    1, 1428, 3102,    1,   32, 3360,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  354, 2072, 2588,    1, 3115,  184, 1114,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,  225, 1660,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  432,  226,  967,  193, 1976,  810, 2252, 2298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 2186, 1901, 2421,  215,  957, 1074,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1183,    1, 2288,    1,    1,   28,   98, 2372,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  389,    1,  338, 1139,   45,  739,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 2379,    1,  239,  565, 2430,  191,  104,\n",
      "            9,  133,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190,    1,  335,  105, 1526,   39,   45, 1158,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 1579,  596, 2953, 1463, 2146,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  848,  361,  766, 2243,  617, 2403,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1542,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  884, 1003,  176,  900,   12,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2606, 1147, 3006, 2856, 1855, 3102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2106, 2309,  140,   32, 3367,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  344, 3403, 2414,   32, 1260,   98, 1147,  947,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,    1,  733, 1204,  286,  886,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  142,   37,    1, 2604, 1534,  384,    1, 3027,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3310,   12,    1, 1079,  398,    9, 1650,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2264,  774,  829,   12, 1001,   61,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1579,  971,    1, 2930,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2777, 2202, 1264,  187, 3115,    1, 3285,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  113,    1,  631,    1, 2523,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1043,  338,  297,  419,   98,   69,  509,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   12,  365,  210, 2937,  466, 2177, 1825,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1900,  907,   37, 2000,  651, 1031,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3168,  140,    1,   32,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2142, 3232,    1, 1214, 3323,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2155,  166,  661,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   10, 1408,    1, 1638,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2617,  774,  104,  469,  190,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  792,    1, 3106,  792,  629,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  520, 2786, 2673,  484,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1987, 2599,    1, 1986,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,   12, 3355,   37,   77,  593,   97,   98, 3369,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  168,  115,    9,  365,  116, 1008,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3036,  753,    9,    1, 2130,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3269, 2005,  191, 3186,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1829,  497,    1,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,   45,    1, 2980,  640, 2474,  618,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  186,  187,  383,   69,  102, 1344,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  766,  361, 2636,   13, 1835, 2071, 2294, 1935,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340,  140,  119, 1909, 3212,   32,  105, 1575,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,    1, 2531,   37,    1, 2073,    1,  345,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 2911, 1046,    1, 2309,   98,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3379, 2147, 1585, 2414, 2144,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  565,    1,   37,    1,   39,  505,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2466,  162,  433,   37,    1, 2824,  302,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  916, 1176,  227,   37, 1306,    1,  267, 2912,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2840,   45, 2725,    1,    1, 2959, 1204,   45, 2502,   32,  854,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1173,   37,    1,  242,   69, 1276,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  896,    1,    1,    1,   82, 2437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1005, 1006,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3075,  513,    9, 2024,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973,  361, 3249,  288,   37, 1776,  365,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  640,    1,    1,  187,  365, 1788, 1249,  166, 1957,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1397,   32, 2096,  187, 2138,  261, 2460,   32,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3233, 2303,   37,   77,    1,    1,  483,   37, 1334,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2494,  872,   39,   45,  671, 2107,  548,  354,   37,  208,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2998, 2161,   12, 3134,  571,  754,   98, 1970,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,  313,  176,  829,   32, 2995, 1523,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977,    1,  166, 1188,    9,  846,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2270,    1, 1337, 3227, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2227, 1105,   37,   52,    1,   37, 2804,  787,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  794,  547,  365, 2382,  618,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3178, 1774,    1,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    1,    1,  967, 1055,    9,  334,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2822, 2378, 1291,    1,  176,    1,  166,  596,   67,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1668,    1,   61,    1,   37,  105, 1183,    1, 1183,  914,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3299,  631, 3260, 1159,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2542, 2576,  449,  356,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1097,   57, 1269,  187,  644,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159,  720,   32,   91,   98, 1913,  401,   44,   45,    1,\n",
      "          372,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   91,   98,    1,   45,  119, 1477, 2651,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  374,    1,   12,  552,    1,  329,  810,  720,  118,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3221, 1564,  105,  400,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,  105,  183,   92,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3215, 3009,   32,  311, 2936,  714,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  987,  507, 2694, 1442,  158, 1491,   37,  333,   45,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  805,   45, 1629, 1630,  133,  134,    1,  176,  314,  361,  760,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1584,    1,  872,  168,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,  859,   37, 2653,  800,   60,    1, 1261,   65,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  364,  166, 1178,   37,  688,    9,  180, 1990,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1198,    1,   12,  411,  748,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1674, 3289,    1,    1,    1,  245,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2483,  104,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  872,   98,  166,  335, 3290,   55,   37,   23, 1816,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2197, 1585, 2416,  100, 1081,   12, 3401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1628,  367,    1,  793,  172,  533,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  994,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3152, 2967,  583, 3263, 2365,   32, 2138,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  590, 1031,    9,   94, 1184,  347,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3306,   32,   46,  220, 3191,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1157,    1, 1585, 1229,    1,  191, 2596,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9, 3220,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1968,  159,    1, 1010,  400,  122,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1133, 1204,   45,  105,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1370,   45, 1674, 2965,    1,   12,  195, 1463, 2713,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967, 2213,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2838,  619,    1,    9,    1,    1,  428,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  156, 1253,   32,   72,  401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3010,    1,   37, 2394,    1, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1611,  736,   37,    1,  224,  714,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 102, 707,  28,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  45, 105,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2025,  987,    9, 2080,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  840,    1,  967, 3084,  416,  105,  132,    9,  234, 3041,  235,\n",
      "          334,  234, 3041,  235,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2925,  729,    1,  683,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1974,  231,   45,  829,  132,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2551,    1, 1584, 3285,  670,  191,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  111,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1128,   51,   47, 1100,  279, 2168, 1128,   82,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1420,  197,  418,   98,  649, 1220,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,  359,   37, 1195,   46,   98,  138,    6,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  331,    1,    1,    1,  552,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3250,  726,    1, 1075,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2850,    1,    1, 1401,    1,   12, 3154,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  544, 2780, 1031,  166,  550,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,  387,  417, 1913,  401,  983,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  431,  949,   45,  784, 1778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,   98,    1,   37,  439,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2184, 3102,    1,  113, 1920,  176,    1,    1, 1333, 1530,  191,\n",
      "          947,  716,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 3293,    9, 3178,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  645,  469,    9,  844,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3257, 2421,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  593,  458,  404, 1033,   93,   51,  606,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1661,    1, 2583,    1,    1,  928,    1,  593, 2655,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 1893,    1,  160, 1161, 1308,   37,    1, 1394,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1063,  267, 1604,    1,  191,    1,  163,    1,   12,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  156,  245,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3300,    1,   39,  220, 2961,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2707,   37,  619, 2306,    9,   26,    1,  342, 2927,   46,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2286,   37, 1154,   69,    1, 2715,  548,    1,    1,   32,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3134,  163,    1,   12,    1,    1,  608,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  485,  967,  105, 2299,   45, 1184,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2173,  774, 1444, 1807,   37,   44, 1791,  582,   45,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2689, 1717,    1,    1,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428,    1,  453,    1,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 2924,    1, 3006, 1388,   32,  531,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3012, 1821, 3027, 2421,   32, 3013,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,   51,  606,    1,  607,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  810, 2226, 1210,    9, 1104,   61,  105,   59,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   74, 2246,  395,   81,   98, 2315, 1171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1929,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  388, 2997, 2538, 2481,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3175,  439,   28,  187,  166, 1509,   32,  539,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  261,   39,   46,  220, 3149, 2751,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  729, 1176,  445,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1166, 1444, 1734,   98,  166, 3388,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,   32, 2936,   37,    1,  219, 2318,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 3372, 1458, 3339, 2271,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3385, 1161,   32,  864,   12, 2673,  210,  967,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1940,   12, 3134,    1,    1,    1, 1198,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69, 1372,   37,    1,   65,   79,   67,  469,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1228,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3280,   37,  335, 1526,  176,  183, 1158,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2964, 1253,   98,  898, 1778, 2558,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  422,  839,  458,   45,  365, 1788,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  952,  726,   32,    1, 1194,  427,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2004,    1, 1353, 2177, 1027,  260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2561, 1713,  523,    1,  314,   32, 2093,  278,  315,    1,  191,\n",
      "         1629,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  990,  852, 1159,  734, 1527,  681,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  957,  686,  220,  885, 2738, 1465,  595,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3391, 2372,    1, 2572,    1, 2347,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962,    1,  868,   39,  187, 2633,  439, 3260, 1844,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3276,  203, 1762,  565, 1444,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2327, 1507,   69, 1391,   25,  186,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2596,   61,    1,   27,  105,    1, 1166, 2893,    1,  220, 1861,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  288,   37, 1611,   79,   69,  633,   37,    1,    1,  962,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2573, 2182,   85,  336,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1455,  680,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  221,  297, 1230,    1,    9,  105, 2589,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3333,  951,    1,    1,  683, 1977,   37,  664,    9,  683,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1240, 1403,   81,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,    1,   28,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  673,    1,    1,    1, 2271,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2366, 1039, 2690, 2462,  953,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 2527, 2946, 1976,   79, 2140,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  825,  593,   12, 1411, 2240,   30,    1,  722,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2571,  474,  952,   28,   37, 2924,    9, 3118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  684,  685,   27,  687,    1,   69,    1, 1653,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2738, 2960, 2414, 2144,   32, 2597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2693, 1803,    1,  191,  594, 2212,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  114,    1, 1976,   32,    1, 1620,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3271, 1066,    1,  444, 3117,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220,  388,    1,  204,   12, 2218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2172,    1,    1,   45, 1523,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 3397,  387, 1447, 2673,   46,   32,  857,  740,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1975,  321,    1, 2041,  459,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116,    1,  509,  171,  379,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   63,  166,  862,    1,  159,  554,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178, 1179, 2331,   45,    1, 3181,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  746,  376,    1, 1251,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,  650,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  151,    1,    9,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1,   81,  218,  332,  191,  672,   81,  102,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  730, 2614,    1, 2087, 2614,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1629, 1396, 1107,  293,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1542,    9,  121,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   82,   37,  930,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,  879,  142,    9,  647,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  200, 2355, 1013,    1,  884,   98,  829,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   26, 1039, 1872,  700,  794,    1, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 1656, 2596,   32,  531,   12,    1, 2414,  947,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1487, 1275,    1, 1690,  525,   15,   28,  419,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  684,  475, 1707,    1,   45, 1769,   37, 2103,   60,   12,  245,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  787,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1172,   12, 1173,  115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  409,   25,  439,  242,    1,   60,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  166, 3369, 2299,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2214,    1,  334,  321, 1074, 2310, 1656,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1, 1194,  401,  156, 1253,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,  108,  104,  444,    1, 1196,   45,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   37, 1611, 1479,   69,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  567,  510,    1, 2807,  361, 3103, 1090,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  405,    1,   37, 1504,    1,    1,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  415,   45, 2855,    9, 1009,    1,  736,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116, 1108,    1,  912,  388, 2819, 2039,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  584,  171,   12,    1,   37,  698,  176, 3229,  444,  403, 2926,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   12,  964,   37,    1, 1691,    1,  220,  854,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  982, 1774,   39, 2079, 1499, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1,   98,  868,  455,    1,   51,  686,  409,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3079,  901,  247,    1,    1,  361,    1,    1, 1167,  920,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116,    1,  619,  168,  115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2448,  386, 1413, 2884,    9, 3177,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,    9, 3176,   12, 1001, 1940,   37,  574,  405,    1,   12,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1143,  654,  494,    1,   45,  639, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  613,   16,    1,  460,   12,  758,  951,    1,  224,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,  119,  197,  187, 1412, 2382, 2401, 1258,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1,    1, 1102,  931,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3092,   37, 1463,    9,    1,  548, 3213,   12,  195,  997,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  493, 1253,  902,  596, 1793,  997,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1307, 1236,  297,  768,  361,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  673,    1,    1, 1744,   10,    1, 1160,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1610,  365, 1230,    1, 2438,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,  750,  475, 1356,  917,   37,    1,    1,  868,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  412, 1394,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2707,   37, 1838,  453,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1652,  967,  365, 1046,  680, 1718,    1, 2608, 1085,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 3381,  437,  396,    1,   37, 1926, 1927,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  601,  671,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2494,  872, 2257, 2017,   37,  688, 2468,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  544,  334, 1188,    1,  286,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503,  744,   28,  365,  749,  231,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2746, 1822,  544,  388,    9,    1, 2591,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  414, 1380,  787, 2780,   98,  166, 2655,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1988,   45,    1,    1, 1347,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  886, 1070, 1700,   37, 1334,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   32,  166,  550,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2190, 2640,  991, 1438,    9, 1821,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  388, 2873,    1, 1542,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3152, 2967,    1,   98, 2347, 1638,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1353,  104,    1,  220, 1056,    1, 1960,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,   32,  105,  998,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  189, 2089,  580,  927,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  684,  102,  417,   63,   65, 1953,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3101,  622, 2414,  547, 3375,   32, 3339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  608,    1,    1,   98,  627,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   65,  782,  954, 1239,   32,  496,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,   71,  187,  185,  186,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,  639, 1874,  864,   12, 2673, 2199,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  443, 1202,  837,  531, 2751,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  150,  338,   98, 1057,  297, 1607, 1463,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1906,  515,    1,  562,   37, 3283,  302,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2967,  801,   37,  581, 1385,  176,  104,  465,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,    1,   74,   45, 3336,    9,  851,  298, 2372,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98,    1,    1,  932,   51,  193,   52,    1,    9,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2899, 1359,   81,  220,  365,  912, 2285, 1597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3184, 1557,  650, 2356,   45,    1,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1437,    1,   98, 2103,  617, 1116,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  986,    1,    9,    1, 1632,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  872, 2567, 1632,  888,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3083,  103, 3331,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,    1,  176, 3376, 2596,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  729, 1610,    9, 2321,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,    1, 2018,  288,   37,    1,  846,  443,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  647,  167,   52,   26,   37,  148,  142,  940,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1073, 1658,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  104,  385,  389,   93,  143,  763,   76,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1312,  159,  298,  327,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2822,    1,  488,   37,    1,   69,    1,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,  487, 2548, 2572,   32,  344, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1925, 1583,  387,    1,    1,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2790,  952, 2500, 3036,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3381, 2431, 2572, 1897,  104,   22,  477,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2206, 2435, 1110,  872,  420,  385,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  627,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1390,    1,  587, 1421,  132,   37, 1066,  669,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2040, 3186,  877,   28, 1737,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,  700,  548, 3379, 2596,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 3006,    1,  547,    1, 3365,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3234,  872,  420,  385,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  130,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  116, 2264,  193,  187, 2440,  111,  187, 1444,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  920,  105, 1479, 1863, 1810,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   20,  140,   22,   23,   24,   37, 1539,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,  251, 2146,    9,    1, 2528,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  353,  242,  572,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3159,    1,    1,    1,    1,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3285,  726, 1515, 3283, 1090,  741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  321,  612,  489,   79, 2963,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1702,    1, 2146,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096, 3066,  361, 3215,  631, 2741,   37,  593, 1990,    1,   28,\n",
      "          726,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1848,   37,  138,   59,   32,  399,   45,  636, 1336,  400,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,   37,  649,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  799, 1414,  350,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 1174, 2813,   37,    1, 2069,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  328, 1498, 1079, 2173,   37,  927,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051, 3007, 1108,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  793,    1,  359, 1769,    9,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2297,    1, 1863,   45,  166,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3129, 2523, 2482, 2797,    9, 1269,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1293, 1894,  548,    1, 3116,  922, 2712,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2638, 2548, 2228,   28,   37,  104,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200,    1, 1013, 2549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2509,   45,    1,    1,  105,    1,    1,   98, 3015,  420,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 2214, 2453,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  542,    1,    9,  449,    1,  176,  365, 1090, 2692,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186, 1566,  163,    1,   12,    1, 2099,    9,  388,  531,  764,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 1753, 1158,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 2104,  692,    1,    9,    1,  622,  522,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1700, 1262,   37, 1865,  105,    1,  252, 3017, 2225,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 1707,  104, 3148,    1,  187, 2325,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3361, 2572,    1,   69, 1078,    1,   32,  645, 1450,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275, 1708, 1148,  220, 1817,    1,  471,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  183,  365,  390,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1172,  852,   81,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  299,  213, 1797,    5,  302,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1764,   61,  645, 1247,  901,    9,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  766,   37,  872,   98,  526, 2104,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  716,    1,  572,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  291,    1,  301,   29,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584, 2871,  289,   98,  750,  548,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1918,    1,   28,    1,   45,  872,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1720,  460, 1494,   37, 1094,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  500,    1, 1191,   37, 1835, 1651, 1607,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1220,  696,    1,  197, 1124,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977,  475,   37, 1540,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 2806, 1243,   98, 1117,  112, 2750,  949,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1051,  361,    1, 1505,  455, 2471,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,  670,   63, 1611,    1,   65,  907,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   79,    1,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  927, 1159,  677,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  342,  497,    1,   37, 2244, 1760,   98,    1,    1,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   15,  361,  207,  245, 1010,  290,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,  220, 2204,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974,  614,    9, 1411,   95,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  377,    1, 1812,   32,  871,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2496,   45, 1147, 2548, 1976, 1333, 1530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1100,  183,    1,   32, 1913,  401,    1,   15, 1716,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,  338,  187,   15, 1124,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2004,  306, 1268,    1,   37, 2179,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2861,    9, 1918,   32, 1984,  741,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2573,   12, 2288,    1,  565,   32, 2205,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  365, 1305,  321,  612,  151,  105,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  203, 2341,   61, 1658, 1465,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,  816,  187, 1345,   32, 2755,  531, 1650,  532,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1509,  151,  716,   72,  401,  156,   71,  118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  484,   98,  166, 2069,    1,   45,  909,    1,   98,  976,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2069,    1,    9, 3243,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  169,   15,   16,  818, 2050,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  736,  297, 3101, 1583,   12,  808,   32,   36,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1902, 1205,  191,  422,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359,   12, 2789, 1707, 3057,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3256, 1674,  119,    9,    1,    1,    1,    1,  384,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  455, 2450,   37, 1418, 2924,   32, 3102,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  815,  388, 2165,   37,    1,   32,   29,   98,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  969,  297, 1724,  885,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758, 2329,  224,    9,  166,  617,  259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3260, 1542,    9,  284,  227,  754,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  957,   37, 1174, 1168,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3349, 1038,    1,  361,    1, 2856,  176,  177,  548, 2237,  191,\n",
      "          104,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  449, 1023,  197,  801,   98, 1325,  124,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2398, 1394,   37,  168, 1425,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  636,  640,  119,  845,   45,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,  566,  365,    1,   12,    1,  507,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  742,    1,  884,  365,    1,   98,   74,   45,    1,  176, 1691,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  636, 1494,  123,   37,  202, 1608,  460,    1,  105, 2338,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2875, 2640, 2905,    9, 1198,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3369,  267,  163,    1,   12,    1, 3148,    1, 2179,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,   12, 3401,  884,    1,  187, 1009,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3043, 1051, 2690,    1, 1061,   32,  215,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 2407,    1, 2681, 2417,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2546, 1475, 1107,    1,  102,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3286,  566, 1427,    1,  691,   37,  973,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  171,  550,   45,  129, 1184,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3052, 2872, 1183, 1253,    1,    1,    1,  375, 1524,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1764,    1,  469,   37,  815,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   37,  138,  331,   37,  439,  768, 2096,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   75,    8,   67, 1806,    9,  259,  725,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708,  344, 3403,  640,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428,  267,  903,    1, 1447,  476,    1,    1,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   64, 2032,    1,  914,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,   37, 1816,  915,  916,   37,  864,   98, 2673,  315,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  617,   37, 1027, 1892,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  155,    1,   59,   32,  453, 1126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  105, 1300, 2988,    1, 1370,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1748,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 3143,    1,    1, 1890,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  644, 1285, 1415,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  626,    1,  325,  337,    1, 1021,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  709, 2925, 1863,    1,    1,  928,  176,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497,  168, 1159,    1, 1034,  220,    1,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3177, 1015,  891,  176, 2448,  386,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  506,  577,   98, 1855, 1625,    1,  108,   51,  335,  199,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1679, 3391,    1,  548,    1, 1523,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,  105,    1,  698,    1,  166, 1973, 2963, 2388,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1739, 1226,  608,  403, 2926,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1227, 1560, 1702,  460,   37, 1731, 2639, 1876,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2141,  361,  105,    1, 2209,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,  256,    1, 2105,    1, 2687,   37, 2340,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2393, 2134, 1676,  851,   37, 1054,   32, 2235,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3270, 2405,  667, 3222,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  894,    1, 1354,   45,  166, 1096,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  747,  197, 1042,   98,  526,  983,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1007,    1,  105,    1, 1325,    1,  548,  861, 2716,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  223, 2153, 1140,    9,  365, 1116,  569,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1108, 2827,    9,    1, 2891, 2372,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1746, 2564,    1,    9,  337,    1,    1,    1,  384,  602,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2246, 1545,  140,    1,  879, 3158, 1045,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 2917,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2733,  251,    1, 1211,  116,  259, 1484,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707,  108,  104,   98, 1850,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1545, 2565,    1, 3213,  267,    1,  220, 1178,  163,   45,  590,\n",
      "         1184,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,    1, 1458, 1853,   37,  877, 1647,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 2505,    1, 1624,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  256,  192,   37,  645,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  640,   81,   37,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1,    1,    1, 1782,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  398, 1484, 1715,    1,  399,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3232, 3130, 1258,   37, 2139,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1818,  147,    1,  544,  193, 1140, 1638,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,   12,   32,  105, 2225,    1, 1103,    1,    1,   61,    1,\n",
      "          763, 1432,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  777,  844, 1310,   37, 2833,  365,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1000,  155,  736,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2242,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  410,  751,   37, 1538,  477,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  916,    9, 2963,  415,  105,    1, 2539,   12, 2494,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2678,  967,    1,   32, 2090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  501,   37, 2553,   39, 3231, 1090,    9,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3128,  267,  204,   12,  193,    1,  191, 2924,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 505, 351, 140, 790, 562,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 266, 353,  72, 401, 207, 354,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  716,  242,  572,  156,    1,    6, 1069,  570,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  582,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1744, 1937,  753,   32,    1,   12,  195,    1,  384, 1958,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186, 1216, 1251,   45,  161,  931,  190,   52,  959, 1427,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2280,  437,    1,    1, 1381,  115,   45, 2823,  863,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2608, 2607, 2985, 1061,   32,    1,    1, 2928,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1118, 2978,   95,  288,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,  251,   40,  259,  220,  999,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    5, 1639, 1198,    1,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2201,  155,   59,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  550,  304, 2786,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1411,   84, 2029,  622,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 2494, 1293, 2793,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1325, 2657,    1,   37,    1,  171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2499, 2618,    1,    1,    1,  498,  349,  636,   45,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  202,  585,  361,  388,  805,   32,  166,   72,  401,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,    1,   54,  887,   45, 2918, 2585,  700,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,    1,  196,  619,  562,   37, 2123,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   45,  786,   12,  248,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3260, 1758,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3235, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  268,  251,  331,    9,  413,  524,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,  242,  951, 1547,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123,  892,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  581,  401,  207,  197, 1137,  118,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1372,   37, 1343,  581, 1463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1082,  163,    1,   12,    1,    1,    1,  193, 1798,    1,\n",
      "          220,  903,    1, 1447,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  612,  376,  636,   98,  116,   19, 1108,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  754,    1,   13,    1,  686,  220, 2730,  149,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  775,    1, 2079, 1228,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  369,    1,   32,  132,   37,  151,    1, 1218,    9, 1940,\n",
      "          361, 2161,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2822,   78,  498,   37,  105,    1,  469,   37, 1121,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,  156,  688,  586,  739,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2737,    1,   79,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,  114,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1133,   98, 2095, 2639,    1, 1160,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2565, 2582,    1,    1,  906,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3045,  319, 3392,   32, 2646,  548, 2024,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3272,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233,  476,  657,  475,  220,  673,  774,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1256, 1256,  420,  919, 1026,  159,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  664, 2630,  671,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  297,  249, 1061,   32, 2638,    1, 2678,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2939, 1321,  384,  331,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3288,    1,    9, 3238,    1,   81, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2802,    1,    1, 1343,   85,  943,   45, 1246,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,  190, 2286,   37,  429,  453,  248,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2563,    1,    1, 2158,   39,    9, 1517,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  990, 1536,  449, 2650,  400,   32,  163,    1,   12,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2968,  639,   96,  661,   98,  507,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  215, 2567,   37, 1211,  531, 3102,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   37,    1,  978, 2953, 2334,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 479,  32, 593, 186, 543,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 457, 593, 994,   1, 150,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1928,   30, 2249, 1645, 3073,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  566,    1, 2771,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1,  112,  259,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  336,    1,   98,    1,   45, 2890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2960,   32, 2752,   12, 1633, 2766,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  267,  204,   12,  590,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  700,  267,    1, 1360,   81,  332,   45,  218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  657,    1, 1412, 2586,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1375,    6,    4,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1544, 1737,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  314,  551, 1692,  884, 1277,  686,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193,    1,  528,  198,  698,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  650,    1,    1, 2543, 2396,   98, 3369,   12, 3118, 2299,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3318,  670,  191, 3103,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2984,  927, 2483,    1, 1748,   45, 2662,   12,  553, 2918,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1151,   25,  729,  186,  528,  304,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1283, 2227,  786, 3275, 2052,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  130,  735,    1,  413, 2146, 1972,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3167,  132,    1,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  260,   28,    9, 1718,   98,   74,   45, 1211, 1228,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2584,    1,  902,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  942,  300, 1132,  384,    1,   37,    1,   37,  764, 1897,\n",
      "          477,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  246,  142,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,  267,  163,    1,   12,    1,    1,  365, 2673,\n",
      "           46,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  447,    1,  453,    1,  444,    1,   37, 1785, 2044,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1412,  661,   98,  510,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98,   32, 1327,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1785, 2044, 2167,  845,   69,  102,  590, 1665,   37,  593,  996,\n",
      "           93,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204, 1249, 3230, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1486,   37,   47,   48,   32,    1,   37,  194,  734,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,    1, 3348,    1,  297,  582,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  492, 2263, 2343,   12, 3043,    1,  493,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1189,    1, 2827, 3102,   32,  531, 1683, 2147,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3330,    1, 3260,   81, 1159,    1, 2522,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   71,   63,  156,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3079,    1,   37, 1910,  273,  548,  786,    1, 2872,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  443, 2502, 1916,  444, 2343,   37,  698, 1411, 1034,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  688, 2964,  361,    1,   37, 2968,  176, 1327,  275,  264,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1544,  700,  444, 1443,   32, 1111,  218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2226,    1,  182,    1,  331,    1, 1612,  619,   59,   32,  573,\n",
      "          149,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2799,  105,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 1215,  765,   37,    1, 2294, 1602, 1632,   37, 2675,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3306,    1, 3181,  475,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   58,  737,  156,  388,  763, 1427,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2717,    1,  680,  649,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  811,  300, 1407, 1190,   37, 1811,  404,   37,    1,   98,  531,\n",
      "         3365,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,  622, 3350,   45, 3339,  796,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2549,    1,  440, 1501,   37,   52,   53,    9,    1,\n",
      "          331,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,    1,   12,    1,   32,  978,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 2336,  220,  365, 1778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2577, 1952,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2004,  818,    1, 1874,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947, 1664,  116, 2502,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  321,    1,    1,  166,    1, 3357,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2279,  251,   59,  469,   37,  860,    1,  223,  963, 2122,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  550,  398, 1800,    1,  400,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405, 3291,  476,  388,  384,  872,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1001,  977, 1672,   32,  645, 1034,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3052, 2249,   32, 2835, 1585,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  365, 1863,   32, 2355, 1013,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   22,  359,    1,  297,   24,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   49,   50,   37,   52,    1,   79, 1411,  339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91, 1648,   37,  764, 3069,  388,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,   69,  532, 1315,    1,  187,  965,  686,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1,   39,   45,  395,   26,   32,  449, 1385,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1281,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   60,  682,   98,   94,  187,  239,  240,   65,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,   73, 1939,  967, 2626,   37, 3059,  985,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1240,    1,  909,   98, 1537, 2700,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2672,    1, 1086,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  872,   12, 1343,    1,  967, 1846,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  940,    1,   37,  930,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1473,  202, 1723,  729,   39,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  232,  121,  193,    1,   32,  927,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 2170,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1592, 1171,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1463,    1,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 2070, 2357,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 2748,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  777,  778, 2073,  163,    1,   12,    1, 3102, 2572,   32,  531,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  815,    1,    1,    1,  506,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1008,    1,  929,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  288,   37, 1124,    1,    1,    9,  581,  199,   32,\n",
      "          187, 1744,  537,  963, 2122,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  851,    1,    1,   32, 3360,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 1850, 1423,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3321,    1,    1,  202,  753, 1544,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,   78,    1,    1,  220,    1,   39,   45,  166, 2340,    1,\n",
      "          166,  104,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1870,  794,  449,    1, 2355,  327,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2682,  395, 1725, 1259,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  463, 1447, 1550,    1, 2330, 2339, 2673, 2375,    1,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,  335,   81,  166, 2539,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1260,   32, 1619, 2597, 2414,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1292,  662,  295,   51,  211,   57,   37, 1709,  388,  600,  296,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1183,    1,    1, 2222, 1631,   39,   45,  701,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2882,  307,   39,   98, 1306,  593,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1051,    1,   28, 2798,  861,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  140, 2522, 3201,    1,    1,  446,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   36,   12,   39,   37,    1, 2997,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1294,   61,  193, 2567,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  721,    1,    1,   37,    1,  927, 1159, 2658,   12,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  437,   30, 1184,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 2094,    1, 2750,   37,  403,  507,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  864, 1293,  700,   98, 2673, 2109,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1680,  861,    1,    1,    1,    1, 2596, 2372,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2102, 1107,   37,  105, 2408,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1938, 2809,    1, 1388,    9,  632,    1,  663,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  342, 1094, 1822, 1847, 1221,   61,  590, 1021,    1,   32, 2708,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,   12, 1429,  741,   45, 1161,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 2800, 1246,    1,    1,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2229, 2232,    1,  910,   32,  829,  260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,  302,   37, 1814,  442, 1559,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  291,   12, 2720,   45, 1018, 2706, 2232,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  386,   78,  921,  968,   32, 2025,  199,   37,  726,  671, 3126,\n",
      "           32,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 2075,   81,  384, 1515,  465,   74,  832,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  288,   37,    1,  219, 1267,  444, 2448,  386,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3303, 1435,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  901,    1, 1401,   37,  223, 2298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1459,   12, 1918,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1417,    1,    1,  466,  275, 1456,  884, 1412, 1107,  105,\n",
      "           84,  981,    1,  202,  460,   12,  590, 1230, 1160,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 3278,    1,  729,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3259, 1403,   39,  166, 2491,   32,  166, 1668,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  476,  845,  147,    1, 1638,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 146, 147,   6,   1,   1,  32, 735, 149,  37,  59,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 879, 693,   9,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3282, 2779, 2682,    1,   32, 2592,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183, 2415,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,  396, 2334,  846, 2545,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1581, 1597, 1799,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2104,  267,  531,   37,  429,  890,  740,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  935,  200,  132,    9,  449, 1972, 1821,  541,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2800, 1794,    1,  297, 1583,    9, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861,    1,  366,  667, 2778,  115,   45,  863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1, 933,   1,   1,  32, 854,  88,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 884,   1,  48,  32, 121,  12, 141,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   37, 1075,  906,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,    1,  105, 1875, 2119,    1,  202,  224,  967,    1,  453,\n",
      "            1,  636,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3309, 1554,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422, 1099, 1464, 2089,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2506,  297,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  449, 1023,  932,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2911,    1,  220,  695, 2789,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275, 2122,    9, 2161,   12, 2591,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  249,   12,    1,   45,  282,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,   81,   32,  938, 1230,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1492,   12,  166, 1178,    1,    1,    1, 2523,  332,  631,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   67, 1239, 2056,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2445,  744, 2306,   37, 1611,   49,   50,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325,    1,  596,    9,    1,  131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  531,    1,   45, 3373, 2249,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  375,   96,    1,  220,    1, 1260,   98, 2741, 2465,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1363, 1008,  709,  413,  187,  365,  582,   45, 1796,   50,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1587,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  501,  220,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1053, 2272,   85,  548,    1,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2639,  879,   37,  777, 1085,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 2580,   37,  844,  220,  535,  656,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3343,  957,  267,  195,    1,  254, 2072, 2179, 1260,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708,    1,  850, 3304,   28,   32,    1,    1,  218, 2572,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2475, 1421,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1251,   45,    1, 1149,  223,  641,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3336, 3375,  543,  741,   37, 1504, 3358,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2656,  550,    1,  103,  111, 1624,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  894,   84,   85,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  565,  735,   12, 1890,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3321,   12,  627,   61, 2353,    1,  190,    1,  548,  914,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275,  442, 1593,   98, 1926, 1927,    1,  954,    1,\n",
      "          223, 2135,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  723,    1,    1,  170,   46,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 2373, 2255, 1901,    1,    1,   98,  470,   45,  815,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  596, 1793,    1,  658,  763, 1999, 1592,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12,  252, 1284,    1,    1,   61,  623, 1885, 1638,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,  667,   26,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,  606,  183,  689, 2738,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,  952,  808,   32, 2657,   45,  166, 1411,  116,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1530,    1,   59, 2816, 1219,  187,    1,    1,    1,  854,\n",
      "            1, 1853,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3151,   12,    1,  459,    9,  632, 3116,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   69,  102,  288,   81,  596,  471,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1166, 1851,  166,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,   12,    1, 3175,  288,    9,  855,  335,  810, 2522,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2899,    1,    1,  218,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 2712,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  296, 1867,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2919,  297, 3102,   12, 1623,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  116, 1204, 1938, 2607,  382, 2206, 2989,    1,   37,  777,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  938,  939,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3058, 1974, 2282,  776,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   37,  720,   43, 1232,  647,    1, 1464,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3112,    1,  389,   45,    1, 2777,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1112,  176, 1115,   93,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,   28,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1680,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 1504, 3264,  187, 2792, 1831,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  698,    9, 1591,  159,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  122,   98, 1051,  142,    1, 3000,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,   37, 1982, 3369, 1450,  187, 3148,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  396,  105,  808,   32, 3128, 1798,  318,  361,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  276,    1,  187,  596,  304,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1029,   12,  469,    9,  105,    1,    1,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 1009, 1926, 1927,   61,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3285,  193, 2525, 2330,  388,    9,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1437, 1071,   32,  455,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  302, 1712,   32, 2197,   37, 2392,    1,  132,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  225,   70, 2127,  115,   45,  646,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  397,    1, 1838, 1034,   45,    1,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   82,    1,   37,  930,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1876,  384, 1891,  593,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  227,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  342,  695, 1411,  339,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  539,    1,    1, 2741,   37,    1, 3116, 3217, 2069,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1022, 2296, 2935,  593, 2522, 1569,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  811, 1550,  204,    1,   37, 1937,  531,   12, 2877,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 593,  12, 449,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 842, 686, 191, 195,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  104,  246,    1,  497,  734,  591,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2983,   32,  105, 1280,   45, 1515,  248,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1461,  872, 1219,   32,   98,  166, 2918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647, 1707,  148,  142,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3361, 1000,  547, 3395, 2496,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  370,    1,  987, 1159,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2837, 2867,  311, 1778, 2580,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  457,    1,   61,  288,   37,  335,  105,  581, 2784,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,  437,  213,   32,    1,   37,  151,  849,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1629,  314,   51, 1046,  388,  763,   59, 1780,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  612,   42,   43,    9,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 2702,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,  140,    1,    1,  695,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123, 2685,    1,    1,    1,  187,  512,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2835,  936, 2666,   98, 3388, 2024,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  618,   37,  619,   40, 2589,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1962,    1,  618,  504,  412,   37, 3068,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196,    1,    1,    1,  218,  269, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2767, 2043,    9,  829, 2515, 2657,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  936,    1,  720,   32,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  794, 2627,   29,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,   37, 1343,  166,    1, 3201,  427,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 1913, 1843,  156,  245,    1,  419,    1,  225,   79,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 1877,   37,    1,    1, 1232,    1,  191,  531, 3102,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1087, 2065, 2474,    1,   37,  470,   29,  656, 1604,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1353, 2729,  493, 1184,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,    1,   37, 1604,   98, 2210,  613,  858, 2146,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622, 1942,   23, 1554,    9, 3118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  602,  603,  176,  381,  604,  605,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2802,  921, 2494,  633,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3117,    1, 3296,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2061, 3069,   37, 2905,  214,   45, 3360,  622,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1419, 1325,    1, 3011,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  597,  654,  940,    1,  600,   83,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  647, 1366, 1445,  193,    9,  333,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  811, 1550,  204,    1,   37, 1937,  531,   12, 2877,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    1, 3329,   32, 2941,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,   12, 2069,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1123,    1, 2155,  460,  176, 1658,  248,  629,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967,  786, 2107,   37, 2394,  247, 1960,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1674,    1, 3163, 2030,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  256,  242,  439, 1671,    9,    1, 1117, 1525,  361, 1274,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2700, 1000,    1,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2375, 2616, 1976,   32, 3391,  531, 1190,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2925,   12,  844,    1,   30,  590,  459,   45, 1115,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  879,  119, 1844,   37,    1, 2284,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  882,  572,  156,  554,   98,  786,  199,  682,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1,    1,  921,  403, 1739,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3285,  375,   39,  220, 2961, 3131,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785, 1414,    1, 1313, 1314,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1749,    1,  224,  220,   47,  731,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1104,    1,    1,   28,  810,  297,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018, 1009,   37, 1334,  187, 1583,  475, 1190,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,    1,    1,   45, 1919, 2710, 3382,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  273, 1685,    1, 1787,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  534,  476,    1,   12, 1357,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  673, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,  361,  179,   37,  125,  278,    9,    1,  617, 1397, 2928,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1465, 2323, 1118,   22,  942,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,   12,  197,  388,  763,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2971,    1, 1125,   98,  557,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1, 2254,  875,  768, 2096,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1037,  275, 2415,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2936, 1864,  132,    9,    1,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98, 1090,  698,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,  267,    1,   51,  193,   52, 1976,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1444, 1343,   55, 1444, 1445,  707,    9,  105,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2980,    1,    1, 1521, 2762,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  497, 1220,  506,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 2095,   32, 1081,    1,    1, 1373,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  104,  684,   12,    1,   37,   84,   85, 1837,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1061,  115,   45,    1, 2237,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  251,  441,    1,  861,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  750,    1,  460,  441, 1505, 2461,  437,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2029, 2218,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2266,   90, 2868,  163,    1,  903,    1,  190, 1527,  531,  741,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 2924,    1, 2856,  547,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   61,  479,   39,   45,  166,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  359,  167,  674, 1623,   45,  104,  358,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962,  902,    1,  608, 3263,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    1,  332,    1, 3000,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   91,  361,  104,  498,   37, 1598,  864,   12, 2673,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1093,  574, 1132,  588,  230,   32,  301, 2108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  884,  297,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  186,  444, 3356,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3343,  787,   62,  548,    1, 2696, 2357,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,  778,    1,  229,    9, 1509,  325,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  251, 2432,   37, 2324,  861, 2762,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2939,  581,   32, 2743,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788, 1178,  140,  331,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2972,  475,    1,  939,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2741, 1917,  942,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,  582,  108, 2707,   98,  342,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  666, 1666, 1675,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,   12,    1,  140, 2674, 3292, 1267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,   12,    1,  884,   98,  166, 1021, 1787,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  717, 1417, 2420, 1273,  777,    1,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,  879,  453,  622,    1,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826, 2472,    1,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,  251,  864,    1,   37, 2199, 2673,  210,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,    1,  716,  331,  197,   32,  871,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2615, 2935, 1194,   73, 2941, 1569,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2819,  140,  166,  581, 1385,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2699,  246,   32,   98, 3024,   12, 2319,  651,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  851,   96,   81,  548,    1, 2527,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2483,    1, 2072,  166,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1567, 2398,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1852,  487,  858,  102,  729, 1176,  845,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,    1,    1, 2716,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  582, 2800, 2565, 1558,  548,  354,   37,    1,  171,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  954, 1032,   32,  581,  401,  763,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3269, 1710,  619,  247, 1445,    1,  384, 2685,    1,  202, 1444,\n",
      "         1188,  388,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303, 1707,  943,   45,    1,   60,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1674, 2172,  277,  439, 3071,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    9,   91,   12,  183,  564,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1051, 1003,   37, 1496,  725,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2159,    1, 1717,  810,   32,    1, 2695, 2193,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,    1,    1,  612,  606,    1, 1232, 3240,    1,  612,\n",
      "            1,  166,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,  632, 2834, 2134, 1021, 2428,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  376,  163,    1,   12,    1,   15,  570,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730,    1, 1445, 1421,    1,   37,  356,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   82,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  548, 3312,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  748,    1, 2085,    9,   26, 1940,   12, 2069,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2221,  854, 1401,  593,   32,    1, 1655,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  310,  159, 1171,  236,  237,  390,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2275,    1,  451,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,  449, 3127, 1916,  565,  288,   37,  335,  913,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3377, 1114,  513,    9, 1922, 1204,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2717, 1031,    1,  176,  842,  548,    7,  195, 1464,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1518, 1663,  574,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2807,  619,    1,    1, 1394,  361,  105,  354,   37,  519,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3087, 2414, 2144,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2779,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  954,  160,  102,    1, 1068, 1069,   71,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  609,  952, 1368, 2191, 1377,  695,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2790,  292, 2474,  259,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2755,  624,    1,  737,  197,  418,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 2962,    1, 1164,  764, 3263,  439, 1826,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  861, 2429, 2083,  166,  327,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964, 2770, 3367,   63, 2823,  741,    1,    1,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   49,    1,    1,  220,  104,  467,  625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3160,  610,   37,  547,  537,    9, 2772,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3262, 2671,    1, 2912,  928,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  353, 1884,  390,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  241, 1559,  488,  103,  342,  770,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193,   37, 1445,  142,    9, 3192,  663,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1212,    1,  104,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,    1,  104, 1832,  176,   56,  497, 1990, 1663, 2161,   12,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  884,  845,  439, 2041,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,    1,   98,  861,    8,  220,  365, 1228,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1169,   15,   85,    1,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 3205,    1, 1313,    1,    1, 1678, 1159,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3144, 1557, 1484,  477,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,    1, 1061,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  846, 1782,   28,   37, 2227,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  442,  656,  695,   51, 1251,  460,   28,   37,  152,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  727,  713,    9,    1,    1,    1, 1136,   32, 2101,    1,  135,\n",
      "           39,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1839, 1176, 1298,   37, 2324, 1793, 1428,  651,  475,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,   98, 2667,  176, 3194, 3195,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  729,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1851, 3358, 1841,  321,  619, 1983,    1,  447,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2960,   27, 3339,  787, 3150,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1645, 1900,    1,  361,    1,   37, 2123,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98, 2734, 2372, 1316,  166,  593,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  447,    1,    1, 1705,   37, 1154, 3365,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1398,  612,    1,   98, 2349,    1,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  539,    1,  688, 2741,   32,    1, 3135,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 1283, 1675,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   42,  149,  297,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12, 2318,   74,    9,    1,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  645,  170, 1710,    1,    1,   12, 1046, 1728, 1114,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  417,   98,  355,    1,   69,    1,    1,  496,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3152,  186,   37,  720,  902,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  198, 2164,    1, 1850,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  104,  422,   57, 1093,  977,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  223,   37,  151,  449,  223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,  104,  851,  856,   51, 1000,    1,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  614,   37,  166, 3233,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1292, 1681,  357,  105,    1, 1204,   98, 1965, 2977,  162,  166,\n",
      "          593,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 2746, 1248, 2275,   37, 1594,   28,    1,   45, 1708,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  640,  121,   12,  535,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12,    1, 1077,  131,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  632,   69,  532,   37,  168,  403,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878, 1300,    1, 1984,  155,    1,  347,  191,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1073,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1564,  172, 1330,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  443, 2938,  776,  891,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2197,    1,  453, 1876,    9, 2707,   12, 2927, 1159,  342,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  183, 2960,  898,   32,  903,    1, 1447,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 1800, 1428,  304,   45,  365, 2649,    1,   37,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2086,  302,   12, 2829,    1, 1935,  668,    1, 2928,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 1549,    1,  430, 1564,   69,    1,  172,  616,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,    1, 1853,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,  166, 2488,  774,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1631, 3172,    1,  813,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  954,  471, 1071,    1,  366,    1,  720,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2316, 2545,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2718,  661,    1,  220,    1,    1, 2043,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3123,   12,    1,  967, 1857,    1, 1360,  612, 1343,    9, 1700,\n",
      "          257,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  140,  331, 1448, 1429,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  528,    1,  954,    1,  590,    1,  221,   98,  734,  591,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,   51,  606,    1,  440, 1294,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  715,  112,  783, 1276,   32,  367,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1976,   37, 1527,  864, 2673, 1896,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3296,  712,   28,    1,   12, 1144,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 2924,   32,  531,  698, 1782,  403,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  942,   12, 1880,   37,  151,    1,    9,    1,  131, 1714,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2175,   79,  271,    1,    1, 2051,  763, 1520,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2235,   19,   37,  166, 3261,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1645, 2153, 2000, 3102, 1512,   32,  531,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 2548, 1988,   45,    1,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2226, 1924,    1,    1,  101,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,    1,    1,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  539,    1,    1,  846,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  765,   98,   37,  365, 2329,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,    1,   81, 3329,  631,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  553, 1313,   45, 1034,   76,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3132,  542,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117, 2208, 2298, 1976,   32, 2998,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,   68,   70,  429,  530,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1458, 3176,   37,  688, 3316,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361, 1051, 1505,  955,  662,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,  830,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  358, 1075,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3257,   37, 1758,   37, 1286, 3179,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2683,   37,   47,    1,   32,    1,  187,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,   12,    1,   45,  443,   98,    1,    1,    1,   98,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3375, 2844,    1, 1941,   32, 3339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  848,    1,  321,  612,  271, 1230,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  901,  787,   45,    1, 1976,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3087, 2668,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  864, 1360,  612,    1, 2673,  210,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3164, 3317,  696, 3262,    1, 3116,  922, 2413,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,    1,    1,   37, 2018,    1,   45,    1,   98, 1815,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2967,    1,  600,  104,  863,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  433, 2540, 3153, 2220, 1281,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2163,   37,  470, 1381,   98,  137,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,  456,  381,  457,  458,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,   45, 2986,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2843,  361, 3337,   32,  166,  631,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   71,   32, 2466, 1397,   51,  805,  890,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1110, 1585, 3231,   37, 1527, 2941, 1625,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2476,   32, 3343,  776, 1079, 2508,    9, 2417,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1994, 2095, 1506,   51,  168,  981,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  603,    9,  402,  444,    1, 3181,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,    1,   39, 2529,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,   12, 1341,    1,   45,    1, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 747,   1, 746, 151,   1,   1, 150,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 437,   1, 191,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2554,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746,  251, 1766, 1767, 1108,   37,    1, 2264,    9,    1,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1312, 2909, 1316, 2468,    1,  228,   32,    1,   45,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1966,   37,  138,    1, 2372,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1957,  191,  166, 1397,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,    1,  829,  872,    9, 2819,  767,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  709,  373, 1682, 1439,   32, 1405,  126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984,    1,    1, 2662, 2918,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3066, 2917,  191, 2936,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  388, 1890,   45,    1,    9,  527,  562,  705,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,    9, 2347,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428, 1090,   51,   52, 3238,   12, 1851,  698,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2,  69, 102, 245, 995,  98, 163,   1,  12,   1,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 968,   1, 395, 187, 105, 218, 954,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2911, 1406,  600,  531,  187, 1103,  187,  195,  408,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  517,    1,  405,    1,  552,    1, 1877,   37,  693,    1, 2521,\n",
      "          176,  453, 1209,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2,  60, 831, 548,   1, 340, 951,   1,  94,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  74,   9, 104,  32, 257,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2317,  384,    1,  872,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,    6,   69,  568,  837,    1, 1278,   98,    5,  302,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3288,    1, 1857,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2449, 1595,  361, 2177, 2567,  548, 1674, 1918,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2442, 1743, 1867, 2229, 3093,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2136,   10,    1, 2676,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  405,    1,    1,  191, 1990, 2022,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   69,    1,  720,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1186,  267,   97,   98, 3369,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,  919, 3287,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1123, 1110,    1, 3231,   37,    1, 1131, 2545,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  335,  674,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  567,  510,  884, 1003,  176, 1273,    1,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  224, 1108,   51,    1, 1691, 2471,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  328, 2236,    1,  387,  393,  467, 1371,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,  530,  687,    1,  590,    1,   66,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  103, 2635,    1, 2963,  176, 1311,   26,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2466,    1,   37, 1937,  786,  659,   45,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1464,  125,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1260,   98,  104, 3150, 2414,   32, 2597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  987,  507,    1,  331,    1,   98,    1, 2434,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  386,   37,   47, 1737,  187,  214,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1425, 1033,   12,  616,  834, 1658,  454,   37, 1488,  571,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,    1,    1,  967, 1183,  759,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   91,  927, 1921,  176,  166, 2918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1436,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2643,    1,  168,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 3102,   12, 2068,  267,  947,    1,  492,  754,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  657, 1353, 3019,  260,  220,  365,  660,  331, 1151,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1663,  325,    1,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2517, 3370,    1,   28,  315,   37,    1,  890,  104,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2877, 2450,   37,    1,  191, 1004,   45,  166,  487, 3102,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2700,    1, 2663,   45,  365,    1, 1183,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  476,   37,  168, 1698,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2327,    1,   45,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1149,  437,  267,    1,    1, 2001,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2621,    1,  202,  193,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  574,   12, 1998, 2554,  105,  845, 1251,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  396,   37,    1, 1151,  846,  220,    1, 2666,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  358,   37,   47,   35,   48,    1, 1636,   32,   91,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2786, 2558,   32, 2993,    1, 3056,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1370,   45,  166, 3020,   45, 2178, 3093,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3239,    1, 2763,  220, 3327,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 1034,   32, 2026,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1831, 1550,  439,   45,  971, 1832,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  799, 2134, 1817,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2279,    1,   37, 1937,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1411, 2273,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1116, 2393,    1, 2583,  155,    1,   37,  792,  151,  792,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1013,    1,  619,  388,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  233,  908,  397, 2927,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3239,  690,    1, 2771,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  768,  484,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006, 2192,  447,  885,   74,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2275,    1,   10,    1, 1523,  297,  451,  378,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  515,  460, 1509, 1333,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   12, 1846,  105, 2337,  452,  460, 1924, 2181,  176,  166,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  547,   37,  332,  331,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  531,   12, 2877,  884, 1140,   32, 1574,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087,  433,  986,    1,   37, 1428, 3397, 2572,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  530,  548,  365,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363, 1949, 2018, 1819,    1,  202,  629,  997,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  534,    1,   37,  222,  413,   12,  214,  142,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,   71,  548,  883,  361, 1161,    1,  720,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   42,    1,   61,  331,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,  187,    1,    1,   32,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3013, 1635,    1,   37, 1504, 3305,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1825,    1, 2403,    1,  220,  365,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  857,    1,  583, 2523,  176,    1, 2957,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1718, 1586,   28,  128,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  550,    1,   37,  334,  191,  326,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190, 1306, 2241,   45,  314,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  715,   14,  633,   32, 1296,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1771,    1,   98,  389,   93,    9,  890,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3144,   12, 2823, 1708,    1, 1370,    1,  105,    1, 1844,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503, 1536,  365,    1,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  108,   45,    1,  754,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  561,  927, 1256,  551, 1256,    1,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,    1, 1822,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187,  166, 2875,  633,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361, 1051,  872,   28,    9, 2348,  725,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204, 1401,  103,   56,    1, 1159,  401, 3179,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  167,   52, 1411,   98, 3315,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,  418,  202,  159,  720,   98,  157,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3405, 1310,   37,    1,   62,   32,  557,  540,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,   12,    1,  580,  709,  391,   32, 1422, 2823,  806,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1792, 2215, 1396,  730, 1777, 1718,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  223, 2135, 2664,   37,  611,    9, 2608, 2607,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2977,    1, 1821,    1,   37,    1,    1,   45, 2983,    1, 3009,\n",
      "            1,  361,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 2095, 2985, 2007,   32,  147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1478, 1056,  183,    1,   32, 3201,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  261,  444,  171,  777,    1,  625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  306,  256, 1935,    1, 1108,   37,  215,  525,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1173,   37,    1,  548,    1,   61,    1,  166, 2009,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3196, 1542,   37,  439, 2002,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2911,  582,    9,  806,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1957,    1, 2475,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  737,  197,  418,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  647,   12,   82,  648,  162,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9, 1246, 1167,  967, 2626,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1425,  166,  593,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  446, 1921,    9,  854,  342, 2396,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,    1, 2035,  394, 1145,   87,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  141,  361,    1,  469, 1651, 1604,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  342, 1984,    1,  191, 2096,   98,    1,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2930,    1,    1,   32, 1029,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  597,    1,    1, 1236,   36,    1, 3172,    1,  422,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  742, 1680,   48,   32,  386,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2314,  492, 3096,    1,    9, 1343,   79, 1294,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,  213,   37,  138,   59,   37,  875,   43,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2414, 1147,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3043,  903,    1, 3165, 1237,   12,    1,  464,  395, 2699,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2757,  162, 1133,   98, 1606, 2096,  204,    8,  105,    1, 2099,\n",
      "            9,  105,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,    1,  441,  498,   98, 2461,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 2079,  980,    1,    1,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,    1,  359,  774, 1444, 1445,  123,   37,  105,  132,\n",
      "           98,  672,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  396,  453, 2334,   61,  593,   12, 1254,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1022, 2350, 1560,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 551, 789,   1, 129,   1, 221, 218, 242,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 476,   1, 176, 902,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 3204,  321,  427,  247, 1183, 2113,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  493,  633,  462,   37,    1,   32,  632, 1611,   45,    7,\n",
      "           49,   50,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3358,   12, 3137,   61,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  313,   37, 1000,  901,    1, 2728,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  634, 3224,    1, 1159,  985,   45, 2522,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,   52, 2399,    9, 3070, 3149, 2774,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   89,  267,  104,    1,   37,    1,  673,  448,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2658, 2269,  686,   32, 1046,   32,    1,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1,   32,  622,    1, 2862,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 2002, 1938, 3197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,  736,  297, 2208,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363, 1401,  741, 2116,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  242,  763,    1,   32, 3184,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1607,   37, 1787,   29, 2759,  650, 2278,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  189,   21,  417, 1913,  401,  983,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2077, 1205,  297, 1656, 1311, 1987,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3025,  162, 1973,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275,   37, 2228,   79,   32,  915,  736,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  275,  494, 1862,  600, 1278,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1979,    1,  854,  429, 1285,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  384, 3012, 3027, 1866,   37, 2616,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,  792, 2814,   45,  484,  792,    9, 1850, 1423,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  365,    1,    1,  294,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2045, 2743, 1760, 1689, 1891, 2710,  299,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1898,  720,   32,  156,   37, 1177,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,    1,  361,  166,  230,    1,    1,  123, 2471,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,    1,  542,  877,    1,    1, 1102,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835, 3109,  228,  297, 3393, 3389,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  492,  587,    1,    1,  361,  957,  759,  630,   98,    1, 1553,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,   39, 2278, 1876,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    9, 1018, 1691, 1597,    1,    1,  460, 1924,  105,  227,   74,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  295,  529,  408,   28,  191,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1487,   15,   28,  419,    1,  159,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1579,  302,    1,  957,   37, 1195, 3107,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2593,  327, 1228,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1459, 1702, 1994, 2834,  469,  548, 2596, 1260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3236, 1285, 3175,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 3336,  166, 2162,   45,  531, 3102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2528,    1,   12,  365,    1, 1027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  225, 1656, 2514,   32,  942,  162,   92,  384, 3076,  132,  220,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3241,    1, 2463,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1631,  166, 1076,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1412, 2530,   15,   37,  686,  131,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066,   81,   32, 2741, 3273,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  236, 1022,    1, 2321,    1,   81, 1159,  166,  938,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3104, 1346, 1373,   37, 1911, 2325,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  835,    1,  118,   48,   32,  989,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925,    1,    1, 2206, 2207,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3238, 1401,  730, 2614,  608, 2615,    1, 1414, 1090, 1312,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766, 1401,  293,   32,    1,    1,   29,    1,   37,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  140,    1,    1,  232,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1751,  513,  514,  190, 1642,  257,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  120,   37,   98,  121,  122,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1, 2389,  256, 1876,    9,    1, 2943,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1179,  360,  365,  214,  142,  384,  635,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  449,  221,  220,  166, 2685,   61,   37, 1805,  433,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2275,  267, 1636, 1099,    1,  281, 2053,  289,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796, 2924,    1,   37, 1334,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2819, 1117,    1,    1,  207,  819,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1232,    1,  221,    1, 2298,  240,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 964,   1, 247,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 640,  39, 176,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   37,  429,   28,    1,  202,    1,  297,  229,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2095, 2985,  168,   37,  147,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3052, 1313,  444,  443,   32, 3367,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3322,    1, 1957,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  107,  475,    1,  220,   69,  636,   71,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  500, 1680,  570,   98,  636,    6,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  491,  580,    1,   54,  430,  302,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 1863,    1,   37,  907,   32, 2184,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   83,   37,   84,   85,  187,  654,  475,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708, 2554, 2866,  361,  247,  249,   12, 2721,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1452, 1676,    1,    1,    9,  166,  754,  872,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1,    1,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  764,  220,  567,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1413,  539,    1,  424, 1034,    1, 2488,  774, 3096,\n",
      "         2246,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 600, 395,  12,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 667,  25,  25, 123, 417,  98, 217,   1, 137,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1186,    1,   37,    1,  342,    5,   67,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  167,  362,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2983, 1505,   55,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3244,  335,   85, 3227,   32, 2925, 3246,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,  365,    1,    9,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1151,  669,    1,  422,  927,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3390,   32,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1617,  288,    9, 1675, 3135,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  824,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2851, 2264,    1,  384, 2987, 2762,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3167, 1834,    1,  365, 1788, 2685,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 2170,   32,  198, 2027,    1, 1463,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1711,  186,  444, 1902,  900,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  991,    1,  151,   45,  189, 1501,  963, 2122,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  857,  477, 1408,    1,   98,  103,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1,    1, 1155,    1,   37, 2206, 1898, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   39,   45,  674,   32, 2916,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  721, 1458,    1,  187,   82,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  438, 1109,  572,  207,  972,   28,  202, 2015,  583,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1324, 1663,    1,   98,  531,   12,  627,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1980,  792, 2381,    1,  792,  522,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 1981,   98,  844,    1,  538,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   55, 2746,    1, 2466,    1, 1980,   37,    1,   85,  613,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1125,   32,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3001,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    4,  420, 1702,   25,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 2924,    1,   37, 3383,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3128,  387,  531, 2271,  191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2912, 2226, 2582,   37, 1413, 2982,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   70,  670,  548,  626,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,  515,  148,  501, 1125,   37,  151,  647,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,   98, 1072, 1235,   12, 1623,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1183,  865,  919, 3250,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  858, 1680,  219,  777, 2264,   37,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1550,    1, 2282,  722,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1,    1,   37,  163,    1,   12,    1,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,  863, 1167, 1745, 1086,    1,    1,    1,  111, 2928,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  410,   98,  303,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  968,    1,  759, 3295,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  418, 1270,  118,   98,    1,  104,  341,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1412,  754,   37,  288,   79, 1411,  183,  623, 2842,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  662,    1,   37,    1,  845,    1,  734,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3129,    1,   12,    1,   45,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1935, 1510,  744, 1000,  105,  913,   98, 1055,    1, 1160,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2049,    1,  376,  157,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 1981,   98,  844,    1,  538,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,  509,    1,  236,  237,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 1252,    1,  590,    1,  511,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1433,  565, 1221,  320, 1744,  585,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2531, 1995,   98,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 2003, 1585, 2414,  176,  177,    1, 2753, 2249,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  183, 1272,  193,  810, 1167,  183,    1,  700, 2167,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  324,   37,  130,  326,  466, 2359, 1131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3057,    1,   37,  726,    1,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2868,   12, 2890, 2784,   79, 1010, 2357,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  613, 2543, 2519, 2776,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  492, 2263, 1178, 3043,   45,    1, 2343,  443, 2938,    1, 3148,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1629, 1921,  176,    1,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1051, 1353,    1,    1, 2320,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2098,  402,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101, 2404, 1190, 2405,   37, 2197,   37, 2000,    1, 1450,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2686,    1,  480,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  183,  458,  361, 1630,   32,  170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230,    1, 3257,    1,  384,  166, 2197, 3329,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  424, 1034,   32, 1230,  550,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  130,    1, 1021, 1541,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  398,   32, 2235,  515,    1,   37, 1584,    1, 2214, 2844,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61, 1094,  330,   37, 1260,  864,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 579,   1, 148,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 353, 197,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  420, 2851, 2298,  805,  118,   45, 1778, 2580, 2261,  918,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1968,   40,  612,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1061,    9, 2638, 2931,   32,  691,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2160, 2049,  831,  384, 2628,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,   82,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1230, 1159, 2815, 1671, 3031,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,  455, 2147,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1257,  960,  891,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,    1,  148,  142,    9,  647,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3392, 1585, 2414,  176,  177,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2018,   12, 3380,  387,  916,    9,    1,    1,  220,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,    1,   95,  473, 1415,   37,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  758,  891, 2587,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1963,    1,    9,    1, 1013, 1522, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1249,    1,   32,    1, 1787, 3201,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3028,    1, 2997,   61,  227,    1,  202,  460,   12,  193, 2398,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   12, 1135,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2149,  640, 2327,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,  613,    1,    1,  441,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1656, 2909,   32, 2597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1159,  455,   26,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  195,    1,  437,  708,    1,    9,  103,\n",
      "          389,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3226, 2802, 1631,    1,   32,   38,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3048, 2818,    1,  191,  219,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   56, 2572,  187, 2909,    1, 1632,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 1771,  171,    1,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1841, 1207,   37,  764,  215, 3102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  129,  922, 2677,  384,  166, 1283, 1074,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1268,  449,  395,    1,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,   12,    1,  952,  148,  647,  484,  191,  439, 1352,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151,  154,    1, 2308,  565,  320, 1533, 1979,    1,  284, 2047,\n",
      "         1756,  167,  915,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3253,  765, 1159,    1,    1, 2033,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800, 2226,  190, 1403,  166, 3098, 3098, 1890,   81,   37,  902,\n",
      "            1,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  859,    1, 2196,    9, 1821, 1697,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1,    1,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  428, 1002, 2275,  113,  803,  631,  297,   10,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1398,  612,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,    1,  335,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  526,  528,  839,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2673,    1,  103,   45, 2521,  187,    1,   12,  590,    1,  738,\n",
      "          395,   12, 2153,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3239,  114,    1, 3301,  548, 1056,    1,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   11, 2771,    1,   61,  105, 1090,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3025,  215,  321,  612, 1761,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   36, 3071, 1683,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,   37, 1075,  906,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,   98, 2751,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  433,   15,  245,   32,  871,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,    1,    1, 2169,    1,  967, 1846, 2445,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2741,  979,  913,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  705,    1,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   61,  224, 1542,   37,    1,    1, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2451, 2058, 1483, 3115,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3116, 1911,  581,  901,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  430,  947, 1229,   37,    1, 1384,  710,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  579,  166,   65,  967,   37, 1982,  176,  906,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 3361, 2572,   32, 2596, 1260,   98,  163,    1,   12,    1,\n",
      "         2924,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  654,  138,   79,  400,  744,  105,    1,    9,  104,  681,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,    1,    1,    1,    1, 1139,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   61, 2647, 2861, 1159,  914,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2881,  572,  551,  105,  829,   82,   98,  861,    1, 2086,\n",
      "            1, 2019,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1474, 2153,    1,   32, 3082,  966,  379,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1674,  142,  519,    1,    1,  966,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  187,  651, 2344,  361,    1, 1064,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358, 1536,    9,  467, 1942, 2073,  199,   32,  537,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2708, 2153, 2192,   16,   45, 1945,   32, 3358,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 2560, 1089, 1090,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  716, 3117,  480,    1,    1,    1,    1,    1,  361,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  258,  361,  834, 1013,  565, 1239, 1810,  116, 2264,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777,    1,   28,  395,  285,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 2924, 2856, 3065,    1,  228, 3006,   32,  539,  458,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2084,    1,   32,  365,    1,   66,  187,  837,   45,  887,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183, 2978,    1,  193, 1610,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2331, 3281,  315,  411,  439,   37, 1684, 2107,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1249,    1,   37,  726,   32, 2445,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,  325, 1117, 1525, 1013,  669,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1444,    1,  384, 1675,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1709,    1,   98, 1506,    1,    1, 1393,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,    1,    1,    1, 1194,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3371,  830,    1,   98,  854, 2237,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129,  922, 2246, 3271, 2651, 1110,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1652,   37, 1599,   26, 1039, 1228,  220, 2351,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  581,    1, 2498, 1567,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  968,    1,    1,    1, 2234,  881,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9, 2321, 1239,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  790,  113,   79,  432,   45,  365,  503,    1,  195,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861, 1906, 3067,    1,   45, 2292,  444,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2779, 2659,   79,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1, 2873,  815,   37,  120,    1,  191,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  105,  686,  384,    1,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1266,   37,  125,    1,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,  60, 953,  98, 303,   1, 455,  29,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  21,  37,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  619, 1595, 1198,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 2153, 1988,   45,  402,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1038,    1, 2414,  176,  177, 3080,    1,    1,  716,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  319,  539,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  732,   12,  529,    1,   37, 1124,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2069, 1374,    9,  331, 2639,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1009,   37,   84,   85,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2158,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  200, 2355, 1013, 2549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112, 1028,    1,  551,    1,  869, 1512, 1554,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1109,  474,  488,  477, 1010,    1,  122,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,   12,    1,    1, 2909, 1096,   98,    1,    1, 1484,    9,\n",
      "         1994, 2095, 1259,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3381,  437,  396,    1, 1260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1085,  420,    1,    4,   29,    1,   60,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1584,  166, 3177, 1015, 1174,  176, 1178,  163,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  854,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  453,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213, 1041,    9,  247,    1,    1,  190,  193, 1377,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   94,    1, 1315,    1, 1714,  115,   45,  517, 1953,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2977,  267,    1,  894,    1,  510,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2579,   37, 2192,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1990,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2269, 2177,   37, 2535,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3297,  696,    1,    1,  100, 1515,  823,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  991,   22,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1128, 1713, 3044, 2232,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1165, 2291,   32, 1531, 2414,  786,    1,    1, 2803,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1353,    1,    1,   45,    1, 2758,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1831,  166,  593,   12, 1354,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  726,    1, 2843,  384,  103,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1379,  149,  176,  654, 1380,    1,   32,  105, 1381,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2211,    1, 1342,    1,    9, 1610,  333,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49, 1536,    9,  467,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2494, 2363,   45,  166, 2895, 1976,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3024,   61, 2333,    1,  365,  506, 1770, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3132, 1758,   37,    1,  548, 2148, 3108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1603, 2290,    1,  590, 2537,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,   82, 2855,    1,  275,  736,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  702,   37,  130,  169,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1106, 2188,  220,    1,    9,  920,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1220, 1167,  957,   38,  297, 2417,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2, 189,   1,  37, 168, 202,  28,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 554, 187, 347, 701,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1465, 1466,  597,   82, 1231,  220, 2154,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   59, 2198, 1021,  187,  666,  868,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  669, 2055,   28,  105, 1787,   37,  224,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   71,   98,  198,   14,   15,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  565,    1,  384, 1737,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2295, 2757,  200,    1,  469,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3383, 1656, 2596, 2766, 1700,  163,    1,   12,    1, 2548,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 2379,    1,  907,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   15,  187,    1, 1413,   32,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2813,  810,  166,  454,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1294,    1,  187,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  884, 1617,   12,  581,  671,  220,    1,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232,  664, 1277,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1032,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  191,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   59, 1197,  297,    1,   32,   15,   37,  622,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3143, 3328,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1570,  338,  548,  800,  570,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492,    1,  191, 1300, 2162,    1,  384, 3348,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1007,    1,   37,  151,    1,   12, 2688,   50,    9, 1417,   59,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  104,  506,    1,    1,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1458, 3306,   37,  865,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3108, 1827,    1, 2582,  119,  548,  810, 1292,  271,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  884, 2187,    1, 1765, 1211, 2256,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,   91,  176, 2413,   98, 1649,    1,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  104, 1458,  198,   60,    1,   21,  649,    1,  652,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 2069,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3380,   12,  809,   98, 1256,  551, 2196, 1836,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  567,    1,  537, 2248,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1797,   20, 2328,    1,    9,    1,  892,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,  681, 1776, 1089, 1994, 2086, 1017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3129, 3210,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  571,   37, 2857,   12, 1717,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 361,   1,   1, 223,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 854, 190, 693,  37,   1, 260,  45, 674,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2675, 3275,  176, 1796, 3222, 2052, 2007,   37, 3121,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3155,   61,  778,   45,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  506,   80,   37,    1,   32,  104,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2685,   26,    1,  220, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  531, 1656, 2596, 2414, 1312,   32, 2597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3127,    1, 2770,  220, 2698,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  636,  640,  104,  105,  106,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 3107,  210, 3146,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1700,    1,  105, 1092,    1,    1,  166,  517,    1, 1117,    1,\n",
      "          454,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1759,  309,  954,  897,  118,   32, 2073,  401,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1127,  697,   37, 1636,   32,  104,  220,   54,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2699,    1,    1,   79,  903,    1, 1417,    1,  540,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2628,    1,  140,    1,    1,    1,   32,  105,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  260,   28,    9,  159,   32,  458,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1207,   37,   77,    1, 1208,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   10,  292,    5,    6,    1, 2431,    1, 2127, 2432,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,  141,   48,    9,    1,  131,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1, 2937,    9, 2249, 1527, 1149,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,  102,  529, 1253,   32,  104,  442,  448,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1571, 1831,  958, 1233, 2227,  214,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3349, 2162, 1950,  418,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  782,    1,    1,    1,   32,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  422,    1,   98,  195, 1091,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   37, 1079,  163,    1,   12,    1,   37,    1,  284,    1,\n",
      "            1, 1603,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  348,  353,  242,  737,  197,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843,   12,    1, 2523,  190,  865,   37,  103,   45,  247, 1090,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  386,   12,    1,    1, 1404,   12,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2701,   46,  168,    1, 2056,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1809,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 1107,  293,    1, 2733,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3153, 2745,   37,  619,  247,  916,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  197,  640,    1,   54,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   61,  166, 1011,  293,  166, 2537,  357,  166, 2389,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26, 1039,  911,  289,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  434,    1, 1124,    1,    1,    1, 1014,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2451, 2308,    1,  542, 1231,   32, 1169, 3141, 2811,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  837,  387,   15,   93,   27,  118,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1463,  546, 2673, 3085, 1461,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1053,    1, 1325, 1958,    1,  279, 1294,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,    1,  105, 1031,   45, 1821,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,  675,  125,  617,  259,    1, 1604,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1570,  200,    1,    1, 2367,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  729,   98,  103,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  665,    1, 1046,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1476,  977, 2704,    1, 2591,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2963,  600,    1,  482,  193,   19,   81,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  159,   98,  166, 1314,  187,   69,  636, 1324,  919,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2475,  125,    1,    1,    1,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1731, 2735, 2095,   37,   52,  289,   45,    1, 2531,   46,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1157, 2986, 2816,  365, 3121,    1, 1530,  357, 2249,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  848,   37, 1539,    1, 1892,    1,   32, 1169,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  197,    1,  983,   71,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2912,  571,   37,  631,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,    1,    1,    1,  224,    1, 3005,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   29,  410,   98,  954,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  557,  540,    1,  167,    1, 1316,  539, 2170,    1,  267, 1428,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3006, 2253,   37,    1, 1164,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 1117,    1, 1417,    1,  290,   98,    1,  176,    1,\n",
      "         1229,   37,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  156, 1473,  176,    1,  975,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1, 2274,  210,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3101, 2224,  908,  797,  625,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3209, 1173,   37, 1832,   28, 2522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  810,  294,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2297, 2565,   45,    1, 1437,  872,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  565, 1507,  526, 2104, 2105,   98,  166,  454,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    9, 3228,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2013,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1516,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2899, 1581,  365, 1204,  187, 1300,  669,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1292,  493, 1974,    1,    1,   51,  588,  467,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2473, 2367,   37,    1,  618,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,   61,    1,  746,   12,   80,   44,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   26,  699,  242,  187,   69,  980,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 1013, 1522,   37, 1523,  224,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  342,    1, 1617,  297, 1675,  625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384,  166,    1,    1,   37,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  661,   98,   25,    9,  906,    1,   86,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1034,   32,  231,  105,  402,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1267,  288,    9,    1, 3286,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3188,  162,  411,  168,  115,   37,  698,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2132, 2309, 2208,  775,   32, 1206,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2073,    1,    1,  565, 1542,   37,  943,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1454,  596, 1793, 1560,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081, 1419, 2147, 1260,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  386,  267,  869,    1,  972,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1463, 2030,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3170, 1936, 2214,  992,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305, 2784,  417,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  845,  147, 1392, 2096,  297,    1, 1393,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1797,    1,   45, 3373,    1,  384,  778,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3132,  631,  273,  548,   56, 2799,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1602, 2539, 2800,    1,   75,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2677,  361,  712,    1, 1260, 3132, 1521,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  666, 2865,   39, 1021,    1, 2817,  584,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  108,   45,  197,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2493, 1960,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3358, 2162, 1645, 1190,  267,  590,    1,   37, 3060,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1089, 1090,   13,    1, 1536,    9,  467,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2642,  688, 2722, 3074,   37, 1121, 3231, 1027,    9, 2941,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,    1,  326, 1776,    1,  883, 1017,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2159,    1,    1, 2030,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1568,    1,  162, 1217,   32, 1090,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2227,    1,  182,    1, 2226,    1,  614,    1,    9, 2179,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  656,    1,    1,  861,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147,  398, 1800,  400,  444,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,  688, 3296,    9, 1194,   73,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  220,    1, 3284,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   95,  473,  474,  721,  908,  477,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2883,  947, 1003,   37,    1,  195,  442,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282,  548,  410,  356,    1, 3230, 1042,  247, 2565,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3374, 3384,  928,   32, 3339, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  837,   45,  312,    1,   43,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  405,    1,  942,  140,   32, 2138,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2748,  167,  729, 1296,   28, 1030,  756,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   71,  187,   69,  636, 1276,  548,  510,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  356, 1691, 2572,   32, 3339,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  593,  954,  176,  629, 1232,   69,  102, 2449,  845, 1929,  721,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,   11, 2495, 1935, 2308,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  365, 1046,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  142,    1, 2100,    1,   32, 1256,  551, 2196,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,  476,  147,   37,  125,  138,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  872, 2090,  267, 1384,  533, 1360,  612,    1, 1990,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1247,   37,  698,    9, 3132,   98, 1517,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1580,   50,    1,  844,  423,    1,  317,  197,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  387,    1,   45, 1064,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  288,   37,   26,  242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  892,    1,  600,  121,    1,  481,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1144,   37,    1,   28,    1,   67,  696,    1,    1,   37,    1,\n",
      "           32,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1795, 2279,  872,   32,    1, 1259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 3164, 1764, 1990, 1632,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  645,    1,  550,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  403,  464,  535,  720,    1,  650, 1684,    1, 2122,    1,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3321,   32,    1, 1247,   39,  176, 3229,    9, 2807,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  982,   37,  130,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,    1,  746,   32, 1766, 1767,    1, 1259,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  761,  108,   98,    1,  195,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2725,    1,    1, 3021,  190,   77, 3126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2153,  907,    1,    1,  442,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  835, 1228,  934,  330, 2549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,  37, 151,   1, 669,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  75,  37, 100,  98,   1,   1, 725,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  755,    1,  282, 2264,  220,  365,    1, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,  315,   37, 2000,    1,  453,  568,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1861, 2329,   37,    1, 2789,  115,   45,  863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3226, 3240,   81,   32,  166, 2340,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  936, 1711,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  297, 2102,  102,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,  288,   37,  619,  388,  487,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  721, 1579, 1417,  152,   32,  394,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3292, 1452,  548, 2667, 3021,    1,    1,   12,    1,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2712,    9, 2627,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2611, 2135,  191, 1089, 2382,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  622,   37,  619,  449, 3348,    1,  420,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  845, 3146, 2530,  288,   39,   37,  726,  166,    1, 2015,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   25, 2035,  317,  863,  186,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  691,    1,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98, 1638,    1, 2927,   37,  163,    1,   12,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2322,  190,   52, 1183,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  341,  166,   64,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326, 3007,  593, 1659, 1222,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790, 1579,  365,    1,  505,  195,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3126, 1293,   32, 2944,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861,    9, 2826, 2133,    1, 1676,  750, 1190,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2286, 2177,   37,    1,  166,  636, 2928,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   31,  338,  981, 1315,  837,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   98, 1021,   37,  166,  249,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340,    1,  590,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  503,   12,  790,  211,    1,  761,   12, 2537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  190,  856,  217,  331,  798,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 3400,  619, 1890,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2122,    9, 3365,  949,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  657, 1614,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  469,  562,  705,   37,    1,  284,  531,  734,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3079, 1421, 1415,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1024,  221,   37, 2615,  680, 1665,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1, 1159,  166,    1,   45,  166, 3356, 2426,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  116,  378,   32, 2823, 2107,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3358,   32, 1328, 3137,    1, 1407,    1, 2684,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1550, 2343,   98, 3136,  477,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3330,  140,  247, 2674,   73,  698,  187, 3260,  688, 3234,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183, 2960, 2668, 3343, 1633,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  593, 2153,   81, 1147,  863,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,  245,  187,  275,    8,   53,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   10, 1426,   39,   37,    1,  176, 2630,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2879, 2946, 1929, 1086,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  251,  638, 1516,   37,    1,    1,    1,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  313, 1437,    1,  956, 1010, 1355,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3230,   37, 2192, 2468,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  146,   98, 3163,  872,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3232,    1, 3234,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1409,    1,  803,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  159, 1253,   98,  104, 2568,    1, 2054,  496,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  267,  861,    1,   32, 3118,    1,  591, 1604,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3171,    1, 1953,  220, 2615,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,  682,    1,    1,   79,   69,    1,  671,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2569,  195,    1,    1,   37,  163,    1,   12,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1173,   37,    1,  548,    1,  140,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  342,  213,   37, 1198,  976,  909,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  218,    1,  365,  433,  102,   28, 1114,   32,  367,    1,\n",
      "          267,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2352,    1, 2735,  695,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 1537,    1,  277,  486,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  979,    1,   37, 2449,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1663, 1107,  293,  437,  794, 2086,  767,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2737,    1,    1,  608,  396,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066,   51,   52, 1542,   37, 1343,  424, 1981,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2050,  902,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1550, 1094,  132,    1, 3397,   12,  865,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   91,  140, 1477, 1990,  191,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,  300,  388, 2924,   37,  557,  540,   32,    1,    9,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  219,    1,   37,  927, 2918,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,  261,   80,  193,    1,   37,  171,  261,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  986,    9, 3236, 1838,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,  361,  326,   37,  332, 1151, 1017,    9,  547,  388,  537,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428,  782,  590, 2673, 2596,  210,   32,  864,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,  386, 1408, 2878,  252,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  449, 1173, 2124,    1,    1,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2871,    1,    1, 1110,  498,   37, 1145,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  245, 1086,    1,  907,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  794,   22, 2262,   98, 3155,    1, 1527, 2664,   12, 3125,\n",
      "         2192,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2265, 1860, 1273,  618,    9,  547, 2074,   32, 1313,  176,  845,\n",
      "          408,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1786, 2358,    1, 1268, 1099, 2281,  927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2994, 1148,   37,  877,  777, 1488,    9,  810,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1436, 2908,    9,    1,   98, 1602, 2539, 2800,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  365, 1102,  931,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1017, 2005,  529, 2727,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  647,    1,    1,  213,  148,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  612,  717,    1, 1200,   32, 1259,   98, 1842,   50,   48,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2547,    1,    1, 3047,   32, 2752,  297, 1981,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  657,  952,  808,   32, 2657,   45,  166, 1411,  116,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  103,   60,    9,    1,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2746,  774, 1444, 2233,    1, 1063,  808,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1189,  650,  261,   39, 2199,   32, 3107, 3366,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  338, 1139,   32, 2138,  354,   37, 2142,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  864,  387,  803,  916,   45, 1428,  996,  909,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2107, 1336,  927, 1668,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1645, 2924, 1866,   37,    1,  557,  540,  555,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  959, 1211,   98,  617,  618,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1307,  259,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938,  741,    1, 2072, 2275,    1, 2737,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,    1, 1827,  803,  615,   39,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885,    1, 3258, 1863,   45,  166,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1481,  738,    1, 1292,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2472,    1, 2562, 2317, 1175,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   91, 1827,  984,  191, 2869, 1089,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  267,    1,  600,    1,   32,  463, 1430,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  729,  476,  342,  399,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   52,    1, 1159, 1003, 1841,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  155,  983,  570,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971, 1346, 1140,   79, 1604,    1,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1,  220,  639,  288,   28,   37, 1527, 3375,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2114, 2925, 1517,    1, 1034,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  870,  148,    1, 1682,  176,  647,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  458,    1,    1,    4,   37,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  356,  611, 2113, 2156,    9,    1,  446,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  889,  679,  408,   76,   37,  103,    1,   98, 1738,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3369,   12, 3118, 2219,  763,  531,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1216,    1,    9, 2614,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2551,    1,    1,  951,    1, 1779,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69, 1298, 1382,  548,    1,   98,  104,  109,  276,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3231,    1, 2642,    1, 2799,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1717,    1,    1, 2840,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  680,  166,    1,   45,    1, 1340,  571,  754,   37, 1198,  247,\n",
      "         1239,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3087, 2668, 1081,   12,    1,    1,  786, 1530,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  354,   45,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700, 1865,    1, 2655,   45,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 1419, 2355, 1013, 2750,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  874,    1,    1,  875,    1,  768,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  636,  125, 1391,  858, 1523,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1824, 2826,   74,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 3027,   76,   37,    1,  284,    1,   29,  528,  298,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  267, 2334, 1631,  846,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,    1,   98,  148, 2706,   15,   85,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1087, 1042,  315,   37,  665,    1, 1017, 1159, 1087,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,  672,  118,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  910,  703,   37,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2445, 3109, 1056,   32,  994,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  293,    1, 1498,    1,   28, 1994, 2086,  856,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1366, 2233,   38,  297, 3377,   37, 1529,   45, 3025,    1,  108,\n",
      "         3353,  437,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  964, 1408,  460, 2306,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1256, 1256,  267,    1,  195,   51,  423, 2725,  505,  629,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1576, 1670,  132,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1375,  295,   37,  125,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,   12, 1126,  636,  288,  176,   63,  714,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2754,  750, 1190,  267, 2754, 2924,  894, 1910,  531,  176,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3324, 1401,    1, 3154,  191,  547,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374, 3352, 1207,  388, 1450,   98, 1094,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2838,   37, 1343,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  818,  157,    1,    9,  773,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,  163,    1,   12,    1, 2479,  166,  671,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2192, 2349,   81, 2310,  663,    1, 3378,   90,  146,  147,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101, 2548, 2856, 2708,   32,  539,  458, 2625,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  372,    1,   48,    9,  333,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  132,    9,    1,  604,   50,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280,    1,   81,   37,  726,   32,  365, 1788,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3218,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204, 2257,   39,   45, 2197, 3329,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  375, 1401, 3285,   37,    1,  726,  297, 3323,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  294,    1,  571,   37,  197,   32,  572,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,  872,  387,   93,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  548,    1,    1,   26,   37,  810,    1,    1, 3011,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  396, 3358,    1,   45, 2141,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  289,   98,  531,   32,  378,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1002, 1132,  661,   25,  317,  863,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2078,   32,  786,   74,    9,    1, 2334,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1544, 1813, 1823,  361, 3179,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,  321,  612,  804,   39,   69, 1069,    6,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  447,    1, 2468,    1, 1689,    1, 2791,  469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  615,  672,  166, 1285,   45,    1,  166, 1868, 1172,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1216,    1, 3114,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3270, 2745,  528, 2249, 1383,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  305,  470,  699,   98,   69,  805,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1430, 3109, 2764, 2765, 2985,    1,    1, 2147, 1260,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  654,  721,  313,   37, 1000,  365,   82,  191, 1014,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1471, 1149, 1267,  365,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  627,   61,  920,  104, 1579,    1, 1151, 1167, 1898,   37,  223,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228,  342, 1726, 1508,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  313,    9,    1,    1,  846,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  317,    1,    1,  408, 3199,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  155, 1184,  347,   37, 1664,   31,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  102, 1473,  548, 2950,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1818,  147,   37, 1709, 1842,    1,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  444, 2643,    1,    1,  460,   12,  193,   32,  931,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  160, 1161,  418, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   60, 1308,   37,  365,  687,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  656,   37,  317,  449, 2895, 2655,   29,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 1940,   12,  238,    1, 3154,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3166,    1,   79,   37,  105, 2056,  698,    1,  140, 3023,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  169,  614,   37, 1478,  439,   37,   92,  777,  778,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962, 1024,  542, 2685,  187, 2142, 2418,  832,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1111,   98,  157,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1070,  579,  190,   52, 1411,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1,    1, 2522,  190,   52,  547,   41,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 2161,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3250, 3276,    1,   37,  166, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  215,    1, 1031,  453, 2653,  361,    1,   91,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,   37, 1527,    1, 2778,   32,  531,  863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  459,  365, 3187, 2800, 1218,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2547,    1,   37,    1,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  433, 2424,  302,    1,  207, 2441, 2852,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,    1,    1,  297, 1783,  589,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,  45,   1, 565,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 121,  12, 964,   1, 600, 531, 863,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,   37,    1, 1994,  195, 1896,   32, 2883,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1924,  786,   45,  166,  227,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  163,    1,  640,  207,    1,  949, 2306,   32,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 1065, 1190,   37,  588,  863,    1,  384, 1428,  475,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2751, 1260, 3149,  947, 2190,    1, 2006,  249, 2572,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2225, 1991,   37,   97,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1051,    1,  829, 2123, 2348,    1,  220, 1872,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  139, 1658, 1944,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    6,  132,  220,  183, 1379,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1568, 2247,    1,   59,  754,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,   98, 1171,   37,  907, 1698,  356,  197,  739,  159,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  794,    1,  776,  777,  778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 3213, 1041,    9, 1691,    1, 2001,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   87,    1,    1,    1, 1158,   12,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  422, 1093,  574,    1, 1822,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1717, 2920,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3115,  606,  612,    1,  405,    1,    1,  202,  483, 1188,  284,\n",
      "            1,  428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1268,  400,  444,  455,    1,   32,  667,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2292,    1,   32, 1815,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 2332, 1648,   37,    1,  164, 1333,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 1937,    1, 1662,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2774, 2153,   37, 2237,  854,    9, 2024,   46,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  964, 1450,  539,   12, 3367, 1427, 2146,    1,    1,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1096,   37,  168, 1425,   32, 1602, 2539,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  105, 1302,   32,  166,  821, 1681,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,  713,    9,  257,    1, 1608,    1,   28, 3079,\n",
      "          384,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777,    1,  326, 2274,   32,    1,    1, 3031,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1254, 1178,  418,  384,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2561,   32,  166, 2454,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,  245,    9,  284,  183, 1008,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788,    1,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,   45,    1,    1,  191,    1,  487,  358,  541,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  550,  420,    1, 2501,  861,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,   37, 1119,  289,  384,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1982, 1610, 2823, 1844,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2860,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  147,  400,    1,  224,  361,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2193,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2104,  475, 1550,    1,  600,    1,   98,    1,    5,  571,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  167,  619,    1,  671, 2007,   37,  413,   12, 1894, 1463,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1283, 2925,   90, 3200, 2236,   37, 2553,   39,   56,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,   51,    1,   98,  574,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1064, 3042,  161,    1,  755,   81,   98,  721,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3270, 1103,  168,    9,  460,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1259,  395,    1,    1,    1,  310, 1443,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2597,   12,  104, 2060,    1,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2637,  835, 1479,    1, 1273,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 2554,   39,    1, 2836,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  667, 2153, 2905,    9, 1352, 1002,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1013, 1522,    1, 1381,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 2946,   45,    1, 1976,   32,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1249, 3257, 2337, 3253,  801,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  770,   45,    1,    1, 1976,   32, 3360,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  565,  972,   37, 1083,   11,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,  640,  339,  340,  444,   94,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622, 1942,   23, 1921,   32, 3118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   25, 1296,   79,   69, 1251,  509,   37,  186,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2693, 1450, 1307,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1457, 2182, 2216,    9, 1817,    1, 2079,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1, 1790,  345,   98,  777, 1085,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   65,  697,   37, 1083,  347,   72,  199,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  364, 2954,  220,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  764,  384,  530, 1253, 2055, 1497,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2528,   45,  596, 2691, 1388,    9,  987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,    1,  647,    1,    9,    1,  693, 1757,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  650,    1,  449, 2237,   37, 1815,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   61, 1167,  105,  535,  656,  327,  357, 1018,  439, 2601,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,  653,   39,   32,    1,  472, 1343,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428,    1,  330,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1019, 1675,    1,    1,  361,  810,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,   98, 3351,    1,   12, 1623,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2906, 1774,   37, 2800,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1133,  342, 1145,    9, 2707, 2824,   45,    1, 1908,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273, 1219,  105, 2124,   32,  567,    1,    1,  154,  774,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1405, 1988, 2492, 1997, 1991,   37, 1463, 1994, 2095, 1506,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200, 1663,  517,  617,  259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2597, 2137, 2856, 3128, 2770,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  446, 2216,  163,    1,   12,    1, 1572, 1414,    1,    9,\n",
      "         2891,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,    1, 1910,  176,  177, 1530,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1002,    1,  275,  315,  565,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3276,  619,  119,  726,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2140,    1,    1,    1, 1662, 1292, 1492,    1,    9, 1009,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2802, 1258,    1, 1844,   98,    1, 1105,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1023, 1204,  949,    1,    1, 1169,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2877,  267,    1, 1414,    1,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2265, 3365, 1683,   32,  531,  924,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2496,   45, 3070, 2095, 2372, 2449,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2117,  859,   37, 1124, 2756,    1,   32, 3118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3052,  186,  444, 2095,    1,    1, 1530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810,  632,    1,   32, 2106, 1990, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  861,    9,  116, 2264,    1,  800,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2474,    1, 1273,  786,   32,   46,    9, 1832,   28,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,   28,  419,    1,  679,   69, 1588,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2132, 1164,  261,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1117, 1510,  535,  656,  327,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968,  782, 2848,  265,   45, 2821,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1817,    1, 1818,  147, 1380,    1,   98, 2661,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,  625,  884, 1601,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321,  391,  371, 2436,  105, 1488,  627,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   46,   37,  439, 1345,   32, 2597,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790,    1,  437, 1261,    1, 1987,   32,    1, 1916,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  190,  424,  712,   28,  260, 1604,    9,  334,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197, 1249,  739,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2518,  513,    1,   37, 1995,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1583,  476,  352,   29,   98, 1610, 1601,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1257, 1572,  437,   51, 1706,    1,    1,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2877, 1479,  622,  522,   32, 3391, 1954,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   32,  574,  287, 2160,   28, 1140,    1,  615,  686,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2283,   12, 1123, 2246,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98,  166,  917, 1438,   37, 3098,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  108,   45, 1718,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1090,  494,    1,    1,    1,  636,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2632,   32,  105,    1, 1731,  114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2707,   98,  811,    1, 2521,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  104, 1414,   37, 1096,    9, 2891,   45,    1,    1,  267,\n",
      "         2877,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  386,    1,  562,   37,  125,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  350,    1,  162,  620, 2887,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2925, 1675,   98,  844,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2754,  446, 2450,   46,   98,  531,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  348,   37,   47,   48,   32,  596,  486,   50,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  327,  313,   37, 2277,  220, 2800,  542,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1043, 1042,  118,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  651,  279, 2876,   37,    1, 2800,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2559, 1822,  804,   98, 1227, 1994, 2143,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3010,    1, 2671,    1,    1,  928,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2457, 1370,   45, 3209,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,  163,    1,   12,    1,  232, 1231,  220,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1181, 2384, 1199, 1101, 1102,  931,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  853,    1, 2797,   98, 2500, 2485,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1, 1750,    1, 2918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,    1,    1,  986,   79,  183,    9, 2954,    1,  187,\n",
      "         3190,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3143,    1,    1,  357,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  439,   45,  166,    1,   61,    1,  104,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,   37, 2225, 2309,   37,  631, 1580, 2358,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1709, 3240, 1377,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,   25,  504,  159,   45,  381,    1,  458,   45,  507, 1758,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884, 3192,  844,  663,  856,   37, 1818,  147,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  727,    1,    1,  444,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1364, 1365, 2963,  297,    1, 1013,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   60, 1784,    1,  202,  311, 1001,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2437,  202,  213,  365,  132,  220, 1326,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 1910, 1652, 1201,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  457,    1,    1,  619,  105,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3061,    1,  191,  645, 1899,  695,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2476, 2249,   32, 3360,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 1011,   25,  410,   98,    1,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  503,  852,   37,  627,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1024,   12,  872,   32,    1, 2027, 1345,   81,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870, 1353,  535,  656,  327, 2340,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  777,    1,    1,   32,  104, 2456,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 1998,    1,  453,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1236, 2764, 2765,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   89,   37, 2449,  187,  684, 2541,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2517,  342,  361,  864, 1980,   37,  759, 2673,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,   12,  954,  897,  191,    1,  118,   32,   72,  401,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  396, 2334,  846,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  744,  863, 2306,  202,  555,  488, 1002,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  102,  190,   77,  383,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3298,  140,  449, 2760,  176, 2620,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  680, 2579,  927,    9, 1791, 1995,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159,    1,   98,    1,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  647,   12,  648,    1,  600,  148,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 3103, 2565,    1, 2245,  872,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  179,   12,  205,  180,  132, 2612,   98,  613, 1565,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3225,  114,    1,   88,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  964, 2598,   37, 3367,    9,    1,   37, 1919, 1009,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1867,   16, 1902,    1,   45,  985, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 161,   1, 162, 163,   1,  12,   1, 164, 165, 132,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 365,   1,  98, 207,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 1361,    1, 1647,   98,    1, 3004,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  786, 1178,   16,    1, 2137,   56,  608,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1447, 1484,   10, 2179,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  865,   45, 1938, 2607,  382,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1326,    1,    1,  207,  197,   28,    1,  118,   37,  686,  119,\n",
      "          845,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  358,  359,  774, 1384,   46,  271,   85,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 732,   6, 734, 220,  35, 333,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 491, 167, 319,   1, 393,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2563,    1,  972,   39,    9, 1056,   37,   56, 2119,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3330,  313,    9, 3260,  449, 2522,  726,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  580,  581,    1,  582,   98,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   25,   37, 1075,   98, 1837,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3343, 3389,    1,  104, 1697, 2393,    1,    1,  191, 2266,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  315, 1506,  444,    1,  293,   32,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  657, 1008,  356, 2469,  187,  453,  449,    1,    1,   82,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  446,   32, 1656,  298,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1861, 2405,   37,  104,  680, 1239,   97,   37, 2346,    1, 1521,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  183,  176,  656,    9, 3120,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 3328,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,  794,    1,  259,  512, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  385,   14,   15,   28,  191,    1,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1024, 2437,  384,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  116, 2542, 1654,  218,  332,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 2548,  437,    1,    1,  220,    1, 2162,  149,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1534,   98,  581,  851, 1458, 2095, 2047,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1457,   45,    1,  741, 1458, 1459,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  136,  253,   81, 1499,  297,    1, 1816,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  565, 1366,  255, 1935,    1,    1, 1452, 1232, 1366, 1398,  612,\n",
      "         1075,    1, 1160,    1,  150,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1521, 2762,    1, 1778, 2261,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1061,    1,    1, 2083,    1, 1218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  428, 3006, 1799, 2095,  220,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  478, 1177,    1,   91,    1, 2705,   32,  447,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,  839,    1,    1, 2608,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437, 1070,   37, 1313,   32, 1619, 2578,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  674,   45,  104,  233,    1,   98,    1,   45, 2177,    1,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,  159, 1269,   98,  236,  237,  354,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   65,  475, 2478,  616,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2047,   61,    1,  191,  770, 2829,    1,  506,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   32, 1769,  199,    1,    1,   85,  689,   45,  389,   93,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2596, 2414,    1,  356,  548, 2343, 2555,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1107,  525, 3049,  103,   59,    1,    1, 1158,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  794,  365, 1230,    1, 2528,  361,  163, 1442,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  975,  197,  388,  763, 1660,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2916, 1003,   37, 2075,   81,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  217,  875,   32, 2299,  927,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2380,    1, 1976,   32,    1, 1167,    1,   69, 1159,    1,\n",
      "         2203,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1149,  856, 1628,  341,   37, 2192, 1527,   37,   64,    1, 2140,\n",
      "         1530,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1474,    1,    1,  317,  443,    1, 1527,    9,  531,  104, 1592,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1454,    1,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2476,    1,  191, 1412, 2530,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2003,    1,  400, 2762,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  443,   45, 1886,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3330, 2352, 3260,    1,  693,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095, 2181,  361, 3088,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  657, 1475, 2403,  102,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   81,   32,  166,  104,   37,  582,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1695,  294,   61,  972, 2466,  233, 2409,   32,  584,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  575,  576,  577,  578,   98,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2547, 1611, 1688,   98, 1095,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  716,   16,  105,  410, 1470,   45,  954,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2415,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,  188,    1,   32,  105,  365,    1,   45, 1973, 1945,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  655,   32, 2275,    1,  583,   32,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  526,  187,   69,  640,  885,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1292, 1021,  120,    9,  853,  538, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2987, 2988,    1,    1,  111,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3209, 2286,   37, 2935, 1194,   73, 1131, 1684,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  446, 1454,  174,    5,  672, 2824,  673,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1744,  344, 3035,   39, 1221,    1, 2178,  947, 1152,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1631,    1,    1,  190, 1306, 2069, 3192, 1463,  444,  854,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  744, 3252,  119,    9, 1477, 1990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203,    1,    1,  368,   37, 1389,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   37,    1,  787,   12,  673,    9,  166,    1,    1, 2295,   96,\n",
      "           37, 1095,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  193,    9,  166,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3327,   37, 2565,  463, 2926,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1831,  315, 2625,   98,  273,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181, 1727,   37, 3092,  297, 3306,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1436,    1,   85,  105,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2171, 3134, 1923,    1, 2486,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  306,    1,  150,  912, 2026,    1,    1, 2039,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  353,  197,   88,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2528,   45,  829,   12,  365,  535,  656,  973,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727, 2055,  840,  593,  259,   37,  575,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2124,   45, 1521,    1, 3002, 1552,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3253,  140,   32,   73,  744, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2751,    1, 1625,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2333, 2630,    1,   37,    1, 2072,  166, 2918, 1821,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  642,  643,   57,   28,  365,  754,   15,   85,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1883,  159, 1253,   98,  420,   45,   46,  220, 2425,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1574,    1,   37, 2252, 3310,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,    1,  776,  891,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   69,   51,  529,  201, 1656,   45,  627,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12, 3137,   61,    1,    1,  716,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  739,  242,  671, 1069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2844,  187, 3374,  475, 3090, 3101,  477,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1983, 1592, 2047, 1582,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  390,  417, 2527, 2116,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3297,  476,    1,   45,  915,  356,   12, 1343,  951,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1704,   37, 1237,  784, 2403,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2753, 1056,    1,   37,  631, 3247,  608, 3248,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   69,  102,   28,  699,  115,   45,   29,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1341,  207, 1042,  118,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3333,    1,    1,    1, 1751,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  311,   12,    1,  251,   37, 1540,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,  395,   12, 1733, 2000, 1789,    1, 2471,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1319,  696, 1966,    1, 2471,  220, 1033, 2211, 2517, 1386,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1465,  220,  166, 1230,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1268,  242,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  794,  365, 1821,    1, 2328,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  439,  242,    1,  374,   81,  530,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186, 1760, 2114,    1,    1,    1,   79, 1861,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   37, 1343,    9,   32,    1, 1090, 3135,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,   25,  276,    1, 1572,  191, 1420,    1,  361,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1538, 2303,   37, 1418,  477,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  872, 2243, 2252, 1351,   37,    1, 1965, 2699,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  321,  544,  388,  763,  415, 2460,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  877,  221,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158,   32,    1,  856,  297, 2102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280,  782,  166, 1691,    1,    9, 1922, 1411,  825,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  936,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  650,  952,    1,  951,    1, 3362,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  297,  932,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1151,    1,  764, 1100,   92,  218,  332,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2681,    1,  770,   45,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  487, 1190,  387,  531,  741,   98, 2462,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   71,  329,    1,   12,  551,  552,  176,  339, 1653,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1404,  267,  312,    1,  967, 1846,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3371,  267, 2018,  476, 2024,  220,  854,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307,  361, 1363,   37,  631,    1,    9, 1273, 2255, 2461,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  288,   37,  698,   98,  577, 1318,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1,    1,   37,    1,   32, 2596, 2716,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2563,  354,   51,   52, 2275,   12,  504,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 1269, 1750,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1,  182,    1,  105,    1, 1974, 3240,    9,  166, 1694,\n",
      "           45,  166,  914,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3005,    1, 1632, 1106,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75, 1579,  196,    1,  170,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  567,  510,  134, 1159,    1,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 1009, 2726, 3040,   98, 1002, 2784,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1024, 1631,    1,  119,  191,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  813, 2743,  236,   12,  245,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3001,    1,  857,    1,   42,    9, 2505,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   75, 2407,    1,    1, 2800,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564,    1,  221,    1,   18,   28,  220,  445,   45,  166,\n",
      "         1001,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  935,  321,  151, 1537,  793,   48,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1759,  309, 2700, 1758,  166,  856,  444,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   68,    1,  679,   69,  288, 2078,   98, 2759, 2250,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    8,  116, 2542,  861,  328,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,   37,   17, 1807,  112,  187,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,   51, 1046,  182,  388,   32,    5,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 3251,  190,    1,  221,  463,   37,  316,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2476, 1414, 2596, 3155,    1, 1523, 3045,   32, 2597,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1965, 2982, 2699,  879,  220,  365,  569,    1,  365, 1799,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  588,   37,    1,  596, 1793,  187,  105,  663, 1816,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1440, 1109,   98, 2187, 1045,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3198,    1,  915,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,    1,    1, 1980,   37,  759,  442, 1259,    1, 1757,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1237, 1658, 1117, 1525,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  459,   28,    9, 1832,   28,  220, 1537,  681,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485,  160,  102, 1672,   32,  367,  187,   69,  102,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  814,  733, 1131,   37,    1,    9,  331,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,    1,    1,  220, 1343,  175, 2665,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  632,  232, 1243, 1147,  734,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713,  777, 1525, 2329,  220,  365, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  262,  263,  737,  420, 1961,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1042,  149,  444,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2141,   27,    1,  402,   32,  854,    1,  395,    1,  121,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885,  567,    1, 1316,  465,  584,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3359, 2431,    1, 2708,  171,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2609,    9,  166,  307,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,  361,    1,   28,   98,  166,  207,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  459,  132,  220, 1181,  725,   37, 1978,   12,    1,  464,\n",
      "          218,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   51,  764,  877,    1,   41,  506,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  420, 1004,    1,  652,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3172,  695, 1564, 2805,  683,  105, 2800, 1292, 2198,  105,  872,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2777,  884,   95,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1110, 1621,  427,  726, 2300,  384,  915,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,  656, 1267,  187,  654,  776,    1,   98,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1081,   12,    1, 2908,    1,  108,   98, 2095,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3037, 1523,    1,   98,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    9, 1128,  361, 1100,    1,  105,    1, 2360,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,  441,  726,   32,  147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1289,   59,   37, 2638, 2135,    1,   92, 1841,    1,  191,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203,  596, 1793,  321,  631,   37,  105,  183,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1855,  446,    1,  342,  379,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2743,    1, 1159,  248,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  799,  488, 1817,    1,    1,  510, 2097, 1739,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2576,  439,   45, 1018, 1015,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  755, 1564,    1, 2812,   37, 2798, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236, 1022,    1,  157, 1571,  218,  220,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  183, 1585,    1,    1, 1324,  898,   32,  903,    1, 1447,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  267,   51,  606,    1, 3086, 2924,   32, 3114,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1708,   85,   37,  166,    1,   32, 3144,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  727,    1, 1304, 1079,  147,   37,  222,   75,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  202,    1,    1,  334, 2518,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2395,    1,   45, 3095,   37,  166, 2162,   45,    1, 3358,  361,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3290,    1,   39,    9,  914,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  602,    1,    1, 3098,   32, 2890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  293,    1,  596, 1793, 1245,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  636,  120,  682,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1, 1054, 2376, 2223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2304,  272,    1,    9, 3247,  444, 3323,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  894, 2192, 3188,  166,  873,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 2261,  220,  365,    1,  279,  861, 1151,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  954,    1,  810,  566,   98,  104,    4,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2468,  632, 3162, 1976,   32, 3387, 2108,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2614, 1210,   37,  439, 2522,   63, 3175, 2160,   28,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  365, 2240,   32, 2218,   45, 1223,    1,  220,  166, 2024,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1498, 1099, 1453,  967, 2298,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3198,  361,    1,  759,  581, 1385,   32,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2232,    1,  191, 2508,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  397,    1,    1,   98,  104,  532,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 1564, 1647, 2029,  999, 2723, 2724, 1935, 2308,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  715,  673,  448,  703,   32,  449, 1023,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2841,  375,  884, 3119, 2148,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,   1, 131,   1, 142, 328,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 374,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1084,    1,  716,  242,  572,  207,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   60,  765,   32, 2091, 2320,  444, 1479,    1,   32,  310,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2770,  121,  528,  649,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3300,    1,   39,  220, 2961,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  657, 1660,  158,    1, 1353,  752,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796, 1975,  921,  529,    1, 1638,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  914,   98,  166,    1, 1478,    1,   32, 1684, 1090,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3203, 1401,    1,  229, 1787,  191,  786,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   98,  424, 2539,    1,  247, 1677, 1924,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   28,  384, 1034,  687,   98,  163,    1,   12,    1,  341,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 1066,   79, 1067,    1,   50,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,  331,   32,  390,   32,  401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  837, 2509, 2007, 1371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1,  657,  439, 2336, 1151, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1474,   96,   37, 1718,    9,  845,  439,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2489,   85,  861,  997,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1035,  162,  365,  228,  356,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  840,  980,  187,  218,  566,   65,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1465, 2693,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  202,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  321,  635,   12,   71,   37,  166, 1787,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37, 1537,  872,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,    1,  315,    1,  202,  590,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1877,  856,   98,  645,  768,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,    1, 2134,    1,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  626,  408,    1,  954,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2962, 3108, 2341,   72,   73, 2764, 1619, 1684,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   51,  810,   18,   85,   37,  166, 2910,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564,  183,    1,    9,  730, 2614,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  602,    1,    6,  297,    1,  382,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181,    1,    1, 2250,   32,    1, 1545,  140,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  567, 1527,    1, 2977,    1,  977,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  612,    1, 1046,    1,  187,  914,  431,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1851, 1428, 2635, 1159,    1, 2445, 3293,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,   37,  123,   56,    1,  508, 2152,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  443,    1, 2643, 1940,   32,    1,  606, 1846,    1,\n",
      "         1159,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  961,    1, 2104,  884,   98,    1,   45,  116,  259,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1821, 2057,  293,  884,   79,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2924,  288,    9, 1104,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2868,    1,  403, 1447, 1220,   98,   46,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2806,    1, 2460,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3172, 1090, 1829, 2906,  951,    1, 2388,  171,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  282,    1,   28, 2759, 1208,    1, 1519, 1525,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  121,  852,    9, 1389,   45,  851, 2421,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1194, 2132, 2388, 1993,  608,  590,    1, 3110,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3141,  590,  315,   37, 1031,  402, 1333,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1046,   79,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2747, 2325,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  726,  515,    1,  227, 1333,  176,  105, 2771,    1,    1,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  636, 1806,   51, 1251,   69,  681,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,    1,   37, 1403, 1011,   32,  539, 3118,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1386,    1,   37, 1583,  625,  528, 2357,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,    1,   34,   10,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018, 1273,  259,  681,    1,    9,    1,   28, 1220,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2959, 2712,    1, 1367,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,   46,  220,  593,  458,  297, 3339,  548, 2271,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296,  387,  183, 1220,    9, 1797, 1497,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   26, 1039, 1117, 1525, 1873,    1, 1713,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,  830,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2275,    1,   10,  469,   37,  480, 2924,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   37,    1,  704,    1, 1751, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  171,  729, 2198,  105, 2696, 1056, 2119,  548,  806,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 1676,  336,    1, 1220,    1,  361,  851,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,  587,  565,    1, 1979,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3385,   37, 2000,   12,    1, 2571, 2673, 1655, 1411, 1034,  420,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2,  25, 577,  57,  29,   1, 236, 237,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  12, 197, 418,  98,  69, 605,   1,   1, 328,   1,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  463,  310,    1,   37,  429,    7,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2028, 1679,    1, 3091,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3173, 1086, 3168,   12,  356,  439,  590,    1,  142,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  166,  914,   37,   52,    1,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  804, 2101,  786,   52,    1,   37, 1154, 2398,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  867,    1,  552,   37,  552,   43,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  492,    1, 1492,    1,    1, 1919,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1149, 2572,   32,    1, 1325,  434, 1686,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1774,   39,  340,  439,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1518,  573,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  686, 2041,  187,  493,  102,  554,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2692,  105, 1822,  606,    9,    1,    1, 2177, 1331, 2691,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1613,  353,  197,    1,    1,  308,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3117,  599,    1,    9,  380, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,  724, 2793,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,  606,    1, 2088,  230,    1, 1592,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  935,  794, 1808, 1895,  541,   37,  691,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3103, 3228, 2052,  191,  567,  799,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1007,    1,  105,    1, 1325,    1,   26,  548,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  176,    1, 2452, 1173,    1,  361,    1,  187,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  952, 1876,    9,  673,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  361,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190, 2580,  328, 2192,    1,  105,   92,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  225,  809,  103,  275,    1, 1638,  176, 2466, 1209,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1163,   12, 2073,  401,  156, 1253,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  316,  317,  603,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424,    1, 1126,  967,  105,    1, 1551,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  571,  220,  365, 1107, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,   37, 2192, 2017, 2680,   37,  893,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3120, 2712, 3268,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  727,  613,   37,  151,    1,  728,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1373,   37,    1,  187,   64, 1552,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 2124,   45,  383, 1979,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  750, 1408, 2206, 2207,   32,   44,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160, 1278, 2126,  526,   32,  367,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428,  476, 3369, 2024,  132,  191,  439,   45,  356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282, 3198,  140, 2936, 3329,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  284,  458,    1,    1,   98, 1047, 1638,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 2549, 1353,   98, 1331, 1017,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  459,   45,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  387,  265,   45, 1032,    1,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  790, 1579,  815,   45,    1,    1,  985,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2673, 1541,    1,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  485,    1,   32,    1,  221,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,    1, 1998,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 2384,  593, 1659, 1222, 1300,    1,   37,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   12,    1, 1550,    1, 2339, 1953,  220, 3374,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,   79,    1,  242,   69,    1,  197, 1406,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380,  267, 2018,  967, 2764, 3394,   98,  166, 1844,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1778, 2580, 1108, 1779, 2259, 2495,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  420,  267, 1763,   32,    1,  759,  105,  131,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  268, 1086,  857, 1469,    1,  387,  526,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  920,    1,    1, 2163,    1, 2235,    1, 1821,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 1739,    1,  191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,  688, 3260,    1,   92, 2941, 1625,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1461, 2414,  786,   32, 3339, 2791,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1380,    1, 2043,   32,  786,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2161,   12, 3282,    1, 2540,    1,  176,    1, 2689,  447, 3009,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2227,    1,  705,    1,  105,    1,    1,  538,    1,   98,  195,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  602,  315,  365, 2791,   32, 3360,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  870, 2226,  716,  572,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2095, 2985, 1377,   37,  625,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3045,    1, 1147,  947, 2856,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  800,  605,  640,    1,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203, 2750,  460,   61,  176, 1959,    1, 1292, 2578,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  374,   28, 1114,  187,   25,    1,  581,   73, 1034,   45,  682,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671, 1078,  253,  360,  105,  170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3168, 1454,    1, 1684,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993,  546,   28,    1,  220,  829,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1312, 3361, 2844,   32, 3391, 2329,    1, 2597, 1260,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,  501, 2749, 2528, 2687,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3338,  191, 3352,   32, 2597,    1, 1147,  947,  774,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  656,   32, 2197,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  967,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1461, 1463, 1558,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 1774,   39, 1354,    1,  880,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  719,  388,   69, 1208, 1063,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  310,  225,  616,  123,  242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2097, 3045,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  755,   37,  693, 1108,   37,  856, 2964,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  708,  355,  710,   37,    1, 2166,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1090,   45,  166,   74,  191,  166, 1397,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1, 1848,  387,  207,  174,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  585,    1, 1290,  396,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  315,  365,    1,    9,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3404,   98,  454,   37, 1937, 3358,  528, 1404,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3168, 2257,   39,   45,    1, 1787,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  189,  927,  786,   45,  942,   12, 2084,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2466, 1458,   79,   98,    1, 1064, 2722, 3074, 1215,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  306,  794, 1935,    1,   32,  215,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  519, 2712, 2807,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  393,   59, 1754,    1,  110,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3251,  972,   37,   52,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  176, 3036, 1409,   12,  815,   45, 2971,  384,  166, 1530,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387,  682,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2222, 2034,    1,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  683,  967, 1350,  562,   37,  151,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  320,  334, 1210,   37,   52,  105, 2501,    1,    1,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  865,   32,    1, 1240,  930,  548, 1056,  388,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  379, 1096,    1,   32,  104,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,   12,  166,  132,  220,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051,  325,  861,  698,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,  446,  267,  770, 1976,   32, 3155,  972, 2249, 1527,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  758, 1867, 1697, 1013, 1522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1360,  612,  142,    9, 1503,  129,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2414, 1700,   32, 2597,   32,  645, 1260,   98,  531,\n",
      "           12,  947,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,    1,  418, 1897,  385,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3214, 2471,    1,   12,  914,  640,  119,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1,    1,    1, 1022,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  513,  514,   37,    1,  966,    1,  133,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144,   12, 1557,  387, 1438,   37, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,  315,   37, 1403, 1410,  111,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,  877,  259, 1167,   96, 1159,  105,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3002,   77,   98, 1239,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 2962, 1751,    1,    1,  608, 2920,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1625,    1,    1, 2422,  566, 3126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 2122,  534,    1,   28, 1876,    9,  104,  221,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  171, 2358,    1,  108,   45, 2292,   32,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  586,  952,  518,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3228, 2761,    1,    1,  600,    1,  548,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3194, 3195,   12,  365, 2800, 2565, 1564,  714,  892,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  335,  271,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  679,   69,    1,    1,  493,   70,   71, 1010,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275,  442,  134,   63,  736,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   51,  583, 3343,  650,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  528,    1,    1, 3069,  190, 1124,  531, 2172, 1346,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  726,    1,  497, 1684,   37, 1864,    1,  471,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 1447,   12,    1,  267,  590, 1188,   37, 1882,  403,\n",
      "            1,   46,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,  814,   12,  605,   50,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2004, 3016, 1935,  437, 2023,    1,   50,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  412,    1,   37,  413,   12,  172,  414,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  688,   32,  985,   45,    1,  454, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1398,  612,  619, 2623,  220,  923,    1,  619, 1452,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2523,  852, 1542,   37,   71, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,   12,    1, 1480, 1362, 2873, 2030,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,    1,   37, 2436,    1,   12, 2585, 2948,  656,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3203,  884,   56, 2847,  631,  176,  171,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1645,  947,    1,  228,   32,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1114,  879,  647,  693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2198, 1021,  187,   64, 2682,   12,    1, 1417,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   45, 3358,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,   12,    1,  812,  365, 1015,   45,   12,    1, 2170, 2471,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  304,  297,  104,  869,  448,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2700,    1, 2786, 3012,  436,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  491,  200,   54,  471,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  183,    1,   32,  183, 1272,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1675, 2175,   37,  617,  618,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1333, 1530,   32, 1785, 2044,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   37,  130, 1092,    1,    9,   54,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  964,    1, 3144,  220,  105,  632,    1,  218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190,    1,  168,  166,  454,   45,  166,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1100,  981, 1243, 2071, 1331,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1, 3340,   32, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 1070,  885,  331,   32,  567, 1527,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  954,   66,   98, 1735,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1981,  834,  575,  619,  166,  389, 2740, 1444,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656,    1, 1501,   77,  112,    1,   98, 1434,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1773, 2510,  535,    1, 1371,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  756,  757,  267,  460,  190,  125,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  782,  365,  754,  187, 2117, 1740,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,  744,   28, 1876,  656,   32,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 1173,  176,  163,    1,   12,    1,  622, 2705,   32,  531,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3174, 1249, 2779,   32,  395,   26,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   26,   98, 1104,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,  114,   37,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,    1,   45,  730, 1731,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2967,    1,   98, 2347, 1638,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  810, 1401,   26,   98,  632,  851, 2421, 2122,  267, 2834,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2006,    1,    1,    1, 1976,   32, 3391,    1,  391,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2373,    1,    1,  376,  983,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1629,  149,   98,  286, 1008, 1630,   32,  878,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1149,  168,   98,  477,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  866,    1,    1,    1,  530, 1547,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,    1,   79,  396,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2710,  437,  267,  460,  967, 3395, 1056,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  224, 2995,  166,  627,   45,  166,  116,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3229,    1, 1090,  891,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3092,   37,  927,    1,   12, 1664,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2157,    1,    1,   32, 2618,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1,    1,  321,    1, 1159,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  936,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3016,    1, 1415,   37,  350, 1069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1392,    1,   32,  678, 1432,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1454,  163,    1,   12,    1, 1461,  469,    1,  202, 1360,\n",
      "          612,  774,    9,    1, 1232,  942,   12,    1,  963, 2122,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,  267,  590,  484, 1724,   98,    1, 2924,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2889,  384,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,  413, 2450,   37,    1,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  994,    1,  150,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1173, 2869,    1, 1779, 1136,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  755,  794,    1,  834,  778,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,    1,    1, 1437, 1027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1006,   39,    9, 2335,  257,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 2361, 2024,   46,  220, 2755, 2751,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1955,   12,    1,    1,  921, 2332,    1,    1,  758,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283,  730, 2614, 2087, 2614,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  440,  183,  427,   28, 2697,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  167,  877,  449, 2318,  698,    9, 3103,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,  779,  453, 1117, 1525, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1604,  465,   95,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,  190,    1,    1,  193,    1,    1,  220,  531, 3345,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2618, 2577,    1,  202,    1,    1, 1293,  754,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  140, 2024, 2223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1287,   37,  688, 1789,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2648, 2801,   12,  517, 1116,  640,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   66,    1,   32,  795,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,    1, 1564,  198,  269,  714,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1848,   37, 1706,   32,  310,  250,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  393,  729,  193,   39,   45,  172, 2523,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,   12, 2626, 1514,  220, 2843,   12, 2482,  191,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3067, 1887,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1509,   37,    1, 1778,  328,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1918, 2094,  753,    1,  361, 1406,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1009,  580,    1,  191,  299,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  778, 2008,  938, 1510, 2208,  582,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  105, 1487,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  286,  287,  288,   37,   52,  289,   45,  233,  290,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  425,  426, 1837,    1,   15,  729,   66,   28,  419,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066,    1, 1103,   98,    1,    1, 1748,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  438,    1,  267,  190,  439,  170,   46,  220,  440,  441,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3364, 1464,   37,  726, 2708, 3384, 1302,  543,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  450,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   26,  242,  548,    1,    1, 1087,  156,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,  187, 3303,  765,   28,  176,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3296,    1,    1,   37,  332,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   67,  729,  845,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2586,  361,    1,   45,    1, 2085,  502,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2789,   37,  319, 3359,  957,  297, 2271,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479, 2094, 1292,   81,   37, 1204,   32,  378,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  103, 2343, 3404,   37,  168,   98,  776,  384, 1411, 1034,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1480,    1, 1976,   79, 1238,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1257,  960,   37,  588,  467,   32,  630,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  389,    6,  288,  191,  176,  612, 2300,   37,  686,   45,\n",
      "         1346,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2127,    1,  125, 1266,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388, 2357,  187, 3144,   46,  439, 2198,  630,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  695, 2007,   32, 2227, 2096,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2275, 1662,  193,    1,   37,    1, 1260,  378,  940,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  708,  355,  710,   37,    1, 2166,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1472,   28,  220,  375, 2385,  612, 2177,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1867, 1894,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  231, 1107, 1863, 1553,  472, 1224,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3388, 2396, 2239,  289,   37,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 1505,    1,  202,    1, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 1484,    9, 2251,   45, 2095, 2985,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2508,   21, 2292,  176, 2466, 1209,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296, 1321,  829, 1322,   32,  342,  149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  245, 1270,  297,  608, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 1042, 2336,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2414, 3361,    1,  356,  548, 2343,   12, 2555,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1410,   32,  105,  207,  627,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,  324,  325,  326,  466, 1465,  112,    9,    1,  372,\n",
      "         1714,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3384, 1231,  548,    1,  384,  602,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1718, 1542,    9, 1065,  199,    1,  657,  267, 2928,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1536,  397, 2118,  444,  104,    1,  942,   32,    1,    1,\n",
      "         2096,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,  852,   37,   92, 1228, 1069,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   12,  647,  142, 1757,  431,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  363,    1,    1,  364,   12,  365,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 2224,  213,   37, 1211, 1156, 3375,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  632, 3071, 2070,  593,    1,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,  140,  104,  331,   24,    9, 1127,    1, 2664, 2229, 1140,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3160,  610,    9,  531, 1038,  966,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1758,    1, 1017,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  447, 1109,  587, 1140,    9,  477,   37, 1313,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,   61, 1229,   37,   52,  123,   37,    1,  142,  191,  148,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1181,  580,  122,  297,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  159,    1,  187,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    1, 2545,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  861, 2538, 2481,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  203, 1476,  977,  321,   52,   55, 2220,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,   45,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3279,   32,  531, 2856,  583,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  785,  786,    1, 1890,    9,  483,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1088,  446,    1,  267,  204,   61,    1,   37,  907, 1683, 3398,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,  547, 1763,   16,  590, 2527,  164,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2645,   37, 1230,    1, 1158,   12,    1,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2287,   28,    9,    1, 1798,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1222, 2359,    1,   37,  460,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,  353,  242,  737,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056, 2572,   32, 2597, 3392, 1388, 1147, 2924, 2905, 1995,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994, 3153,  342,    1,  894,  319,    1,  267,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2707,  108,  104,  460,  167, 2446,  531, 2532,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 2414,  315,    9,    1,  660,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2553,   32, 1337,    1,    1, 1314,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,  455,   12, 1561, 2717,  275,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2104, 2873, 1360,  612, 1154, 3015,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622, 2924, 1910,    9, 3118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1785, 2044,    1, 1549,   78,   37,   92,  568,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   23,  972,   37, 1192,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2770,  220, 1786,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  882, 2361,  327,  883,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1345,    1,   32,  463,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  189,   37,  508,   79,  118,   45, 1346,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,  365, 2630,   32,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1105,  787,    6,  737,  354,    1,  225,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  219,  441, 1413,   32,    1, 1718,  861,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3323,  168,  384,  103,   37,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 529, 102, 972,  37, 168,  28, 384,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 447,   1, 191,  69, 120,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1212,    1,    1,  845,  275,  443,   98,  617,  618,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,  267,  204, 2233, 1488, 1496, 1833,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066,   12,  193,    1,    1,  267, 3242,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3298, 2421,   32, 2760,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492,    1, 1061,  297, 2501, 2502,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2086,  302,   12, 2829,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1744,  441,  774, 1444,  190, 1012,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,  560,    1, 1631,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3182,    1,  153, 1090,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3257,  967,    1,   37,    1,    1,  384,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964, 1707, 2638, 1529,   46,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  616,    1,    9,  241,  567,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1, 2103,  617,    1,  167,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3343,    1, 1009, 3090, 1260,    1, 2924, 2572,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460, 1924,  105, 1476,  484, 2167,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  559, 1483,    1,    1,   12, 1309,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2590, 2963,  176, 1022,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  572,  105,  579,    1, 3358,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3155,   12,    1,    1, 3045,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2140,    1,  591,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,    1,    1,  856, 1428, 2103,  617,  506, 1281,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   99,  392,   93,  739,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  154,   32,    1,   98, 1756,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  810,  566,   98,  430,  187,   69,  636,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  896,    1,    1,   37, 1046,    1,    1, 3277,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1186,   51,  576,   28,   37,    1, 2025, 2924,   37,  531,  420,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  105,  581, 2565,  424,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  405, 1104, 2209,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,  744,   26, 2798, 2232,  949,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  234, 3041,  235, 1366,  234, 3041,  235, 2833, 2168,    1,\n",
      "          234, 3041,  235,  334,  234, 3041,  235,  321,  612,    1,  104,  876,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,   92,    9,    1, 2024,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2997,    1, 1348,   37,  504,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 1580,    1,  686,  191, 1656, 2596, 2572,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1940,    1,  384,  826, 2162, 1569,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3308, 1990,    1, 1427,  515,    1,  726,  297,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   92,  187,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700, 3386, 1940,  514,   45, 2930,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  619,    1,    9,    1, 2580,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,  159,  832,   98,    1,  308,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  260,   45,    1, 1034,    1,  105,    1,   98,    1,   12,  533,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1640,  476,    1,  147,   37,  335,   98,    1,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1089, 1090,    1, 3039, 3040,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1201,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 3276, 1497,    1,   32,    1,  361,  193,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1554,    1,    1,    1, 2318,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  593,  616,  385,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964, 1484,    9,    1,   45,  890,    9,    7,  353,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1689,  492,    1, 1333, 1530,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3382, 1988,   45,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1128, 1396, 1230, 2543,  220,  365, 1234, 1863, 3011,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  934,    1,    1,  928,  176,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  159,  720,   98,  197,  304,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  258,    1, 1685,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2993,   12, 2994, 1564,    1,  714,  892,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  457,    1, 1415,   37, 2276,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 1617,  361,  166, 1675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3320,    1, 1258,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 166,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 363,   1, 884, 694,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  613,    1, 1508, 1663,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,    1,   37, 1146,  106,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3276, 2871,    1,   32,  979, 2340,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1292,    1,    1,    1, 2437,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2347,   32, 2563,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  613,   29,  789,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  269,  220,    1, 2232,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  744, 1853, 2702,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  964, 1458,  462,  132,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  295,   37,   47,    1,   98,  365,  620, 1294,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428,    1,  917,   37,    1, 2165,   32,  864, 3399,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550, 1357,   26,   37, 2988,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 1530, 2534,    1,  105,  784,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  727,  613, 2094,  517,   37,  388, 2458,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  197,  921,    1,  570,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  798,  403, 1383,    1, 1625,   37,  477,   69,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596,    1,    1,    1,  395,   12, 1239,  996,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094, 1550,  163,    1,   12,    1,  232,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2067,  166,   97,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1062,  458,  267,  460,   12,  193,   32,   46,  220,  742,    1,\n",
      "         1550,  420,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 1042,  315,   37,  665,    1, 1017, 1159, 1087,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 2427,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1380,   79,  296,  400,   37, 1411,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  876,  612,  939,  115,   45,  890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1257, 1904,  437,   37,  912,    9, 2240,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1906, 1579,    1,  388, 2924,    9, 3114,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1941,  104, 2548,    1, 3155, 1523,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2460, 1159, 2287,  220,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1902, 1141,  187, 3287,  245, 1979,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  765, 1415,   37, 1117,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2886,   12, 2234,  162,  365,  845,  275, 2524,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  711,  744,  636, 2320,    9,  331,  752,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1082,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1034,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1617,  336,  946,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,   28,   98,  605,    1,   93,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,    1,    1,    9,  449,  199,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1827,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321, 1095,   77,  166,    1,  707,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1661,    1,  700, 1236,    1,   45,  207, 1568, 1669,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107, 1070,  104,   37, 1978,  453, 1482,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  547, 3375, 2572,   32,    1, 3375, 1585,  786, 3101,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3236,  132, 2051,  202, 2040,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2569, 2838, 1210,  199,   37,    1, 1515, 1054,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,   61,  855,   32, 3343, 2823,  863,    1,  379,  774,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3282,  691,   12, 3169, 1426,  401, 3179,  176,  316, 3282,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1290,  396, 1253,  191,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 306,   1, 150,   1, 132, 220, 457,   1, 700,  88,   1,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2464,    1,  191,  589, 2323,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  212,   37,  151,  215,   12,    1,    9,    1,  372,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2414, 1029, 2231,    1,  876,  612,    1,  176,  163,    1,\n",
      "           12,    1,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3064,    1,    1,  245,   32, 2459,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2672,    1,  967, 2961,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  457,    1,  891, 2813,    9,   59, 2695, 2223,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  360, 3069, 3343, 2362,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2778,  504,   32,  715,  890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2835, 1004, 1094,    1, 1887,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  212,  213,  214,   45,  215,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2990,   51,  606,  377,    1,  763, 2112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303,  108,  600,  442,  448,  805,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1795, 2279,  936,   59,   32, 1495,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3003, 1236,  885,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1783, 1666,  156,  949,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2006, 1530,  361, 2347,  187, 2702,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  632,    1, 2827,   32, 3344, 3071,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2322,   37, 2303, 1232,    1, 3207,  190,   77,  671, 3126,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2391, 2116,   37, 1171,    1, 1397,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398, 2794,  104,  358,  138,    6,    1,  105,  221,  386,  483,\n",
      "          952,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1557,    1, 1364, 1365,   12,  645,  142,    9, 2024,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  896,    1,  307,  386,   12,  915,  437, 1090,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  702, 1240,  221,  453,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1594,  242,  187,   69,  640,  119,  845,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3338,   32, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1169,  389,   93,    1,  800,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2278, 1635,  597,  326, 1222,    1,    9,    1,  808,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2676,    1, 2136,    1,   32,    1,  736,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,    1, 2683, 2043,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181,  387, 1151,   15, 1115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 365,   1,   9,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  168, 1412,   37, 1171,  378,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   79,   37,  166, 3145,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1364, 1365,  877,  460,   56,   39,   45,   56,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428,    1,  190, 1073,   85,  548,  537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,    1, 1536,    9,  467,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1423, 2590,  400,   45, 2623, 2624, 2130,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   45,    1, 2325,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  180,    1,  179,  123,   37,  170, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  727,  361,  180,  498,   37,  720, 2039,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,    1, 2991,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3190,    1, 2748,    1,  449, 3278,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    1, 1354,  972,   37,   52, 2713,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1701,   37, 1753,  111,  668, 2852,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,   51,    1, 2140,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  184,    9,  537,  297,  207, 3049,  506,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  566,   98,  654,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2103,  617, 2948,    1,  357,    1,  787,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622, 1942,   23, 1921,   32, 3118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  446, 2405,   37, 1725, 2396,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1072,    1, 3047,  187, 2292,    1,   32, 3339,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3336,    1,  105,  865,   37,  166, 3141,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973,  590, 1400,  680,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1290,  396,   28, 2051,  763,   76,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2091,  104, 1588,   92,   69,  636,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2275,    1,    1, 2081,   45,   10,    1,    1,  408,   45,  531,\n",
      "          443,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096, 3213,  859,  627,   37, 3180,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1090,  275,  353,  417,  572,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2111,   38,  166, 1557,  166, 2505,    1,    1,    1,    1,  320,\n",
      "          460,   51, 2222,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2844,   32,  885,  649, 2003, 2291,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999,   91,  325,    1, 2618,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1053,  102,  123,    1,  118,  242,   32, 1111,  605,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1720,  334,    1,   98,    1, 1173,   39,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  612, 1273,  891,  840,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1159, 3343,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2313, 1061,   98,  134,   45, 1809, 1117, 1525, 2429,  444,   36,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1413, 2080,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1163,  624, 1359,    1,  992,   85,  187,   82,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  562,  705,    9,  464,  793,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  640,  547,  187,    1,    1,  754,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3212,   45,  730, 2614,  872, 1698,   45,    1, 2308,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3287,    1, 1902, 1765,  105, 2742,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,   12,  572,  354,  703,   98,   44,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3369,  861,    1,  365,    1,  722,  639,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  137,  588,    1,  951,    1,   20,   87,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2700, 2655,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,  670,  187, 2163,  293,  831,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  437,  313,   37,    1,    1,   39,   45, 1718,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,   37,  720,    1, 2225,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1,    1,    1, 1758,   37, 1929, 3179,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162, 1569,   98, 1477, 1990,  872,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2425,   37,  151, 1883,    9,    1,  131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  502,  458,   37,    1,    1,   59,  297, 1446,  278,    1,\n",
      "            1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  907, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1157,  947, 2884, 3035,  548,  218, 1585,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2375,    9,  987,  132,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1990,  142,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1585,   32, 2597, 2774,    1, 2414,  176,  177,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,  195,    1,  168,   98,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2405, 1159,  889,  271, 3158,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707,  267,  342,    1, 2740,    1,  501, 1125,  115,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,   37, 1442, 2954,  986,   79,    9, 1110,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2676,  361, 2136,  168,    1,   37,    1,   32,  736,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  316,    1,   39, 2015,   32, 1238,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,    1, 1614, 1718, 2355,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,  441,   32, 1674, 1330,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  424,  914,    1,    1,    1,  105,  730, 2614,  186, 1291,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,  140, 1363, 1322,    9,  179,  142,  420,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  597, 1531, 2824,  712, 2572,    9, 1273,  259,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  694,  845,  921,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2126,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117, 1525,  126, 2489,   98,  104,  890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,  116, 3005,    1, 1117, 1104,  841,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2604, 1021,  302,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1157,    1,  631,  593,   32,    1,  244,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3174, 1426,  449, 1938, 2809, 1286,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   14,   15,   28,  699,  187,   76,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1795,  197,  407,  118,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,   12,    1,  387,  244,  120,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087,  433, 1261, 2500,  808,   32,  596, 1793,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  506, 3032,    1,   85,   32, 2822,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3296, 1445, 1421,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  647, 1707,  148,  142,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283,   45,  166, 1215, 3330,  738,  427,  176,  637,   45, 3232,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2792,  691,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510, 2682, 1549,  540, 1530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2839, 1568,    9, 2741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  868, 1001,    1,  460,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,   12, 2819,  469, 2443,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  698,   28,   37,  693,    1,  116,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3066,   37, 1343,  760,  593, 1990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1816,  516,    9, 2891,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  710,    1,    1, 3090,  880,  298,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2500, 2103, 2727,   16, 2252,    9,  661,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  387,  156, 1239,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1008,  413,   12,  597, 1213,   82,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1443, 1388,   98,  531,    1,  954,  361,  223,   32,  581,  736,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2477, 2908,    9,  365,    1, 2291,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  208,  140,  449, 3134,  671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3374, 3352, 2856, 1791,    1,   32, 3339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  538,  786, 1564,  453,  221,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  108,  575,   98, 1117, 1525, 2574,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  669, 2055,   28,  105, 1787,   37,  224,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  755,    1, 2007, 1411,  339,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  615,    1,   37,  777,    1, 2165,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  671,  884,    1,    1,  104,  384,    1,   37,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,   12, 3380,  884,   32,    1,   12, 2165,   32, 2507, 2784,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  166,  803,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1292,    1,    1, 2376,  855,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2504, 1386,    1, 2862,  446,    1,    1,  680,  433, 2263,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  439,   28,  187,  802, 2200, 1986,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  180, 1990,  166, 2107,   63,  166, 1948,    1, 1494,   28,  220,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 2770,  942,   98,    1,    1, 2579,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   12,    1,  294, 2060,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  498,   37,   59,  399,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 2170, 1949, 3342, 1953,  220,    1,    1, 3058,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  454,   37, 1594,   79, 1628,    1,   61,  288,    9, 1958,\n",
      "           98, 2500,  566,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3102, 1512,    1, 1337, 1604,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98, 1020,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  294,    1,    1,  361,    1, 2536, 3340,    1, 1056, 3361,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  166,    1,  551,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3089,  176,  590,    1,  584,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107, 1877,   37,   26,  166,  708,   37,  838,   85,    1,   69,\n",
      "          102,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  754, 1675,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  691,   32,  220,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3203, 3274,    1, 1271, 2457,  142,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1203,    1,    1, 1021, 1129, 2007,   37,  114,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2591,    9,  365, 1009,    1, 3372,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  105,  596,  613,  593,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,   96,  444,  453,  248,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2751,    1, 1147, 2924,    1, 2856,  163,    1,   12,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1833,   12,    1, 2176,    1, 2072,    1,  163,    1,   12,    1,\n",
      "         1463, 2753, 2704,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1817,    1,    1,    1,    1, 3390,   32,  187,  365, 3104,  475,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1615,  361,   40,    1,    9,  259, 2419, 2545,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  197,   28,  570,  410,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1821, 2190,    1,  109, 2440,    9,  920,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614, 3055, 1159,  631,  297, 3175,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   85, 3337,  967,    1,    9, 1523,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3132,    1, 3237,    1, 2614,   32, 2651,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1725, 1726,   37,  943, 1211,  442,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  193,  320,    1,  220, 2580, 1108, 1779,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1550,   60,    1,  798,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1741,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  575,   77, 1278,    1,  645,   29,   16,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   85,    9,  531, 3365,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2762, 1268,  755,    1, 1228,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  325, 2943, 1416, 2683,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1110,    1,  421, 2225, 3188,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1116,   32,    1,  572,  197, 1137,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2863, 2188, 2956,  856,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9, 2161,    1,  600,    1,    1,    1,  458,   61,  105,  365,\n",
      "         1144,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  187, 1479, 2103,  617,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,  361,  510, 1403,   97,   98,   69,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1070,  147,   37,    1,  804,   98, 1476,  574,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458,   45,  507,   37,  221,    4,   37,  273,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,    1, 1159,  829,   12,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3215, 2753,  187,  311, 2936,  140,   32, 3116,  922,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,    1,    1,  202,  729,  415,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  561,    1,  912, 2285, 2165,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   63,  166,  862, 1099, 1453,   85,  419,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1751, 2317,    9, 1056, 1675,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2800, 2741,    1,  297,  966,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275, 1355,   10,   98, 2095,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3359,  520,    1,  469,  220,  365, 2708, 1513,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947,    1,  549,   98, 2967, 1665,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,  879,  693,    9,  647,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1707,  104,  798, 1167, 1926, 1927,   27, 2555,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 951,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 702,   1, 169, 498,  37, 182, 170,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   10, 1008,    1, 2922,  103,  163,    1,   12,    1,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1423, 2272,   85,   98,  116, 2574,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  379,    1,    1,  548, 1522, 1281,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193,  166, 1690,   32,    1, 2717,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428,  515,   28,   98, 1896,   37,  588,  481, 3036, 3037,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  374,  375,   37,  151,    1,    9,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  640,  531,   12, 3391,   63, 2731,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  947, 2263,   32,    1, 1313,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 2162, 1780, 1809,    1,  682,   32, 2170,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,    1, 2355,    1, 2812, 3011,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1808, 1670, 1537,  793,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  694,    1,  608, 1183, 2921,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  306,  325, 1159, 1239,  649,  111,   14,  218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  176,    1,   45,  617,  802,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   10, 1877,   37,  125,  448,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  475, 1082,  439,   37, 3344,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1228,  700,   37,  125,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1090, 2677,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  190,  326,   47,  327,  112,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  742,  155,   48,   32, 1178,  386,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  649,    1,  987,   32,   98,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2743,    1, 2315,  142,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1292, 1681, 2966,   45,  166,    1,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2976, 1228,    9,  282,  659,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   66,  242,  187,   69,  953, 1315,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  625,   39,  105,  339,   37, 1312, 2119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2107,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  379, 2199,    1, 1218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  342,  475, 1877,   37, 2965, 1511,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  772,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2942,  190, 1838, 2826,  187,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340, 1401, 2505,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2028,  952,  104, 1011,  442,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2310,  753,    9,  166, 1811,  404,    1,  191, 2868,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1126,  157,    1,   88,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1203,   32,    1,    1, 1871,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   65,   12,    1,  267,  104,   93, 1735,    1,   69,  193,    1,\n",
      "           31,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2892,   45,    1, 1558,    1,    1, 1530, 1142,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2, 148,  12, 156, 415, 103, 689,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1, 142,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1838,   37, 1940,   12, 2472,    1,  294,   12, 2505,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1028,  321,    1, 3371, 2654,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  208,  951,    1,    1,   32,    1, 1990, 3201,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,   20, 1644,  513,  514,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  812,  792, 1442,  792,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  190,  771,  587,   32,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1366,  565,   26,   37, 1428,    1,    1,  267,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3202,   12, 1705, 1464,   37, 1198, 1957,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1545,    1,    1, 1631, 2380,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1186, 1625,   37,  973,  163,    1,   12,    1,   98,  651,\n",
      "         1031,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2227,   12,    1, 1992,   37,  777, 1225, 1499,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1848,   37,  138,  105,  599,   32,  166, 1336,   45, 1151,  102,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  259,    1, 1662,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2910,   77, 3161,  590,    1,   32,  166, 3278,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1216, 3097,   12,  808,   32,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3060,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1181,    1,  848,   32, 1731, 2234,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,    1,  985, 2456,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 355,  82,   1, 156, 739,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 262, 263, 353, 207, 354, 548, 134,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  854, 1648,   37, 1982,    1, 2362,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 1656, 2909,   32,  531,   12,    1, 2856,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2610, 2697,   12,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  614,  671,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2991, 2767,    1,    9,    1,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   57, 1674,    1,  927,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  854,    1, 2018,  439,   46,    1,    1,   98, 1815,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  925,   65,    1,    1,   32, 1169,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3374, 1004,  365, 2708,  863, 1294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1264,    1,    1,    1, 1152,   98,  932,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  460,   12, 2970,  361,    1,  190, 1210,  460,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2708, 1763, 2572,   32, 3339, 1585,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1090,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   28,    9,  331,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  303,  967,    1,  388,    1,   65,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645, 3102, 1512,  256,    1,   37,    1, 1281,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2028, 1419,    1,    1,    1,   32, 2678,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2246, 2802,    1,  631,  220,  633,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1084,    1,  159,  720,  187,  458, 1025, 1830,    1,  389,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2903,  247, 1509,    9,  915,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  256,  934, 1499, 2524,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,  949, 1411,  659,   45, 1778,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1794,  321,  612, 1838,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947, 2856,  854,   12, 1354, 2556,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,  695,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2389,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1712,   51,   52,  593,   12, 1354,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    7,    1, 1011, 1039,   61,    1,    1,  506,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1468,  267,    1, 2081,  416, 1590, 1558,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  758, 1822, 1046, 1645,  822,  522, 3000,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  743,   12,   82, 1877,   37, 1155,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  424, 1034,   12, 1586,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766, 1707,  848, 1302,   32, 3016, 1935, 2723, 2724,  443,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2925,    1, 2958,  191,  379,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1585, 2668, 1739,    1,  493,   50,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1839, 1360,  612,  686,  632,  954,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1243,  344, 1450,  722,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307,   37,   47, 1273, 2515,   37, 1182,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  123,  242,   32, 1125,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  391, 1926, 1927,  972,    1,   57,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2918,  493,  167,  907, 3024,   12,  627,  626, 1004, 2700,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2087,  433, 2808,   98,    1, 2128, 2099,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,  193,  489,   39,   45, 1611,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   65,  267,  217,  470,  209, 2461,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 2313,    1, 2572,  191,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  744, 3018,  949,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204, 1249, 3169,  176, 3329, 1990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1545,  726,    1,    1,    1,    1,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  444, 3290, 1360,  612,  544,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1186, 2768,  193,    1,  304,   45, 2282,  722,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  884, 2206,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1140,    9,  388,    5,   98,  581, 1219,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284, 1147, 3045,    1,   32, 2375,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2885,   98,  103,   45,    1, 1114,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2039,    1,  425,  426, 1064,   82,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  403, 1447,    1,    1,   10,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964, 2182,    1,  176,    1,    1,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  561,    1, 1099, 1453, 1039,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1517, 1360,  612,   52, 1851, 2247,   32,  903,    1, 2227,    1,\n",
      "         1007,    1,   12,  365,  844,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  295,  390,   76,   37,  686,    1,   54,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3012,  872, 2040,  600,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  215, 3102,  513,    9,  247, 1204,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  331,    1, 2226,    1,  612,    1, 1564,    1,    1,  449, 1920,\n",
      "           37,   52,  453,  475,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1988,   45,    1,  131, 2089,  133,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1867, 1348,   98, 3358,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 2459,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942, 1426, 2069,  176,  497, 1990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1718,  437, 1702,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2885,  726,  388,  763,   59,  104, 1714,   32,  786,  914,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  754,  757,  418,   63,  166,  862,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1, 2925,  943,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1366,    1,    1,  105,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105,  241,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,   25,    1,   60,  276,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  879,  822, 1942,   37,  810,   17,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1925, 1583,  162,  365,  650,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1304,   37,  138,  331,  399,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2939,   37, 2303,   98, 1427,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3389,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977, 2700, 1000, 2481,   45, 2820, 2312,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,    1, 2572,   32, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3280,   37, 1844,  365, 1788, 2472,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492,  458,   37,  508,   79,    1, 1346,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2483, 2774, 2678,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2906, 2871,  415,  168, 2017,    1,    1,  193, 2906,   12,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,   37,    1,    1,  459,  220, 3231,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2680,  313,  176,  803,  681,  220, 1117, 1525, 1108,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  936,  365,  825, 2679, 1013,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1778, 2432, 2493,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  256, 1561, 1876,   37, 3034,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  476, 2168,   37, 1027,  756,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1178,  163, 3067, 2408, 1313,  444,  742,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  220,  105, 2589,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  105,    1,  629,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1536,  388, 2819,  767,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1585, 2414,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1186,  134,   32, 2095,  722, 2260,   37,  163,    1,   12,    1,\n",
      "         2393,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,  108,   45,  651, 1031,   12, 1665,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  398,  556,  142,   37,    1,  386, 1202,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144,   12, 1557,  213,   37, 1198, 3071,   45,  957,    1,   32,\n",
      "            1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,   66,  417,    1,  485,  640,  374,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3186, 2435,  580,    1,   44,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1470,  403,  464, 1585,  778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   83,  924, 1229, 1143,    1,  612,   52, 1558,    9, 1389,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  975,   37,  151,    1, 2403,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962, 3319, 1285, 1110,    1, 3260,  554,   37, 1264,  841,\n",
      "          631,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1487,    1,   28, 1412, 1107,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1,  297,    1,  187,  163,    1,  903,    1, 1953,    1,\n",
      "           28,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3190,   53,   39,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1477, 1990,    1,   92, 2467,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777,    1, 2798, 1718,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1093,  574,  475,  939,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  711, 2593,  365,  535, 1131,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1716,  387,  410,  627,   32,  481,  327,  218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  176,  177, 2572,   32, 3339,  787, 2137,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  293,  437,  267,    1,   61, 1997,    1, 1488,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 2851,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1833,  593,  830,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1425,  166,  593,    1,  220,  529,    1,  361,  105, 2210, 1311,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2243,    1, 1362, 1480, 2873,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  920,  342, 1786, 2040, 2682, 2210, 2698,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,  655, 1231,  297, 1919, 3339, 3065,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,  315, 1279,    9,  228, 1479, 1410,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  980, 1750,  119,  340,  951,    1,   94,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1720,  190, 1687, 1022, 3008,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584, 1818,  147, 1380,    1,   98,  171, 2661,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,   79,    1, 1554,   94,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1591, 1126,  490,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1662,   30,  365,  531, 3365,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 2518,    9, 2777,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   26,  242,   98,    1,  682,   32,  104,  159,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,    1,  619, 1018, 1901,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1497, 2497, 3384,    1,   32,  531,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3168,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3066,  313,   37,    1,  460,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  100, 1064,   33,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1937,  148,  647, 2552,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  297, 1861,   12, 1140,    9, 2024, 1929,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1433,  166,    1,  606,  810,  901,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2722, 3074,    1,    1,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  284, 3069,  893,    1,  176,    1,  531, 2699,    1,  163,    1,\n",
      "           12,    1,  267,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  411,  218,  578,  410,  115,   45,  104,   67,  221,    1, 1017,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1018,    1,   74,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  182,    1, 1417,    1,  921,  539, 1037,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  195, 1463,  932,    1,    1,   13,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3121,  868,    1,    1,    1, 2249,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 3375, 2572,   32, 3339,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  550,   56, 1231,   32, 1422,  215, 2026,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1021, 1863,  894,  726, 3303,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   82,   83,   37,   84,   85,   32,   86,   87,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1199, 1007,    1, 1117,    1,  705,    1,   12, 1192, 1159,    1,\n",
      "            1, 2749,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  422,  520,  521,  522,  444,  523,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  665,  447,   28,   98, 2468,  548,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2388, 1086, 2748,   45, 1771,   12,  726, 1045,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1631,   38,  548,  380, 1090,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3407, 3392,    1,   32, 2018,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043,  338,  187,    1,  640,  275,  159,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,  200,  365, 2543,  124,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,    1,  180,   32,  182,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2021,  142,    1,    9,    1,  716,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785, 2044,   37,   92,  568,  187,   69,  921,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3118,    1,    1,    1, 1428,    1, 3030,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779,  801,   37, 1447,   26, 2069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 1536,    9, 2240,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647, 1917,    1,  148, 1090,  297,    1, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  921, 2158,   45, 2121,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,  475,  261,   39,  721, 2027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1247, 1654,  191,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  641,  453, 1184,   32,  734,  802,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3308, 1990,  906, 2677,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1891, 1726, 1911, 1428, 3146,   98, 1430,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  323, 2288,    1,   12,  638,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1794,   37, 1624, 1797,  853,   24, 1371,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3050,  640,   81,  176,  923,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387,  166, 1125,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  189,  225,    1,  191,  388, 1628,  550,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1827,    1,  972,   37,    1,  166, 1354, 1184,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3096,    1,   81,  202,    1, 2781,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2161,    1, 1674,    1,    1, 3163,  119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  794,  754,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1143, 1988,   45,    1,    1,   37, 2122,   32,   12,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2088,  605, 1408,    1, 1986,   32,    1,   33,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,   71,    9,  581,   74,   32,  105, 1559,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2117,  267, 3369,  891, 2128, 2129,  384, 3118,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2292,  321,  612, 2446, 3343, 1002,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1955,   12,    1,    1,  921, 2332,    1,    1,  758,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2693,  272,   98, 1100,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  384,    1,   37, 1674,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,   98, 2820,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,   37, 1604,   32, 1313,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3250,    1,  176,  754,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1022,    1, 3008,    1,  167,  631,   37,    1, 2630,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  917,  199,    9,  105, 1183, 1027,   61,    1,    1,    1,\n",
      "          920,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1840, 2078,    1, 1194,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 2548, 2856, 2708, 3065,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  121, 1707,  163,    1,   12,    1, 2081,   45,  205, 1511,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,   74,    1, 2675,    1,  367,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2832,    1,  632,  876,  612,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1966,  267, 1033, 2211,   37,  973,  792, 2312, 2177,  792,    9,\n",
      "          397, 1259,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1178, 1179, 1917, 1545,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3256,    1,  967,  105,    1,   37,    1, 1922,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1596,  105, 2050,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   66,  242,    1,  479, 1680,  570,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1216, 2050,  176, 1545,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1,  640,  463,  455,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,  154,    1,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,    1, 1478,   59, 1799, 3031,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  160, 1161,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3377,   12, 1841,    1,  379,    1,    1,   37,    1, 1887,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  236,  237,   37,   26, 1298, 1382,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1811,  404,  142,    9,  215,  238,  700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  729,    1,   37,  865,  671, 3126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3231, 1421,    1,   37, 1056,  356,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  947,    1,  715,  924,   32, 2086, 2625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  897, 2380,    1,   45, 1448,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  121,   12,    1,  608,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3198, 1249,    1,    9, 1913, 3329, 2545,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  189,   37,  949, 1961,  172,  932,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  267,  770, 1976,  193,  531, 3102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  113,  700,  187,    1,    1,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2327,  218,  289,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  727,  613,  951,    1,  196,  613,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  853, 1108, 2329,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2820,  123,   28, 1851,  256,   37, 2919,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,   37, 1636, 1300,   48,   32, 2673,  633,    1,   37,  419,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1127,    1,    1, 1835, 1412, 1107, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  500,    1, 1191, 2274,   37,  693,  111,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2175, 1371, 1658,  258, 3087,  739,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2431, 3358,  193,   32,    1,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,   42,  573,  149,    1,   37,  335,   44,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2591,  565,   32,    1,  361,  320,   61,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2569,  195,    1,    1,   37,  386,   78,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  410,   98, 1121,  954,    1,   69,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,    1, 1207,   37, 1211,  163,    1,   12,    1, 3091,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   85,    1, 2995, 1681,  565,   81,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2171, 3134,    1,    1, 1739, 2365,   37, 2613,  140,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   28,   79,  119,  340,    1,   25,  526,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  801,  176, 2490,   26,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1183, 2849, 2177,   37, 2923,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3110, 2540,  590,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  302, 1564,  714,  187,  302,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   75,    1,    1,  637,   79, 1992,   37,   80,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2744,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2822,    1,   51,    1, 1793,    1,  506,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2347,    1,  321,  612, 1838,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1984,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  915, 2823,  427,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3204, 1249, 3253,   37,  759,   26, 3293,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  876,  612,  794,  447, 1109,   48,  333,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  820, 1855, 1149, 2684,  176, 2147,   32, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  130, 1417,  551,  717, 1716,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 635,   1, 315, 331, 142,   9,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 393, 353, 331, 354,  32, 572,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  550, 2693,    1, 1289, 1074,    1,   37, 3005,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  476,   37,   77,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  968,    1,    9,  118,   45, 1649,   45,    1,    1,   32,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3303, 1396,    1,    1,  548,    1,    1,  533,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  149,    1,  590,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  188,  548,  304,    1,   82, 1596,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3371,  830, 3354,  379,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  814,    6, 1469,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2446, 2615,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  773, 2866,   32,   37,    1,  688,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  393,  716, 1167,  453,  987,   61,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   79,  118,  187,  163,    1,   12,    1,  889, 1293,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2680, 1419,    1,  220,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3236, 1360,  612,  712,   28,    1, 1144,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,   37,    1,  622, 1240,   32,   22,   16,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,    1,  115,   45,    4,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  896,    1,  140, 2674,    1, 3126,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  288,   37, 2303,   98,  148, 1411, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2957, 1118, 2871,  529,  617, 1539,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,    1,   10, 2487, 1036,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3356,    1,  729,   32,  674,   45,  531, 3346,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2238,  868, 2403,  132,  220,  657,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  102,    1,   32,  105, 1101,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,  365,    1,  110,    9, 1411,    1,  207,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1249,    1,   32, 3308, 1990, 3096,  427,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  761,   15,   37,   52,  583,   32, 1411,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  531,  952,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2696,  476,    1,    1,   37, 1348,  472, 2722,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2522,   37,    1,   32,  584,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358, 3346,  897, 2083, 1645, 2611,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  527,  315,    1,  474,  138,    6,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1811, 1280,  507,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1024,  631,    1, 3154,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1419, 1626, 1106, 1013,   37,    1,  224,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1364, 1365,    1,    1, 2018,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  794,  454, 1021,    1, 2168,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3369,   12,  957,    1, 2751, 1140,   98,  593,   37,  843,   59,\n",
      "         1714,   32, 1527,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  792, 2474,  792,  176,  792, 1870,  792,   37,  166, 2918,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 2570, 2540, 1022,    1,    1,   12,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2404,    1, 2839,  384,  531, 2271, 2001,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  593,  626, 1220,   37,   71,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2148, 3132,  193, 2398,   37, 2856,  166, 2769,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  441, 1636, 1085,    9, 2567,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2572,   32, 2835,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1290,  396, 1269,    1,  590,   64, 1601,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 2334, 2107, 1258,  220, 2977,    1, 1510,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  225,  338,  187,  104,    1, 2104, 2407,  413,  195,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  642,  643,   57,    1,  754,   15,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  379, 1240,   52,  199,   37, 1198, 1281,   98, 2611,  617, 1484,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1201,    1,    1,    1,  596, 2395,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1021, 1045,   37, 2335,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  794,  365,  163, 1230,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1574,    9, 2977,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106, 2355, 1013,  775,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1605,   15,  603,  227,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  410,   98,  800,  389,   93,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  777,    1,   37,  764,  220,    1,   45, 1778, 1994, 2888,  861,\n",
      "         2432,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  924,    1,  187, 1039,   45,    1,    1,  798,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,    1,   32,    1,  548, 2095, 1665,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  774, 1444,    1, 3327,   12,  484,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 2128, 1119,  105, 2775,   45, 1056, 2458,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  765,    1, 1159,  160,  623,  112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  903, 1447, 1011,  102, 2328,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3403, 2414, 2083,    1,  947,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  318,   45,  121,   12,    1, 2270,   37,   84,   85,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1528,  105, 1415, 1173,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284,  829,   17,  190,  619,   37, 1937,  756, 2690,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  499,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1884, 2620,    1,   39, 2685, 3209, 1090,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1955,    1,  326,    1,   32,    1,    1, 1819,    1, 1294,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1458, 1021, 2285,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  506, 1770,  105,  417,    1,    9,    1,   37,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  841,    1,    1,    7, 1147, 3006,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2844,   32,  142,   37,    1, 3363,   12,  472,    1,   32,\n",
      "         3343,  806,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  108,  310,    1,   45, 1718, 2039,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1075,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1186,   12, 1861,  580, 1002,    1,  531, 3102, 1512,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   45,  166,  442,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1224,   45, 1097,   93, 1784,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  735,   12,    1,  669,  967,  198,  401,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  754, 1844,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199, 2202,   39,   98, 2563,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1237, 1658, 1117, 1525,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3261,  927,  375,  195,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1547,    1,   85,  187,   69,  102,  686, 1653,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1445,  863,    1,    9,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1287,    1,  202, 1705,  338, 1139,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   45,  166,  608,    1,    1, 1720,  166, 3258,   45,\n",
      "          507,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2977,    1,    1,    1,  928,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,    1, 3230,    9, 1194,   73, 2069,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1414,  288,    9, 1954, 1995,   98,  531,\n",
      "           12, 3391,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 3096,  872, 1830,    9, 2826, 3295,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1019,    1, 1991,    1,   37,    1,   28,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,  908,  858,  297, 1021,  847,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2374, 2167, 1994,   10,    1,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2987, 2988,  898,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3124, 1082, 2453,   37,  335,  916,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 3118, 2517,  729,    1, 1428,  232,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  487, 3282,  288,    9,    1,    1,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1687,    1,  787, 2641,   37,  123, 1772,   98,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   25, 1473,   98, 1894,   14,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1420,    1,   37, 1624,  253,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  196, 1564,  259,    9, 1135,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3171,  738,  220, 1214,  379,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  961, 1482,  458,  475,    1,    9,  105,  551,  331,  389,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,  338,  548,  585,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  224, 2560,  251,    1,   45, 1772,  111,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2327,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,  123, 1387, 1675,   45, 2615,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 2308,  693,  118,    1,    1,   32,  365, 2362,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1309,    1,    1,  152,  647,  159,   37,  148,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1537,    1,  162,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  768,   61, 2443,    1,  202,  669, 1877,   37,  856,   81,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  542,   19,    9,    1,  619,  312,  260,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  208,  650, 1484,  592,  582,    1, 1914,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169,  614, 1632,   32,  316,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  196, 1732,   46,   37, 2264,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1687, 1022,    1, 3008,    1,    1,  677,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  547,    1,    1, 2572,   32,  463,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3289,  884,    1,   12,  770,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,  794,  596, 1116, 1222,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3278,  729,    1,  187,  105,  595,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  683,    1,  640,    1,   37,   52, 2812,   98, 1102,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151,    1,  474,  498,   37,  907, 1411, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  167,   52, 1890,   63,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  361,    1,    9,  675,    1,   37,    1, 2500,    1,   98,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  747,    1,  746,   32,  365,    1,   37,  151,    1,    1,  150,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1107,  293,  437,  794, 2086,  767,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2767, 2695,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1017,   45, 1680,  361, 2622,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  187,  104,  801,   32, 3391,    1,  365, 1345, 2897,   32, 1850,\n",
      "          531,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2511,   37,   47,  535,  437,    9,  152,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   66,  417,    1,    1,   85,  191,   69,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2711,  753,   37,  125,   37,  166, 1948,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2069,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  912, 1411,    1,   45, 1994, 2819, 2039,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1718,  833,  612,  877,    1,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,  159, 1374,  388,  763,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2311,    1,    1,  384,   10, 1002,  778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2978,   51, 2354, 2198,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  425,  426, 1225,   81,  530, 1722,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2634,    1,    1,    1,  766,   37, 1505, 1395, 1597,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1415,    1, 1827,    1, 1810, 1354,    1,  719,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  856,  297,    4,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  111, 2025, 2226, 2192,  320, 1444,  321, 2192,   81,    1,  111,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425,  779,    1,  861,  280,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1005, 2942, 2270,   37, 1418,  384,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1486,  361,  453,  709, 1831, 1041,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2180,    8,    1,  275, 1149,    1, 1515,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12, 2813,   37,    1, 2069,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,   47,  224,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2918,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2, 105,   1, 916,   1, 167,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 166,   1, 159, 334, 321, 151,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1171, 1193, 1140,   37,    1,  844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1771,    1, 2661,  695,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,  317,  417,  244,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  648,   12, 2213,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  286,  338, 1139,    9, 1744, 1149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  636,  120,  884,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2778,    1,   32, 2069,  973,   37,  477,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,  716,  354,   32,  572,    1,  387,    1,   32,  572,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  596,    1,  338,  187,  460,  952,  365,  394,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,  166,  862,  159, 2680,   98,  166,   71,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  177,  228, 1530,   32,  885,  854, 2702, 2291,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2716,    1,  732,   95,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  668,    1, 1107,    1,    1,  147,  297,  912, 2285,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183, 1272,    1,  238,  361,  987,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,   32,  275,  389, 2891,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2662,   12, 2918, 2820, 1494, 1159,  289,  892,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  875,    9, 3077,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,  166, 1239,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1433, 1924,    1,  648,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  448,  850,   39,   37,    1,   54,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2877,  488, 2774, 2827, 3155,  220,   23,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  389,    6,  194,  390,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2073, 1843,  207,  418,   37,    1,  372,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  320,  579,   61,  460,  600,  726, 2196,  861, 1227, 1360,  612,\n",
      "            1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  193,  603,   28,  176,    1,  613,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2295,    1, 3206,  528, 2811,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  171, 3272,  590,    1,  584,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,  108,  539,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115,    1,  167, 1306,  284,  199,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  489, 3222,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1542,   37,  319,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141, 1902,    1, 3287,   37,  601,   73,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1064,    1,   98, 1815,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1965, 2982, 2139,  220,    1,    1,    1, 2604,  889,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116, 1484,  321,  243,    1,  408,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2659,  444,    1,  695,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2905,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  487,  358,  851, 1564, 1193, 2585,   32,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  178,  342,    1,  144,  145,  759,  399,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3045,  798,    1,    9, 2597, 2625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226,  331,  707,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2637,  335,  631,  187, 1186,  701,   32, 1660,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1, 3155,  856,  193,  297,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2193, 3370,    1, 2572,   32, 2018,   12,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1201,    1,  267,  460,   12,  435,  333,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  915,  667, 1527,  437,   32,  531, 1554,  548,  645, 2705,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183, 3001,  361,    1,    1,  504, 1942,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,    1,   39,    1,  302,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1784, 1101,    1,  187,  218, 1276,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2529, 2164,  640,   79,  540,   45,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  275,    1,   32, 2171, 2800,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  304,    9, 1033,  195, 2264,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  571, 1717,    1, 2911,   81, 3153, 2220, 1281,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387,  572,  134,   45,    1,  182,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962,  375, 1401, 3209, 1415,   37, 1131, 1684,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1663, 1929,   98,  531, 2410,   32, 2835,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,   12,    1, 2726, 3040,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  315,    9, 3358,    1,   32, 3339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  384,  617,  259,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2807,  750,    1,  726,  297, 3103,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1086,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2377,  415,  105, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3096,  183, 2954,   79,   37, 2315,  698,   32, 3116,  922,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  719,  764,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1891,  844,  716, 3006,    1, 1056,    1, 3365,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  651, 1031,  805,    1, 1173,   32, 1658,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  571,    1,   45, 3182,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1405, 2281,  776,  891,  892,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  844,    1,  928,   32,  104,    1,  477,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,    1, 2102,    1,   32,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2924,    1, 2751, 2572,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  312, 2819,    1,  478,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1028,    1, 1380,  317,    1,   32,    7,    1, 1213,  353,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 3018,  315,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  463,  464, 2830, 1523,  947,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  476,  864,   37,  168,   63,  163,    1,\n",
      "          903,    1, 1906,  428,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  854,    1, 2531,  379, 2000, 2673,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181,  775,    1, 1273,  259, 1102,  841,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1, 2954,   28,   98, 2334,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1902,  900,   12,    1, 1544, 1483,    9, 1852,   12,  290,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  159, 1269,    1,  734,   28, 1010,  861,  997,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,  142,   37,  130,  180,   98, 1978,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3256,  429, 3214,   32,   33,    1,  221,   81, 1159,  449,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  354,  415,  105, 2195,    9,  730, 2614,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  489,    1,   39,   45,  531,    1,  513, 3377,   32,  365, 1089,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  741,   37, 1083,  487, 1184,  347,  232,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  803, 2032,  729,    1, 2738, 2032,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2473,  256, 1018,    1, 1766, 1767,  841,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1974,  538,    1,  768,  396,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,  392, 1090, 1667, 1758,  636,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  224, 2355, 1013,    1,  829, 1778, 1013,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  315,   37,  877,  793,  238, 2219,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1345,    9,  912,    1,   98,    1, 1006,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  861, 2996,  565,  820,  191,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2999,   91,  313,   37,    1,  923,  220,    1, 1450,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,  307,  776, 2263,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3009,   37, 1237, 2158,   45, 2121,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  519,    1, 2807,   32, 1264, 1838,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1481, 1349,   37,    1,   98, 1170,  538,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1795,   12,  354,   32, 1821,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  744,   39, 1004,  115,   45,    1,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  506,   30, 1228, 2718,    1, 2264,  176, 2413,  297, 2019,\n",
      "         3004,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3168, 2005,   37,    1, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  696, 3276,  726,  119, 1194,   73,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2448,  386, 2800, 1218,  512,  476,    1, 1231,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  142, 1772, 1054,   32,    1,  187, 2458,    1,  460,   39,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  477,   51,   52,  915,  916,   37, 1154, 1796, 1123,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,   12, 1021, 1343,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  107,   66, 1587,   98,  183,   69,    1, 1124,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3373, 1976,   32,  632,  880,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1065,  199,  207, 1604,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1, 2072, 1220,    9,  526,  844,   12,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  364,   12,    1,  288,  460, 1979,  384, 1130,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  850, 3265,   39,    9,  166,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  503,   12,  225,  418,  528,    1,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1187, 1658,  275,    1, 1188, 2025, 1942,    1, 1160,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1497, 2967, 1408,  838,  548,  105,    1,  698,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,    1,    1,    1,  605, 2199,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  873,   81,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1388,   45,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  929,  267,  800,   60,    1,  786,   79,  408,  606,  686,  437,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564, 1018,  411, 2022,    1,    1, 1745,   37,  865,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1062, 2115, 2143,  170, 1812,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203,  321, 1366, 2446, 2492,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  479,    1,  391,  371,  420, 1121, 1169,   15,    1, 1796, 1091,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3340,   32,  531, 2572,   32, 3155,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,   37, 1292,   32, 2069,  117,    1,    1, 2275,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,    1,  693,  365,  613,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   56, 3375, 2572,   32, 3339,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3039,    1, 1090, 2900, 2795,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2442, 1740,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537,  446, 2352,    1,   37, 2237, 2018,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,   79,  444,    1,   32, 1764, 1990, 1286,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  225,  616,    1,  191,  677,   69,  102,    1, 1630,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1095,  213,   37, 2010,    1,    1,   98, 1611,  778,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1879,  619,    1,  191, 3228,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  197,   93, 1391, 1031,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1,  365, 1228,   37,   52, 1211,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1352, 3002,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2453,  125,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1178, 1061,    9,  840, 1778, 1039, 2690,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   89,  163,    1,   12,    1,    1,   37,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3173,  683,    1,    1, 2736,    1,  261,  166,  147,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1281,    1,   32, 1300,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  721, 2853,   28,   37,    1,   32,    1,  551,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2283,   12,    1,    1,    1, 1298, 2205,    1,  947,  774,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  119, 2098,    1, 1380, 3211,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  384,  105, 2164, 1167,    1,  537,  857,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2141, 3061,    1, 1209, 2630,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2958,   77,    1,    9, 3103,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3350,    1,    1,  193,   32, 2018, 2517,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2863,   61,    1,  885,  822, 1641,   32, 2956,  149,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  729, 1625,   37,  875,  220,    1,    1,  710,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  818,    1,  157,  590,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2373,    1,  938, 2404,    1,    9, 1230, 3011,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91, 2055,  365,  829,  927,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3168,   32,  142,    9,  103, 1569,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 2419,  218,   32,  276,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2868,    1,  632,  232,   32, 3144, 1388,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3228, 1493, 1515,  454, 1159, 2925,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   56, 2722,    1, 2616, 1149, 1558,  297,  861,    1,  230,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200,  201,    1,    1,  202,  193,  203,  204,  205,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,   12, 3355,   21, 2707,   12,   46,  220,  342,   37,  698,\n",
      "           32, 2020,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   37, 1636,   29,    1, 1316,  593,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  952, 2966,    9, 1674, 2712,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2268,  786, 1710, 1370,  220,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  190,  750,  357, 3130,  726,   39,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314, 2483,  579,   12,  176,   48,   32,  927,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  487,    1, 1740,  664,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  524,  525,   15,   71,   32,  166, 1893, 1034,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1943,  786,    1, 2056,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1794, 1707,  927,   45, 2275,   12,  443,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   98,   37,  978, 2953,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1, 2497, 2774, 2827, 1147, 1223, 3133,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2135, 1337,  531,  285,  548,  940, 3340,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  356,  560,  347,   16,    1,  276,    9, 1034,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  220,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  305,  670,    1, 1463,    1, 2320,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3358,   12, 3137,   61,    1,    1, 2431,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2195,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2458, 2286,  915,    1, 2428,    9,  207,  259,  962,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1385,   28,  410,    1,    9, 1973,  187,  902,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  295,  125,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2175, 1371,  821,  724,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3370, 1665,   37, 2856, 3347,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1658,  327,   51,   52, 2051, 2341,  763,  334, 2898,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1663,  251,   37,  335, 1501,  457,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2737,    1,    1,    9,    1, 1388,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2563, 1240,   52, 2198,    1, 2158,   98, 1517,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  885,    1, 2644, 3102,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2751,  288,   79, 2909,   32, 1633,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  190,  907,  453,  107,  125,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  865,   37,    1,    1,  754,   45, 1675,    1,  548,    1,\n",
      "          537,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2087,  433,    1,   39, 2605,   98,  864,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,  147, 1800,  142,   37,    1,    1,   12,  863, 1918,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  150, 1268, 1116,  656,   32,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3354,    1, 1980,   37, 2341,  949,   45,  649, 3365,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2851,  116, 2542,    1,    9, 1778, 2580, 1851,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  585,  631,   37,    1,   32, 1290,  396,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,  945,   69,  267,  729,   32,  112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1, 3367,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3118, 2774,  437, 1710,    1,  909,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1527,  317,  354,    1,    6,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1147, 1583,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885,  879,  631,    1, 1518,   32,   98, 2523,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  506,  782,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1855,  669, 1321,  384,  531,   37, 1154, 3102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,  200,    1, 2969, 3019,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2890,    1,    1, 1675,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 2446, 2587, 2523, 2225,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1654,  142,    9,    1,  671,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1020,    1,    1,  284,    1, 2946,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2540, 3267,   37, 2555,  449, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,    1,   12, 1594,   37, 1343,  750,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2194, 1705,    1, 2195,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2159,  275,    1,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1211,   37,   22,    1,   93,   45,  853,  844,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  156,   71,  187,    1,  418,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2913,  593, 1587,   45,  829, 1017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1484,    9,  927,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3024,   12,    1,  288,   79,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1287,   37,  688,  590,    1, 1739,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3271,    1,   32, 1948,    9, 2941, 1569,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   63,  166,  862,    1,    1,  338,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1000,    1,  321,  619,    1,   98,  229,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  736, 1268,   98,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 1396,  163,    1,   12,    1, 3150,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035,   37,  398,  611, 2349,  920,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1788,  787,    1,  453, 2364,    9,  105, 1209, 2401,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2178, 2147, 1585,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  551, 2238, 1421,    1, 2019,  630,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1940,    1,  284,    1,  220, 3134, 3077,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,  686,  119,  548,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  306,    1,  829,  149, 2032,    1, 1056, 2119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  114,    1, 1632,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1147, 2681,    1,    1,  163,    1,   12,    1, 3111,  361,\n",
      "          105, 3160,  565, 2572,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2041,  533, 1348,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1902,  220,  247, 1394,  361, 1183,    1, 1593,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  273, 1609,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2950, 2414,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,  388,    1, 1046, 2527,  164,  127,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 3160, 1156,    9,  531,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  880, 2421, 1159,    1,    1,   32,  395,    1, 1887,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 1361,  787, 1684,    1,    1,    1,   37,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1579,  196,    1,  176,  551,  612,  887,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  287,  685, 2177,    1,    9,   22,   23,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3354, 2161, 1822,  193,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,  162,  105, 2075,    1, 1086,  453,  449,   74,   28,  118,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  231,    1,   32,  617,  618,    1, 1103,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  686,  191, 3092,  134,  548, 2811,  176,  539,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1407, 2128, 2129, 1851, 1720,  531,    1,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094, 2414,   32, 3339,   63,    7, 2129,  741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,    1,    1,    1,  176,    1, 1090,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1918, 1114,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1147,  947,  379,    1,    1,  565, 2572,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  215,  146,    9, 3025,   12, 2126,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  231,    1,    1,  256,  365,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1128,    1,    9,  166, 1509, 1311,   32,  166, 2301, 2012,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2357, 2263,   45,    1,    1,   32, 2772,  927,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  548,    1,  287,    1,  105,  221,   37, 1155, 2143,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3065, 2903,    1,    1,  384, 1264, 2854,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   51, 1289,    1,   37, 1527,  531,   12,\n",
      "          622,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   61,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  683, 1426, 2069,  176,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 1061,   32,  602,    9,  722,   98, 2877,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  546,  582, 2800, 2565,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  251,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1100,    1,  845, 1998,  769,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,    1,  447,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  299,  556,    1,   45,  116,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1625,   37,    1,    1,   45, 2890,  533,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2502,  902,  463, 2170,   12,    1,   37,  522,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  256,  278,    9,    1,    1,  259,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1544,   85,  187, 1163, 1831,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  967,  252, 2209,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1089, 1090, 1091, 1343,  460, 2440,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  561,    1,  927,   45, 1955,    1, 1917,  546,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  794,    1,   37,  843,    1, 1013, 1085,   37,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  829,  875, 2474,  259,   43,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2420,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  348,   37,   47,   45, 1537,    1, 2456,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3194, 3195,    1,  321,  712,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1764,    1, 1779,  688,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  447, 1976,  454,   37, 2763, 3345,   32,  531,    1,  267,    1,\n",
      "           45,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  361, 1087, 1636, 2575,   37,  265, 1754,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  193, 1059,   28,  753,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115,    1,    1,   32,  105, 2396, 1953,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1656,   15,  686,    1,   32,  367,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2411,   37,  865,  671, 3126,    1,    1, 2971,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  479,    1,  148,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,  163,    1,   12,    1, 1832, 1832,   32,   56,  497,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  852,    9, 2249,  851,   32, 3360,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1103,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  680,   97,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2753,   32,    1,   12,  914, 3201,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2454,   32,  262,  263, 1560,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1,  640,  463,  455,    1,    1, 2817,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,  875,   98, 1788,  163,  778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3290, 2236,  513,  193,  514,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32, 3279, 1813, 3354, 1414,    1, 3006,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2448,  386, 2800, 1218, 1831, 1216, 2958,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1211, 2760,  361,  105, 2091, 1523,   32,  525,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,   37, 1543,  326,    1,  187,   82,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1717, 1215,    1,   10,    9, 2516,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2855,    1, 1056,    1, 1944,   98, 1407, 1563,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  453, 1228, 1097, 1135,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2241,   45,  647,  253,  690,  148,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  980,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,   32, 2088,  818,  605,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   46,   37,   52, 2827,    9, 1428, 3345,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,   25, 2075,  548,  148,  695,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3282,    1,    1,  103, 2635, 3198,   39,   45, 2106, 1990,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   50,   21,   37, 1083,   28,   37,    1,  131,   32,\n",
      "         1126,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3114, 1583,    1, 1388,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2137,  176, 2835,    1, 2856,  176,  177,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,   12, 2681, 1108,  680,  365,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1107, 2610,  778,    9,    1, 2051,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  104,    1,  633, 1536,    9,  467,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3302,   37,  927, 2468,   12, 2107,  966,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1228,    1, 1792, 2821,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1230,   15,  120,    1, 1230, 2528, 1220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 1994, 2819,    1,    1,  176,   46,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  190, 1031, 1298,   98,  236,  237,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2748, 1245, 3159,  166, 1367,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327, 3102, 2162,   32,  531, 2503, 1833,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   83, 1454,   59,  138,    9, 1558, 1143,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1883,    1, 2232,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  992,   85,  384, 1428,  317,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  216,  135,  730, 2288,    1,   32, 2835,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  972,   98,  284,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1687, 1022,    1, 3008,  103,  316,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  176,    1, 1759,  309,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1189, 1662,  140, 1537,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,  327,  218, 2198, 2226,    1,  182,    1,  331,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  847,  197,   28,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1458, 3309,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  177,  898, 2572,   32, 1815, 2292,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  925,   12,    1,    1, 1766, 1767,  207,  190,   52, 1787,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,  193,    1,   32, 2179,  756,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2891,   45, 1147, 1583, 2924,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  121, 1821, 2640,  288,    9,  865,   37, 3024,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1592, 1079,  203,    1, 1710,  741,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,  395,    1,   51,    1,  994,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2701,  922, 1760,    1,    1,  384, 1675,  548,    1,   32,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1568,    1,    1,  551,    1, 1332,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2178, 3382,   98,  776,    9, 2834,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  600, 1046,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,   66,  187,    1, 1959,   65, 2395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1716,    1,  988, 2759,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1364, 1365,    1,  913,  770, 2083, 2147,   45, 2024, 1630,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1758,   37,  166,   72, 1385,   45,  166,  455,   26,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  790,  246,    1,  762,    9, 2332,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1461,  477, 2414,  103, 3374,  650,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  203,   37, 1865,    1,    1,    9, 1658,  224,    1,  378,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 2405,   85,    1,  113,  530,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3121,    1,  765,  297,    1,    1,  541,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  590, 1048,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2162, 1950, 1137,   37,   32,  121,   36, 3071,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   81,   32, 3263, 2340,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2209,    1,   37,    1,   12,    1, 2537,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,    1,    9, 2779,    1,    1, 1343,  408,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  891,    1, 2571,  474, 2924, 1159, 3118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  585,  125,  584,    1, 1069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  220,  365, 1173, 1327,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282, 2468,  335,  631,  297,  104,   32, 1764, 1990, 2069,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101, 2924, 2856, 3375,   32, 3339, 2625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2313, 2414,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  273, 1609,    1,  218,  332,    1,  225,   28,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1866,   37, 3209,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  794,    1, 2731,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  319,  357,   52,    1,    1, 1926, 1927,   90, 1785,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2467, 1251,  104,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1,   12, 2978,  127,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  311,    1,  220,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 2551,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3087,    1, 1850, 1327,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  446, 2877,   12, 1841,    1,  191, 3345,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094, 1353, 3339, 2731,    1, 1428,   12, 2266, 1082, 2199,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359, 2431,   90,   45,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  810,  547,  140,  297,  447,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2692,  166,    1,  729,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1850,  135,  577,   98,  244,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1809, 1270,    1,   98,    1, 1013,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1583,    1,    1,   45,    1,   32, 3339, 2625,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  315,  377,  163,    1,   12,    1,    1,   37,    1,    9,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 3139, 1462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  908,    1,    9,    1, 2701,  872, 1603,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  177,   56,    1, 2548, 2572,   32,    1, 2517, 3279,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1818,  147,   37, 1709, 1377,   98, 1107,    1,    1, 2730,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1980,   37, 2709,  741,  652,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  374,  640,    1,  340,    1,    1,    9,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3140, 1550,    1,    1, 3137,    9, 2024,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510,    1,    1,    1, 2732,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1739,    1, 1052,  570,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,    1,  527,   12,  386,  317,  183,  390,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,   26,  417,   98,   69,    1,  954,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1, 3338,   32, 2597,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1645, 3102, 1512,    1,   98,    1,  531,   12, 1850,   69,  532,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1284, 1400,  187,  104,  295, 2139,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2104, 1082,  977,    9,  626,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2400,    1,  321,  631,   37,  340,    1, 2116,  361,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1697, 2327,    1,   12,    1,   32,  237, 1204,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,   12,  103, 1410, 1421,   28,  220,  224,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  380, 1717,    9, 1214,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3117, 2035,  631,   32, 3235, 1264,  841, 2107,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612,  322,  104,   79,  444,  691,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2308,  193,    1,   98,    1, 2579,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3115,    1,   39,   37, 2119, 2777,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  591,  187,  592,  361,  593,  458,   46,   98,  594,  439,\n",
      "           32,  595,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  159,  176,  365, 2284,  187,  156,  308,   71,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2474, 1298,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  396,    9, 1549,    1, 1080,    1,  531,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1325,  861,    1,    1,    1,  420,  267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1539,   45,    1, 1464,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3183,    1,  571,   37, 2760,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,    1, 2524,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1276,    1,    1,  679,   25,    1,  341,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   94,    1,  220,  119,  845,  115,   45,    7,   29,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213,   37,  713,   98,    1,    9, 1388,  220,    1,  386,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3177,   28,    9,  593, 1624,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,    1,  388,    1,    9,  657,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3052, 2712,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3272,    1,   37,  759, 2592, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  848, 2352, 1234, 2294,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2662,   12, 2918, 2820,   51,  429,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1936,  829,    9,  105,  559,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   10, 2317,  384, 2681, 1480,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3134, 2158,   45, 2121,  256, 2570,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1443,  220, 2080, 2056,  517,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  403, 1447,  267,    1,   45, 1700, 1833,   46,    1,   98,  104,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  224,  166, 1411, 3028,    1, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,  242, 1913,  401,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2470,  387, 1896,    1, 1224,    9,  903,    1, 1447,   46,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3257, 1587,   45, 2342,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1187,  166,  163,    1,   12,    1, 1188,  166, 2824,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  878,  908,    1,  382, 1649,  261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1591,    1,  952,    1,  714,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3046, 2659,  247,  454,   37, 2841, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 2776,    1, 2625,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  132,    1,  439,  176,  654,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,  957,   37, 2000,    1, 1839, 1259,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3215,  477, 2094,  311, 2936, 1918,  297, 3313,   32,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3241,  729, 1555,   37, 1709,  384,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3343,  806,  264,  528, 1508,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3117,    1, 2633,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  116, 1484,    1,  417,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1419, 2229,  327, 3011,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  334,  321,  698,    1,  600, 2615,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2563,    1, 1515,    1, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  368,    1,  102,   37, 1198,    9,  667, 1295,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2292, 1258,    1,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 2769,   45, 1622,   69,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  365, 1656, 1729,   51,    1, 2711,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2254, 1392, 1140,   45, 2382,  618,    1, 2383,  183,  199,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,    1,  596,    9,    1,  182,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,   28,  166, 2498,  220,  552, 2168,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  640,  247, 1194,  754, 1844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3180,  168,   37, 3262,    1,  191,  388,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2373,  861, 2432,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  677, 3120,    1,   79,   37, 1509, 2085,  698,  220, 1524,   73,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  891, 2817, 1805,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3337,  515,   91,  411,    1,  176, 2916,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  780,    1,  587,  211, 1259, 1757,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  126,    1,  384, 2693,    1,  327,  593,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3209, 2511, 1554, 1090,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1181, 1249,  982,   32,  218,  332,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  619,    1, 2714,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,   48,   32,  121,   12,  633,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  698,   28,  251,  340, 1021,  466,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  463, 1447, 2489,   85,  943,   45,  403, 2396,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  167,  197,  220,  845,   69,   82,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777,   37,  130, 3028, 1074,  861, 1228,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  288,   37,   26,    1,  242,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220,  661, 1750,  627,    1, 3375,    1, 3358,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1968,  884,   40,   37,  854,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,   37,  480,    1, 2400, 1021, 1129,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1043,   85,  176,    1,   98,   69,  509,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584,  567, 2162, 1950,  418,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1716,  155,  327,  157,    1,  392,  570,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1931,    1,  297,  393,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1, 3188,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1771, 1603,    1,  317,  248,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361, 1485,  217,  943,   45,  956,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282,    1,  744,   28, 3257, 1388,   32, 2197,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   20, 2373, 1972, 1202,   32,  572,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 2222, 1949, 1412,  844, 2186,  934,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 2172,   98, 2689,    1, 1648,    9,  803,  851,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,    1,  829, 1039, 2690,  333, 1924,  105,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1117,   12, 2145,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1989, 1990,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  864, 1463,  546,  723,  659,   45,    1, 1461,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2217,    1, 2536,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1348,  468,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  451,    1,   81, 2245,   50,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2798,  861,   61, 2491, 2085,    1, 1592,  774,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380, 2405,    9,  449, 1953,  220, 1537,  446,  176, 1428,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,   1, 613,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 176, 551, 612, 353,   1, 131, 354,   9, 166,  72, 401,   1, 234,\n",
      "         182, 235,   1,   1,   1, 234, 182, 235,   1,   3,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  176, 1668,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453, 1118, 1318,  333,    1,   37, 1282,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,   37,    1,   39, 1553,    1,  176,    1,  954,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192, 2741, 2712,  854,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2855,    1, 1094, 2708,  384,  736,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766,    1, 3016, 1935, 2871,  327,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2209,  934,   37,  837,  680,   12,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066, 1625,   37,  877, 1987,  865, 2248,  424,  339,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1421, 2829,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  744,  593,  119,   32, 2161,   12,    1,    1, 3163,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  953, 1315,    1,   37, 1034,  340,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1,   37, 1413,  657,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  632,    1,  649, 2153,  907,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363, 1401, 2107,   32, 3343, 2823,  806,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1203, 1228,  841,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2228,    1,    1,    1, 2116,   98,  848,    1, 1773,   37,   92,\n",
      "           15,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  298,   32, 1639, 1294,    1,  191, 2500, 2485,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2945,    1, 1107,    1, 1018,    1, 1230,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1170,  853,  538,    1,    1,   98,  792,  538,    1,  792, 1893,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2881, 2770,  365,    1,   32,  854,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1249,    1,   37, 1758,   32,  715, 1990,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2500, 2946, 2952,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   69, 2598,   81,   37,    1,  889,   25,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2046, 1518,    1, 2147,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  244,  554,   37,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2415,    1,  162,  449, 2941,  698,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    6,  425,  426,  731,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260, 1445, 1421,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  433, 2466,  952,   37,    1, 2824,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1488, 1470, 1159,    1, 3031,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3326,  153,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98, 1616,   32, 1717,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2754, 1009, 1082,   12,    1,  464,  681,   37,   92, 2754,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790, 1151,    1,  321,   52, 1991,   37,  619,  223, 2078,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  567,  510,  488, 2977,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2702,    1,   32, 2140, 2414,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2104,  267, 3363,  855,   32, 3360,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,  884,   98, 1230,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3359,  744,   39, 3339,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 2591, 1114,    9,  166,    1,   45,  104,  996, 2782,  444,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  741,    9,   10,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3116,  922,  437,  182,  231,  311, 2936,    1,   39,  203,   37,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3200, 1292, 3245, 1240,  619, 1034,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  114,   32,  668,    1,    1, 2347,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  420, 1178,   32, 3379, 2950, 1061,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968, 3340,    1,   12, 2804, 1683,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3117,  726,  601,   73,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3272,    1,    1,  682,    1, 2069,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1606, 1149,   32, 2458,   51,  477, 1517,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1379,  167, 1031,    1,   45,  829,  290,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   59,  572,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  167,    1,    1, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3342, 2059, 2827,   32,   12, 2170,  927,    9,  808,   32, 3058,\n",
      "         2282,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  996,    1, 1276,    1, 1424, 1258,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  547, 1530,   32, 3101,   22,  477,   32,  539,  458,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3402, 3408,  420,  288,    9,  949,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3359,   12,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,   12, 3107, 3366, 2199,   37,   52,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1115, 2748,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  344,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,   12,  276,  122,  215,  458,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  480,    1, 2423,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2357,  837, 2673,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  686,  191,  388,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2710,  299, 1707, 1009,   12,  693,   37, 1540,  947, 1539,\n",
      "          927,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739,    1,  392,  983,  308,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  761,    1, 1162,    1,  727,    1,  657,  565,  125,   69,   81,\n",
      "           27,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2317, 2144,  537,    9, 3185,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  919,  511,   37, 2651,   45, 3089,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107, 2475, 1210,   37,   77,  102,  845,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 706,   1, 220,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 789,  82, 162,   1, 152,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1380,  453, 1001, 1166,  453, 1149,  565,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358, 3404,  498,   98,  861,  469,   37,    1,  521, 1250,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  593,  518, 2153,    1,  734,  591,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3361,  998, 1645, 3073,  288,    1, 1757,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  108,   45, 2108, 2107, 1969,    1, 3107,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1342,    1,  187,   82,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1545, 3320,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1173,  105,   40,    9,  259,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  529,  102,  972,   37,   52,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  221,  297,    1,  166, 1452,  807,    1,   61, 2175,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,    1, 1998,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,    1,  365, 2452,  517,   12,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  449, 1385,   45, 2531,  854,  336,   46,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,  105,    1,   45,  166,  522,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  669, 1809, 1792,    1,    9, 1116,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1625,    1,    9, 3156, 1295,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1965, 1456,  685,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  736,   98, 2707,   12,    1, 2951, 1844,   28,   37, 2396,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2454,  999,  424,  356, 2700,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433, 2746,   37,  289,   98,  734,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1002,    1,   37, 2242, 2208,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3110, 2590,  449,  354,   45,  914,   37, 3100,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3319, 1508,  683,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  903,    1, 3165,  271, 1159,  942,   12, 2592, 2147,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  544,  193,  804,   39,  417,    1, 1158, 2452,  586,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260, 1066,    1,  220, 2633,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  560,  347,  335,  105, 1150,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,   12, 2102,  920,    1, 2464,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  169,    1,    1,  361,  624,    1,   12,  225, 1137,  548,  311,\n",
      "            1,  700,  325,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0],\n",
      "        [   2, 1021,    1,    1,    1,   37, 1758, 1659,   45,  623,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  111,    1,  700, 2733, 1044, 2264,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2628,  696, 2629,    1,  229,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1439, 1529,    1,    1, 2222,   32,  147,   32,  142,   37, 1048,\n",
      "          247, 2225,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200, 1230, 2543,    1,    1,  328,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2695, 2223,    1, 2421, 1821,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 1340,    1, 1194, 2318, 2907,  444, 3319,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  215, 1850, 1973, 2778,    1,   37, 2392,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,    1,   37, 2510, 1220,  187,   57,   71,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 1458,   28,  988,  279, 2815,  315,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,   25,  439,   85,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2893,   37, 2237,  976,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,   37,  815, 2618,    1, 1539,  274,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  920,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   28,   32,  218,  714,  548,    1, 1126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   56, 2572,  187, 2292,    1,  548, 1428, 2924,   64,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  886,  637,  297,  331,    9,  104, 1151,  700,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1848, 1426,  399,  220,    1,   98,  293, 1849,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283,  830, 2327,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  835,    1,    1, 1013, 1522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   71,    1,    1,    1,   14,   15,  764,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  957,    1,  829,    1,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3229,    1,  967, 1568,   38,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  524,  525,   15, 1121,   32,  645, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2819,    1,  105,    1, 2457,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,  650, 3093,    9, 2862,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1841,    1,    1,  372, 1448,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  413,    1,    1,   79,   94,  315,  187, 3308,  108,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  446, 2226, 2233, 1334,   32,  876,  612,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  582,   45,    1,    1, 1723, 1484,    9,    1,  219,    1,  681,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  430,  476, 2117, 2924,   37,    1, 3118, 2751,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,   12,    1,    1,  775,   98, 1870,   12,  327,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  992,   28,   97,   98, 3391,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2811,    1, 1510,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777, 1359, 1450,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1107,    1, 1707,    1,   85,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9, 1110,    1, 3252,   61, 2149,  506,  176,  230,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  803,  112, 1986,  729,  198,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  855,    1, 2572,   32,  186,   45,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1940, 1343,   32, 1238, 3246, 3293,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2949,   12, 2640,  480,  856,  220,    1,  114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2680,  256,  311,  199,    1,   37,    1, 2650,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,  719, 1858,  132,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1965, 2982,  619, 2919, 1021,   92,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2716, 2007,   37,    1,  312,  821,  456,   85, 1325,    9, 1018,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,   37,  453, 2315, 1262,  444,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  640,  365,  845,   98, 2046,  477,  997,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2786,  350,    1,    9, 1100,   12, 1151,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,  112,    1,  861, 2521,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  499, 1549,   69, 1069,  641,  105,  784,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  561,    1,    1, 2905,   37,    1,  166,    1, 2655,   32,    1,\n",
      "           46,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3017, 1008,  729,    1,  528, 1013, 1522,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  198, 3087, 2414,  786,   32,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  273,  176, 2295, 2614,    1,  446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843,   12, 2742,  967,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1583, 1216, 2500,  663,    1, 1897,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2335, 2844,   32,  455,  344,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1474,  246,  853,  719,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  879,  647,  693, 1757,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,  27, 439,  45, 539, 540, 423, 428,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  25, 439, 526,   1, 829, 919, 185,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428,  147,    1, 1342,  750, 1576,    9, 3378,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1113,   67, 2917,  699,  915,  339,   37,    1, 1146, 1703,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  398,  148,    1,  647,    1, 1415,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1419, 1734,    1, 2943,    1, 1671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1962,    1,  132,  220,  161, 1228,  700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  786, 1167,    1,  612,  619, 2017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3230,    1, 3064,    1,    1,  726,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1246, 1167,    1,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1460,  741, 1552,   98, 1094,   12, 3339, 2129,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1654,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3359, 2162, 2429,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  113, 1056,  402,  631,  297, 2275,   88, 1002,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,    1,   37,  463, 1383,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  162,   24,  881,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1444, 1445,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810,  166,  365,  535,  656, 2261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2162, 1950,  176,    1, 2960,  418,   37,  228,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  442, 2060,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2755, 1306, 2213, 3115,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1,    1, 1058,   98, 2028,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  398,  134, 1899,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  215, 2924, 2572,   32,  531,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1077,    1,  528,  410,  550,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2615, 1980,   37, 2654,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2615,  167,   52, 2198,    1,  411,   32,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  665,   98,  105,   16,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  829,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3303,  361,    1,   32,  427, 1343, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  160, 1161,  526,   32, 1352,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1060, 1999, 3156,  187, 2817,    1,    1,   32, 1932, 2741,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2655,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  456,   85, 1022,    1, 2296,    1,    1,  162,  590, 2731,\n",
      "          764,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   56, 1530,  548, 1260,   98,    1, 1178,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2489,   37,    1,   32, 3376,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1420, 2331,   45,  395, 1220,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  681,  187,   64,  868,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1381, 2781,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  671,  716,  572,  197,   45,    1,  331,    1,   28,  384,\n",
      "            1,    1,  356, 1490,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   12,    1, 1992,  967, 1846, 2399,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1227,    1,    1, 1505,  662,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,    1, 1272,   39, 2496,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1,   51,    1,  294,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1542,    9,  166,    1, 2749,   45,  593, 2522,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,  953,   98,  800,  455,   15,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3321,    1,    9, 1090,  444,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 613, 725, 112, 696, 780,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 324,  37,   1,  28, 326, 327,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1712, 3018, 1382,   37,  877,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1, 1243,   98, 1465, 1151,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  709,  978, 3138,  512,    1,  928,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2813,    9,    1,    1,  744, 2438,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  159,  554,   98, 1625,    9,  365,  161, 1607,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963, 2695, 2223,  872, 1666, 1539,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  344, 3403, 2414,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  614, 1273,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 567, 686, 584,   1,   1, 220, 802,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 219, 858, 412,  28,  98,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2835, 2329,    1,    1,    1,  384,  976,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  193,  166, 1690,   32,    1, 2717,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3144, 1557,    1,   98, 1009,   12,  756,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3164,    1,  515,    1,  985,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,    1, 1307,  872,   28,   37, 1835,  792, 2474,  792,  259,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2960, 2668, 1619, 2597,    1,  640, 2764,    1, 1074,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3274, 2590,    1, 1987, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3060, 1216, 2764, 3394,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,    1,   28,  417, 1251, 2706, 2232,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1521,   61,    1, 1160,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3094, 2572,   32,  649, 2003, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 326, 852,  37, 395,  32,   1, 973,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  12, 183,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  103, 3382,  852,   37, 1630,  132,   32, 2646,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1109,  102, 1126,  176,    1,   45, 2320,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1478,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  469,    1,    9, 2594, 1257,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  365,    1, 2510,  813,    1,  884, 2193, 1412,   37,\n",
      "          166, 1411, 1722,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,   37,   52,    1,  191,  539,  540,   12, 1577,\n",
      "            9,  331,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  374, 1086,   28,   98, 1256, 1256,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2034, 1909,  671,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035,   37,  544,  199,   32,  717,    1, 1741,    1,  961,\n",
      "         1038,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200,  593,   12, 1254,  201,    1, 1656,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  167,  698,    9, 3183,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,   12, 3359, 3358,  190,  619,  579,  204,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   68,  338,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3238,   12, 3288,  190,    1, 1857,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  196, 2652,  887,   45,  176,  551,  612,  613,  327,  593,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  140, 2161,   12,    1,  671,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  104,   15,  720,  300,  159,  417,  207,  418,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785, 2025,    1, 1514,    1,   45,   68,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  224, 1475, 1126,   12, 2293,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  437,  729,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1757,    9, 1428, 1149,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  613, 2896,    1,   98,    1,    1,  852,   37, 2992,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2387,   12,  166, 1090,    9, 2523,  183,   74,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1324,   45, 1691,    1,  544,  193,    1, 3286,   12, 1990, 1992,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1095, 2870,   37,    1,  453, 2293,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,    1,    1, 1000,  187, 2249,  345,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  550,   32,  870,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  356,    1,  365,    1,    9, 1361,   12,    1,  475,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  447,   51,  771,    1,   45, 1273,  618,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2002, 1938, 3197,    1,  912,  166, 1194, 2227, 3222,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  463, 2476,  877,  693,   37,  342,   98,  442,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  607,  102,   71,   32, 1352,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  193,   37,  877,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  668, 1701, 1753,  912,  239,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2596, 1260, 2414,  176, 1853,  186,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1574, 2294,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1121,   37, 2286,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1388,   45,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3192,   12, 2170,  105,  688, 2741,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  638, 2087,    1,   61,   66,  187,  105, 2566,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  976, 1874,    1,  460, 2582,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,    1,  716,   45, 2548,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   35,   37, 2354,   98,  528,  477, 2429,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  225,   70,    1,  105,  526,   26,  892,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  506,  396,    1,   98, 1965, 1924, 1849,    1,  323,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1, 1674,    1,  191,    1, 1094,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  418,  530, 1568, 2413,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160, 1161,  338, 1114,   32,   86,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1228,   37,  764,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  103, 2635, 3204, 2845, 1133, 3201,  176,  163,    1,   12,    1,\n",
      "           26,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  694,  376,    1,   15,    5,   37, 1146, 1703,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,    1, 2029,  166,   60, 2174,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  108, 2824, 1610, 1232,   10,  140,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  463, 2926, 2565,    1,  515,   28, 1090,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  267, 2299,  220, 1789,   51,   52,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  790, 2104, 1082,  388,    1,   45, 2847,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   37,  168,  460,    1,   98, 2673,  934,    1, 1232,  590,\n",
      "          132,  220,  455,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  255,  199,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2780,  565,  638,    9, 1013, 1522, 2788,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 3111,   32,    1, 2646, 2426,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  904,    1,   30,  459,   45, 1204,  528,    1,  354,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,   12, 2877,   37,  907,  220, 3113,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160, 1278,  831,  995,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  657, 1023,  131,   98,  105, 1151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2477,  944,    1,    1,  934,    1, 3053,    1,  928,  176,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,  353,    1,  504,   32,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3345, 1427, 1036, 1560,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  552,  552,  361, 2730,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1396,    9, 2992, 2365,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,    1, 2856, 2144,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  539,  455,   98, 2681,    9,    1,  548,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1420,  140, 2025,    1,  372,   45,  649,  368,    1,   15,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  310,  477,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1545,   12,  832,    1, 1224,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,  105,  183,    1,    9,    1,  187,    1,   61,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1486, 1680,  570,  548,  198,  401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1458,    1,    9,  442, 2027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  938,    1, 2072, 3070,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2523, 2836,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,  176,  814, 1990, 3154,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1018,    1,  777, 1116,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  886,  682,    1,  365,  535,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1033,    1,  105,    7, 1228,  218, 2881,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,  937, 2145,   98,    1, 1991,  191, 1763,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2603,    1,    1,    1,   71,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 303, 267, 163,   1,  12, 321, 341, 119,  69,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 176, 166, 103,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  753,    9,    1,   12,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  936,  885, 1778,  861, 2762,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1574,  166,    1,  484,   37,  741,    9,  166,  673,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  331,    9,    1,  190,    1,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  413,    1,   12,  142,    9,    1,  361,  772,  437,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006,   32,  531, 2856,  487, 3102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3380, 1815,  469, 1658,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3298, 2479,  455, 1383,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  171,  640,    1,   12,  278,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   34,  294, 1684, 1625,   32, 2841,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  447, 2562,    1, 1747,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  327, 1828,   71,  118,  481,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,  884,  297,  647,  918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3128, 1713,  531,    1, 1559,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1151, 2094,  844,  450,   37,  166, 1732,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   66,  242,  528,   69,  636,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 1474,   12,    1,  808,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  315,   37,  221,    1,   37,   26, 1039,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  479,    6, 1069, 2337, 1548,   12,   15,   71,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1601,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328, 1116, 2393, 1721,  125,   26, 2679,  748,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61, 2332,  615,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2192,  424, 1178, 1018, 1624,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1191,    1,  500, 1421, 2657,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  390,  959, 1427,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282, 3204,  108, 1443,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  299, 1401, 2022,  806,   32,    7, 1537,  171,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613,   12,  612,    1,    1, 1912,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1086, 3143, 1313,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302, 1712,  387, 2819,  792,  680,  674,  792,   32, 1056,  537,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    9, 2205,   98,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,  942, 1564,  166,    1, 1159,   80,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2278, 1710,   55,  424,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2345, 1818,  147,  894,  771,    1,  442,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094,   12,    1,  580, 1479,  741,  548, 1689,  399,  484,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    8,  197,  304,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  286,  927, 1825,   85,   25,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,  140,  331, 2229, 1140,  656,   24,  220, 1127,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2048,   45,    1,  741,   32, 1422,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  267,  460,   12,  193, 1322,    1, 1147,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,    1,  864, 1388,  297, 1145,   45, 2673, 1806,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 1989,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1478, 2494,  808,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  389, 1347,    1,   32,  350,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2483,  365,  632, 2981,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978,  769,   27,  526,    1,  275,   25,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  617, 1151, 2657,  959, 2740,  766,  475,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2978,    1,  162,  365,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  964,   12,    1,  469,  958,  247,  674,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1435,    1,    1,  750,   32, 2178,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 326, 733, 453, 327, 112,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 582,  37, 806,  32, 129, 890,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  665,  388, 1001, 1159, 1888,  469,  920,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1, 2196,    1,  437,    1,   45,  242, 2102, 1251,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2903, 2110,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796,  542,    1,    1,   12, 2507,  686,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1790,    1,    1, 1413,   37,    1, 2417,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1823,  535,    1,    1,  987, 2014,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2504, 1190,  267,  247, 1831,  476, 1590,   37, 1844,  163,    1,\n",
      "          903,    1,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   42,  755,  133,    9,  152,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   14,   15,  720,    1,  118,   32,  367,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283,  574, 1550,    1,   32,  142,    9, 3187,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  642,  643,   57, 1285,   28,   32,  385,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  166,  754, 2892,  220,    1, 1918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  649, 3340,   32, 2018,    1, 1746,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3211,   32,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2980,    1,  632,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  907,  166,    1,    1, 3005,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2631,  544, 2017,  220, 1214,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  686,    1,   98,  889,  509,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  640,   39,  176, 1176,  445, 3192,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1454,  484,   37,  114,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  519, 2939,    1,    9, 1517,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,  232,  267,  590, 1421, 3358,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  477,   32, 3155, 2414,   56,    1, 1656, 2596, 2083, 2597,\n",
      "         2414,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,    1,    1,    1,  786,    1,  162,   53,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2960,   32,    1,   12,    1, 1606,    1, 3307, 1606,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401, 1245,  608,  166, 3142,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  247,   72,    1,    1,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1056, 2621,   45, 3213,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2781,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,   37, 1819,    1, 1274,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  872,   28,   37,  142,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3327,   81,  176, 1817,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  103, 2673, 1409,    1,    1,   61, 1530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,   96,   28, 1245,   98, 2708, 3136,  477,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1178,  387,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,    1, 1526, 1691,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1574, 1099, 1453, 2089,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,  166, 2488,  774,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1123, 2246,    1,    1,  967, 3288, 1857,  361, 1830,    9,  105,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   33,  402,  407,   98,  242,  983,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   64,    1,  640,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282,    1,    1, 1594, 2721, 1159,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2685,  688, 2642,   37,   26,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  973,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  912,  134,   32, 3141, 2811,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  168,    9,  593, 2522, 2872, 2697,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1309,   37,    1, 1597, 1469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018,    1,    1,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 1497,  686, 3043, 2416, 2440,  433,   32, 3155,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3269, 3237, 1586, 2685,  297,  730, 2614,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1266, 1997,    1,   37,  221,   37,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1972, 2115,    1,   71,   32, 2073,  401,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 2580, 2432,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1173,  176,    1,    1, 2337,    1,    9, 2210,  129,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2333,   74,   45, 2586,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3248,  125, 2469,    1, 2279,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1994, 3185,  639,   61,    1,  191, 1281,   45,    1,   32,    1,\n",
      "          400,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1222,    1, 1539,  669,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2895,    1,   30,    1,   32,    1,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,  190,  138,  331,   32,  755,  399,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  612,    6,    4,  176, 1140,    1,  187,  460, 1141,   37,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1231,  220,    1, 2856, 1009,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  510,   51,  211,  357,  221,  153, 3182, 1090,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3178, 1810,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  191,    1, 2250,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98, 3020,   32,    1,    1,  147,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,  259,   34,   29, 1208,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  420, 2425,   32,   46,  220, 1883,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773, 2510,  105,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1305,  225,   85,  548,  156, 1306,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2080,    1,   61, 2644,   79,  218,  297,  985,  997,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3369,  108,   45,    1,  443,   32, 3118,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,   12, 2232,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  786, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  787,    1,   37, 1937, 3301,  168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1711,  260,   28,    9, 2692, 1090,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1924,   98,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2828,  321,  860,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1359,  997,    9,  627,   45,  638,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,  359,   51,   52,   27,  138, 1259,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,   32,    1, 2946,    1,  191,  439,   45, 2350,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3129,  838,  582,    1,   28,    9,  166, 1990,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   95,  190, 1463,    7,    1, 1294,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2926,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  884,  166, 3077,   32, 2161,   12,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  764,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  519,  449,  726, 1924, 1460,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1366, 1445,  193,   37, 1096,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3162, 1976,   32, 1994, 3387, 2262,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2070,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3294,  288,   37,  865,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2548,    9,  722,  444,  163,    1,   12,    1, 1414,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  884,  297,  187, 2565,   45,  208,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  551,    1, 1056,   45,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870,    1,    1,  253,   47,   45, 1904,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1440,  288,   37, 1343,   32,  183, 1684, 1090,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 1282,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1, 1343,    1,  191,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2098,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2685,  125, 2471,  220, 2611,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 3247,    1,    1,    1,  928,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    6,   93,  157,    9,  104,    1,  455,    1,   91,   98,\n",
      "           69,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  200,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  476,    1,    1,    1,   37,  477, 1505,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    1, 2056,  858,   61, 1120,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  342,  991,    1, 1502,  887,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,  421,   12,    1,  919,  197,  220,  755, 2131,  682,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  694,   12, 1854, 1924,  105, 1298,  857, 1284,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  245,   45,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  228, 2827,    9, 3393, 3389,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  447,    1, 3358,    9,    1,    1, 2708,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1090,    1,    1,   98,    1,   45,  467,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425,  779,    1,  861,  280,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1170,  353,    1,  354, 1010,  677,  408,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783,  251,  411, 1888,   37,    1, 1149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141,    1,  885,  938,  661,    9, 1531,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  359,   37, 2904,  383,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1992, 1778, 1108, 1779,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 2700,    1,    1, 1281,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  439,  417,   98,   14,    1,  636,   29,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 1702,    1,    9, 2336,    1,    1,    1, 2168,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 1031,   45, 1434,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1841, 2209,   13,    1,  625, 1250, 1786,   61,    1,    1,    1,\n",
      "            1,  951,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  229,  533,  361,    1,    4,   29,  576,  236, 1022,  417,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2978,    1,  167,  103,    1,  182,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  931,  477,  449,    1, 3260,   32, 1090, 1918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  614,   37,  166,  806,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,   85,  327,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3112, 2745,  187, 3180,    1, 2453, 2250,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  864,  267, 2673, 1806,   46, 1822,  193,  915, 1183,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,   37,  125,    4,  365, 1788,    1, 1893,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,    1,  385,   12,   14,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  275,    1,   37, 1787,  657,   12, 1151,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 1075,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,    1,  150,  777,  778, 2361,  285,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3182,    1,    1,  943,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965, 2686,  190,    1, 2080, 2056,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1602, 2539, 2800, 1497,  554,   37,   32,    1,  404,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,   69,  102, 1865,    1,    9,  104,  954,  684,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  386,   78,    1, 1212,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1282,    1, 1657,    1,    1,   39,    9, 1694,   45,  914,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  200, 1778,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3013,  953,  786,  183, 1569,   32, 3278,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,    1,  163,    1,   12,    1,   32, 2763,  220, 3374,    1,\n",
      "          437,  650,  267,   88,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   61,  590, 1665,   37,  224, 1724,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1654,  956,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596, 1793, 1258,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3255,    1, 1484,  199,   98, 1663, 2318,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3296,  166,  365,    1, 1092,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3382,  920,  267,  204, 2233, 1910, 3088, 3346,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437, 1082,    1,   37,  125, 2150,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2743,    1, 2748, 1817,    1,  608,  511,  275,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   76,   37, 2449, 2204,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  617,  259,    1, 2263,    1,    1,  736,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1454, 1958, 2141,  229,   32, 1763,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   25,   28,    1,  479,   34,  682,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,    1,    1, 3186,  484,   61,  415, 1938,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  105, 2315,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964, 2786,   45,  365, 3144,  741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  758, 2384,  466, 1013,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,   26,  699,  242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2222,    1,  284,  802,    9, 3118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3102,  513,    9, 1204,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2264,  729,    1,  191, 2819,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3361,  949, 3340,  104, 3091,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  438,   25,   85,  199,    1,  429,  284, 1184,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433, 1579, 3106,    1,  567, 1527,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2502, 2842,  444,    1,   32,    1, 2070, 1057,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  191, 2594,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2664,    1,  312,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3257,    1,  191, 3204,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,  361,  882,  776,  613,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203, 1583,    1,   37, 2377, 1827,  590,   98,  166,   81, 2380,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2885, 1177, 1159,  631,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  260,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1147,  446, 1070,    9, 1876,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  325,  698,   28,   37,   92, 1273,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3164,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106,    1,  686,  220,    1,    1, 2693,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  428,    1, 1625, 3097,  190, 1413,  342,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2966,   45,  166,    1, 1292, 1681, 1090, 1380, 1298,    1,  176,\n",
      "          166,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  418,   32,  218,  714,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  477, 3356,  787,   32, 2597,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  455, 1090, 1091, 2116,   98, 1273, 2287,    9,   93,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  490,   98,   64,    1,  109,  122,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  506,  923,    1, 2693,    1, 1284,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2408,   37,    1,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2596,  937,   16,  295,  565, 3102,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1380,  453,  327,  112,   28,    9,  333,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  196, 1732,   46,   37, 2264,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128, 1203, 2400, 1021, 1588,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1467, 1013,   93,   51, 1121,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1420,    1,    1, 1162,   37,   47,  159,   32,    1,    1,   50,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  657, 1475,    1,  102,  191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  114,  176, 1680, 1153,  729,  680,  549,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   75,  431,  196,    1,  176,  551,  612,  484, 2552,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,    1,  132,  220, 1427, 2853,   45, 1997,    1,  361,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1369,   37,  788, 1074,    9, 1663, 1484,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089,   30,  517,    1, 2226,    1,   12,  176,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  325,    1,  918,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   37,  211, 1604,   98,  284, 1674,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  147,    1, 1991,   37,    1, 3043, 1730,  565,    1,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  274,    1, 1754,   37,    1,    1,   12, 1075, 1638,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1545,    1, 1685,    1,   32,   91,    1, 1654,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707,   12,  342,  142,   51,  335,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  244,   28,    9,    1,    1,   13,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066,   12, 1567,  515,  365,  311, 2936, 2565,  726,   32,  714,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1427,   34, 3315, 1625,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,  774,    1,  167, 1021, 1975,    1, 1219,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147,    1,  288,    9, 2646, 2024,  142,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196,   12, 1715,  349,   45,  176,  551,  612,  613,  162, 1876,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2614,    1, 1515,  693,   37, 3237,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884, 1524, 1569,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1079, 3063,   37,   92, 1013,  778,  220,    1, 2524,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3242,  389,   98,  260,   32, 2839,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  256,    1,  361,   20,   37,  453,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777,  387, 1023,   45,   15, 2083,  163,    1,   12,    1,\n",
      "         1387,  105,  356,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1082, 2746,   37, 2446,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2669,    1,  176,  531, 2498, 2611,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,    1,  244,   98,  845,   69,  636,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,    1, 1597,  315,    1, 1796, 1151,  250,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  545, 1508, 2221, 2356,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1178,  928,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564, 1273, 2118,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2640, 1993, 3206,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,  710,   51, 1752, 1465, 1466,   82,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,    1,  453,  517,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  920,    1,  861,    1, 1997,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  700,    1, 3358,   66,   37,    1,  247,  706,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  492,    1, 2772, 3060,  580, 2095,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  225, 1279,  176,  356,  845,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  620,    1,  716,  242,  572,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3171,    1, 2615,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3178, 2005,  608,    1,    1,    1,  338,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12, 1404,  267, 2153, 1003,   37,    1, 1590, 2793,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  282, 2367, 2695,  135, 1735,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 2483, 1124,   32, 1527,  133,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    7,   37,  166,  132, 1924,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503, 1475,  570,    1,    1,  749,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3325,    1,  191,    1,  176, 1477, 1990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2122,  233, 2153,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,   9,   1, 629,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 644,  77, 104,   1,   1,  32, 871,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  189,  387,  417, 1913,  401,  983,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  497,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,  459,   37, 1343,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567, 1582,    1, 1159,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,   69,  636,  423,    1,  267,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,  427, 2524,  105,  183,  186,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3303,    1,    1,  361, 1434,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  220,    1,    1,    1, 2679, 1263, 1086,   32, 2772,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2660, 1056, 1394,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310,   25,  504,    1, 1572,  191,    1,  369,    1, 1420,    1,\n",
      "            1,    1, 1473,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3194, 3195, 1564,    1,  484,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3060, 2632,   98, 2382,  259,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  422, 1360,  612,    1,  596,    1, 1359,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1414, 1539,    1,   32, 3155,    1, 3356,  787,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3359,  580, 1056,  590, 1161,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 3257,   61, 1866,   37,    1,   32, 2936,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,    1,  587,  588, 1358,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2640,  744,   79,    9, 1663, 1821, 2190,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2561,  572,  338,   98,   64,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    6, 1126,  636,  191,  105,  401,   37,  105,  332,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  632, 2924,    1,  384, 3071,   36,  798,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  477, 1665,  640,  104,  358,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  150,  251, 1211,   29,    1, 3031,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  250,    1,  365,    4,   37,  274,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  619,  365,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220,    1, 1488,   37,  168,    1, 1093,  977, 1334,   32,   69,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1035,  267, 2289,  476,   37, 1174, 1922, 1038, 2113, 1371,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2056, 1011,    1, 1213,   61,    1,  475,   45,  702,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,   12,  375,    1, 1396,    1,  220,    1,    1,  636,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  354,  703, 2216,  585,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3349,    1, 2572,   32,  237,    1, 2625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  991,    1,   15,  191, 1026,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2226, 1210, 2310, 2445,  844,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  140,    1,   32, 1022, 1385,    1, 2022,  806,\n",
      "           16,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  334,  321,  544,  460, 1176,    1,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,  361, 3364,  774, 1444, 1542,   37,  907,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  882,  361,    1,  125,  739,  187, 1151,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 2345,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1105,  787,  572, 1690,  525,   15,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3267,  140,   98, 2410,   74,  176,  136, 3217,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   13,  884,  749,   79,  218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162, 1780,    9, 3343, 1529,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  528,    1,  802,    1,  803,    1,  804,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 2072, 1260,   98, 3374, 1098,  716,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1712, 1452,  829,    1,   61,    1,  191, 2819,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,    1, 1593,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2966,   61,    1,  363,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 1415,   76,   37, 1343,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  852,   37, 1412,  187, 2610,   15,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204, 1627,  119, 1772,  220,  104,   26,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1377,   32, 3184,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   26,  178, 1819,    1, 2657, 2043,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  125,    4,  297, 1411,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1270,  249, 2572,  187,   64, 2682, 1117, 2140,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3053,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  711,   82,   39,  115,   45, 1698,  333,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2941, 3210,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1143,   90,  776,   83,    1, 1590,  176,  654,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    1, 1654,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,    1,  729,    1, 1412, 1107, 3049,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,  197,  225,  417,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3279,    1, 1813, 1157, 2924,    1, 3348, 2751,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  750, 1576,  774,    1,  220, 3378,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3352, 3353,  547,  893,   45, 2877,   12, 1841,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  597, 1583,  655,    1,    1, 1009,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,  709,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1613,  200, 1615,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1361,  726,  593, 1023, 2472,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  410,  115,   45,   65, 1953,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  104,  432,    9,    1, 2130,  195,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2016,  272,   37, 1000, 3283,  394,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,  952,  111,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  588,  297,  166,    1,  562,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,   61,  920,    1,    1,  267, 1716,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2206,    1, 1283,  841,    1,  631,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739,  275, 2503,  590,    1,    1,    1, 1022,    1,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  328, 2857,  361, 2828, 2827,   98,    1,  105, 2410,   74,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2226,   32,  116,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428,  861, 1906,   37, 2237, 2170,    9,   46,   98, 3369,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  431,  865,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2047,   45, 2169, 2299,  134, 3383,  555,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2731,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  386,   44,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65, 1484, 1560,   98,  347,  270,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  790, 1454,  453,    1,   45,  749,  230,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  268,  353,  354,    1,  159, 1374,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1613,   32,  829, 1117, 1525, 1259,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,  851, 3035,    1,    1, 1294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    9, 2518,   45,  166,    1,    1,    1,    1,  105, 2775,   45,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  947,  332,   29,   32,    1,   45, 2502, 1568, 1669,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158, 2408, 2165, 2438,  220,  943,   45, 2528, 1542, 1230,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2448, 1179,  720,  742,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  493, 1042,   37,    1,  636,   32,  257,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,  776,  176, 3127,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,  155, 1194,  401,   15,  570,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 3163,  872,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  671,  640,  356,  845,  187,   60,    1,  951,    1,   94,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,   71,   98, 1986,  297,  455,   12,  954,  104,   60,\n",
      "           28,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2988,  640,  255,  117,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1423,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2147,   12,  822,    1, 1333,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,    1,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2703,    1,   39,   45,  557,  540,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  915,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1017,    6,   37,  166, 2149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  515,   80,  453,  248,  274, 2690,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2940,   39,   98, 3177,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1614,   29,    1, 1228,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  417,   57,    1,    1,   12,  157,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2620,  113,   28, 3334,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  409, 1285,  166,  645,   32,  754,    1,  327,  593,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2257,   39,   45,    1, 1705,   37,    1,  361,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1577,    1,    1,  220, 1872,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  766,    1,    1, 1183,  472,  468,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,  251,    5,    1,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,  697,   37,    1, 1690,  312,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  800, 1068,  568,  246,   98,  487,   93,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 1550,    1,   39,   10,   44,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2974,    1, 2977,  719,  105,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1216,    1, 2072, 1797, 2164,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1248,  531,  863,  211,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  853,  162, 1762, 1747,   37, 1821,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1547,    1,  191,  677,   69,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129, 1286, 2037,  105,    1,   98, 2261,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3218,    1, 2290, 3259,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1968,  768,  149,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1137,  187,    1,  793,  325,  331,   48,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,    1,   51,  582,   37, 2571,  611,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1938, 2607,  382, 2206, 2989, 1892,    1,   37,  166,  777,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  361,  829,   37,  328,   29, 2285,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3375,    1, 3095, 2844,   32, 3339, 1345,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1936,  166,    1,   39,   45,  434,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  233, 1623, 2353, 1010,  735, 2187, 2096,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  435, 1313,   45,    1,   12,  671, 3126, 1918,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,  601,  356, 1144,    1,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,    1, 1167,  877, 2659,    1, 1452, 1810,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   61,  848,   32,  166,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,    1,   32, 2882,  587,  917,   37,  477,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,   96,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100, 1353,  596,  759,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  572,  105,    1, 1098,   46,   28,    1,    1, 3004,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   51,  774,    1,   37,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3316, 2035,  631,  176,  166,  103,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,   23,   61,  198,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   98, 2884,    9,    1,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,    1, 1107,  293,   98,  163, 2304,    1, 3011,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,   12, 2653,   37,  163,    1,  903,    1,  952, 2532,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2998, 1272,   51,  759,   81,    1,  537,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  190,   52,    1,  191,  166,  274, 1417, 2003,    1,\n",
      "            1,  915,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  758,   37,  151,    1,  777, 1108,    9,   59,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,    1, 1977,  600, 3358,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3128, 1921,  176,    1, 2688, 1967,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1808, 1831,   32, 1821, 2057,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  103, 1569,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1574,  565,   66,   98,  503,   12, 1058,   98,  888,  195,   12,\n",
      "          815,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3116, 3217,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  433, 2540,  790, 2362,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1029, 1457,  958, 1578,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  147,    1,  297, 1450,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1369,  852,    9,    1,    1,  952,  131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,   37,    1,    1,  970,    5,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1403,    1,   37, 1206,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612,    1,  192, 1724,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537, 2292, 2414,    1, 2803,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3096,  104,    1, 1380, 2448,  386,   32, 1343,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  267,  590, 2707, 2927,   46, 2198,    1, 2690,  652,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,   12, 1568,    1,    1,  191,  287,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  515,    1,    1, 3135,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  963, 2102, 1107,  525, 2052,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178,  407, 1159, 2551,    1,    1, 1310,   37, 1154, 2588,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  388,  754,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,    1, 2197, 1218,  734,  591,    9,  531,  517, 1039,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2517, 3105,    1,  166,  439,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2031,  437,  777,  778,    1, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2155,   28,    1,  606,  800,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  104, 1477, 1990, 1292, 3325,  792, 2226, 1924,    1,  792,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2993,   12, 3056,   61,  168,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2053,  102,   76,   37,   77,  677,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2, 104, 996,   1,  85,   1,  32,  72,  73, 276,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 592, 536, 658,  93,  32, 596, 954, 424, 356,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 2188,  973, 1159, 2913,  280,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3158, 3297,  162,    1,   39,   45, 2484,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  622, 2705,   32,  531, 2709,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,  232,  326,  733,  327,   50,   37,  649,  669,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  812,    1,  854,  971, 2271,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  393,  721,  908,  225,  469,    1,   37,   52,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2764,    1,  140, 1940,   12, 1427,    1, 1939,  671,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  147,   37,    1,    1,   12,  802,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1287,    9,  332,   45,  631,  176,  746, 3154,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  867, 1536,  449,  767,  444,  668,  912, 2852,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   15,   61, 2934,   37,  123,  166,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3227,  245,   37,  548,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  864,  267,  460,  967,    1,    1,    1, 1021,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 2026, 2574,  207,   59,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  492, 2886,    1,   37, 1463,    9, 3113,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,   16,   79,  872, 2657, 2043,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,   66,  187,  972,   37,    1,  467,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359, 2794,    1,  388,    1, 1219,   32,  539,  458,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    6, 2150,    1,  220,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  184,    9,  537,  297,  207, 3049,    1,  506,   30,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2437,  187,  786,   45, 1090,   12, 1509,    1,  193,  786,\n",
      "           45,  453, 1354,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3226,    1,    1,  384, 2347, 1638,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3380,    1, 1583, 1710,   52,  227, 1265,    1,  104, 1386,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1, 1243,   98, 1465, 1151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,   46,  220,  359, 1686,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,   12,    1,  564,    9,  768,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  750,  167,  184,   32,  166,  183, 1985,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  561, 1083,    7,   67, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  819,  195,  426,  572,  197,   28,  176,    1,  331,  187,   15,\n",
      "           71,   37,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,  224,  162, 1918,   32,    1,   43,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  447, 1707, 1147, 3345, 1220,   98,    1, 1281,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1574, 2481,  600,   10,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2700, 1000,    1,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3257, 2329, 1159,    1,  401, 3179,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051,   37,   26,  704,  551,  705,  656,   32,  455,   37,    1,\n",
      "          858,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  510, 2682,    1, 2028,   32,  260,   45,  114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3359,  132,   37,  470, 2271,  384, 3339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 1447,   12,  695, 2789,  582,  939,   98, 2742,   12,\n",
      "          608,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  799, 1554,  176,  177,    1,   59, 2198, 1021,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  754,    1,   32,    1, 2012,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1209, 2832,    1,   37, 1174,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 3186,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1655,   71, 1810, 2161,    1,  420,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  851,    1,  548, 2596, 2716,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1157,    1, 1975,  298, 1159,    1,    1, 3156,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1999, 2572,   32,  395,   12, 2201, 2003,  139,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,  954,   28,    1,   32, 1022,  257,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  541, 1910,   32,    1,   62,   32,  557,  540,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1465, 1466,  253, 2712, 2362,   37,  480,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,   37,  836,    1,  548, 2673, 2534,  361, 2519,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2208,   32, 2823, 1844,   79,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200,  529,    1, 2446,  698, 1294,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  224, 1126, 1489, 2069,  432,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  510,    1,    1,    1, 1069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2209, 2830,  664,  112,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  377,  249,  898, 1429,  174,   37,    1,   32,    1,  267,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  627,   45,  342,  768,    1,   32, 1820,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,   37, 1412,  538,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3113,   12, 1277,    1, 1023, 2068,   12, 1684,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,    1,   43,  444,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3355, 1321,    1,  396,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 2571,  947, 3342,    1,   37, 2816,   63, 2263,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 2025, 2924,   37, 3360,   37, 1846,   28,  861,    9,\n",
      "          890,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2792,  140,    1, 1990,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  101,   98,  776,    1,  193,  415, 3254,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  442,  448,  703,   37,  131,   98,   69,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056, 1061,   32, 1939, 2162,   45,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   61,   66,    1,  148,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2523,    1,    1,   32,  547,  454, 1832,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106, 1013, 1522, 1539, 1657,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1178, 1061,  548, 2572,    1,  583,   32, 2950,   45, 3354,    1,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2265, 1009, 1008, 2193,    1,    1,    1,    1,  187, 1411,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  424,  259,    1, 1159,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  570,    9, 1151,  293,  387,  105,  365, 1250,   45,  112,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  105, 1762, 2810,   32,    1,   12, 1294,  220, 3318,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  613,  112,  696,  780,  197,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3328,    1,    1,  361,    1,    1,    9,  915,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147, 1648,   37, 1709,  912, 2285,  400,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1539,  926,  420,  892,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2438,   45, 1610,  837,    1,  827,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,   12, 2692,  792,    1,  792,   37,  166,  593,   63,  205,\n",
      "          333,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1270,  583,   32, 1050,    1,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3322,    1, 2475,    1, 2138,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089, 1675,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1529,    1,  190,   52,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,  159,  245,   98, 2089,  533,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    9,  166,    1,   45, 3192,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1459,  606,  105,    1,   45,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  335,  572,   44,   98,   50,  333,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2137,    1, 3348, 3088,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2692,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282, 2472, 1832,    1,    1, 1380, 3204, 1159, 3329, 1990,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1419,    1, 2367, 2695,   37, 2324,    1,    1, 1090,    8,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1844,    9, 2708, 1009,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3196,  140, 1485, 1938, 3197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  581, 2596, 2803,   32, 2504,  463, 3133,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3244, 1902,    1,    9, 1517,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2603,    1, 2870,   32,  507,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1233, 1380,    1,   98,  176, 2507,  250,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2658, 1040, 2770,    1,   74,  548,  298,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1181,   37,  877,  182, 1151, 1429,  191,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1,  864, 2673,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  878, 2458,    1,    1, 1753,  829,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2757,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  627,    1,  167,  429,    1,   45,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,   12, 2244, 2054, 1542,   37, 1192,   28,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  684,  685,  686,  339,  687,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810, 3156,  649, 1295, 1530,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3123,   12,    1,  405,  614,  384,    1,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  420,  782,  590, 1534,   45,  531,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  203,    1,   28,   61, 1123,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2357,  837,   10,  176, 2396,   32, 1966,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  197, 2749,  114,  680,  225,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  288,   37,   26, 1796,  704,  551,  705,  656,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,    1, 2139,  431,  439,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136, 3007,    1, 1402,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  129,  922, 1090, 1829, 1834,  176, 2459,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092, 2039,   37,  477,  207, 2633,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3282, 1090,    1,  288,    1,    1, 3173,  986,  636,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  476, 1757,  881,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1366,  565, 1542,    9,  386,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 2954,   32,  166,  472,   37,   52,  889, 3116,   32,  602,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  631,    1,  345,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 1759,  309,   26,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2533, 2483,  810,    1,  357,  176,  177,  284,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2106,    1,  964,   12, 1715,  315,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   28,    9,  219, 2223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2942,  980,   81, 1159,    1,  176, 1139, 1434,  907,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  669, 1203,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3356, 2450,   37,  907,  220, 2024,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 1658, 2455,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1968,    1,    1,    1,   32,  803, 1273,   41,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  147,    1,    1,  193,    1,    9,  111,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1938, 1723,  839,  523,    1,   12,  552,    6,  314,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  766,    1, 1102,  275, 1835,  365, 1935,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3123, 1958,    1,   74,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1120,   12,  166,  132, 3031,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1300,  844,    1, 1568, 1607,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056,  681,  774,   37,  319,  531,   37, 1154, 1855, 3102,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  612,  852, 1159,  181,  453, 1778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  942,  967, 2084,    1,   32,  537,    1,  986,   85,  734,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  469,   37, 1575, 2119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2615,  865,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1691,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2630,    1,  388,  763,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  167, 1982, 2018,   12, 1815,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  957,    1,   98,  593, 1990,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106,  794, 1013, 1626,  918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1643,    1, 1370,   45,  189,   12, 1251,  672,  315,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2995,   37,   52, 2812,    9, 1778, 1273,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2266, 1707, 1484,    9,  247, 1596,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870,  327, 2744,  365,    1, 2146,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1700, 2572,   32, 3343,  611,  271,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  240, 1515, 1623,   32, 3184,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  547, 2548, 2572,    1,  547, 1941,   32,  531, 2416, 1260,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  168,  460,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3066, 2226,  416,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,    1,   45, 3155,    1,  104, 2924,  729, 1046,    1, 2329,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  299,  908,    1,  331,    9,    1, 1116,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1717, 1606,    1,   39,    1,  474,    1,  477, 1999,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,   55,    1,    1,   12,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3344, 1940, 1260, 2597,  336,    1,  176,  177, 1530,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2841, 2096, 2599, 2730,  302,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1260,   32, 3339, 2414,  228, 3375,    1,    1,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2222, 1000, 2177, 1825,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  326, 1085, 1501,    1,  191,    1, 1914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  229,   32, 1020, 1123,    1,  191, 1340,  361, 3294,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545, 1188,  792,    1, 1001,  792,   37, 1054, 1178,  787,   12,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1550,  973,   37,    1, 2266,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968, 1249, 3349,  187,  497, 1343,    9, 2024,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1181,  614,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  446,  939,    1, 1707, 2433,   97,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  229,    1, 3306,   37,    1,    1,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2751, 3353, 2476,  361,  105, 3347,   32, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1674, 3289, 3021, 1550,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1720,  105,  826, 1765,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2528, 1128,   12, 2528,  810,   32,  786,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2608, 2607, 3060,  513,  514,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2801,  967,    1,  345,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12, 2881, 2964, 1284,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612, 2116,   39,    1,    1,  202,    1, 1822,  168,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  882,  459, 1085,  132,  220, 1128,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  137,  664,  131,  384,  585,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196,  733,   45, 1537,  617, 1597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   98,  103,  176,   26, 2689, 2936,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1062,  458,    1,    1, 1445,    1, 1643,    1,    1,\n",
      "          715,    1, 2677,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   61,   76,   37,   52,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,  622, 2414, 2708, 3006,   32, 3339, 2456,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  828, 1079, 1099,   37,    1,    1,  977,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777,  325, 3028, 2798, 2750,  781,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1277, 1118,  865,    1,  476,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,   12, 3339,  489,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977,  288,   37,  271,  644,  846,  119,    9,  581,  199,  424,\n",
      "          356,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564,   54, 1204,  286,  714,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,    1,   12,  365,  996,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647, 2120,   82, 1010,  148, 1523,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  744, 2306,    9, 3018,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1, 1492,    1,  531,   12, 1354, 2556,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1910,    1, 2576,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,  531, 1656, 2909, 2856,  176,  177,  249,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   28,  921,   79, 1821,   95,  220, 2247,   37, 1747,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  293, 1236,    9,  207, 1107,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2648, 2801,  794, 1766, 1767,  517,  617,  259,  918,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741, 3181, 1242, 3328,    1, 1645, 1414,    1, 1545,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,  46,   1, 442,   1, 861,   1, 361,   1, 674,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,  476, 2725,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  140, 3077,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  302, 1712,  163,    1,   12,    1, 1188,  193, 2047, 2311,  275,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283, 2438,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1292, 1681, 1090,  515, 1523, 2579,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1118,  164,  165, 1828,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  326, 1353,  538,    1,  161, 2320,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,   37, 2919,   45, 3088,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2932,  726, 2376, 2223,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2082, 1000,    1, 2565,  824,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   65,  155, 1184,  347,  191,  402,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3043,  912, 2285,    1,    1, 2928,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2779,  140,    1,   32,  449, 1385,   45, 1447,   26,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496,  267,  829,    1, 2473,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1, 1976,   98, 2073,  851,   32,  632,  945,  139,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1065, 1726, 1140,    9, 2397,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2198,  166,    1,  460,    1,  612,   52, 3192,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  267,  348,    1,  625,  297,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 262, 263, 422, 927, 703,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 349,  51, 817,  85,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  872, 2058,  297,  424, 1578,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  958, 1106, 1107,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  663, 2042,   37,   52,  820,    1,  776,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 2206, 2989,    1,  565,    1,  191,  105,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  669,    1,   59,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  289, 2094,  104,    1,  671,  361, 2505,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  251, 1516,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  113, 1354,   45, 3155,  187,  856,  614,   98,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 2670, 2232,  769,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  262,  263,  932,  606, 2538,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  224, 1205,    9,    1, 1898,   37,    1,    1, 1748,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,   12, 3355, 1554,    9, 3369,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1090,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447, 1877,   37, 1427,    1, 1232,  163,    1,   12,\n",
      "            1, 1360,  612, 1031,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1419, 2996,    9, 1312, 2786,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9, 2381, 1863,  772,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2266, 1082, 2862,   37, 1211, 3351,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2094,    1,   37, 1718,  260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  387,   15,   37,   71,  419,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98, 1340,  361, 1123,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2801, 1996, 2226, 2969,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  321, 2155,  361,    1, 2527,  164,    1,  506,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1520,  884, 1003,  176,    1,  218,  220, 2084, 1395,  844,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  867,    1,  469,   37, 1753,  668,  912,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1233, 1086, 1656, 1809,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1436,  550, 2844,   32, 1260,   98, 1147,  129, 2681,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   64,   12,    1,   61,    1,    1,  361,  105,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  382, 2152, 1073,   32,  477,  191,    1,   45, 1711,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  105, 2177,   37,    1,    1,   98,  869,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  147,    1, 2412,   98,  170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  458,   45,  507,   37, 1289,    4,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  276,   98,  503,   12,  749,  533,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2993,   37, 1289, 1876,    9,    1,    1,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  874,  875,  768, 2096,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2136, 1484,    9, 1064,   37,  195,  315,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,    1,   45, 1273,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  615,    1, 1501,   45, 1568,  433,    1,  574,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144, 1009,  476,  365,  863,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  593,   61,   32,  388, 2124,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  798,  455,  967,    1, 2572,    1,   32,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   32,  786, 1178,   12, 1470,    1, 2153,    1, 1560,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49, 1541,    1,    1,    1,    1,   51,  142,  220,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1935,   15,  190, 1027,    1,   12,  156,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1411,   32,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3169, 1287,   37,  688,    1, 3230,  140, 2198, 1509, 1642,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,    8, 3121,  304,    1,  616,   37,  123,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1055,  841,   51,  193,   52, 1211,   37,  815,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  919,  158,  187,  104,  112, 2590,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,  220,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2396, 1004, 1805,    1,    9,  810,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273,  259,  772,  288,   37, 2401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   42,    1,  551,    1,   43,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1419,   26, 1039, 2255,    1, 2639,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   12,  551,  552,  155,  157,   98,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1675,  220,  619,   28,  361,  168,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  164,   61,    1,  388,  361,  388,  249,   37, 2611,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,  681, 1248,   10,   37,  289,   98, 2972,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3192,    1, 1401,  166,   44,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,   37,  125, 1069,  548, 1700, 1034,  636,  276,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3405,  738,  220,  557,  540, 2774, 2153,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  943,   45, 2379,    1, 2817,    1,    1,  509, 2830,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2059,   45,  857,  655, 1574,   10,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1023,   45,  104,  777, 2264,  815,  858,  116,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783, 1240, 1306,  932, 2092, 1757,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3200,    1, 3245, 1867, 2347,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  476,   37,    1,    1,  384, 2673, 1806,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1037,    1,  590,    1, 2142,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  161,   12, 3340,    1,   32, 2883,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  413, 3114, 1583,    1, 1388,   27, 3086, 2735,  963, 2122,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  792,  166,    1,  792, 2713,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  633,    1,    1, 1841,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  104, 2161,   12,  872,  386,   32,  505,  856,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  729,   32,  856,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  939,  187, 3097, 2565,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  342, 2061,  104,   37, 2535,  149,    1,  548,  121,    1, 1839,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  476,   37,  856,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  424, 1544,  187,  340,  402,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974,    1,    1,    1,    1,  493,  388, 2181,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2298,  211, 1539,   45,    1,    1, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3403, 2414, 1147, 2924,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2885, 1360,  612, 2553,  729,  176,  590,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3296,    1,   32,  593, 1863,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1380, 1204,   98,  166,  260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  421,   12, 2958,    1,    9, 1110,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  650,    1, 2822, 2393,   10,   12,  865, 1628,  550,    9,  596,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  593,    1,  388,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,  251,  466, 1013,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,  166,    1, 1517, 2488,  774,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  992,   28,    9, 2920,   32, 1869,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  251,  125,  636,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  193,    1,   45,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171, 1567,  125,  493, 1649,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 2170,  947,  114,   98,    1, 1313,    1,  583,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3318, 1917,    1, 3059, 2528,    1, 1370,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  949, 2306, 1961,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,  606,  284, 3089, 2015,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2773,    1, 2489,   85, 1461,  477,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  361, 2064,  817,  365,    1,   98, 2822,\n",
      "          651,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  428,  864, 2390,  529,  210, 2055,  176, 2003,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  443, 2502,    1, 1484,  449, 1142,   32, 3378,  750,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,   12,    1, 1554, 2235, 2611,  548, 2456,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1114, 1450, 3381, 3045,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   10,    1, 1963,   37,  631, 2734, 1527, 1705,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  151,  920,    1,  151,    1,    1,  202,  877,  105,  227,  132,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1433,  320, 1744,  585,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1118,   11,  296, 1497,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1421,   98,   37,  105,  365,  829, 2146,    1, 1433,    1,    1,\n",
      "         1366,  705, 2518,    1,    1,    1,  234,  182,  235,    1,    1,    1,\n",
      "          234,  182,  235,    1,    3],\n",
      "        [   2,  219,  159,  504, 1565,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1186,  213,   37,  221, 2924, 1415,   37, 2597,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3269,    1,  105,  183, 1463,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   26, 1039,  162, 2469, 1876,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,    1,   37,    1,  326, 2043,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   10, 3404,    1,   79,    1,  736,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1, 1853,  861,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1866,   37,  947,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374,  650, 1484,    9,  264,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  683,    1, 3103,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,    1,   28,   80, 1108,  220, 1842,  802, 1160,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2763, 1532,  220, 3102,    1,   32,  121,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 3018,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  686, 2597,    1,  104,  868, 3356,  787,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1630,  515, 1158,  159,  105,  636,  837,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3253, 2329, 1632,   37, 2069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3298,   12,  461,   37,   52,    1,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,    9,    1, 1812,    1,  202,  220,  105,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  849, 1654,  105,    1,  187,  636,  418,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1137,   98, 1230, 1601,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  459,  116,    5,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  187,  105,  544,  460,    1,  934,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1307,  361, 2382,  618,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  189, 1118,    1,    1, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1397,  402,   37, 2163,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  335,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2372,  729,    1, 1786,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2648, 2801, 2660,  132,  220,    1,    9, 2226, 2969, 1539,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,   98,  112,  226, 1499,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    8,  786, 2324,   32,    1,  861,  328,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296,  387,  105,   57,  115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 1339, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232,  726, 2941, 2522,  384, 3231, 3209,   23, 1090,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,    1,   32, 2210,    1, 1559,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3373,  168, 2249,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  196,    1,  132,   37,  619,    1,  562,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61, 1094, 2482,  171, 1167,  167,    1,  163,    1,   12,    1,\n",
      "          863,    1,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  138,   59,  422,  599,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3145,  454, 1159, 1948,  220,    1, 1918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  770,    1, 3320, 2773, 1159,  315,    9,  105, 2213,  627,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 1178, 2572,  487,    1,    9,  195, 1001,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2355,  820,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  171, 3145,   32, 1212, 2353,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   59,  872, 1144,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,  225, 1279, 1086,  417,    1,   60,   85,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3359,  952,   37, 1636, 3057,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713,  166, 2107,    9,  627, 3076,  270,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3241, 1844,   39,   45,  128,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3227,  664,    1,    9,  914,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3235, 1340,    1, 1194, 2318, 2907,  444, 3319,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463,    1, 1236,   37,  619,  612,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1000,  166,  777,   12, 2491,  861, 2558,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 2018, 2567,    9,    1, 2389,   45, 1815,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2962, 1432,    1,    1,    1,    1, 3299, 2495, 3175,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885,  315,  365,    1,   37, 1334,   98,  103,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 2061, 3032,  626,  639,    9,  198, 1734,   98,  864,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1899, 2263,    1, 2317,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1786, 2358,    1, 1337, 1705,   37,  222,  148,  647,  170,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3230,   37, 2192, 2468,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   10,   98, 2095,  856,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   37,  912,  397,  400,  444,  296, 1859,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1638,   45, 2879,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1109,    1,  325, 1273,   48,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  303,    1, 2393,   98, 2212,  861,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2457,  726,    1, 3168,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1645,    1,  396, 3102, 1419,  123,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 2135, 2664,  513,    9, 1922,  949,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    9,  105, 1034,    1, 2186,  175,    1,   37,   43,    1,  654,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3005,    1, 2072, 1104,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 1118,  365, 1778, 1013, 2560,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,    8, 2638, 1964,  304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  233, 2104,    1,   85,    1,    1,  302,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1,  331, 1159, 2673, 1821,  927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1341,  733,  215,    1,   50,    9,  152,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  338,  548,  586,    6,  731,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,    1, 2050,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2620, 2094,   81, 1628,    1,    9,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 2049,    1, 1684,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  903,    1,  904,    1, 2501,  861,  681,   37, 2123,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   72, 2635,    1, 2421,   39,   45,    1,   26,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 3345,  949, 2178, 2161,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3067,  163,    1,   12,    1,    9,  443,   98, 2095,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  528,  810,  166, 2081,    1,  166,  182,    1, 1417,    1,   12,\n",
      "            1,  967,    1,  105,  628,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  980, 1114,  187,  529,  408,  686,  954,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1594, 3048, 2923, 1159,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3166,    1,  903,    1, 1440,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,  261,   98,  116,  279,  259, 1085,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1789,  267,  163,    1,   12,    1, 2471,   37, 1673, 1232, 2108,\n",
      "          132, 1464,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,  297,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   94,   25,    1,   60,  186,  187,   69,  188,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32, 2611, 1656, 2596,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  675,  726,  104,  957,   24,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 1260, 3045,   32,  404, 2597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  506, 1898, 2209, 1241,   37,  596, 1793,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1007,   12, 2821,   45,  166,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   36,    1, 1753,  171,  297, 1442,    1, 1799,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1375,  353,  331,   72,  401,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 3030,   37, 1428,  939,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 1090,   32,    1, 2308,    1,  176, 3039,  614, 1176, 1533,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2200,  750,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  251,  590, 2383,   98,    1,    1,  384,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  593, 1990,   45, 2701,  104, 1249,  121,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  260,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,   26, 3253,    1,  247, 1090,    9, 3204,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380,    1,    1,  187,  365, 2018,  446,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3232, 1021,  454,   37,  631,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147, 1550,  365,  776,    9, 2701, 2162,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  159,  554,   98,  365,   50,  550,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1227,  251,  311, 1778, 2580,   37, 2264,   45,    1, 1228,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  741,   37,   77, 1459,   32,  756,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  476, 2707,   37,    1, 2129,   45,  302,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  845,  408,  665,    1,  156, 1632,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   28, 1010,  943,   45,  179,  180,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  654,   12,   83, 1143,    1,  440,  103, 1346,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700,    1,  353,  419,    1,  720,   32,  572,  197,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  709,  114, 1863,    1, 1401,  386,   32,    1, 1990,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  395, 1013,    9,  368, 1295, 3156,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 2275,   12,  315, 1710,    1,    5,  423,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1140,  656,    4, 1782,   37,  942,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1087, 2767, 2105,    1,  535, 1153,  280,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1142, 1143, 2556, 2825,    1,  187,  654, 1009,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1128,  361,  829,    1,   37,  194, 2432, 1604,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3086, 2924, 1237, 3114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1342,  365,   82,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  195,    1, 2988,  531, 1803,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  782,  885, 3043, 2623, 2624,  400,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  374, 1518,  680,    1,   98,   69,  997,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2036,    1,  681,    1,   37,  837,  395,  218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,   12,    1,  566,    1,   12,  841,  285,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3254,    1,   44,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101,    1,  546,    1,  176,  437,   32, 1850, 3339,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  170, 2744,    1,  197,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1309,  475, 1310,    9,  365, 1311,   98,  573,  721,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,  104, 1414,   37, 1237, 1147,  590,  168,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  861, 2298, 1472, 1011,  384,    1, 3349, 2785, 2372,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  834,    1,  150,  159,  554,  419,    1,   32, 1126,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1228,    1,    1,   37,  142,    9, 2025, 2344,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1877,  751,   37, 2328,  114,  384, 1430,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3334, 2308,  804,    1,   39,    9,  691, 3023,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   32,    1,    1, 2786,  171, 2708, 3397,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  242,  408,    1, 2051, 2135,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  388,    1,    1, 2111,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  996,   93,    1,   37,    1,  118, 1224,   32,  581,  401,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3276,   98,  166,    1,    9,  105,  199,  332,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1277,   12,  590,  388,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   28,    1,   25,    1, 1340,  526,   63,   65,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3066,   98,  837,    9,  311,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  612,  353,    1,  372,  354,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1583,    1,  898,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  379, 1533, 1979,   98,  531,  734,  591,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  942,   12, 1417,  372,    1,  942,   48,   61,    1,    9,  333,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  286, 1630,   12,    1, 2471,   51, 2394, 2177,   37,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,   37, 1539, 3048,    1,  191,  857,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   21, 1253,   32,  845,  275, 1196,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2157, 1710,   52,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 1707, 1428,  909,   98, 3369,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1751,  744,    1, 1224,   32,  584,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602, 1249,  455,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1993, 1159, 2936, 3293,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 2565, 2584,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2265,    1,   37, 1428,   78,  453,  400,  115,   45, 2266,  420,\n",
      "           98,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3329,    1,  429, 1512, 1953,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  313,   37,  588, 1428,  909,  444,  864,    1, 2868,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  738, 2122,  590, 1243,   98,  223,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    6,  572,  983,  157,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3264,    1,    1, 2082,  187,  190,  247, 1351,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3116,  922, 1545, 1632,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1386, 1475,  636,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  459,  365,   59,  132,  220, 3244,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1788, 3322, 1421,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  199, 2385,  612,   32,  247,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129,  975, 1974,    1,  220,    1,    1,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  487, 2611,  300, 2695, 2796,  191, 1465,    9, 1028,   32, 2468,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746,    1,  758,    1, 2035, 1259,   37,  693, 1108,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3076,   12, 2557,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2520,    1, 1416,    1, 3031,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  777,  778,   30, 1056,    1,   32,  531,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1257, 1904,  112, 1536,    9,  467,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  715, 1228,    1,    1,  361,  247, 2742,  619,  611,  199,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,   59, 1763,  176,  629, 1232, 1527,  193,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  875,    1, 2730,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1656, 1260,   98, 1009,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1765,  365, 2036,   12,  119, 1463, 1844,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  729, 1345,    1,    1,  804,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1290,   67,    1,   32,  367,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,  119,    1,   37, 1753, 2441, 2434, 2633,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510,   12,    1,   23,   69,  102,  242,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1109,   37,  504,  674,   45,    1, 2013,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707,   12,  342,  142,   81,   98, 1434,  548,    1, 1559,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1583, 1564, 2263,   32, 2638,   12, 2162,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  517, 1273, 1108,  288,    9,  335,   79,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3222,    1, 2107,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1948,    9, 1990, 2175,   37, 1264, 1838,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   75,  475, 1702,   37, 1496,  207,  259, 1085,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1, 2695,  934,   37,    1, 1821,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,  542,    1,   45,    1, 1035, 1559,  220,  586,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  912,  605,  302,  765, 1836,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 1465,   32,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2699,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  297,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2573,   34, 2735, 1075,   37,    1,   32, 2527,  164,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1236,   37, 2446,    1, 1109,  126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2628, 1635,  597, 3239, 2565, 3301,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2531, 2167,    1,  311,    1,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1976,   32, 1147,  350,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  959, 1023,   45, 1089, 2691,  672,  844,  815,  506,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2475, 2368, 2335, 1090, 1044, 1826,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  335,   44,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,    1,  199,   51,  856, 2638,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  954,  640,  715,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1159,  105,  365, 2318,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3177, 1427, 1308, 3328,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1338,   45,    1,  384,  378,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3226,    1, 1133,    1, 2317, 2308,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1121,    1,   39,    9, 1867,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2266,  267, 3118, 2024,  132, 1610,  191,  356,  439,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 3391,    1, 1185, 3111,    1,  166,    1,   45, 1018,    1,\n",
      "          443,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3103,    1,  191,    1,  872,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2716,  176, 2936, 3283,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1044,  884,  453, 1950,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3043,   45,    1, 2834, 2430,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   51,    1,  878,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3053, 2855,    1,    1,  517, 1821,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1333,  631,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1203,    1, 2687,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37, 3380,   12, 2362,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1537,  171, 2591, 1010, 2091,  861,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1186, 1419, 1178, 2827,  452, 1837,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1675,  168,    1,   81,   32,  199,  892,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  200, 2492,    1,  552,  552, 1665,    1, 1074,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3240,  744,  166, 1224,  444, 3241,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2529, 3087, 2478,  409,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2065, 2064,    1,  397,  506,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  854, 2506,  297,  691, 1867,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  167,  168,   39,   45,  169,  170,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1105,  787, 1586,   28,  176,  612,  207,  259,  469,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  361,    1,  190,  197,  384, 1126,  528,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2, 683, 580,   1, 149, 428,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 733,  48,  37,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2594,   12,    1,  919, 3286,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 2170,  267,  590, 2251, 2099,    9, 3342,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1186,  213,   37,  163,    1,   12,    1, 2924, 2099,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2610, 2678,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,   98, 1089, 1675,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  600, 1029, 2500,  663,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  854, 2192,   28, 2198,  105,  856,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1725,    1,  691,    1,  903,    1, 2036, 1937,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2008,  597,    1,  609,    9, 1204,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1463,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 3096, 2471,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2569,  957, 1360,  612, 2199, 2731,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2468, 2331,  115,   45, 1764, 1990, 1832,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1748, 2555,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  424,  199,    1,    1,  515, 1758,    1,    9, 3220,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   52,    1,  176, 1428,  651, 1031, 2396,   32,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1009,  140,    1, 1918,   32,  391,  890,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  576, 1658,    1,   37,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2925,    1, 2149,   37,   84,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303,  104,  217,   32,  227, 1134,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1039,    1,   37,   84,   85,  176,  439,   45,  914,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  560,  347,  707,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1109, 2319, 1109,  293,  738,   32, 1869,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   42,    1,  400,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2055,  176,  581,    9, 3216,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2523, 1086, 3106,  220,  449,  726,   32,  455,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1090, 1829, 1834,  176, 2110,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3290,    1,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092, 2039,   37,  477,  207, 2633,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,  325, 1117, 1525, 1013,  700,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  384,  166,    1,  105, 1920,    1,   12,  724,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,   37, 1021,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1631,  365, 1737,   98,    1, 2579,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  381,   82,  261,   39,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2063,  973,   81,    1,    1, 1867,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  822, 1787,  444,    1,  681,   37,  698,  892,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870,  256, 1362,  656,   37,  453,    1, 1049,  918,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1766, 1767,  662,  200,  535,    1,    1,  275,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1577,  675,  738,  237, 1470,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1307,  197,  338,  118,   98,  636,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321,    1,  764,   32, 2095,  443,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1680,  566,  395, 1915, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1264,    1,    1,    1,   23,    1, 3358,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2528,  166,  116,  736,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2097, 3391,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2442, 2003,  669,  992,   28, 1896,   37,  151,   32,  691,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947, 1535, 1974,  815,   45,    1,    1, 2887,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1659, 1310,   37,    1, 2028,   12,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 2835, 3382,   12,    1, 2421,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2893, 2137,  342,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  984,  443, 1015,    1,    1,  928,  176,\n",
      "          823,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,    1,  671, 1946,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1968,  794,   40,  220,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  585,    1, 1963,  361,  166, 1708,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  527,  369,    1,  952,  467, 2022,  394,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  729,    1,  384, 2651,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1778,    1,    1,    1, 2558,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  105,  119,  367,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1070,   10,   37,  194, 1175,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2336,  193, 1953,  657,   12,  569,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 2414,  249,    1,  267,  193, 1969,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1796,  116,  669,  835,  872,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,    1,   37, 1697,  220,  166, 1411, 1821, 2190, 2640,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,   12, 1996, 2493,  225,    1,  321, 2595, 1604,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151,  474,    1, 2308,  271, 2378,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   25, 1253,  187,   69,    1,  384,  845,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845, 2326, 1798,   32, 2646,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2605,    1, 2040,   98,   93,    1, 1910,  347,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1433, 1366, 1210,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,   12,  754, 2232,  124,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314,  551, 1692, 1337, 1469,  176,  656,   45,  927,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  597,    1,  609,  610,   37,  257,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2686,    1, 1991,   37,    1, 1628,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453,   37,   92, 1356,    1,    1, 2600,   37, 2324,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2347,    1,  193, 1724,    1,    9,    1, 1463,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361, 2594,   92, 1477, 1990, 1077,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   29,  190,    1,   65,  347,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,    1,    1,  140, 1674, 2161,   12,    1,  331,  671,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3017, 1008,    1, 1284,  252,   98, 2588,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2229,    1,  190,    1,  537,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12,    1, 1046,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  386,  952,    1, 1384, 1251,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1468,    1,  840,   48,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2537, 1118, 1539,   45, 3029, 2981,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1435,   61, 2250,    9,  645,    1, 1816,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1832,    1,   37, 2935, 3220,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1107,  293, 1236,  219,  207, 2441, 2852,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   32, 2457,  142,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  166,  954,   61, 2219,   32, 2275,   12,  637,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2238,   37, 1865,    1,    9,  657,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  197,   28,    1,  597,   82,   39,  176,    1,    1,  633,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  455,  295,  387,  197,   98,    1, 1007, 1697,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878,    1,    1,  928,   27,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428, 2673, 1063,   37, 1816,  420,   98,  463, 1447, 1411, 1034,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,  335,    1,    1, 1918,  297, 3108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2870,   27,  104, 3150,   32, 3383,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  131,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  839,  829,  199,  421, 1597,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  179,    1,  180,    1,  170,  630,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1734,   32,    1, 1604,    1, 1950,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3087,  640, 3097, 1565,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3234, 1025,   53,    1, 1240,   52,  123,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  961,  147, 1800, 2863,  798,  444, 2956,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,   12,  224,    1,  131,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3121,    1, 1527,  384,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,    1, 1094,  498,   98, 1994, 2095,  474,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3128,    1,    1,    1,    1, 1301,  861,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2884,    9,    1,   32, 2295,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1559,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428, 2332, 1827,   32, 2170,    1,    9, 1031,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2322,  288,  548,  829, 1443,  319,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2159, 2094, 1412,  844,   37, 1658,  327,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  487, 1386, 2797,    9, 1997,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,   76,   37,  498,   37,  132,    9,  647,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  589,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1971,    1, 3228,  856,   63, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2326,   66,   32,  131,  469,  413,  142,  167, 2481,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219, 2873,  852,    9,    1,   98, 2662, 2918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1227, 1994, 2819, 2362,    1,   37, 3042,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,   37, 2243,  105,    1,  182,  142,    9,    1,  178,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  326, 2951,  103, 2334, 1638,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1844,    1,  191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  403, 1447,  852,   37,  211, 2673,   46,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3108,    1, 3079,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,  936, 1892,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,    1, 1353,  613,  858,   32,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1340, 2934,    9, 1194, 2907,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2676,  361,  517,    1,  405,    1,  552,    1, 1687,    1, 1995,\n",
      "           98, 2275,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1771, 2700, 1835,    1,    9,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2746, 2434,    1,  433,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1100,   12,    1,  288,    9,  818, 1798,  220, 3019,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  124,  565, 1568,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3143,  686,  191,    1,   12, 2775,   45,  166,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,  823,   45,  824,   69,   61,  297,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2,  69, 640, 845,  98, 109, 509,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 872, 449,  37,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2987, 1260, 1075, 1258,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885,   69, 1011,  287,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1075, 1166,  334,  402, 1167, 2382,  259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,    1,   32, 1990, 3275,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  506, 1158,    1, 1128,  631,  327, 1889,    1, 1279,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1997,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  315,  105,  752,  361,   34,  158,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  361, 3354,  943,    1,    1, 1583,  808,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2774,  437,  476, 3118, 2517,  680, 1663, 1942,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2122, 2557,  297, 3140, 1430,  221,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3228,    1, 2672, 2858,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1930, 2317,   32, 3208,  287,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  515,    1,  671, 2942,  140, 2492,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2702,  288,    1,  187, 2292,    1,   32, 1853,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  197,  418,  176,  649, 1273,  633,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105,  857,    1, 2675,    1,    1,    1,   32,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1, 2463,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965, 2982,  729,    1,  754,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3066, 1987, 1057,    9, 2839,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2298,  211,  632, 1821, 1539, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  197,   92,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613,  829,  132,  193,  227,    9,  227,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  305,    1,   28,   98,   67,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1308, 3079,  384, 1211,    1,  260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,   23,   32,    1,    1, 1159,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826,  249, 1021, 2151, 1675, 2630,    1, 2939,  140,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  499, 2677, 1282,    1, 1275,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087, 2614,  512, 1866,   37, 2611,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  147, 2794, 3153,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,  197,  418,  187,   15,  688,   93,   67,    9,  293,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1200,  353,  197,    1,  682,   17,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,  497,  498,   37,   92,  499,   69,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3229,    1,   37,  698, 1517,    9, 3232,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2038,  922,  427,  716,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  921, 2579,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3278,  884, 1134,  187, 3190,    1, 3297, 1864, 3158,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,  453,  156,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   94,  123,   37,  119, 1653,  187,   60, 1141,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1147, 2548, 2844,   32,    1,    1,  104,    1, 2572,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,  232,  590, 3245, 1114,    9, 3200,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1963,  967, 2133,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2899,   37, 1237,    1,  218,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1087, 1230,  794,  892,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2410, 1240, 3249,    1,  938, 2321,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   22,   45,    1,   61, 1884,  187,  517,    1, 2226,    1,   12,\n",
      "            1,   37, 2394, 1515,    1,   32, 3391,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  738,  236,  237,   12,    1,  220,   72,  401,  932,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  530,    1,   98,  417,  104, 1588,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  227, 1017,    1,  191, 1087,    1, 1181,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2929,    1,  150,  550, 1085,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  347,  729,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,  103, 3132,   32,    1,    1, 1090,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  835,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  519,   39,   37, 1911,  698,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111,   14,   15, 1348,   37,  120,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2177, 1215,  176,  262,  263,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3075, 2694, 1689, 1347,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3141,  892,  428,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  191, 3288,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  236,  237,  410,  187,  289,  571,   37,  197,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3237,  321,  612,  544,  445,  388,    9,  273,    1,    1,  405,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2211,    1,  572,  197,   28,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2034,  810,    1, 1383,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  683, 2257,   39,   45,  449, 1726, 1953,    1,  267,    1,    1,\n",
      "         1677,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,    1,   32,  469,   37, 1835, 1606, 1589,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1932,   37,  125,  541,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426, 2590,  885, 1641,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  803,  112, 1986,  176,  356,  845,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,    1, 2726, 3339, 2596, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  183,  978,  884,   98, 2278,  220, 2759,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1934, 2678,   98,    1, 1975,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,   70,  102,   71,    1,   98,    1,  720,   32, 1588,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  590,    1, 2334,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  776,   45,    1,    1, 3093, 2052, 1010, 1313,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  347,   28,  885,  401,  402,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  225,  809,    1, 2052,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1536, 1312,  365, 2819, 2039,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1047, 1236,    1,    1,  361,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2156,    9, 2993, 2677,  973,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   21,  449, 1698,  356,  197,   98,  677,  102,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2932, 1835,  705,  259, 1017,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  593,  458,  267,    1, 2590,  384,  594, 1521, 1810, 1407,  615,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2932,   37,  927,    1,   98,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2820,  252,   32,    1, 1167,    1, 1204,   37, 3024, 2977,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181,  617,  618,   37,  619, 1199, 2177, 1027,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1128,  794,  764,    1, 1108,    9,  999, 1244,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2414, 1029, 2231,    1,  876,  612,    1,  176,  104,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  204,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,    1, 1632,  283,   87,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,    1,    1,   16,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  198, 2164,  640,  455,   12,    1,    1,  583,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  393,    1,   28,   37,  331,   32,  394,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  811, 1945, 1140,   32, 3102, 1559,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1643,  835,  163,    1,   12,    1,    1, 2442, 1501,   45, 1643,\n",
      "         3122,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12, 3137,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  147, 2322,  966,  398,   51, 2192,    1,    9,    1,  191,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181, 1249,    1, 2965, 3314,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   75,    1,   98,  104,  858,    1,  270,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1007,  156,   71,   98,  198,   15,   93,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  168,    9,  340, 2277,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984,  162,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  437, 1661,  231, 3181,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  348,  207,  418,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,    1,   45, 1299,  671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 2883, 3384,    1,   85,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  647,  940,   37,    1,  176,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3375, 2572,   32,  539,  458,   32, 3101, 1583,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1625,   37, 2760, 1411,  339,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2379,    1,  493,  239,  606, 2306,  220,  398,  892,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  121, 1458,  968,    9, 1428,  861, 1906, 1311,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1963,  536, 1891,  593,   12,  627,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 2170,    1, 1248, 1743,   98, 3153, 2220,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2988,    1,    9,  829, 2987, 2762,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,    1, 2347,   32, 1815, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  387,  455,    1,  442, 1372,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1212,  967,  633,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,  716,  276,   32,    1,  382,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1973, 1025,    1,  220, 3276,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715,  112, 1161,    1,  528,  845,   69,  102,    1,  198,   94,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  414,  275, 1121,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  727,   12, 1140, 1555,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2680,    1,  136,    1, 1994, 2650,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  261,    9, 1186,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,  954,   61, 1887, 1600,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,  141, 1611,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  531,   76,   37, 2854, 1411,  163,    1,   12,    1, 1009,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  418,   98, 2366,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  764,    1,  334,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  325, 1117, 1525, 1013,  669,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  389,   93,   61, 1103, 1315,  236,  237,  739,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1343, 2361,   32,  449, 1463,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   37, 2677,  365, 1013, 1522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,  391,  477, 2317,  474,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2640,  193,   98,  837,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,   93,  288,   37,   24,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   24,    1,    6,   79,  393, 1011, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  879,  231,   45,  829,  199,  421,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  978, 3138,  688,    1,   37,  439, 1826,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2820, 2918,  113,   98,   37, 2919,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  422,  267,  523, 1300,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,   12,  197,    1,    1,    1,  191, 1211,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1848,   37, 1706,  131,   32, 1088, 1097,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1615,    1,   37,  619,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1189, 1461,  321,  759, 1094,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,   55, 2467,  220, 3330,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  121,    1,    1, 2005,    9,  854,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2264,   37,  619,  192, 1647,  328,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  585, 3130,  256, 1987,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2547,  665, 1688,   98, 1095,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3089, 1176,  445,    9, 2307,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1502,    1, 1503,  142,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   75,  331,  613, 2264,   77,  617, 1397,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  389,  173,    1,  220,  367,  495,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  469, 1731,    1,  630,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1057,  297,  903, 1447, 1461, 1463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275, 1207,   37,    1, 1926, 1927,  548, 1928,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   25,  670,  548,  236, 1022,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,   10,    1,   51,    1,   32, 2592,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   25,  565,  697,   37, 1758,  981,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,  859,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2997,  162,    1,  191, 2994,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2528, 1122,   12, 2869,  853,  538,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  138,   59,   37,  875,  134,  297,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1470,    1,  365,    1,  740,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,  676,  389,  378,  176, 1056,  356,  845,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 1778, 2851,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2832,    1, 2752, 3392,  548,  531,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3271,  688, 3117,   37, 1066,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835,    1, 1094,  269, 3080,   32, 1421,   45, 1793,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  275,  441,  434,    1,  220,  395,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785,    1,  928,   32,    1,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    9, 2376,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  371,    1,  267,    1,    1,  190,  764, 1083, 1633,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1591,    1,  387,  159,   71, 1022,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2830,   37,  125,  347,  680,  399,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2962, 2615, 2651, 2720, 2796,    1, 3108, 2923,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3238,  162, 1194,  187,  730, 2614,  688,  705, 2796,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2476,    1,   32,  331,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,   45,  593, 1990,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1095,  716,    1, 2298,  220, 2464,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2433,  455,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  531, 3382,  213,   37,  439,    1,    1, 1345,    1,   98,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26, 1039,  625,  361,  129,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1022,  104,  880,  452,  443,   37, 1054,   32,  451,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,    1,  504,    1, 1718,    1, 1180, 2871,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  982,   37,  776,  331, 1943,    1,  618,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1751, 1401,    1,   37, 2513,    1,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962, 3330,    1, 1194, 1918,  187, 3260,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1023, 1204,    1,  820,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  321, 2805,    1,  877, 1577, 1488,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1, 1427, 2503,  219, 3116, 1617,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3363,   98,    1,   45, 1918,   32, 3360,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1492, 1924,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1671, 1976,   32,    1,  429,   45,  667,  880,  420,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,   37, 2237,  602,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1841,   32,    1,  372, 1448,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  176,    1,  340,  951, 1547,   98,    1,  533,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  506,    1,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2446,    1,    1,    1,   90,  487,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1398,  612, 1140,  460,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159, 1253,  959,  419,   98,  898,  425,    1, 1746,  469,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  420, 3138, 1030,    1,   37, 1421,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  510,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1757,    9,  938, 1075,   37,    1,  629,   45, 2456,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2798,  861, 1790, 2976,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1163,  321,    1,    1,    1,   12,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3184, 1234, 1061,  297, 2811,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2883,    1, 2751,    1,  297, 3082, 2434,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  901,   32,  166,  501, 2060,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1100,  729,    1,  315,    9,  105, 1651, 1597, 1151,  250,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,  755, 1614, 2858,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,    1,    1,   49,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3348,    1,    1,  492, 2339, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158,  680,    1,  187, 1107, 2015,  418,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1107,  293, 1236,  176,  350,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2511,   37,   81, 2487, 2723, 2724,  361, 3016, 1935,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1117, 1631,   39,  187,  388, 3396, 2253,   37, 1731,\n",
      "         2735,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  311, 2659,   81,   37, 1493, 2250,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1414, 2856, 3006,   32, 3339,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2691,    1,    9,  129,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3079,    1,   37, 1296,    1,  390,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1, 3375,  240, 2868, 2237,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  922, 1090, 1829, 1214,  176, 2916,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,  155, 1708,  977,   32,  705,    1, 1417,    1,    1,  903,\n",
      "            1, 1417,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2871,  810,  566,   98, 3190, 3010, 1798,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,  288,   37, 2035, 2108,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,    1,    1,    1,  207,  105,  331,  157,  577,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  187,   69,  636, 1137,    1,  616,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984,    1,   30,    1,   98, 2662,   12, 2918, 2820,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  166,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2373,    1, 1912, 1027,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1712,   37, 2243,  535,  656, 2261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1454, 2282, 2001,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  597,  491,  929, 1355, 1063,  297,   69, 1356,  287,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2490,  958, 3079, 2844,   45, 2527,  164,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2448,  386,   98,  166,  791, 1638,  220,  214,  142,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1034,   32,    1,    1,    1, 1230,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2522,  698, 1408,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   66,  242,  187,   69,  953, 1315,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  275,    1,  535,    1,    1,  519,    1,    9, 1121,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9, 1899,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3157,    1, 3102, 1665,  202,   16,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219, 2871, 3124,    1, 1167, 2051,   61,  388,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  761, 1646,  776,    1,  548,  985, 1450,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993,   12,  332,   61,  677,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147,  555,   51,  211,  890,    1,  379, 1152,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,   12,  832,    1,  637,   79, 1992,  191,  104,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3048, 2923, 2007, 2697,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2960,    1, 3101, 1967,  176, 3339, 2835,    1, 3101,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,   12,    1,  580, 1002,  211,   32,  667,   50, 2187,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   46,   37, 1195,  903,    1, 1423, 2024,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3215,  729, 2934,    9,  979,  808,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  179, 1996,  613,    1,   41,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,  967,    1,  202,  247,    1,   37,  726,   61,\n",
      "          729, 1221,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  864,  488,   37, 1860, 2673,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  586,  267,    1,  167,  168,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,  908, 1211,  442,  630,  220, 1212,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1831,  261,  189, 1299,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  418,  187,  107, 1566,  109,  125,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12, 2162, 2786,  199,    9, 2708,  249,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    6,  197,  570,  361,  159, 1150,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1450,    1, 1178, 1492,  407,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 1090, 1419,  167,    1,  818,   45,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,    1, 2317,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  567,  390,   51,  759,   54,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   15,   28,   32, 1169,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1631,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 2162, 1950,  384,    1,  418,   37,    1, 2249,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1848,   37, 1155, 1069,  250,   32, 2573,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2226, 2233,   52,  176, 2771, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  316, 2424,    1,    1,  302,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 2153,   37, 1421, 3341,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3327,  884,  297,  176,  463, 2926,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,  507,    1,   53,    1,   37,  166,  593,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  231,  829,   12,    1,    1,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  354,   45, 1046,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2396, 1707,    1,   32, 3118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  350,    1,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3232,   77,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282,  632,    1, 2779,    1, 1033,  220, 1427, 1684,  726,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2917,    9,  902, 2712,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1321, 1705,   37, 1281, 2500, 3036,  481,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  786, 1178,  928,   32,  350,    1,  264, 1747, 2291,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  986,  105,  331,    9,    1, 2115,   50,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1019,    1,    1, 1674, 1551, 1976,   32,    1,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3079, 1445, 1421,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  212, 1395,  149, 1396, 1158,    1, 1130,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3285,  361, 1971, 2434,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1368, 1727,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,  903,    1, 1447, 1800, 1461,  716,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1955,   37, 1706,  104,   59,   37,   92,  382,  568,   32,  395,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  251,  365, 2842,   45,    1, 2530,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2924,  288,    9, 2069, 1260,   98, 3391,\n",
      "           23,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 2612,   98, 2471,  220,  968,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  835, 1228, 2683,    9,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1718,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504,  379,    1,  463,  220,  949,   45, 3080,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1778,  469,    1,   81,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  922, 1090, 1829,  365, 1788,  176, 2184,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  709,    1,  475,  680,  433, 2263,   32,    1,  927,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  972,   37,    1,  573,  315,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2868,    1,   37, 2885,    1,    1,  115,   45,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2333, 2527,  338,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1876,  897,    9, 1861,   37,   77,  487, 2924,   32,  531, 1002,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 1988,   45,    1, 2325,   45, 2047,   32,    1,  142,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  786, 3101,    1,   61, 1810,  547, 2572, 3095,   32,  166,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  592, 1579,   59,  209,    9,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  776, 2361,   32,    1, 3058,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  580,    1,  356,   98,   36,  315,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   49,  167,   52,   53,   37,  171,  700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,  249, 1021,  548, 3144,  741,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3362,  476, 3349,  890,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   81,   98, 3278,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2962,    1,  187,  183,  564,    1, 1515,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3194, 3195,  415,  833,  612,  619,  460,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2107,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 2839,   45, 3353, 2566,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2411, 1590,  202,    1,  972,  193,   32,  260,   37, 2565,\n",
      "         3151, 1218,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  167, 1838, 1839,  432,  191,  356,  439,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,  267,  460,  190,   81, 1861, 2024, 1929,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2308,    1,    1,   32,  166, 1054,   45, 2941,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1687,    1,  729,    1,  176, 1215,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,    1, 1710,   77,  424, 1895, 1246,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2421,   39,    1,    1,    1,  885,    1,   44,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  439, 1803, 1140,  191,    1,  650,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1272,  323,    9, 1658,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305, 1374,   98, 1797,    1,   71,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  399,   51,   52,   27,   32, 2690, 2607, 2096, 3031,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3393, 1450,    1,   37,  606,  905, 1601,   98, 2729, 2057,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1430, 2682,  104,    1, 1428, 2824,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141,  892,  428,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3027,  384, 3012, 1821,  927, 2421,   32, 3013,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1520,  207,  197,   28,  118,   32,  449, 1023,   98,    1, 1395,\n",
      "          844,   15,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1617,  546,   22,   23,  475, 1969, 3038,    1,  298,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  202,    1,    1,    1,    1,  247, 1021,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  238,   45, 1204,  361,  440, 1609, 2420,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3084,  939,    1, 1040, 3124,  365,  754, 2541,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  848,   12, 1479,  955, 1119, 1234, 2294, 1876,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193, 1542,    9, 1065,  199,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   93,   32, 1033,  672, 1964,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  242,   69,  102,  361,    1,  301,    1, 1910,  225,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1547,   27, 1034,  340,  951,   60,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1917,    1,    1,  239,    1,   98,  148,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  156, 1986,    1,   25,  242,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1412,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2318,   61,  105,  506,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2436,    9, 2301,  994,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  251,   37, 1504, 1792,    1,   45, 1778, 2580,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   49, 1377,   45,    5,  798,   61, 2052,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   26,  417,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91, 3048,  927, 1627, 2818,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1327,   12, 1056, 3365,    1,   37, 1148, 3361,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1599, 2445, 1684,   32,    1,    1, 2069,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2, 829, 261,  39, 647, 142,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 168, 444,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1700, 2572,  548,    1, 2421, 1159,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,  193,    1,    1,  202,  460,   12,    1, 1433,    1,\n",
      "            1,  111,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  550,  369,  884,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 2483,  596, 1793,    1,   32, 2822,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1708, 1090,    1,  311, 1204,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  794,    1, 3054,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  709,  266,  475, 2297,   37,  631, 1170,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  952,  562,   37, 1636,  331,  469, 1484,    9,  105,  365,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  593,   69,  102,  686,  365, 1653,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  513,  193,  514,   37, 1995,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  686,  487, 1583, 2791,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 1625,   98,  531,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2594,  884,  219, 3329, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1586,    1,    1,    9, 1384,   74,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1225,    1,   71,  548, 2834,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,   12,   83,  387,    1,  187, 1351,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1870, 1251,  672,    1,    1,  190,  631,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  700,   27,   98,  679,  529,  509,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1018,  620,  661,    9,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2089, 1757,  167, 2856, 1228, 1278,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1641,    9, 3262, 2800, 1218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  291,  292,  293,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1123,  892,  428,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1,  411,   32, 1844, 1948,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  187,  531, 1002, 1708,  891,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2486,  850,   39,  463,  584,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  384,  166,    1,    1,   45, 1923, 1494,  166,    1, 1178,   12,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3161, 3053,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1386,    1,  193,   37, 1083,   69,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  695,   32,    1,    1,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    5,  362,  919,    1,  197,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2963, 3300,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1231,   32, 1741,    1,   32,    1,  133,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1290,  396, 1269,    1,  590,   64, 1601,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  368,    1,   37,  130,    1,  369,    1,   32,  170,   45,  119,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3375, 2572, 1072, 1235, 2827,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  609,  952, 1368, 2191, 1377,  695,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   90, 1361,   37,  619,  453,    1,   73,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   68,   69, 1042,  187, 2429,   37,  109,  384,  531,    1,  121,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  267,  460,  967,    1, 1845, 1259,  220,  359,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  341, 1564,  828,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1625,   71,    9, 1645, 3365,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  755,   91, 1042,    1,    9,  224,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1230,  166, 1055, 1167, 1408,   98,  707,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  332,  631,   32, 1327,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  977,    1, 1147, 1726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,    4,  176,    1, 1011, 1097,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1536,    1,  297,  296,  220,  397,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1765, 1009,   45,  179,  160,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  197,   28,   32, 1022,  898,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  786,  227,    1,    1, 1056,  227,    1,    9,  105,   12,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  241, 2527,  164,  640, 2573,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  113,  700,  187,    1,    1,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  320, 1533,    1,    1,   30,  590, 2537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2578, 2619,   98,   37,  726, 2335,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1211, 1117, 1525,    1,  619,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  532,  384,  531,  403,   69, 1078,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1,  166, 1509,  199,   37, 1937,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2563, 2482,    1, 1306,   98,    1, 1864, 1090,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  476,   10,   39,   45,  166, 2087,  433, 1002,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 3373, 2249,  384,  709,  531, 3032,  778,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2991,  794,    1,    1, 2549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2410,  166, 2301, 2012, 1778,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2476,    1,  191,   91,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2859, 2955,  251,    1, 1159, 2990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1412, 1107,    1,  218,    9,    1,  627,    1, 1360,  612, 1504,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  332,    1,    1,   12,  847,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2238,  936,    1,    1,  220,    1, 1017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3227,  664, 3246,  220, 3244,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2306,  220,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3347,   32, 3343, 3353, 2096,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1189, 3372, 2424,  302, 1322, 3107, 3366,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  111,   15, 1348,   37,   71,    1,   28,    1,  384,  105,  356,\n",
      "         1490,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 1830,    9,  627, 1821,    1,  629,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  313,   37,  877, 2359, 2613,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  794,    1,    1,  853,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,  395, 2286,   37,    1,  297,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  908,  132,    9,    1,  971,   24,    1,  202,  474,  630,\n",
      "          110,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 647,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 835, 207,   9, 331,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 2170, 3067,  396,  600, 3362,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   81,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1018,    1, 1705, 1160,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284, 1128,    1,    1,    1,    9,  629,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3386, 2161,   81, 1515, 1940,  115,   45,  312,  776,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,   12,  805,   98, 1020,  270,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  183,  547,  515,  864,  915,  916,   37,   18, 1805,   98,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1337,  573,  469,    9,  365, 1635,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,  326,    1,  327,  112,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128, 1392,  160,  623, 1140,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1, 1493, 1973,  775,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2685,    1,    9,    1,   45,    1, 1015,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3282, 3009, 3274,    1, 3169, 1066,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  733,  104,    1,  112,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2899, 2790, 2483, 1411,   84,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   79,   37,  472,  698,  220, 1973,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,  288, 2364,   98, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   29,    1, 1211,  384,  163,    1,   12,    1,  625,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1123, 2308,  474,  738,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171,  765,  444,  709,    1,  560,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,   37, 1248,  342,   37,  619, 1133,   98,  864, 2673,  313,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  927, 1574,    1, 2562,  191,  487,  709,  754, 2541,   32, 2180,\n",
      "         1559,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  931,  103, 2633,   37, 2872,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  261,   32,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1773,    1,  191, 2371,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,  472,   39,    9,  900,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  627,   45, 2628,    1,   51,    1,   32,    1,  608,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  726,  593, 2522,  220,  726,    1,    1,   37, 2872,\n",
      "         1022,    1, 2296,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,  292, 1222, 2359,   37,   26,   16,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3248, 1914,  742,  765, 1415,   37, 1610,  214,   45, 1178,  386,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1053,    1,   37, 1087,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 1707,  474,  469,    1,   46,  439, 2198,   24,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,  437,  488,   37, 2856, 1147, 2548,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2579,    1, 2689,   23,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  312,  821, 2593,    1, 1325,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  704,    1, 1117,    1,    1,    1,    1,    1,   32,  984,  443,\n",
      "          736,   98,  521,  750,    1,  928,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2634,    1,  766,    1,    1, 1505, 1395, 1651, 1597,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,   98,    1, 2266,  894, 1540,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3060,   32, 1585, 2644, 1159,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321,    1, 2222,   18,  227,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2528,  829,    1, 1656, 1778,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790, 1454,  453,    1,   45,  749,  231,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2857, 2471,  187, 3312,   32, 1485,  922,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,   11,    1,  777,  778,    9,  331,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2095,  134,   32,  896,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1230, 2543,  162,  365, 1787,  384, 1128,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1113,   67,    7,    9,   10,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1097,   93, 1586,   28,  846,   32, 1169,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1191, 2264,   37,  729, 1937, 1744,  378,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147,  947,    1, 2924,  680,    1,  114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   12,    1,  292, 1135,   45,  552,  552,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2632,  454,   79, 1967,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3256,  193, 1960,  166,  636,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3175, 2810,    1, 1159, 1515,  315,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 3390,   32,  187, 1818,  147,    1,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1025,   32,   46,   37,  151,    1,  551,  517,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1884, 1345,  115,   32, 3391,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  271,  384, 1663, 2800,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  469,  596,    1,    1, 2100,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2764,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1949,  248,    1,  663,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  920,  424,   61,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2405,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,  868,   39,  176,  657,  220,  365,    1, 1510,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790,  566,  261,   98, 2638, 1994,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  224, 1396,    1,  388,    1,  676,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12, 2881,   90,   17,   37,    1,  220, 1778,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962, 1194, 1918,    9, 3330,  187, 3260,  726, 1114,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2179, 1511,    1, 1557,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,  25,  66, 242,  69, 102,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 107,  34, 430,  12,  69, 983, 191,   1, 331,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3161,  176, 1739,  105,  551,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1427, 1380, 3176,  103,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  616, 2035,  186,  187,   69,  338,  384,  845,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  356, 3106,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  215, 1648,   37, 1413,  104,  286,  522,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   25,  245,   98,   69,  509,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  166, 2453,  297,    1,  140,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2249,  345,   37, 1204, 1976,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,  176,  166,  219, 1984,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,  190,  193,    1,  582,    1,  625,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  736,  192, 1639,    1, 1355,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1527, 2664,   12, 3125, 2192,    1, 1757,    9,  487, 2924,   37,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3033, 2324, 1821, 2190,   12,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   81,  754,    1,  267,    1,    1, 1590,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1645, 2924,    1,   32,  557,  540,  548,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,  667,    1,   37,    1,  938,    1,   32, 2802,   12,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2493,  204,   12,  166, 1831,   98, 2463,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,   12, 3380,  267, 1360,  612,  319,  187, 1583,  475,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2382,  618,  565, 1822,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   26,  242,  187,   69,  102,  470,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   32, 2455,  632,   36, 1523,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2179,    1,  967,  636,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 2622, 2468,   37, 1046,  691,   32,    1,   45, 2161,   12,\n",
      "          163,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2379,    1,  611,    1, 2414,  176,  177,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3345, 2833,    1,    1, 3361,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  344, 2909,  361, 2774, 1450,  187,    1, 3367, 2591,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1536,  388, 2819,  767,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  942,    1, 2618,  619,  754,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,  884,  985,  384, 1894,  996,  716,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  715,  232, 1562,  104,  448,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1212, 3109, 1479,  195,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1902, 1408, 3300, 1568,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  636,    9,  845,  846, 1273,  728,   32, 2944,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  203,  938, 2538,    1,   79, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,   20,  872,   28,    9,  750, 1604,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  136, 1614, 2650,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885, 3126,    1, 1056, 2078,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  479,   37, 1636, 1996,   45, 1170,  538,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2827,   32, 2468, 2931,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2201,  197,   79,    1,  202, 2201,   15,   28,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  379,   26, 2172, 2791, 1517,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  215,  437,    1,   45,  242, 2102, 1251,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  421, 2418,   81,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  885,    1,  231,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2238,  459,    1, 2234,  220,  657,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  715,  112,  783, 1279, 1993,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2612,    9, 1591, 1126,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,  313,    9,  829,   12, 1718,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1035,  669,   37, 1636,    1,  260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2685, 1435,    1,    9,    1,  389,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  163,    1,   12,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  811,  812,  395,  442,  802,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2266, 1082,    1, 1705,   98, 1811,  404, 2024,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,  191, 1056, 2529,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2396,  220,   10,  105,  726,    9, 1861,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  596, 1151,   15,   37, 1124,  118,   32,  506,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1957, 2977, 1821,    1,  782,  105,  365,  754, 1821,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  569, 1198,  104,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,   12,  816,    1, 2861,   37,  342, 1984,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  420, 2343,  193,   32,    1,   45, 2375,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  216,   32, 2936,  548, 3387, 2596, 1665,  538,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,  190, 1901, 2375, 1017, 1232,  342,  919, 2108, 3368,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1,   37,  907, 2283,   37, 2000, 2735,  345,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  967,    1, 2432,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  369,  221,   37,  104,  162,    1,   92,  384, 1479,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3325, 2352,  808,  187, 1477, 1990,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  615,  335,  105,  818,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1906, 1458, 3364,    9, 2708, 1009,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2111,  576, 1525,    1, 1398,  612,  259,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,  493,    1,  665, 1632,  166,    1, 1463,   32, 1549,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,   12,   93,  157,  969,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   28,   37, 3140,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  861,    9, 1691, 2910,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  652,    1,   32,  395,  753,    9,  105,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3267,    1,    1,   37,  726, 1742,   26,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2592,    1,  829,  132,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  175, 1366, 1398,  612,  606,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1545, 2753,  331,  384,    1, 3283,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1221,   12,  105,  365, 1222,   32, 1223,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1546,  656, 1631,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 2840,    1,  297,  105, 2225,    1, 1000, 2485,   32,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3324, 1401,    1, 3154,  191,  786,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  733,  453,   48,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  460,   51,   18,   85,   37,  181,  199,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1874, 2046,   12,  808,    1, 2386,    1,   45,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,    1,    1,  202,    1, 2409,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1204,    1,   32,  286,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  921,  460,    1,  496,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2257,  166,    1,   98,    1,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1340, 1464,   37,  686,  590,    1, 1110,    1, 1264,  841,  631,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  987,  361,    1,    1, 2567, 1103,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  389, 1013, 1108,  782,    1,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  166, 1228, 2234, 1530,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3285,  949, 2308,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  317,    1,    1, 2298,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 1571,  837,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3258, 2579,  719,   37, 1403, 3009,   37,  999,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1976,    1,   12,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12,  302, 1712,   32, 2197,   37, 2392,    1,  956,    1,\n",
      "          907,  811,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,   29, 1398,  612,    1,   69,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1827, 1036,    9, 1002,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  438,   25, 2763,  159,    1, 1417,   32,    1,  442,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,  136,  475,    1,    1, 2430,   98,  133,  134,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  758, 1713,  166, 1013,  220,    1,  349,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  255,    1, 2882,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  531, 2696, 3090, 3040,  142,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   77,    1,   39, 2191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  479, 1009,  361,    1,  929,   37,  930,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2745,  865,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  709,  136,  475, 2430,  669, 1426,  895,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978,  769,   71, 1256, 1256,   28,    1,    1,  338,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   61, 2572,   32, 2887, 1523,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  324,    1,  349,   45,  326,  327,  112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  593,   69,  102,  759,  365, 1653,   98,  109,  997,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,  454,  220,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  215,  590, 1400,  103,    1, 1833,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1285,   28,   98,  646,    1,    1,   69,  102,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,   12, 1708,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 3268,   37,  930,    1,   12, 2101,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1378, 2500,    1,    1,   59,  537, 1490,  506,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   25,  242,  425,  426,    1,   69,  764,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3403, 1450, 1147,  947,    1, 2414,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2018, 2909, 2416, 2791,    1, 2414,  176,  177,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,  774, 1444,  753,   10, 2352,    1,  220, 3358,   32,  365,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    9,  111,    1,    1,  777,    1,  321,   52,  105,  784, 1176,\n",
      "         1300, 1160,    1,  150,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  806,   16,  667,  957,    1,  361,    1,  220, 1557,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   83,   37, 1910,  654,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 2170, 1564, 1056,  241, 3109,   98,    1,  134,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  940, 3340,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1414,   98,  166,    1,   45,    1, 3155,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1086, 1085, 1437,   37,  289,   98,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  728,  340, 1021, 1017,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  288,    9,    1,  170,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,    1, 1325,   37,  619, 2051,  541,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  189,  376,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2308,    1,  154,   37,  907,   32,  142,   37, 1154, 3151,  914,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1676,    1, 1418,  384, 2826,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,    1,  682,    1,  220,  829,  156, 1160,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  794,  365,    1, 1013, 1522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,  417,   98, 1290,  720,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  773, 1807,    1,  818,   15,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178,  163,  512, 1112,  176,    1, 1777, 2739, 1292,   37,  166,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1385,  730, 2614,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596, 1793,  967,    1,  629,   45,    1, 1245,    1,    1,  506,\n",
      "          267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1043, 1518,   28,  419,    1,    1,  848,  504,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  590, 1488,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  596, 2527,    1, 1046,    1,  276,   32, 2175,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2883,    1,    9, 1973, 2095, 1164,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  273, 2171,    1,  590,    1, 3194, 3195,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3339, 3352, 2856,  547, 3095,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  242,  528, 2066,   69,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1423,  387,    1,    1,   37,  356,  845, 2295, 2302,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 1914,    9, 2213,    1,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968,    1,    1,   37,  420,   98, 2439,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  314,  551, 1692,  792,    1,  792,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2579,  163,    1,   12,    1,   37,  574,  147, 1054,  856,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1188,  885,  792, 2268,  792,  548, 3262, 2712,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2692,  697,   37, 1551,   28,  331,   32,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,   98,    1,  297,  436,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1056,  681,  598,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2352,   56,  356, 2836,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  195,  218, 1618,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788,  681, 1140,   98,   80,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   37,  151,  647,    9,    1,  182,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1631,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1667,    1,    1,   61, 1333, 1530,  191, 3095,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1225,    1,  501, 1125,    9, 2518,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796,   25,   51,   71, 1773,    1,    1,    1,    1,    1, 2648,\n",
      "           66,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  487, 1938, 3197, 2562,  105,  916,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3068,  884,   80, 1228,   37,  166,  282,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,  232, 1082, 2179,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,  908,    1,  365,  399, 1219,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3277, 1216,  386,    1,   37,   52,    1,   79,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1323, 1708, 1464,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  691,    1,  854,  191, 2202,   32,  449, 1463,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1398,  612, 1882,   37,  398, 2266,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  180,  361,  179,  365, 1749,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  388,  166,  730, 2614,  361, 3117,  943,  600,  460,    1,\n",
      "          166,    1,  460,  162,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3232,  245,  526,   32,    1, 2872,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  166,  236,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2774,  475, 3369,    1,  876,  612,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,   12, 2741,  563, 2427,  220, 3217,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3003, 1536,  365,  912,  605, 2039,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  524,  525,   15,   28,    1,  118,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,   32,   14, 1832,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,  777,  778, 2008, 2311,    1, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,    1,    1,    1,   63,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  112,  550,  830,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,  829,  710, 1713,   26, 1039,  934,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  224, 2995,   98,  453,  454,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1,   59,  486,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1572,    1, 2202,  608, 1185, 2498,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1021, 2748, 1245,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3378,  590,  345,   37, 3148, 1976,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   63,  166,  862,  179,    1, 1883,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  245,  187,  122,  600,  109, 1174,   37,  470,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1253,  137,    1,  754,    1,  764,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  938,  551,    1,  162,  562,   37,  151, 2043,   50,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2308,  877,    1,    1,   37, 1413,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  852,   37,  151,    1,   48,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1431,  728,  829,    1,    1, 1089,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  224, 1993,   28,  187,  159,  288,   37,   18,    1,  218,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   74, 2582, 1754,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3182,    1,  583,   32, 3183, 1090,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  868,   39,  187, 1477, 1990, 3164,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  220, 1977, 1827,   37,  726,    1,  542,   45,  730, 2614,    1,\n",
      "         2370,  105,  354,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2501,  861,  756, 1484,    9,  388,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,    1,  726,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2153,    1, 2827,  176,  581,  384,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2161,    1,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978,  769,  245,   98,   69,    1, 1158,  919,  185,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1022,    1, 2296, 3232,  550,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3061,   64, 3372,   32, 2774,  511, 2517,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2275, 2386,   10,   45,    1,  166,    1,  600,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3248,    1,  519,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1700, 1130,  332,  631,   32, 1869,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671,  919,    1,  374, 1308,  220,  503,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  221,   28,   32, 3278,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  335,   44,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1905,   32,    1,    1,  147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1707,  386,  781,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3359,   37, 1978, 1384, 1232,    1,  796, 1386,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,   28,    1,    6,    4,    1,  159,   71,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  939,  187,    1, 2049,  512,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,  606,    1,   32,  105,  559,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1740, 1082,  654,   82, 1013,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  845,  275,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,  167, 1982, 1815,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  782, 2650,  472,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  587,  439, 3101,  391,  477,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2634,  779, 2759,  260,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  112,    1,    1,  197,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1155,  395,    1,    1,    1,    1, 1864,  170,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1141, 1348,    1, 1785, 2044,  140, 1114,   32,  593,\n",
      "         1990,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32, 2960,  176,    1, 1097,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  102, 1672,    1,   32, 1169,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1, 2097, 2755,  455,    1,  380, 1056, 1530,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1725,    1,  691,    1,  903,    1, 2036, 1937,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3266,  276,   37,  693,    1,   37,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,  633, 1686,    1,  354,   37, 1717,   32, 2513,    1,    1,\n",
      "         2941,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1766, 1767,  769, 1124, 2320,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  963,    1,    1, 2418,   28,    1,  493, 1541,    9,  331,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  681,    1,   37, 1155, 1994, 1461,  750,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2232,   15,   32, 1033, 2211, 1124,    1,  118,   32, 1014,  401,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,  744, 1169,    9,  517,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  683,   37,  907, 2779,   32,    1,    1, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2379,    1,  952,   37, 1334, 3158,    9, 3132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  548, 1056, 2119,    1,  460,   12,  729,    1,   12, 1090,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  987, 2014,   32, 1976,  453,  454, 1159,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1128,    1,  453, 3044, 1996,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,   37,  693,  365, 2366,  187,   26, 1039, 1228,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  190,  204,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835, 3109, 3393, 2596, 2985,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 1545,    1,    1,    1, 1178,  386,  664, 1737,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2217, 1579,    1,    9,    1,    1, 2153,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1317,  936,  525,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  952,  531, 3102,  949,  187, 1757,  431,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1823,  662, 3062, 1312,  365,  893,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1234,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2291,    1, 1527,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106,    1, 2750, 1626,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2615, 1641,  631,  202,  688, 3108,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123,   12,  889,    1,   61,    1,   98,  987,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  446,    1,  939,  297, 1563,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56,   39,   45,  228, 1718, 2261,  439,   28,  472,    1, 1778,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  510,    1, 1549,  540,    1, 1554, 1530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,   37,   47,    1,    1, 1499,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1675, 1091,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  967,    1, 1558,   28, 1110,  405,  260,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3288,   12,  193,    1, 1121, 2349,   85,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1710,   55,   37,  865,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,  936,  469,   37,    1, 1711,   45, 2924,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  429,  430,   69,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2115, 2187, 2576,   72,  131,   60,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25, 1285,   28,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  491, 1702,   81,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,   23,  288,    9, 1463,   95,   45,  365, 2328,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1100,  387,  699,  417,   15,    9,  572,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1744,    1,    1,  617,  259,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  166,  636,   45,  679,   69,   61,  590, 2440,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 2107, 2677,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3192, 2427, 2872, 2522,  220, 1844, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1,    1,   32, 2786, 3137,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,    1,    1,  695,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374,    1,    1,   32,  247,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2733,   32,  276,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  200, 1018,    1,   45,    1,  280,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,  613,    1,   28, 1107, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2438,   79,    1, 2882,    1,  815, 1671,   37,    1,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  167, 1719,  611,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1592, 2714,    1,  202, 1820,    1,   10,  651,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3187,   37,  907,   98, 1602,   37, 2000,  365, 1799,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  763,  415, 3282,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2054,  300,   25,  417,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  657,  973,   26, 3044, 2232,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1918,   61,    1,  424,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1770,    1,    1,    9, 1771,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  531, 1118,  890,   37,  740,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  693,  111,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2291,  176,    1, 1325, 2414,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,    1,   42,  220,  990,  297, 2501,  861,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1211,  834,  220,  105,    1, 2193,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,    1, 1159,    1, 1160,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  197,   28,    1,  155,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2493,  204,    1,    1,    1,  104, 2305,    1,   32, 1477,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,   37, 1664, 2212,  861,    8,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175,    1, 1204, 2198,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  357,    1,    1,  994,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2806, 2589,   45, 1280,   37,   77,    1,    1, 1273,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  396,    1,    1,   45,  390,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  134,  857,    1, 2034, 2050, 3077,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  433, 2104, 1574,  808,   45, 1645,  458,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,    1,    9,  854,    1,  395,   51,  335,  199,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  590, 2041,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  680,  365,  625,    1,    1,  127,  590, 1400,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056, 2827,  548,   22,  447,   95,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12, 1043,  338, 1773,    1, 1520,  720,   98,  156, 1057,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  833,  612,    1,    1,   81, 3271,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   58, 1373,   37,    1,  331,   32, 1527,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314, 1692,   37,  125,    1,    4,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2514,  460,   12, 1056,   32,  105, 1559,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   28,    9,  333,   98, 1095,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3151,   46,  271,   79,    1, 1756,  810,  202,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,   12,  811, 1564, 2507,  976, 2784,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  114, 2414, 1891,    1,   98,   22,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,    1,    1, 3181,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  121,  936,  315,   37,   47, 1370,   45,   49,  420,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294, 1983,   37,   52,    1,    9,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  181,    1,  548,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   28,    1,  419,   32, 1275,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1536, 1350,  149,  444, 1084,  841, 1443,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,    1,  384, 1717,    1,  361, 1306,    1, 1997,    1,    9,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2570,    1,  884,    1,  590,    1, 1569,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,  808,   45,    1, 1116,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2708, 1841,  267, 3065,    1,    1, 1924, 2572,  191, 3101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116, 2153,    1,  163,    1,   12,    1,  275,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2741,  563, 2427,  220, 3217,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1662, 1701,    1,  848, 1935, 2294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  904, 2196,    1,    9,  207,  618,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1445, 1421,  705,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1834,   65,  475,  387,    1,  104,  389,   93,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,    1, 2705,   71,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1247,  190,  619,  166, 1140,    9, 1090,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    1,  187, 1645, 2954,  489,   39,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  983, 1108,  794, 2606,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2376,  855, 1484,    9,  458,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3232,    1, 3260,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  744,  365, 2036,   12,    1,   37,  726,  581, 1463,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,  190,    1,    1,  572,  983,  689,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973,   12, 1338,   45,  856,    1, 3305,   12,    1,    1, 1251,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  219,    1,   57,  361,   14,   15,  276,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1433,    1,    1, 1433,  193,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3342, 1401,  176,    1,    1,   26,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2209, 1551,  506, 1898, 1793,   37, 3106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1,   98, 2820,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2978,   12,    1, 1539, 2306, 1961,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   51,   52, 2632,    1, 2845,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1312, 3375, 2572,   32, 3339, 3279,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,  614, 1300,  176,  332,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447, 1484, 1461, 1539,  716,  792, 1801,  792,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,  150,    1,    1, 1490,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785, 3006, 1605,  384,  344,   37,  686,  361, 1844,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  903,    1, 1417,    1,  171,    1,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715,    1, 2430,  297,    1, 3005,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1123,  571,   37,  316, 3251,    1,   37, 2016,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,  741, 2007,   98, 3339, 2129,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2722, 3074, 3231,  872,  420,  385,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1203,  122,  600,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  221,  417,   98,    1,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1002, 1986,    1,    1, 1876,   98,  166,   71, 1810, 3375,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  449, 1385,  176,    1, 2317,  220, 1056, 2285,  631,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374, 1877,   37,    1,  650,   12, 2162,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  793,   25,  866,   98,    1,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596, 1793,    1,  388,    1, 1211, 1890,  420,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3047,  463, 3165,    1,    1, 2470,    9,  595,   37,  100,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  375,  631, 3108,  608, 2615,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1864,    1,   37, 1865,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1616,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,    1,  854,   32,  581, 1853, 1463,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3177, 2256,    1,  147,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  385, 2377,    1,  297,    1, 1209,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3398, 2645, 1088,  446,    9,  949,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  572,  197,  407,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2206, 2989,    1,  191, 2633,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1716,  536, 1718,  218, 1960,  131,  191,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  361,  902,    1, 3322,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  155,  983,  570,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700, 1343, 2859,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158,  353, 1243,   98, 1180,    1,  517, 1616,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363, 2770,  413,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 1101, 2817, 1910, 1530,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 1002,    1,    1,  267,  163,    1,   12,    1, 3030,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1818,  147,    1, 2397,  467,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  161,    1,  459,    1,    1,    9,  164,  165,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1948,  361,  326, 1776, 1064,   37, 1017,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,   30,    1,  366,   32,  858,   93,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 1082, 2476,   37, 1911,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363, 3390,   32,  187, 3360,   12, 1009,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   82,  796,    1,  721,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2095,    1,    1,    1, 1648,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  727,    1, 1304, 1079,  147,   37,  222,  261,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1712,    1, 2881,   12,  138,  998, 1425,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2605,  698,  198,   32, 1477, 1990, 1343,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3199,    1,    1,  140, 1354, 2947, 2886, 1624,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1089,   98,  777,  778,   30,    1,   45, 1178,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3336,  571,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  160, 2393, 1656,    1,  675,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,  288,    9, 2127,  698,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428,  639,  213,   37,  947, 1189, 3366, 1806,  187,  104,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2837, 2844,   32, 3113,  336,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,  187,    1,    9,  438, 1481,   90,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  647, 1268,  454,    9,  148,  142,  191, 2667,  475,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2962, 3186,    1, 3175,    1,  105,   12, 2250, 1722,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  121, 2065,  365, 2673, 1461,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282, 1674, 3289,    1,    1,    1,  884,  356,   79,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   56, 2572,   32, 2597,   12,  501, 2060,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,    1,  156, 1253,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  707,   81,   37,  166, 2807,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066,   37, 1545,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2700,   37,  506,    1,   45, 2728,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  697,   37,    1,   98,  647,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  708,    1,    1,   37,    1,    1,   32,  104,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2308, 2156,    9,  331, 3023,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1024,  936, 1888,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2694,  905, 2756,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1191,  361,  500,  173, 1762, 2422,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   12, 2723, 2724,    1,   37,  606, 1023,  166, 1069, 1251,\n",
      "           45,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  190,   52, 2399,    9, 3070, 3149, 2774,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,   84,   28, 2851, 3049,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  200,    1,    1, 2308,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,  335,  450, 1593,  176, 1718, 1443,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1249, 2499,   32,  166,    1, 1990,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  475, 1558,  548, 1559,  600, 1560,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  922,  379,    1,  704,    1,  683,   12,    1,  907,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1583,   37, 1584,  352,   77,  531, 1197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2177,  135,   37, 1616, 1808,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584, 2629,  260,   28,    9, 1011,    1,  238,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  204,   12, 1846,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 2849,   45, 1820, 3048, 2923,   61, 1103, 1960,  105, 1173,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  215,  915,    1,    1,    9, 1204, 2319, 1089, 2294,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   22,    1,  348,  759,  132,   98,  851,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  232, 3207,  321,   77, 3208,  671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  267,    1,  741, 1710,  576, 1514,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 2334,   32,    1, 2107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2183, 3374,  650, 1941,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1053,  947, 2263,    1,  475,  710,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  958, 2527,  164,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2231, 3226, 2308,   37,   52, 1231,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  483,  384,  424,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   79,   37,  105, 2056,  698,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2451,  546,    1,  187, 2800, 2565,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326, 2384,    1,  220,    1,  636,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,    1, 1428, 1539,    1,  384,  557,  540,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  947,  927, 3379,  344,  808,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,   37,  125,    4,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   91, 2651,  104,   32,  119,    1, 1477, 1990, 1918,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  657,    1,  885, 1151,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3387, 2909,  665,    1,    1, 2789,   32, 2091, 1569,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  367,   31,   67, 1042,   37,    1, 1146, 1703,  384,    1, 1146,\n",
      "         1703,   32,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3012,  640,  166,  813,    9, 3013,    1,  906,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447, 1585,    1,  105, 1165,  778, 3399,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  377,  543,   37, 2434, 2591,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1, 2537,   45, 1228,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  583, 2787,   37, 1306, 2119,  357,  388,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1308, 2942, 1333,  176,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1238,   12,    1,    1, 1284,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2573,   12,  695, 2789, 1373,   37,  665, 3398, 1816, 1483,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  613, 2206, 2435,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1140,   79,  978,    1,  628,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  215, 1113, 2300,  338, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1257,   12,    1, 1285,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1442, 1428, 1953,   98, 3369,  792,    1,  792, 3051,  178,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2476, 2331,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  187, 2255, 2706, 2232, 3004,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2277, 3175, 2340,  765,  105,  595,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  654,  475,  261,   39,  721, 2027,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181,   98,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3113,   12, 1277, 1554,    9,  447,  361, 1327,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  405,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  696,  447, 1832, 1423,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  807,  763,  166,  273,    1, 2789,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  555,   61,    1, 1810,  649, 1097, 1149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2820,   12, 2481,   55, 1018,    1,    1,    1, 1748,   16,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1283,  830,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1025, 1415,   37,    1, 1350,  400,  220,  144,  145,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  102, 1473,   98,  997,   45,  567,  510,   12, 1438,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783,    1,  191,  104,  358, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  645,  116,    1, 2501,    1,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497,    1,  698, 2861, 1159,    1, 1034,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3173,    1,  104,   26, 3289,   32,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1797,    1,    1,   79,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  449, 1173, 1307,    1,  166, 1411, 2273,   32, 2943,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  241, 2292,  640,  531, 1633,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  691, 1594,  166,    1,  444,  854,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,   26, 1039,  413,   37,  269,  820,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1100,    1,    1, 2670, 1159,  769,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363, 1401,    1,  419,   45, 3343, 2591,   37,   52,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  460, 1132,    1,    1,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426, 1149,   32,  487,    1, 1210,   37,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  219,   25,  565,  176,  228,  339, 1653,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715, 3105, 1314,  444, 2095,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2206, 2989,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1,    1,  317,  572,  682,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2504,  446, 1877,   37,   84,   28, 3109,   45,    1,  187, 1746,\n",
      "         2664,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2238,  361,  657, 1421,    1, 1731, 2234,    1,    1, 2234,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1507, 1370,    9,  529, 2727,   37,   52, 2758,   98, 1970,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2175, 1371,    1,  191, 2539,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3292,    1, 3270,  640,   39,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  709, 3212,    1,    1,    1,  928,   32,    1, 2611,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870,  852,   37,    1,   28,  450,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2905,    9, 3121,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1431,   37, 1155,  613,  535, 1074,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3132,    1,    1,  320,  123,   37, 2522,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713, 1238,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2087,  433,    1,    1,   37,  964, 2673, 1461,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1224,  459,  220, 3247,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3170,    1,  593,  119,    9, 1463,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  879,    1,    1,  280,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  449,  726,   45, 2318,  187, 2802,  307,   39,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  267,    1, 1225, 1672,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  434,  105, 1983,   29, 1074,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1022,  726,  297,  103,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   10, 2940,   45,    1,    1,   32, 1819,  600,  531,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   37,    1,    1,    1,   32,  463,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1051,    1,    1, 1809,    1,   32,  845,  439,    1, 1821,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,  936,  389,    6,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2226,  190,    1,  176, 1018,    1,  199,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,    1,  163,    1,   12,    1,  297,  399, 1119,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1106, 1107,  338,  415, 1139,   45, 2102,  845, 2576, 2928,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51, 1496,  444,    1, 1409,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3171, 1586, 2615,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3226, 1521,    1,  548, 2811,    1,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1282,   12, 1283,   32,  870,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2508, 2985, 1094,  967, 2968,   32, 1474, 2374,  550,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1104,  825,  113, 1762,    1,    9,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  484,   98,  636,  423,   45, 1391,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  424,  199,  187,    1,  113,  247,  248,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  379,   37, 2360, 3342,    1,  927,    1,  669,  297, 2282,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1192,    1,  202, 1306,  837,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387, 1032,   93,   32, 1033,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3337,  729, 2175,   37, 1145,  220, 2220, 1066,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3160,  610,    9,    1, 1147,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  967,  872,   37,    1,   98,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3391,  105,  183,  139,    1, 1527,  110,  730,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  410,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  761, 1576,    1,    1, 1213,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  746,   37, 1539,  258,  116,  279,   19,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  245,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1557,    1,   37,  726,   32, 1081,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1362,    1,  166,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  963, 2161,   12, 2701,  872,  801,   37,   56,  497, 1990, 2069,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1586,    1,   82,    9, 1943,  317,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  160, 1161,  188,   32,  367,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   14,   12,  818,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275,  686,  166, 1708, 2290,  548, 2177,    1,  736,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  113,   98,   37,  682,  220,   65,   32, 1470,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  344, 3403, 2414,  547,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,  155,    7, 1184,   67,  401,  402,   37,    1,  118,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  467,  398, 1288,   49,  695,  424, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1414,   64,  121,   36,  220, 3365,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,   52,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  304,   45, 1730, 1665,   37, 1244,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   40,   32,    1,  220,  282, 2367, 2695,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1542,  357,  193,    1,    1, 1830,    9,  183, 1985,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051,  315,   37,    1,  365, 1607, 2575,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1471,  716, 1909,  737,  197,  276,  328,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  422,  476,  388,    1,    9,  616,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1107,    1,    9,    1, 1667,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   25,  526,  187,   69,    1,  297,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3187, 2422, 1827,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   68,    1,  365,  399,  845,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1173, 2957,   12,    1, 1766, 1767,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  123,  215,  250,  220,  354,   45,    4,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826,  249, 1021, 2151, 1675, 2630,    1, 2939,  140,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,    8, 2976,    9, 1228, 2558,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2844,  187,  344, 2909,  135, 2597,  361, 3383,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1965, 2550,  782,    1, 2668,  361,  388,  459,   45,  238,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  171,    1, 1090,   98, 2929,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1090, 2677,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492, 2678,  762,    1,    1, 3105,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2623,    1,    9,    1,  671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1550,  420,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2546,  733,  547,   59,    1, 1632,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 2205, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2960,  176, 1606,   27, 1094, 1554, 1744, 1941,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2694, 1431,  147, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,   12,    1, 1151, 2094, 2992, 1415,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  534,   12,  550,  369,    1,   37, 1413,   12,  552,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3088,    1,  167, 1403,  139,    9,  116,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2269,    1,   61,  365, 3182, 1831,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1853, 2817,    1,  176,  177,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984, 2405, 1750,  633, 2918,   98, 2662,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2658, 2269,   32, 2518,  220,    1, 2280,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  252,    1,  594,  910,  509,  593, 2153,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   91,  313,   37,  123,    1, 1477, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  882,  376,  570,    9, 1151, 1131,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1479,    1,    1, 1766, 1767,    1, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,  439,  417,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2159,  716,  119,  737,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  217,   37,    1,  572,    1,  572,  197,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   29,  656,    1, 2829,  782,  754,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3149, 2774,  650, 2216,  413,    9,   36, 2891,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2971,    1,  590, 1400,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  834,    1,  150,    1,  125, 1126,  159,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,    1,   32,  218,  190, 1403,  596, 1424,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1486,  716,    1,   72,  401,  244,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  273,  765,   37,  365,    1, 3011,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,    7,  698,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,  319,   32,    1,  730, 2614,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2535, 1361,  463,   45, 2735,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  122, 1687,    9,    1, 2249,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  799, 1080,    1,  176,  131,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1430, 3382,    1,   98,  531,  890,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  844,    1, 2747, 1089,   45,   36,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1572, 1414,    1,    1,    1, 2250,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   51, 2192,  985, 1260,  411,  304,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  542, 1388,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2548,  726,  917,   37,  487,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3206,   85,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398, 3311, 3310,    1,   12, 2225,   37,   52,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  617,  259,   15,   77,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160,  437, 1236,  503,   32,  942,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1390,   37,    1,    4,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2563,    1, 1360,  612, 1343, 1517,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3343, 1428, 3345,  240,  949,   45, 3370,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468, 1776, 1764, 1990,  260,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  116,   96,    1,  729, 1604,   32, 1647,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  288,   37, 1776,  365, 2232,    1, 2759,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  379,  774,    1, 2162,  105,    1, 2291,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713,  730, 1777, 2274, 1659,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    6,  572,  157,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   12,    1,  249, 2440,  548, 2734,  232,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1902,    1,    1, 2297, 3141, 2308,   45,  166, 1034,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1397,   45,  594,    1,    1,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,   45, 3217,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2684,    9,  755,   17,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  156,    1,   69,  102, 1027,   25,  417,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1062,  458,    1,  395,  945,    1,   63,  332,  333,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 3134, 1654,   37,  208,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1520,  200,  449, 2723, 2724, 2636,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    8,    1,  861,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   53,   79,   37, 2919,  607,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  310,   25,    1,  417,   98,  275,  509,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2161,  267, 2332, 1827,   32,  430,  565,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2489,  166, 2773,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647, 1550,  494,    1,  148,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1545,  565,  388,    1,  763,  311, 2936,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2414,    1,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  976,    1,    1, 2729,    1,  384, 1327,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  249, 1594,   37,  116,   37, 1000, 2518,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  455, 2164, 2986, 1046,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2978, 2798,  884,  656, 1267,    1,  176,  915,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1665,   37, 1212,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1625, 2088,    9,  627,   45,    1,   12, 2725,  195,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,    1,  190,  606,    1,   98,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878, 2619,   98,   37,  688, 2755, 1306,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1861, 1830,    9, 2571, 2784,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2193, 2884,    1,  176, 1016,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  182,    1,    1,   37,  930,  384,    1,   76,   37,  631,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 2640,    9, 1821, 2190,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2255, 1416,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3117,  125,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  727,  613,   37, 1289, 2458,   37,  858,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1900,    1,   98, 1515,  808,   32,  166,  863,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1416, 2232,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835, 1574, 2985,   32,  730, 2288,    1, 3389,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3303,  765, 1159, 3295,  176,  593,  427, 1343,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1084,  841, 1110,  664,  147,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3021,   12,  671, 3126, 2440,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,   37,   47,  331,  998,   32,  793,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  829,    9, 2071, 1331, 1151,  315,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,    1,  297, 3358,   12, 2162,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  342, 1822, 1343,   73,  220,  864,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,   37, 1947, 1718,  528,  768,  509,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  766,  936,  269,  210,    9,  327, 2871, 1102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  957,   37,  588,    1, 1281,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  566,  395,  187,  218,  361,  627,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2695, 2796, 1594,   39,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3286,  614,  548,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 1147, 1414, 1539, 1479, 2731,   32, 1850,  531,    1,\n",
      "          249,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3347, 1156,    9, 2108,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3306,   37,    1,  809,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3380,  765,   37,   77, 1583,  317,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 2682,   10,   98,    1,   45, 1002,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307,   37, 1539,  810,   32,  786,  259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1749,  619, 1757,    9, 1126,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  203,  445, 1092,    9, 1200,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2733, 1914,    1,  912,    1,  484,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12, 1267, 1777, 2739,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2388, 1022,    1,  831,  220,  726,  297, 2719,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3369,    1, 1421, 2024,  543,  176,  861, 1906,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1189,  828,  562, 3107, 3366,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1178,  220,    1, 2414,    1, 2766,  176, 1619,  395,  845,   36,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  313,    1,  546,  176,  923,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1009,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32,  531, 1656, 3389,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  973,   37,    1,   15,   45, 1089, 1675,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1210,   37, 1697,   98,  105,  457, 1821,  880,    1, 1779,    1,\n",
      "           45, 1448,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1723,    1,    1,   32, 1405,  132,  220,  373,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2637,   12,    1, 2437,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  975,  716,  242,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  187, 3240,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1688,   28,    9,  333,   32,    1, 1611,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  390,  470,   98,  531,  965, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1529,    1,  548,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3090,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1770, 3358,   12, 2162,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1408,    1,  220, 2544, 1499,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2563,    1, 3103,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3241, 1421,    1,    1,  713,   98,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  233, 2104,  908,  302,   37, 1636, 2971, 1867,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  517,  541,  167,    1, 1821, 2057,    1, 1116,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1625,   29,  321,   52,    1,  384,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  108,    1, 2400, 2264,   45,    1,  629,  327,  593,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2002,    1,  928,   98, 2498, 1897, 1537, 1218, 3096,  427,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984,    1,    1, 2662, 2918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,    1,  131,    1,    1,  233, 2104,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2909, 3383, 2751,    1,    1, 2856,  103,  947,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1022,    1,    1,   98,   56,  537,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  586, 1872,    1,  361,    1,    1,   28,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2527,  164, 2414, 2335,  356, 1691, 2504, 3065,    1, 1022, 2566,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  388, 2572,  187,  104,    1, 1428, 3146,  444, 3339, 2456,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  547,    1,  220,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1,  921, 2748, 1771,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  971,  518,   50,    1, 1536,  131,  734,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  844,    1,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  579, 1564,  105, 2334, 2080,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2400, 2524, 1768,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  199,   45,  247, 1204,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  580,  885,    1,   43,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2414, 1312, 3111,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584,   37, 1638,    1,   98, 2661,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3200,    1,   98,    1,  548,  645,  354,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,  765,   37,    1,  616,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1215,   45, 2235,    1,   37,    1, 2294, 1851,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779,    1,   37, 1447,   26, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 2767, 1778, 2232,  328,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,  431, 2069,  220, 2560, 1864, 2677,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1239,    1,  176,  163,    1,   12,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  142,  603, 1488,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2024,   46,   98, 3369,   12, 3118,    1, 1114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1818,   32, 2890,    1,    1, 2942, 2479, 3077,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  741,   32,    7, 1002,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1097, 1149, 1313,  869,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  883,  568,  338, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1,  190,  193,    1,   32, 2673, 2375,  210,  342,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2592,   37,    1,    1,    1,   37,  856, 2141,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2181,    9,  786,    1, 2181,    9,  810,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3280,  140,  365, 1788, 2472,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1173,  176, 2979, 1151,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2140,    1, 1530,  357, 2249,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1815, 2161,   12,  302,    1,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  342, 1974,  104,  970,  909,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2374,   61, 1041,    1,    9, 2080, 2771,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2226,  540,  806,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,  902,  608, 3083,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328, 2153,    1,  439,    1,   12, 3158,  698,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868, 2061,  903,    1, 1447,   98, 2375,   46,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1159,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,  361, 2740,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3115,    1,    1, 3245, 2537,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  894,  429,  247,  582,  845,    1,  713,    9,  885,  389,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147,    1,  774, 3356,  213,   37,  439, 2646, 1512,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  171,  719,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  590, 1008,   61,  227,  550,  446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1477,    1, 3337, 1114,    1,   32, 1990,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   58,   61, 1480,  845,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1851,    1,  321,  764,  865, 3194, 3195,   37, 3098, 1890,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2448,  386, 2827,    1, 1545, 1774, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1400,  415,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    9,    1,    1,    1,    1, 1764,  190,   52,   98,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2496, 1976,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  224, 1205,  191, 1762,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  838,  275,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,   1, 191,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  42,   1,   1,  43,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  643, 1348,   37,    1,  395,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1515,  248,    1,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2018,    1,  166,  104, 2405,    1,  193,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1842,  551,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  455, 1988,   45, 2189,    1,   32,  691,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,    1,   72,  401,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   49,    1,   28,    1,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2698,    1,  164,    1, 1010,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,   37,    1,    1,    1, 2131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2347,   32,    1, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1818,  147,  894,  439, 2840,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,   52, 1411,   98, 1267,    9, 3103,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1330, 3128,   98, 1967,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340,  894,  619, 1333,  176,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  787,  470,   97,   98,    1, 3320,    1,   81, 3180,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 2823,  863,   32, 3367,  328,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1613,    1,  829,  288, 1117, 1525, 1228, 1259,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  647,    1,  170,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   37, 1248,  395,   37,  973,    9,  388,\n",
      "          903,    1, 1447,   46,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,   26,  242,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1186, 2593,  365, 1397,    9,  116,  259, 2264,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 2069,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1043,  338,   37, 1034,  340,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  560, 1274,   71,  187,  347,  470,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   47,  960,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018,    1,  270,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1485, 2246,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   34,  294, 1684, 1625,   32, 2841,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  845,    1,   45, 1646, 2554,  985, 1260,    1, 2847,  629,    1,\n",
      "          761,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1403,   39,    1,   32,  584,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,    1,    1, 3363,  859,  365, 2240,    9, 3360,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  180,    1,  179,   32,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  872,   37,   92,   29,  656,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   51, 1636,    1,    1, 1116,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1823,  662,    1,  326, 1086,    1,  361, 1713,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640,   39,  176,  142, 1443,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3204,   61,  166,  449,  452,    1,   37,    1,   52, 1277,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,   28,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  348,   37,  151,    1,    9,    1,  131,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49, 1536,   32,  104,    9,  467,  680, 2240,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3191, 1249,    1,    1,  641,  631,    1,    1,  105,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  849,  159, 1253,    1,  419,  420, 1770,  132,   27,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2790,    1,  111,  516,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 2483,  284, 1675,    1,    9, 2332,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2984, 2418, 2945,   45, 2662,   12, 2918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  446, 2415, 1338,   45, 1135,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,  552,    1,   34, 1998,   79,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1143, 1556,   39,  220,   83,  384,  698,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3103,  951,    1, 3318,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3013, 1635,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   10,  315,   37,    1,   32,  316,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 2591,   37, 1195, 2673,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  632, 1407, 1190,  738,  220,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  986,    1,  152,   32, 2115,  399,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2464,    1,  150, 2361,  285,  548,   56,   74, 1108,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   74, 1552,    9, 2533,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  716, 1524, 1124,   32,  197,   98,  365,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2780,  606,    1,   59, 2476,    1,  565,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  121, 1550,    1,   32,  531, 2375,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,   37, 1937, 3358,  528, 1404,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,    1,    1,   98,    1, 1997, 2917,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428,    1,    1,    1,  191,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  196,    1,  176,  551,  612,  613, 1416,   66,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3336, 3361, 1096,  163,    1,   12,    1, 2924,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3118, 3279,  222,  412,   37, 3396,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  770,   45, 2249,  487,    1, 1976,   27,  691,   12,    1,  135,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,    1,   69,    9,  987,    1,  225,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  656, 1267,  105,  638, 2814,    9,  166,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 3264,   45, 2645,   37, 1178, 1492,    1, 1590,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3172,  267,  683,  321,  612,  865,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,   32,  471,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2644,   32,  166,    1,    1,  548,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  492,  458,  200,    1,  389,    6,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790, 1579,    1,  700,   12,    1, 2636,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3151,  810, 1292, 2850,    9,  913,   98, 1676,    1,  872,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,   12,    1, 2744,    1, 1101,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1963,  972,   37,  606, 1857, 1602,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190,  814,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  455, 1004,  516,  384,  395,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  920,  334,  321,    1,    1,    1,  119,  810,  844,   30,    9,\n",
      "          105,  974, 1034,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  434,  105, 1488,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2252,  628, 2107,   32,  455,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  634,    1, 2917,   37, 2674,   32, 1250,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3307,    1, 2114,  384,    1, 2318,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 1037,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2300, 3048, 2923, 1494,   39, 2697,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1185,    1,    9, 2158,   45, 2121,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  961, 2778,  477,  132,   98,    1, 1818,  147,    1,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   32,  531,    1,    1, 1140,  884,    1,  361,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  348, 1633,  951,    1,  166,  803, 1223,    1, 2773,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2246,  104, 2659,   37,   77, 3163,  671,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550, 1663,   37,  221,    1,   39,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  487,   14,   15, 1937, 1254,   93,   32,   86,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3173,  400,    1,  187,    1, 1167, 3282,  719, 1017,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3228,  288, 1515, 2364,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   62,   32,  166,  616,  202,    1,  115,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  147,    1,   35,   22,  438,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   12,  472,   98,    1,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   52, 1205,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1017,  353,  197,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1319, 2064,   37,    1,  442,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2745, 1194,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885,  294, 3395,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2676,   51,  764,  357,    1,   10,   12, 2467,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,   12,    1,    1, 2376, 2309,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  876,  612,    1,   39,    1,   98, 2083,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2280,    1,  193, 1322,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2501, 2502,   12, 1960,    1,   59, 1714,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,    1,  633,  920, 1297, 2264,    1, 1515,  248, 2261,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1196,    1,   37, 1154,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118,    1,  865,   37, 1824,   32, 2047,   45, 3357,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1542,  357,  193,  361,    1,  193,    1,  620, 2208,  614,  129,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,    1, 1360,  612,    1,  105, 2219,  121,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1435, 1147,    1,   32, 1188,   45,    1,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425,    1, 2538,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1233, 1149,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968,  474, 1458,  138, 1083,  384,    1,    1,    1,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  449, 1090, 1921,    9, 1100,  784, 1151,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1408,  479,  197,   28,   15,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1536,  449,  149,  444,  792, 2650,  792,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2275,  117, 1070,  600,  531, 2389,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1527, 2664, 3377,    1,  176, 2235, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 2618, 2250,   32,    1,   32,  593, 1990, 2701,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2, 163,   1,  12,   1, 347,  66, 677, 528, 122,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 107,   1, 580,   1, 187,  69, 102,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  190,  151,  449,  223,    9,    1,  131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2573,  744,   28,    1,    9, 2288,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1233, 2562,  365,    1,   45, 1204,  191,  730, 1571,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  104, 2548, 1941,   32,    1,    1, 1450,  686,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  459,   28, 1718, 2860,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1654, 1508,    1, 1523,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1017, 2005,  529, 2727,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303, 1082,  573,  362,    6,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 1051, 1296,   98, 1074,  861,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  437,  396,    1, 2137,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1920, 1236,    1,  297,    1,  396,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510, 2414,   32,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2562, 1516,   37, 2200,    1, 3103,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  936, 2666, 1017, 1758,    9,    1,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,  342, 2390, 1903,   32, 2069,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1041,  361, 2317,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1092,  992, 1159, 1935, 2294,  856,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,  361,  395, 1505, 1718,  662,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  634, 3248, 1509,    1, 2321,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3317,  267, 2081,  190,    1, 2741,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,   12,    1, 2614, 1173,   55, 2764,   12, 1509,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,    1, 2816,  557,  540, 2292,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  992,   28, 1896,   37,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 2789,  475,  261,   39, 1698, 3093,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1051,  361,  829, 1872,  872,    9,    1, 1244,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1, 1025,  123,   37,    1,  220,  422,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1128, 1203, 2400, 1021,    1,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363, 1396, 1230, 2242,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 1601,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1700, 1530,   32, 3360, 2960,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2617,    1, 3358,    1, 3404, 1096,  164,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,    1,    1,   45, 3012,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  546,  494,    1, 1132,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398, 2572,   32,  645, 2755, 2504, 2292,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2742,   45,    1,    1,  928,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  777,   45, 1412,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  548,  537,    1,    1, 2153,  565,  729, 1809,    1,  297,  798,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 1834,    1,  591, 1167,  166,    1,  793, 2126,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1554, 2579, 2689,  447,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2751,    1, 1147, 2548,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  215,    1, 1046, 1405,  133,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  393,   37,  125,    1,  138,  419,    1,   82,  948,  138,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,  267,  460,  967,    1,  284,    1, 3107,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  281,  282,   37, 1195,  737,  197,  716,   32,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2962, 3175,   77,  539, 1684, 1625, 2793,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453,  190,   77,  388,  987,   98,   38,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1183, 3038,   74,   32, 3339,  187, 3101, 1414,  973, 1159,\n",
      "         2791,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  506,  267,    1,    1,  193, 2879,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796, 3048,  927, 1685, 1118,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1407, 1190, 2770,  903, 1447,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3403, 2414,  163,    1,   12,    1, 1920,   32, 3376,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2700, 2243,  934,   37,    1,  201,   32, 2673,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1759,  309,    1,  395,  477,  365,  945,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  938,  796,  187,  941, 1201,    1,   82,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1001,  977, 1150,   37,    1,  182,  424, 1034,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3108, 2935, 3175,  504, 1737,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1625,   37, 1343,  444,  942,  528,    1, 1987,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1675,    1,  550,  361, 2913,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1035,   37, 1642,  199,   32,  539, 1037,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  597, 1486, 1831,   61, 1041,   59,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2136, 1877,  996, 1527,    9,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1345, 1675, 2654, 2865,    9,  166, 2063,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1591,    1,   96, 1425,   32, 1913,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   60, 1287,  384,  119,  687,  951,   94,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   12,    1, 2421, 1897,    1,  220, 1053,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3359,  413, 1458, 1743,   98, 3339, 2271,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 1009, 1484,  734,  591,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962, 2463,  563,  365, 2584, 2565,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1458,    1,  230, 1116,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  792,   32,  750,   45,    1,  792,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  673,  815,   45,  869,    1, 2205,   32, 2206, 2207,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,  750,  475,   46,   98,  163,    1,   12,    1, 2924,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2255,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2976, 1389,    1,    9,   65, 1132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  161,    1, 1627, 1159,    1,  220,  366,  104,  164,  165,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1630,   12,  482, 1991,    1,    9,  457,  244,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1312, 2572,   32,    1, 3392, 2960,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1043,   28,  528,  800,  568,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1074,    1,  980,    1,  888,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 1037,  275,    1,  608,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1423,    1,    1,  133,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1186, 3109,    1, 3382, 2764,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  952,   37,    1,   39, 2095,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,  365, 1788, 1215,  754, 2568,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32, 3376,  187, 2950,    1,  104,  861,  700,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1711,    1,  187, 3343,    1, 1586,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2328, 2870,  530,  104, 1967,   32, 3376,    1,  590,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  968,    1,  602,    1,  854,    1,  455,  877, 1651, 1377,    9,\n",
      "         1428, 1906, 1311,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1, 1055,  910,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1157,  159,  439,  176,  119,  845, 1109,    1,  504,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3299,  191,    1,    1,    1, 1021, 3232,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  769,   32,    9, 2605,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2751, 1641,   28,   69,  965,   32,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2267,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  120,   32,   14,   15,    1,  347,  997,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3382, 2572,   32, 2018,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  917,   37,    1, 1506, 1584,  487, 1575,  297,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2826,    1, 2789,  873,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  200,  792, 1254,  792,    1,  517,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   26, 1298, 1382,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1149,  288,    9,    1,  548,    1,   92,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3323, 2712, 3227,   32,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,  333, 1051,    1, 1039, 2690,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,   37,    1,  284,  950, 2641,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1728,    1,    1,    1, 3103,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  422,   66,   37,  562,  224, 1126,  548,  552,    1,  331,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  206,   12,  174,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361, 3267,  288,   28, 1798,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2132, 2142,    1, 2206, 2207,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428, 2216, 3369,    9,    1, 1450,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  460,   12,  547,    1,  357,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,   10,    1, 1270,  331,   32,  871,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  361,    1,  515,  872,  942, 1018,    1,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962, 3271,  186,   37,  688, 3251,   32, 2295,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,  315, 2869, 2723, 2724, 2636, 1825,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  581,   73, 1050,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  848, 1586,   28,    1,  275,    9, 2371,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,   12,  669,  854,    1,  342,   37, 1237,  956,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3348, 1906, 1713,  856,    9, 3102,   12, 1204,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613,    1,  829, 1413,   98, 1273, 1117, 1525,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  342, 1086,  976,  909,  528,    1,  509,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,    1,    9,  593,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 737, 197, 418,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 691,   1,  98,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  972,   37,  125,    1,    4, 1232, 1903, 1980,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  844,   51,   52, 2261, 1529, 2706,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  874,  794,  365,    1,  327,  220,  613,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1702,   37,  335,  531, 2774, 1223,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   45,  529,    1,   32,    1,    1,    1,    1,    1,\n",
      "         1897,    1, 2456,  963, 2122,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,    1, 1073,   85,   69,    1,    1,    1,  297, 1149,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  119, 2098, 2539,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,    1, 1458,    1,   98,  446,   12, 1140,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,   28,    1,  218,  566,   65,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1587,   45, 3184, 2579,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  125,    4,    1,  335,   44,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1166,    1,    1, 1166,  190,    1,  619,   37, 1343,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 2439, 1294,    9,  121,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   85,  166,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056, 2572,   32, 2412, 1585,   32,  463, 2490,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123, 1340,  640, 2174,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2093,    9,  694,  951,    1, 2160, 2049,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2282,  315,    1,   32,  147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  422,    1, 2861,   37,  457, 2054,  389,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   25,  236, 1022,  157, 1571,  218,  220,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  593,    1, 2772,   45, 3377,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,  138,  331,   37, 1206,    1, 1576,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,    1, 3132, 1343,    9,    1, 2697,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1521,    1,   45,  580,   45,  166, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1154,  268,  478,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  213,   37, 1835, 1523,  437, 1512, 2954,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2453, 2827,  191,  902,    1,    1,  726, 1114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  810,    1,   28,  297,  529,    5,  736,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1869,  378, 2315, 1045,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1225,  193,    1,  191, 1149,  477,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  670, 1114,  444, 1985, 1178,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1019,    1,    1,    1,    1, 2161,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  137, 1205,    9,    1, 1077,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1468,    1,  737,  354, 1052,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   22,   23,    1,  853,    1, 1159, 1821,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1499,   12,  138, 1806,  693,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2816,  384,  104, 3381,  856,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,  919,  171,   45, 1193,   32,  403, 3118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 1361,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,  219,  615,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1698,  128,  115,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2103,  617,    1, 2141,  171,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  590, 2149, 2996,   32, 3369,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  215, 1178, 2827,  297, 1051, 1039, 2690, 2607,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  539,    1,    1, 1876, 3380,   12,    1,   32,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2835,    1, 1094, 1211, 3080,   32,  269,  132,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  267,  460,    1,  955, 1461,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1185, 2887,    1,  140,  166,    1,    1,  187, 3303,  361, 1130,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3058, 1009,  267,    1,  792, 2891,  792,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3121,    1,    1, 1789,   12, 1633,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  754,  757,   42,    1,   43,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  303,  954,    1,  284,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3407, 3105, 1348,   37,    1,   32, 1313,   45, 2950,  176, 3392,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  415, 1584, 2349,  168,   37,  611,  920,    1,  267,  545,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422, 2185, 2461,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1610,    1,   45,    1, 2796,    1,  220,    1, 2796,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   32, 2338,  187,   69,  431,  813,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  138,  331,   37,  875,  422,  927,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,   86,    1,  883, 1279,  338,    1,  408, 1124,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051, 1713, 2992, 1320,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,   26,  361,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,    1, 2615, 1542,    9,    1, 1523,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  954, 1161,    1, 1556,  424,  339,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1412,   15,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  645, 2963, 2566,  176,    1, 3178,  140,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 2294, 1765,  105, 1090,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,  622,  232, 1156,    9,    1,  600,   20,  802,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  204,   12,  193,  311,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  358,  359, 2035,   46,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   60, 2055,  220,    1,  682,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3323,   77,  153,   79,  721,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  442,  157,  227,  528,   69,  636, 1500,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,  146,    9, 3365,  949,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2598,   37, 1327,  548,    1,  471,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12,  111,  834,   32,  777,   45, 2298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2316, 1665, 2005, 3115,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388, 3098,    9,  121,   12, 3282,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2, 135,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 267, 197, 190, 245, 548,  50,  15, 328,   1,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  493,  102, 1269,   37, 1738,    1,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746,    1,   32,  829,   12, 2348,  844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2266,    1,   32, 2059,   12, 1338,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  113,   39,    1,   45, 3339,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  334,  321,  138,    9, 2171,  166, 1868, 1172,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1412,    1, 1781,   37,    1, 2026, 2574,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3319,    1, 3232,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,  192,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,  57, 809,   1, 187,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 550, 369, 253,  37, 741,  98, 221,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37,    1,  333,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766,  200, 2627, 1230, 1027,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,  691,   37,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861,    1, 2952,   32,    1, 2851,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   66,  417,  773,    1,   69,  817,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3244,  321,  612,  726,  460,  810,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,  476, 1123,   37, 1604,   39, 2901, 2537,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181,    1,    1,   45,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  953,    1, 1226,   39,   45, 2205,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1840,    1, 1132,   45,  166,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2984,  927,   37,  865,   37, 2662, 2918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715,    1, 2116,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  811,   37,    1,  342, 1953,  220, 2877,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947,    1,    1,  927, 1159, 2280, 2162,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2070,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1358, 1229, 1610,   98,  864, 2439,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  166, 2667,  260,    1,   28,  361,  105,  176,    1,\n",
      "         1305,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,   37,  151,  861,  698,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2942,   12, 2813,    9,    1,  614,  680,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1557,    1,    1,   98,    1,   12,    1, 3380,   12, 1583,  317,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  447, 2257,    1,   98, 1891, 1074,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1938, 3197,    1,    9, 3243,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  183,  715,  217,  686,  191, 2026, 1450,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236, 1022,    1,   66,  417,   98,   69,  224,  343,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  282, 2367, 2695,    9, 1658,  327,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,   37,  123,  453,  616,  105,  581,   74,    9, 3121,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,    1,   37,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181, 2567,   98, 1199, 1027,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  977,  606, 1030, 1559,    1,  176,  638,    1,  736,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  424,    1,   45, 1125, 1018,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  877,  255,  400,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 1082, 3375,   37, 1314,  754,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  208, 1218,  114, 2414,  176,  177,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1,    1, 1249, 2922,   32,    1,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1985, 2572,   32, 3051,   22, 2625,   98, 3118, 1223, 2774,  437,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  974,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2535, 1632,  994,    1,  150,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1487,  197, 1784,    1, 2025, 1034,  696,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2860,  498,   37,  288,   28,  622, 2172,    1,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3092,    1, 2292,  176,  826,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2528,   45,  596, 2691, 1388,    9,  987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,    1,  548,  985, 1857,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  971,  603,   37,  125,  408,    1,  202, 1977,    1,   98,\n",
      "         1978,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  861, 2972,  475,    1,  939,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2192,    1, 1018, 1285,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118,  105,    1, 2596, 1555,   37,    1, 2117,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1472, 1488, 1171,  384, 1097,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3164,    1,    1, 1625,    9,    1,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 2996,    1, 2232,    1, 2762,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  224,   71,   63,  166,  862,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1440, 2642,  872,  420,  385,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2556,  105,  388,    1, 2862, 1563,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1214,    1,  872,  420, 1169,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   12,    1,   32, 3311,  400, 1270,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  853,    1,    1, 2324,  395,   98,  103,  593,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3254,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2669,  166,  627,   32, 1018, 1691,  293,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  453,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  395, 1082,  104,   37, 2446,  840, 2108,   37, 1789,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1574, 2449,    9,  166, 1497,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  565,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2699,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1340, 2005, 1110,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2802,  140,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  421,    1,    1, 1413,    9,  617,  259, 1107, 3049,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  716, 2877,  267,  531,  167,    1,   39,  890,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977,   37, 1171,    1,  216,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437, 1458, 1994,    1, 1671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  213,   37,  138,   59,   37,  875,    1,  149,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,  774,    1,    1,   51, 1371,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2885,    1,   28,    9,  183, 1838,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75, 1679,   28,    1,    9,  517,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3045, 2481,   32,    1,   45,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2136,  146,   37, 2161,   98, 2095, 1816,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  647,  353,   72,  401,  197,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1874,  949,   45,  453, 1682,   32, 1081,    1,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3034, 2264, 1371,    1,   37,   33, 1117, 1525, 1704,  157,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2473, 1455, 1294, 1396, 2474,  618,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1751,  546,   37,  631,    1,  628,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3196,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  567,  510,    1, 2807,  361, 3103, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3043, 2416,  820,   32,  215,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 971,  91,  37, 125,   1,   4,  32, 132,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 224, 794, 365, 777, 778,   9,   1,   1,   1, 101,   1,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1086,    1,    1,  223,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1256,  551, 1256, 2084,  887,   32,  453, 2218,  190,    1,  166,\n",
      "         1983,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2896,  566, 2627,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,    1, 1156,    9,    1,    9, 1785,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3117, 1556, 1979,  176, 1514,  199,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2451, 1668, 1684, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3038,    1,    1,   32,  215,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,  140,  182,  684,   24,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3043,  632,    1, 1231,  220, 2026,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2328, 1542,   37,  168,   98, 1139, 1694,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  485,    1,    1,    1,    1,  244,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2870,   32, 2504,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  562,    1, 2113, 1650,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,   12, 1281,   98,  582,    1,  665,   37, 1463,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 2660,   79,    1,   32, 1619, 2517,  548, 2169,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1934,  446, 1988,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  858, 1631,   45,  350,    1, 2576,  105, 2786, 2709,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1,  744, 2364,   98,  340,  439,  218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  352,   51, 2346,    1,   50,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393, 1769,   37,   77, 1480,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2496, 1822, 1947,   43,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1877,   37,  686,  166, 1567, 2290,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,  267, 1732,  218,   37, 1121,    1,  332,   37,   71,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2685,  512, 1558,  202,  190, 1838,  914,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  217,    1, 1469,  529,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2180,    1,    1,  664, 1818,  147, 1377,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,  845, 2326,   32, 1090,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3330,  140, 1909,    1, 1185,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3221,  183,  726,    1,  807,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,  952,  104,  147, 1942,   37,    1,   50,  333,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  437, 2652,    7,  538,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 1935,    1,    1, 2261,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,    1,   12, 1462,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1584,    1,  544,  247,  389, 2256,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3239,  114,    1, 3301,  548, 1056,    1,  537,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974,  541,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  187, 2672,  907, 2672,  404,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1076, 1380,    1, 1046,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 1374,   98,  109,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  671,    1,    1, 1654, 3126,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2637,  140,    1,  142, 1144,    9,    1,  372,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  180,  162, 1794,  617,  259,   24,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  324,  325,  326,   12,  327,  112,    9,    1,  131,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3376, 2596, 2162, 1950,  418,    1,   28,   37,    1, 1530,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3209,   23, 1524, 1090,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1477,    1,    9,  104,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2307, 3200, 1421,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1,   37,  877,    1,  361,   93, 1259,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,    1, 1095,    1,  657,  877,    1,  579,   61,  105,    1,\n",
      "            1, 3000,    1,  150,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  852,   81,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   98, 1383,    9,    1,    1, 3222,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3290,  726, 3246,  220, 1971,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1298,  922,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2429,  444, 2476,   32, 3376,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3129, 2442,    1,    1,  744,  166,  411, 1224,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  990, 1536,  149,  444,  116, 2650,  700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2416, 3381,    1,    1,   37, 1926, 1927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496,  388,  763,   59,  858,    1,   32,   91,  892,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1448,  408,   37,  686,    1,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  862,  221,   28,  166,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  288,    9,  526,   26,  326,   32,  289,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  792,  190, 1745,  439,  792, 2673,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1585, 2414,   32,    1, 2018,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  267,  171,  681,  321,  151,   49, 1541,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3369, 1557,  267, 1098,    1,   37, 2162,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1097,   57,    1,  191,  622,  644,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  395,  566,  388, 1553,   37, 1121,  954,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2572,  187,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1951,  863,    1,    1,  140,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  951,    1, 1013,  544,  334,    1,    1,    1,    1,    1,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1804,  119,    1,  532,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3372,   37,  865,  754,  548,  537,   45, 2024,   46,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  485, 1948,  315,   37,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2120,    1,  176,  136, 3217,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2523, 2489, 2155,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2648, 2801,  244,  245,   98,    1, 1339, 2015,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2, 381, 267, 422,  51, 335, 522, 444, 375, 328,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 197,  28,   1,   6,   4, 159,  71,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1,   32,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1987, 1641,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1918,   61, 2213,    9,  787,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,  162,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,   22,    1,  359,   37,    1,    1,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564, 1805,  271,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2024,    1, 1268,  756,   32, 1212,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1190,  384,    1,   37, 1140,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1178, 1061,  297,    1, 2772,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282,    1,  167,  429, 3329, 1990,    7,    9, 3253,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 3354,  446,  884,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1293, 1568,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  679,   69,  997, 1027,   28,   68,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3227,  631, 3326,  176,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,   22,    1,  393,  837, 1682,    9,  365,    6,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  759,   45,  853,  538,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  790,  653,    1,  444, 1628,  229,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2775, 1745,  852,  680,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2656, 2652,    1,   54,  460,   47,   79,   37, 1962,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159,   28,   88,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  848, 1566, 1234, 1876,   37,    1, 1230,  542,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1463,  546, 2390, 3085, 1461,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,    1, 1228, 1632,  163,    1,  903,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433, 1579,    5, 1119,   37,    1,  983, 2285,  125,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1123,  273,  726,  593, 2522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  550,   32,  870,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2463, 2101, 1042,   37,  220, 2651,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1602,   12, 2764, 3210,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1417,    1,  171,  140,    1,    1, 3201,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  225,   15,   28,   32,    1, 2054,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  437,    1, 1128, 1539, 1994, 2650, 1708,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3092,   32, 2811,  927,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  334,    1,  460,    1,  334, 2324,  460,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  567,  510,    1,  328,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056,  216,    1, 1316, 2597,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  315,    1, 1159,  258,  754,  327,  218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2343,    1,    1,    1,  600,  531,   12, 1545,  187,  105,    1,\n",
      "           45,  443,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1687, 1022,    1, 3008,    1,   51,   52,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158,    1,  848,   12,  533,  187, 1230,  884,   79,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 3159,  854,  528,  857,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3169, 2781,    1, 3173,    1,  176,  104,   26,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1047,  615,  912,  149,    9,    1,   32,  104,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  942,  103,  147,   66,    1, 1750, 3153, 2220,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  811,  267,  531,  443,    1,  388, 2342,  593,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  864, 3109, 3094,   98,    1,   45,    1,   98,  453, 2439,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1140,    9, 1860,   45, 2020,  890,    1,   45,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,   25,  686,  191,  120,   32,   69,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087, 2614,  442,    1, 1854,   37,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147,    1, 2598,   37, 2646,    9, 2024,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1798,   32,  166,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3176,    1,    1, 2857,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  291,    1,  777, 2544, 2043,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2993, 1542,    9, 1065,  199,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,  183, 1008, 1632,   37, 3308, 1990,  437, 1267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,  267,  453, 2334,   61,  593,   12, 1254,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  872,   61,    1,   98, 2561,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  883,   93, 1071,   85,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715, 1281,   98, 2710, 1929,    1,    1,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  581, 1463,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1461, 1396, 3339, 3384,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  302,    1, 1038,  199,  297, 2650,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  676,    1,  720,  191,    1,    1,  420,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2765,  909,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2235, 1310,   37,    1,    1,    1,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,   16,   79,  872, 2657, 2043,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3102,   32,  531, 1240,   52,    1, 1178,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2554,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  391,  361, 1943, 2541, 1540,  384, 2224,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  105, 2623,    1, 2623,    1, 2623, 2472,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  530,   98,  679,  529,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   46, 1010, 1011,  856,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  176, 1652,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2995, 2454, 1018, 2613,  837,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2056, 1171,  507,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 531,  37,  52,   1,  45, 118,  45, 734,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 503, 251, 749, 750,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1411, 1009,  190,  712, 2753,   45, 1930,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  922,    1,    1,  683,  865,  658,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2468, 1249,  386,   78,   37,  726, 1764, 1990,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1891,  593,    1,  105,    1,   45,  917,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  468, 1362, 1419,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3252, 1287, 3228,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1087,   37,  877,  131, 2336,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2331,  600,  389,  220, 2685,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  555,   32, 1785, 2044,    1, 2834, 1523,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,    1,  307, 2092, 1757,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,   26,  242,    1,    1,  631,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363, 1401,   32, 3360,  741, 2116,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1433, 2226, 2582,   37, 1910,  691,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2977,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3018,   37,   52,  820,   32,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,    1,    1,  363,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2468, 3109, 1194,    1,   32, 3043, 2596,  722,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096, 3180,  489, 1048,  187, 3181,    1,    9,  449,  199,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1528,   32,   46,   37,  151,  215, 1093,  574,   87,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1899,  580,    5,    1,   44,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  716,  774, 3305,   61, 2626,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,    1, 1307,  872,   28,    9,    1, 1273, 1228,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   75, 1831,    1, 1436,    9,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1577, 1419, 2785,   45,    1, 1274,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  696, 2153,    1,  688,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649, 1448, 1329,  729,   11,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1303, 1421,  517,  630,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2328, 1178,  967,  258, 2471,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1017,  308, 2056, 1011, 1220,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162, 1950,  384, 3393, 3389, 1426,  187, 2835,    1, 2985,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2171, 3134,  511,  275,    1,   37,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1298, 2606, 1167,    1,  612,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1060,  548,  537,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,    1, 3231,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  711,  691, 1874,   59,  858,   17,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  726,   34, 2468,   37,  951,    1,  447,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  810,  424,    1,  361,  590,    1, 1751,    1, 1176,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  500,    1, 1191,   37, 1835,  116,  668, 1607,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,  140,    1,  187,   69,  102, 1826,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 1617,    1, 1018, 2747, 1171,    9,  284,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  928,   32,  306,  851,  298,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755, 1419, 3028, 2995,  328,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2162, 1950,  418,   32,  121,   36, 2426,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  537,   37,    1, 2284,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3167,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982,  953,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3356, 3357,  729,    1,  531, 3346, 3133,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3215,    1,  384,  311,  183, 1034,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  809,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  101, 1435, 3343, 1190,  267, 1450,   98,    1,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3139, 2619,   98,   32,  455,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  497,    1,   37, 1636,  861, 1906,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  617,  618,  365, 1396,    9, 2964,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37,  698,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  105,    1,  458,  572,  174,  418,  118,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2329, 2086,  220, 1211, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2517,   12,  160, 1161,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2664, 1156,    9,    1,    1,    1,   45, 2588,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3075,  571,  792, 2333,    1,  792,   37,  121,   12,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  297,  187,    1,  475,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1366, 1210, 2275,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3318, 2413, 2449,    1,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3330,   37, 1306,  698,  220, 2693,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3149, 2774,  777,  778,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 1916,  894,   52,  548, 1002,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2924,    1,    1,   32,  567,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2347,    1, 1240,  193, 1343, 1517,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2737,   12,    1,    1,  665,   98, 1616,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,    1,  202,  162,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,   51,  125,  647,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  200, 1230, 2750,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2017,   98,  112,    1,  674,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2279, 1713,    1,    1,    1, 3265,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2308,  693,  972,   37,   52, 2443,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3342, 2598,  754,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  156, 2393,  617,  259,   50,    1,   28,  727,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,    1, 1710,  764,  442, 1813,    1,  361,    1,    1,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 2789,  475,  261,   39, 2381, 2789, 3093,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49, 1576, 1079,    9,  365,  398,   32, 2322,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 2388,  171,    1,    1, 1022,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999, 2194, 3050, 1908,  114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1354, 1796, 2161,    1, 3081,  674,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  245,   98,  861,    1,  156,  509,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3115, 2365,  608, 1110,  191,    1, 3188,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  453,    1,    1,   77,  255, 1729, 1199, 1379,   12,  112,  499,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  559,   79,  139,  471,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2036,   12,    1, 2753,    1, 1463, 2350,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1128,  392,  327,  102,    9,  112,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1176,  445,   45,  105,  227, 1265,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  864,   37,    1,  220,  107,  568,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974,   37,    1,  220,  581,   95,    9, 2695, 2223,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2960, 2766,  176,  177, 1056,  249,  176, 1018, 1325,   32, 3099,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741, 1758,   37, 1286,   32, 2620,    1,  427,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   44,    9,  412,   37,    1,    1, 1294,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  774, 3339, 1953,  220, 3359,  105,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  548, 1118,    1, 3378, 1268,  750,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1173,  176,  163,    1,   12,    1,  622, 2705,   32,  531,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2883, 2870,    1, 1054,    1,  187, 2372, 1173,   98,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3157,  774, 1926, 1927, 2290,  967,    1,  984,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428, 2924,  583,   32, 3349, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   32, 1645, 2611,    1, 1685,  105, 1385,   45, 1867,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1087,   12, 1250, 1294, 1803,   37, 1348,    1,  367,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,    1,   12, 2350,    1,    1,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1973,    1,  916,   37, 1012, 3305,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1605,    1, 2797,    9, 2977, 3012,  298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2596, 1665,  851, 2562,  810, 1048,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 2962, 3188,   27,  119,  187, 3244,  688,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2870,   32, 3383,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1126,  288,   37,  442,  424, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2028,   37,  619,    1,   45, 1714,  548,  105,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  534,  859,  667,   93,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1108, 2660,  183, 1643,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 3301,   12, 2220,   37,    1,    1,  384,  698,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   50,    1,    1,    1,  267,  352,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 1419,  453,  659,   45,  166, 1230,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2538, 1976,   32, 1778, 2580,  328,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3160, 2572,   32,  531, 3150,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  849,    1,  197,   28,    1,  734,   37,  686, 1194, 1843,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9, 3087,  686, 3001,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  242,   69,  102,   37,  243,  395,   12,  646,   93,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  297,    1,    1,    1,    1,   32, 1327,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1419, 2851, 1463, 2495,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1473,  528,  677,   69,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  193, 1573, 1675,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,   37,   47,    1,  152,   32, 1541,   37,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1458,    1, 1223,  785,  786,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  852,   37, 2346,    1, 1521,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2, 462,  37, 142,   9,  49,   7,  69,  50,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 455,  12,   1,   1,  37,   1, 957, 232, 716, 101,   1,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1076,  251,   37,  151,  671, 1078,    9,    1,  131,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3227,  631, 3247,  548,  786,  401,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  884,  411,  631,  297,  691,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810, 1444, 1079,    9, 1104,   61,   37,   77, 1515, 1056, 1030,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2785,   45,  365, 2911, 2825,   28,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3352,    1, 2890,  336,    1,  429,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32, 1537,    1,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1, 1147, 1414,  335,    7,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3263,  576, 3141,   81,   37,    1,  721,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 1427, 1515, 2181,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,  446,  162,   85,   37, 1604,   98,  601, 2113,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1178,    1,    1,  611,  949, 2488,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230,  546, 2565,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3232, 1747,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1818,  147,    1,  544,  193, 1140,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 657,   1, 191,  81,  37,  36, 997,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  61, 104, 358,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2800,  386,   12,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 2994,  729,    1,   98,  116, 2542,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   98,  645, 2308,    1, 2309,   61,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3267,    1,    1, 1758,    1, 1654,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1821,   95,  884,  105,  183,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,    1, 1902,  337,  877,    1,  444, 2839,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  624,    1, 2008, 1748,   45,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1143,  952,   37,   52,    1,  384,  105,  654,  149,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  284,  542,    1,   79,    1,  335, 3151,   12,  686,   32,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2695, 2223, 1183, 1593,  729,   32, 1343,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1430, 3345,  606, 1683, 1667,   32,  531,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1419, 2432,   37, 2324,    1,  116, 2542, 2762,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 2486, 2540, 3119,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676,    1,    1,   45, 3077,    9, 3185,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1166,   12, 1658,    5,    1,    1, 1079,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1723,   90,    1,   37,  138,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 2997, 1044,  166, 1285,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3403, 2414,   32, 2597,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,  744,  863,  528,  241, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116, 2995, 2993,  951,  829,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1106, 1118,  365, 2492,    1, 1626,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585,  640, 1853, 2789,  186,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1447, 2081,  716, 1398,  612, 1719, 3203,  143, 1724,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3355,  891, 1811,  404, 2699,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  449,    1,   32,    1,  287,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2967, 1401, 3152,  608, 3287,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3211,    1,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   46,  854,  220, 2018,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 3126,   45,    1, 2211, 1995,  940,   12, 2581,  327,\n",
      "         1935,   32,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 2685,  565,   98,    1,   45, 2825,    1,  187,  273,    1,   39,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1194, 1033,   91,  891,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141,   12,    1,  650,    1, 2347,  444,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3129,    1,   56,  440, 1283,   32,  472,    9, 1674,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  668, 1701, 1753,  104,    1,  219,  912, 2285,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1542,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,   12,  454,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1672, 1216,   37,    1,  331,  551,   12,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,    1, 2902,  125,  102,   98,  116,   19,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1973,  943,   45,    1, 2462,  105, 1298,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  252,   78, 1004, 2253,    1, 3037,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2124,   45, 1521,    1, 3002, 1552,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  501,  716,    1,  109,  524,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1943,  786, 2351,    1,    9,    1,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  355,   27, 1350,  132,  220,  342,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  811,    1,  112,   32,  395,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98, 2162,  361,    1,    1,  928,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  185, 1155,   98, 1282,   12,  682,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967,  105,  636, 1452, 1545,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3166,    1,  590,    1, 3119,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2765,  437, 1877,   37, 2856, 3365,  384,  104,    1,  215,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1343,    1,  105,  591,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   28, 3108,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  103,  318,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  935,   12, 2798, 2094, 2069,    1, 1387,  759,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  437,  952,   37,    1, 1029, 1799, 1559,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1550,    1,   98,  294, 2860,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3198,    1, 3253,   37,  759, 2936, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  250,  251,  252,    1,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 1172,   12, 1173,  115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3318,    1, 2740,    9,  166,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1110,  565,   32,  885, 1211,  245,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1359,    1,  929,  653,  985,   45, 1228,  669,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3375, 2884,    9, 3340, 1072, 1235,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,    1, 1000,    1,    1,  778,    1, 1864,  220, 2108,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1065,  199,  844,  469,    9,  545, 1035,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  788,   37, 1174,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1716, 2759,    1, 1499, 1228,   15,  554,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2637,  353, 1488,  763,   76,  932,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 1370,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826, 3204, 2421,  202, 3230, 3090, 1674, 2716,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2781,  176,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 2170,  726,    1,  497,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  420, 2787,  288,   37, 1421,  881,  220, 1497,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1,  877, 2942,   74,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   23,   61,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,    1, 1027, 1494,   28, 1139,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,   37,  943,  223, 2135,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1,  864,   37,  429,   46,    1,    1,   32, 2673, 2096,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1100, 2384,  340, 1251,  207,  412, 1671,   32,  854,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2217,   12,    1,  680,  454,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  590, 1815,  399, 2198,    1,   46,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1809,  105,  400,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2615, 2035,  105,    1, 1007,    1,  404,  631,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1559, 2897,  187, 2028, 2450, 2927,   37, 1050,    1,  492,  828,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3230,   37,  631,  163,    1,   12,    1,  444, 2062,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1001,   46,    1, 3269,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1312, 2512, 2227,  872,  361,    1,    1, 1776,  411,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1292, 2609,    1,  589,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  273,    1,  384, 1470,  187,  206,  852,  115,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181,  315,   37, 1706,   54,   32,  769,  191,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1340,  140,  119, 1909, 3212,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  439,  242,  187, 1128,   34,  185,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1539,  872,    1,    1,   12,    1,  105,  548, 2069,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   98, 2921,    1, 2700,    1,    1, 2990, 1199,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,  365, 2983,   51,  335, 1400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3280, 1042,   39, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1463,    9, 1941, 2843,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  102,    1,  530,  105,  106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,   12, 3364,    1,   37, 1237, 2701, 2158,   45, 2121,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1789,    1,  716,  119,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3015,    1, 2747,  105,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  813,    1,  986,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3348,    1,    1, 1645,    1, 1281,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1281,    9, 2333,  310,    1,  442,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,    1,  854,    9,  411, 1815,  336, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,    1,  647,  170, 1812,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  923,   32,    1,  220, 2693,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  681,  973,   37,  470, 1133,  961,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1, 1789, 1009,   12, 2024,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,    9,    1, 1718,  117,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  282, 2334,  162, 1998,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   77, 2941, 1625, 2793,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  167,   52,   53,    9,    1,  372,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3103,   37, 1435,    1, 2409,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2740,    1,  972,    1, 2977,  927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1527,    1,  304,   98,  651,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  355,  267, 2073, 1023,  197,  190, 1306,  837,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  418,   37,    1,  103, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  592,  646,   37, 1192,  118,  424,  356,    1,    1,  118, 1411,\n",
      "          356,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2956, 3017,  791, 1563,  884, 1601,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1200,    1,  199,  421, 1776,  172,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2249,    1,  167, 1154,    1,   12, 1674,  671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  325,    1,    9,   59,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  212,   37,  151,    1,   37, 1636,   32,  434,  280,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1940,    1,    9, 2069,   32, 1333,  665,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1713,    1,  669,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  544,    1,  877,  227,  550, 1173, 1628,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  971, 2472,    1,  271,    1, 2078,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,  331,  332,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2345, 3093,   32, 2862,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1203,    1,    1, 1871,   53,  220, 1180,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2984,  288,   37,    1, 2918,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715,  458,   17, 2372,   45,  116,  133,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,    1, 1631,    1,    1, 2770,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,    1,  216,  167,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2767, 2043,    9,  829, 2515, 2657,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,   37,  439,  581, 1119,  176,    1, 1022,    1, 2296,  250,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3123, 1958,    1,   74,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826, 2121,  202, 1574,    9, 1617,   12,  365,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2275, 1574,   10,   12,    1,   98,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2474, 1605,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2371, 1796, 1539,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3183,  103,    1,    1,  726, 1194,   73,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  727,  140,    1,  444, 2679,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  324,   51,   52,   32,  887,   46,  220,  326,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1034,   32,  231,  166, 1248,   37, 2123,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  198,  750,   50,    1,   20,   12,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3374, 1098, 2726,    1, 2596, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169, 2540, 3230,   32, 3329, 1990, 3293,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,  764,  384, 1354, 1975,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  698,   28, 1312,    1,   37, 2255,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2106, 2309,   66,  366, 3367,  741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426, 1408,  385,   15, 1470,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1, 1018,    1,    1,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  726, 2577,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2499,    1,  733,    1,  285,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  794, 1107, 2308,  220, 1234, 1876,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2916, 2672,  442,    1, 2922,   37, 1214, 3323,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,    1,    1,    1, 2713,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 2170,   12, 3405,    1,   28,  557,  540, 2024,   46,\n",
      "          220,   56,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2,  224,   51, 1046,  885,   43,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  854, 1249,  602,   32, 3116, 3217, 2498, 2701,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  721,  908,  131,  752,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2711,    1,   98, 2587,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1000,  105,  826,   37, 2518, 2295, 2302,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3303, 1360,  612,    1,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1097,   57,    1, 1290,  396,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1138,    1,  936,    1,  389,    6,  250,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1319, 1320,   61, 1221, 2330,  402,   37,  460,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  744,   37,  335,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 1028,   61,    1, 2948,   37, 2821,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   95,  473,  474,  475,  476,  477,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,    1,  140, 2161,   12,    1, 3282, 3077,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2994,    1,  820,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 2940,   39,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  300, 3186,  103,  187, 3176,  565, 2827,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98, 1658,  259,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2396, 1082,  388, 1647,   37, 1281, 1054,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1949,  315,    9,    1,  552,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,    1, 2304,    1,  202,  747, 2055,   37,    1,  453,  103,\n",
      "         2533,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  477,    1,  112,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  306, 1353,  777, 1085, 1896,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3209,  439,  547, 1090, 1044, 1045,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1542,   37,    1,  535, 1863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358, 1064,    1, 2459,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2476, 1882,   37,  124,  187,  818,  914, 2055,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2631,  688, 3323,    1, 2035,  726, 1045,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  299, 1648,   37,    1,  453,  248,  286,  290,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1899,   12, 1628,  550,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 1310,   37, 2432,   28,    1,  220,  942,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  702,  361,  169,  170,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  187,    1,  580,  163,    1,   12,    1,  622,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1200,    1,    1, 2153,   32,    1, 1492,    1,  474,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  275,   25,  176,  339,  845,  187,   69, 1042,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299, 2591,   37, 2035, 1281,   98,  116,  412,  962,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2524, 3002,  187, 2821,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2614,  563, 2615,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1072,   37, 1073,   85,  453,    1, 1074,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178,    1,  777,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1228,    1,  162,  611,  199,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947,    1,  580,  134,   32, 1939, 2162,   45, 3160,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  581,  767, 2745, 2939,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 2308,    1,  154,  190,  907,   37,  588, 1262,   37, 1154,\n",
      "          914,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2347, 2967, 1401, 1497,   37, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3340, 1485, 1683,   32, 2755, 2140,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  163,    1,   12,    1,  361, 2442,  439,  671, 3106,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1867, 2155,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  136,  494,  321,   77,    1,    9,  920,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 3029, 2328, 1539,   61, 1961,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  606,    1,   32, 1989, 1990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  441, 2243, 1243,   98, 1284, 1211, 1084,  716,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 2823, 2107, 1354,    1,   32, 2218,  506,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1289,    1, 2035, 2994,   93,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   81,   98, 1018, 1452,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1013, 1522, 1075, 2603, 1268,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  505,    1, 2565, 3202,   12, 3141, 2742,    1,    1,  191, 1957,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61,  460,  495,    1,   28,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1427,  637, 1617,  445,  110, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 3102,   12,    1,  513,    9,  247, 1204,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1794, 1178,    1,  187,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2373,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1166,   61,  166,  567,  707,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  615,  335,  105,  818,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  794,  596, 2359, 1222,   37, 1876, 1116,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3240,  162, 1090, 2836,    1,    1,  228,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2682,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1841, 1512,   32,    1, 3369,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  176,  177, 2844,  548,    1,   32, 2490,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 1234, 1863,  218,    1,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1028,    1,    1,    1,   12,  297,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  987,  384,  971,    9, 1144, 1710,   52, 1595,   12,  551,\n",
      "          552,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 384, 829,   1, 105, 449, 335,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 353,   1, 354,  98,   1, 428,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  547, 1428, 3365,  820,    1,  361, 2647,   32, 3360,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3111, 2844,   32, 3155, 1656, 2950,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1355, 1326,   12, 1736,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081, 1830,    9, 1422, 2823,  863,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,  765,    9, 2642,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  547, 2959,   45,  613,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  750,   30,   79,  453,  227,  175,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1, 1188,   37,    1, 2471,  220,  121,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   65,  996,   93,   98, 1171,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   12, 2371,  640,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2448,  386, 2800, 1218, 1831,    1,  297, 3177,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2117,    1,   51,    1, 1411,    1, 1395,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  864,  167,  498,   37, 1700,  339, 3107, 3366, 2836,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,  361,    1,  774,  244,    1,   32,  401,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   71,    1,    1,  197,  338,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  640,   10,   98,  954,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  550,  215, 2700, 2365,   39, 1766, 1767,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187, 2670,    1, 2671,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  420,  381,   37,  142,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  251, 1797, 2223,   37,  810,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1220,   98, 1645, 3365,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160, 1278, 1924,  526,   32,  367,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1244,    1,   98, 3144,   12,  627,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,  487,  232,  939, 1010,  287,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  384,  443,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321, 3280,   71,  384, 2890,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98,  938, 1075, 1104,  865,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1427, 2461, 1167, 2856,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1100,  353,  197,  297,  354,   32,  572,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  315,   74,    1, 1965, 2699, 1821,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  790,    1,    1,   98, 1763,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311,   37, 1158,  460,   12,   98,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  433,    1,  233,    1,  498,   98,  372,    5,  125,  469,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3389, 2856,   32,  403,  404,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2710,  437,  488,   37, 2856, 1485, 3365,    1,  744, 1757,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2190, 3053,   37,  741,  384, 2818,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,  878,   37, 1918,  297,  316,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1401,   32,  449,   56, 1477,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2087,  433,  476,  344,  625,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  936,  539,  458, 2053,  469,    1, 1961,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  475,    1,  380,  458,  786,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3252,  375,  967, 1959, 2067,  227, 1114,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  669,   56, 1413,  103, 2161,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   32, 1645, 2611,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1808,  794, 1159,  111, 1107,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,  759,    1, 3295,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,   48,   32,    1,  574,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1407, 1190, 2889,  384,  104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1488, 2995,  920,  166, 1509,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  861,  888,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  632, 2980,  300,    1, 2819,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,  476,  131, 2255,    1,  384, 1361,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2103,  617,    1,   37, 2099,  182,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 1515,  627,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1117,    1,    1,   37,  194,  776,  199,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1668, 2681,    1,  967,   38, 1857,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  355,   12,  117, 1561,  331,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1386,    1,    9, 2527,  164,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3204,   12, 2826,  439,    1,  411,  220, 1056,  390,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 2410, 1385,  427,  176,  395,   26,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1257, 1229,   37,  477,  132,   37, 1154,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3170,  167,   26,    1,   32, 2069, 1463, 1917,  691,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2238,    1,   37, 2979, 2639,  384, 2975,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1855,    1,  715, 2153, 2331,   45,  342,  501, 1125,    9,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  476,   37, 1847, 1232,    1,  190, 1343,  873,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1512,  297,    1, 3360, 2405,    9,  741, 2116,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2437,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2062,  650,  140,    1,  741,    9,  365, 2113,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  203,  326,  361,  166,  327, 1382,  166,  593,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 1665, 1965,  311, 2936, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1986,   61,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  619, 1542,   37, 2432,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2863,    1,    1,  331,  207,  174,   32,  572,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2591,  444,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1181, 1680, 1151, 1069, 1278,   54,   32,  365,  847,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496,  334, 1445,  193,  187, 2440,  187,  334, 2898,   98,  166,\n",
      "          116,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  132, 1284, 1415,    9, 3132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,    1, 2565,    1,    1,   37, 1594, 1425, 1771, 1688,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2275,  267,   10,    1, 1738,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  468, 1362,  251,  365, 1273,  861,    9, 2419,  361,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2875, 2640,   37,   52,    1,   98, 1352,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  312,  287, 2668, 1759,  309, 2325,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1973, 2308, 1876,    1,    1,    1, 2667,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  330,   37, 1279,    1, 1410,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1405,   12,  475,  172,  655,  939,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671,  566,  365, 1653,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  856,    9, 1300, 3017,  614,   98,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283,    1, 1173,   37, 2277,  220,  613,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  166, 1158,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  336,    1,  155,    1, 1816,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  854, 2018, 2024, 1625, 1946,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449,  963,   32, 3129, 2158,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,   96,  297,    1,    1,   37,  163,    1,   12,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 2306,   32, 1123,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  121,   37,  429,   49, 1611,  528,  104,  695,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  195,  344,  736,  571,   37,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1808,    1,   37, 1706,   32,  295,    1, 1109,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1,    1, 2359,  260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3130,   61,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  113,  530,  528,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1164, 1456, 1184,   32,  593, 1990,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2551,    1, 1110,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  108,   45,    1,    1,    1, 1232,  977,  193,    1,    9,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2965, 3230, 1177,  608, 3267,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  967, 1193,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  107,   51, 2303,   69,  636,  837,   32,   86,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2077,  353,    1,  131,  207,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2802, 2424, 2017,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  356, 1691,    1, 1976,   32, 1617,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  398, 2443,  384,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1327,    1,   28, 1891, 1876,   37, 1211,  531, 3365,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 1178,   12,    1, 2951, 1891,  535,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1626, 1013, 1522,    1, 1441, 2500, 1013,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   37,  388,    1,    1,    1, 1563,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  682,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3218, 3159,  166, 3219,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1360,  612,    1,    1, 1988,   45, 2930,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   32, 1242,  187, 3102,    1,    1,  344, 1585,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,  919,  996,  909,   98,  976,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,    1, 1579,  237,    1,    1, 1281,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2253,   37, 1860,  531,  863,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282,    1,    1, 1249, 1547,    1,    1,  176,  455,   26,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1024,  551, 1024, 1025,   32,   46,   37,  130, 1026,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  631,    1,   91,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   49,  580,  365,    5,  396, 2300,  302,  530,    1,   54,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  666, 2015,    1,  544,  193, 1982, 2102,  105, 2537,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3045, 1260, 2597,  947,    1,  129, 2681,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,  317, 1149, 2253,   37,  477, 1837,    1, 1897, 1104, 1882,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3209, 2277,   32, 2073,    1,    1,  688, 3231,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  732,    8,  529, 1251,  304,  187,  197,  407,   37,  331,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2137,    1,    1, 1296, 2646,  187,   46,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  164, 1333,   13,  267,    1,  190, 1334,   32,  942,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1711,   45,    1, 2816,  557,  540,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  585,   51,  606, 2963, 2977,   12, 2462,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  794, 2993, 2994,    1, 1013,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426, 1690,  525,   15,   28,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1,    1,    1,  529, 1018,  310,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  908, 1972,    1,   32, 1238,   69, 1482,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2275, 2877,   12,  335,   98,  531,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  443, 2189,    1,  267, 2266,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  346,  518, 1726,  736,  522,   98,   69,  187,  102,  120,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 1920,    1,   32, 1674, 2814,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   98,  756, 2325,    1,  227,  361, 1628,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1576,    1,  990,   12,    1,  400,  190,  221, 1836,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2160,   28,  857,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3152,   37,  442, 2967,   37, 1668,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101, 2548,    1, 2708, 3352, 2572,   32, 3339, 1388,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75, 1070, 1818,  147,   37,  804,   98,  858,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2885, 1745,    1,   85,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  571,   37,  163,    1, 2196,    1,  548,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,   37,  335,  331,   44,    9,  573,  399,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1486, 1241,   28,    1,   72,  401,  244,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 1802,    1,    1,   28,    9,  182, 1802,    1,  104, 1109,\n",
      "         1126,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3255,  691, 1993,   39, 2741,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1088,  225,    1,  831,   98, 3398,  949,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1542,   37,  168,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  225,    1,  133,  776,  891,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   30,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3120,    1, 3219,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  195,  749,   61, 2644,   79,  218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,   27, 2381,  339,  687,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3387,  744,   79, 2909, 1316, 2468,  176,  177,  583,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1915, 2873, 2401,  155, 2813,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3143, 1917, 1545,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2738, 2960, 2414, 2144,   32, 2597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,  392,  682,  548,   65, 1500,  347,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766,   37,  877, 1521,    1,  769,    9,  104,  700,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    9, 1744,  171, 1149,    1, 1018,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  629,  437,  387,   28,   37,  131,  104,  510, 1080,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,    1,  191,   48,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,  105, 2091, 1569,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2523,  361, 3325,   32,  411, 1995,   98,   91,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2190,   12,    1,    1, 1464,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  179,    1,  180, 1776,  170,  315,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387,  244,   71,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  282,  641, 2215,  551,    1, 2759,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861, 1906,    1, 3369, 1648,  191,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2177, 1016,  986,   79,    9,  593, 2101,  786, 2885,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,    1,  191, 1338,   45,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 2338,  187,  163,    1,   12,    1, 1588, 1155,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2380,    1,  572,  197,  738,  308,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  300, 1412,  112,  931,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2907,  515,  273,  593, 2522,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,   12,  112, 1161,  953,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3207, 1408, 3126,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1504,    1,  444,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1417,    1,  782,  453,    1,    1,  361,\n",
      "          105, 1292,    1,  415,   32,  199,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  447,  140, 1022, 3292,  671,  176, 2890, 2826,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   25,  374,  682,    1,  202, 2557,  261,   63,  104,  863,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,   71,  187,    1,    1, 1528, 2034,  504,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2899,    1, 1159,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,    1,    1, 2828,  565, 2827, 1114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3272, 3253,   32, 3295,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1652,  199,    9, 2355, 1718,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1925, 1583,  730,    1, 1708,  891,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 1405,  287,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  442,  220,  104,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2150,  338,   32,  537,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  268,  221, 2084, 1089,  361, 1090,    1,    1,  857,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  546,   81,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111,   15, 1253,   32, 1169,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  487,  947, 2263,    1, 3382, 3402,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  756,  757,   82,    1,  929,  939,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2798,  327, 1828,  198,   32,  572,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  928,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2981,   37, 1539, 1893,  220,  449, 2981,  279,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,  379,    1, 1918,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2708,  954,   32,  276,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2737,   12,    1,    1,  665,   98, 1616,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,  404, 2235, 1311,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136,  936,  391,    1,   45,    1,  704,  680,  136,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3369,  861,    1,  365,    1,  722,  639,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1084,  931,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 1635,    1,  700, 1010,  340,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  359,    1,  132,   61,   27,   98,    6,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  467,    1,    1,  104,  358,   82,  267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,   94, 2494,   61,  297,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  590, 2613,  865,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  384,  403, 2170,    1, 1632,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3221, 2689, 1717,    1, 1798,    9,  810,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  334,  254,    1, 1120,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1018,  945, 2174,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2357,  444,  715, 1511, 1237, 2674, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3035,  321,  612, 1910, 1451, 2398,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380,   61, 1648,   37,  319,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32, 2501,    1,  663,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868, 3369,    1,    1,  187, 3148,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,   18,  384, 2072,    9, 2017,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545,    1,   98,  845,  548, 1585,  384, 1178, 1179, 1831,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  449,    1,    1,  920,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  868,    1,  444, 1364, 1365,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  968,   37,  271, 2141,  195, 2351,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  315, 2355, 1013, 2549,    9,  282,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1786, 2358,    1,   37, 1776, 2501, 2502, 2678, 2928,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1010,    1,  297, 2160, 2628,    1,    1,    1,  582,    1,  187,\n",
      "         1292,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3327,   12,  484,  193, 1167,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,  551,  552,  779, 2628, 1021,   37, 1429,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2835, 1679,   56, 3348,    1,    1,  879,    1,   45,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2614,   51, 1000,   39,  892,   98, 3237,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3380,   12, 1815, 2389,    1, 3371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,  565, 1936, 1134,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  391, 1329, 2478,   28,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3139, 1464,   37, 2199,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2388,  171,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  519, 1022,  726,   45,  914, 2503, 3250,  750,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  112, 1906,  996,  496, 1514,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1629,   51, 1248,  388,  286,    1,   32,  233,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051,  200,  723, 2348,  259,    1,    1, 1605,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,   12,  721,   98,  776,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   21,   37,  698,  444, 2672,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  421,   12,    1,   30, 1167, 3247, 1532,  917, 2309,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1861, 1380,  861,  176,  985,   45, 1378,  863,  315,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796, 1250,   29,  817,   98,   25,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1405,  290,   96,   37,   15,  191,  508,   12, 1404,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,    1, 2264,  220,    1, 2043,    1, 1876,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1286,  155,  157,    1,  225,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,   98,  531, 1514,  443,    1, 1514,  913,    1, 1514,  199,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3361,    1,    1,    1,  176, 1527, 2664,   12, 2772,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,    1, 1146, 1703,  197,   71,    1,    1,  569,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2425, 1774,   39, 1994, 2026, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 1874, 1428, 2673,    1,   37,  865,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  667,  112, 1161,  338,   32, 1352,  202,  729,  227,  496,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,    1,    1,  269,  149,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1628,    9,   25,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  797,  469,    9,    1, 1899, 2372,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977,    1, 2334,  921,   32,  846,  361, 1116,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  884,  631,  187, 3169,  884,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  366, 2718,   81,    1,  675, 1499,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984,  927,    1, 2662,   12, 2918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 2596, 3043, 3381, 2440,  433,   32, 3155,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9, 1089, 1090, 1167,  884,  590, 3080,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3260,  688, 2642,   37,  726, 3235, 2941, 1569,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307, 2557,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2979, 2316,   15,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2028,    1, 1421,    1,  163,    1,   12,    1,  361,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2120,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1062,    1,  602,   12,    1,  471,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  845,  147,   37,  817,  912, 2285, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2015, 1810, 1109,    1, 1284,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  314, 1380, 1469,   32,    1,  574,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  720,  582, 2565,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1017,    9, 2826,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1, 1067, 2690,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1307,   12,    1,  267,  596, 1273,  259, 2264,  759,    1,  131,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  921,   39, 2232, 2320,  220,   29,    1, 2336,  769,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  968,    1,  439,   37,  968,   12, 1428, 2390, 2096,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325, 1736,    1, 1873,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  851,  298,   32,  395, 2414,  388,  763,  249,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  231,    1,    1,  818, 2749,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  398, 1052,    1,   45,  149,  297,  273, 1609,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1899,   12, 2048,    1,  384,    1,    1, 2059,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 1414,  288,    9, 1954, 1995,   98, 3391,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3254, 1401,    1, 3329,  191,  786, 2847,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3318,    1, 3326,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  922, 2701,    1,   28,   32, 3151,   12, 2245, 1215,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1829,    1,   32,    1,  531,  953,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1492,    1,  202, 3303,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1786, 2358,    1, 1360,  612, 1377,  148,  695,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3184, 2109,  663, 1900,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1605, 2537,   98, 3012,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2721,    1,   98,    1,    1, 1739,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1222, 2359,  140,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808, 1273,  256,  388,   17,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  384,    1,   37,    1,    1, 1093,  977,  504, 1737,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3241,  539, 1631,  917,   38,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1941,  359, 1054, 2046,  851,  548,    1, 1260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 2056,    1,  522,   37,  439,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2751, 1418, 2782,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3297, 1519,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147,    1, 2598,   37, 2646,   32, 2024,  142,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2561, 1025,  288,   37, 1910,  730, 2614,    9, 2685,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,   37,  119,  340,  444,   94,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204, 3090,    1,    1,    1, 3230,   98, 1978,  892,  176,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1647,   98,    1,   46, 1813, 1053,  361, 2573,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095, 2479,    1,    1,  150,    9,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2566,    1,   32,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  134,    9,    1,  157,  412,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1349, 1170,    1,  103,    1,   98,  210,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363, 2726,  142,   98, 1204,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,  530,    1,  687,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   33,  402,   12, 1862,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  510,    1,    1,    1, 1069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1479,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2737,   90,   45,    1,   37,  442, 3310,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2498,   45, 2721,    1,   39,  810,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1273,  618, 1018,    1, 1698,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  140,  131,    1,   24,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    9, 3398,    1,  166,  103, 2223,   61,  729,  187,    1,  187,\n",
      "         2085,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2712,   32,    1, 2823,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  758,  835,  885, 1117, 1525,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3259,  726, 1194,   73,  297, 2463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,   91,    6,    1,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3181,  300, 3306,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3095,  114, 1461,  176, 3339, 2649, 2791,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  326, 2182,  798,   37,  881,   45, 2232,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523,    1,    9,  593, 3154, 3023,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3362,  267,  204, 1370,   45, 2389,   37, 3349,   12,  533,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006,  429, 2646, 3346, 2950,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  848, 2371, 1908,    1,  361,  847,   98,  449,   74,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  538,  786, 1566,  865,   37,  705,    1, 1417,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2971, 2690,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3003, 1536,  365,  912,  605, 2039,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1101, 2817,   23, 1797, 1746,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  387, 1884, 1429,   32,  208,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2950, 1965, 1539,   45, 2179, 1708,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  986,    1,  182,    9,    1,   50,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3104, 2417,  163,    1,   12,    1,    1,   45, 1029, 2282,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260, 1747, 3330,    1, 3299,   37,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2147,   32,    1,   34,  861,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  552,  552,  815,  641,  187, 2547,  865,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2569, 1231,   32, 1817,    1,  220,   11,  564,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  108,   98,  197,    1,  159,  720,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   12,    1,    1,   32,   37, 1171,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   42,    1,  149,  220, 2163,    1,  391,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3345,  774, 1444,  606, 2572, 1485, 3102,  844,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1063,   37, 1048,  596,  929,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 1030,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  366,    1,  276,   32,  367,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   91,    1,  148,  647,  474,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800,    1, 1667,   12,  416,  460,   32,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  942, 2800, 1292,  307, 2460,    1, 1581,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1739,    1,  392,  983,  308,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3079,  759,  132,  220,  449, 1385,  712,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2427,    1,  187, 3046,  868,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,  515,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  900,   46,    1,  187,  797,  574, 1830,   37,  912,    9,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  147, 1392,    1, 1393,   15,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  387,  183,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1702,    9, 2024,   32, 1811,  404,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2692,  991,  119,   59,   32,  449,   74,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2419,   15, 1348,   37,  720,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2395,  361,    1, 2813,    1,   37,  877,  885, 1385,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2341,  104,    1,   32, 2069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,  421, 1356,  977,    9,  755, 1780,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,   45,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1203,    1, 1871,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2386, 1771,  171,   45,  903,    1, 1417,    1,  105,    1,\n",
      "          105,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2580, 2851,    1,    1,    1,    1, 2537,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  388, 1350,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187,  542,  240, 3327,    1, 3239,  245, 1114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  193,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,   45, 2027,  202,  193,   39,   45, 2589,    9, 2321,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  422,  520,    1,  261,   98,  494,  138,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1936,    1,    1,   51,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3276,  688, 1497,    1, 2035, 1045,   37,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,    1,  191,  792, 1575,   45, 1090,  792,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,  166,  645,  550,    1, 2111,    1,  424,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310,   25,   71,    9,  601,   74,   32,  104,  605,  848, 1784,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  503,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  229,   32, 1020,   56,  356, 1281,    9,    1,    1,    1,    1,\n",
      "            1,  815,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,  213,   37,  332, 3044, 2232, 1847,  203,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  959,  105,   59, 1128, 2871, 1129,   37,   52,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,  361, 1181,   37,  332,    1, 1017, 2351,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,    1,  716,  354,   45,  105,    1,  331,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  342, 1082,  792,  241,  698,  792,   98,  104,  442,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1013,    1,  361,  166,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2367,  328,    9, 1778, 2580, 1108, 1779,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3188, 1542,   37, 1046, 3250,    1,  750,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,    1,  224,  220, 1273, 1013, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  186,   45,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3141,   12,  522,    1,  474,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3317, 1554, 2760,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1258,  220,  409, 2022,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1721, 1937,  388,  163,    1,   12,    1,  676,    1,  115,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,    1, 1252,  275,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  912,  388, 2194, 2039,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  102,    9,  754,  327, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868, 1484,   79, 2890, 2237,  548, 2357,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3311,  884,   98,  166, 2177, 1574,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  387, 1332,    1,  163,    1,   12,    1,   15,   28,\n",
      "            1,  419,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  150, 1052,  572,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,    1, 1898,  105,   59,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,  187, 3300, 2497, 3263,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2119,   63,  204,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1672,    1,   56,  331,  551,   12,  482,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647, 1707,  148,   12, 1509,  693,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  108,   45, 2357,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  313,   37,  582,   79, 1294,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  236,  237,    1,  972,   37,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141,  638,    1, 2437,  548,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,   79,  453,    1,   63,   94,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  957, 1654, 2095, 1377,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  422,   51, 1753,  523,  297, 2122, 1419,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447, 3397, 1931,   10, 1563,  190, 1031, 1603,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  456,    1,   85,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2170,   12,  533,  877,  460,    1,    9, 1730, 1861,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,  147,  597,    1, 3289, 3139,  321,   52,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  295,    1,   28, 1168,   29,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1087,   61,  593,   12,  103, 1151,  607,    1,  506,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3246,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1353,  210,   98, 1039, 2690,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1915,    8,   98,  166, 1030,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  455,   12, 2801,  200,  517,  618,  220,  705, 1620,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2882, 1920,  884,  199,  776,   32,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1459, 1579,  259,  700,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  729,  103, 2309,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,   81,  530,  528, 1785,  543,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  716, 3359, 1579,  403, 3339,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  967,    1,  166, 1675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1774, 1159,    1,  671, 3126, 1090,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3134, 1698,   45, 2586,    1,  104, 2161,  726, 1913,   73,  671,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189, 1243,    1, 2758,    6,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2991,  794,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  945,   51, 1046,    1,  149,   32, 1053,  147,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3096, 3009,  190,   52,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,  730,  321,  612, 1864,  166,  389,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3014,  251, 2079,   37, 1718, 1659,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  200, 1254,    1, 1354,    1,    1,  517, 2085,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  439,   28,  187,   69,  640,  119,  297,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,    1,   32,  430,    9, 2024,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  273, 1609, 1203,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  202,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  590, 1143, 1881,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3385,   51,  606,   37,  792,    1,  792,  864,    9,  388,\n",
      "         2532,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1024,   37, 2615,  967,  105, 1204,   45,  453,  248,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   79,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1822,  123,    1,   32, 1649,  625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3321,    1,    1,  202,  729,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1018, 3343, 1920,   12,    1,  431,  453,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  952,   37,    1, 2471,  220,    1,  507,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  620,  661,  696,    1, 1316,  166, 2041,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2819,    1, 2819,    1, 2819,    1, 2819,    1,    1,    1,    1,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3068,    9,    1,  327,  884,   37,  166,   22,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   34,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  387,   31,  530,  837,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3189,    1,    1,  321,  612,  764,  202,    1, 1515,    1,  403,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3021,  765, 1159,  590,    1,  389,  548, 3244,  949,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,    1, 3102, 1919,  191, 3125,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  645, 2993, 1419, 2324,  861, 2558,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2695, 2223,   61,  786,  803,   84, 2017,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3321,    1,    9,  914,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,  968,  967,  590, 2673,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3358,   12,    1,  595, 1924, 1167,  204, 1745,    1,   37, 1584,\n",
      "          168,   45,  166,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0],\n",
      "        [   2, 1933,   61,  645,  793,   37,  912,    9, 1942,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1712,    1,   32, 2670,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1079,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1412, 2913,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3115,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,   48,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12, 1718,  117,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  968, 2357,   37,    1,  297, 2689,    1, 1995,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2877, 1479,    1, 1572,   37,    1, 2705,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  709, 2800,  638,    1,    1,  928,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1996,  365, 2549,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,  572,  354,    1,   34,  157,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 1068,  568,   71,    1,   32,  367,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3190,    1, 1246,  614,  323,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,    1,   37,  168,  115,  220, 2271,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  219,    1, 1259,    1,   85,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228,  321,  877, 1658,   74, 3000,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1808,  437,   37, 1539,  104,  111, 1107, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  104, 1654,   37,  208,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2618,   12,    1,  113,  700,   37,  726,    1, 1684,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1454,  531,  443,  528,  420, 2669,  590,    1, 2108,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3117,  606,    1,    1,    1,    1,    9,    1, 1844,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3393,    1,    1,   32, 2835, 1450,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 104,   1, 460,  32,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2, 104, 358,   1, 359, 474,   1,  46,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 242,  69, 102,   1,   1,   1,  37, 157,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  294,    1, 1000,  105,  410,    1,   32,  942,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1659,   37, 2653, 2212,    8,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1308, 1957,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2440, 2585,    9, 3323,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1861, 1464,   37,    1,  247, 1940,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1985, 2572,  191,  531, 1656, 2596,  187, 1147,  104, 1414,    1,\n",
      "          115,  220,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,    1,  220,  854,    1,    1, 2406,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,   67,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1902,    1, 2226,    1,    1,  334,    1,    1,  204,  515,   32,\n",
      "           37, 2834,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  156, 2393, 1790,  198,  528,  720,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  447, 1953,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2177, 1825,   37,    1, 1159, 1729,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  463, 1447,    1,  455,  444,  909,   98,  403, 1447,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  147,  261, 1167, 3207,   61,  671, 3126,  855,   32, 3208,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,    1, 3107,   32,    1,   45, 1428,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547, 1855, 3365, 2572,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  284, 2572,    1,    1, 2249,  361,    1, 1530,   32, 3349, 2038,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2183,    1, 2253,   37,  319, 3101, 1583,   32,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  793,  921,  308,   98,    1,  682,    1,  387,  354,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  632,  379, 1231,  220,    1,   32, 3070,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2772, 1013,  947,  877, 2263,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  794,  365, 1013, 1522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,   98,  754,    1,  548, 1343,   79,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   46, 1174,   32,    1,   98, 2299,   32, 3369,   12, 3118, 2517,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  941, 1467,    9,    1,  938,   12,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1044,  128,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1682,  875,  133,  134,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  288,    9,  120,   32, 1656,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  872,    1, 2065,    9, 1892,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233, 2104, 2591,   37,  791,  844,    1,   37,  230, 1900,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2752, 1557, 1484,    9, 1302,   37,  439, 2782,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   81,  187, 3097,   12, 1831,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,   37,   47,  131,   32,  356, 2415,   98,  906,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3025,   12, 2068,  267,  947,    1,  754,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  891, 1069,   45,    1,    1, 2403,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 2962,    1, 1408,  166, 3228,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  928,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,    1,  289, 2344,  384, 1033,   37,   91,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3058,  792,    1,  792,  193,    1,  924,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1396,    1,  249,    9,  777, 1704,  844,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  626,    1,    1,  102,  583,  163,    1,   12,    1,  244,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826,    1, 1249, 2942,  187,  163,    1,   12,    1, 2590,  671,\n",
      "          910,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2565,    1,    1, 1558,  548,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779,    1, 3064,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  245,   37,  187,  531,   69,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2154,    1,   37, 2709, 3024,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  476,  105, 1345,  916,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2456,  777,    1, 1396,  111, 2502,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1206,    1,   37, 1753,    1,  297,    1,  396,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  313,   37,    1,   17,  187,    1,   16, 1268,  918,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2206,    1, 2757, 2694,  613,    9,  810,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1204,   32, 2890,  384,    1,  600,  492,    1,   37,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1070,  249,   37,    1, 2820, 2481,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  119,    9, 1973,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,   28,    1, 1699,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1210,  105, 1615,    1, 1488,  179,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  125,   85, 1778, 2580,  820,   32,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1725, 1822, 2056, 1171, 1416,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  691,   32, 2300,  674,  297,  438,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  864,  894,    1,  220, 3385,  191, 1332,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  590, 1031,   37, 1184,  347,   66,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3302, 1413,  856,  444, 1863,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1307, 2980,    1,   85,  618,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  267, 2924, 2856,  547, 3339, 3006,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  972,   37,  619,  902, 1217,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1,  395,  606,    1,    1,  651,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  332, 3116, 2579, 3275,  631,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2946,    1,    1, 1976,   32,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  907, 1088,    1, 2178, 2153,  600, 3348,  555,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,    1,    1,  104,    1,    9,  365, 3397,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2700,  588, 1488,  454,   37,    1, 2620,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  346,   93, 1071,  699,   32,  581,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  458,   45, 2741, 1554,   67,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1579,  105,  803,  413,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1545,  512, 3213, 1800,  311,  345,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302, 1712,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2103,  617, 2010,    1,  612, 1133, 2398,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3190,  361, 2748,    1,  449, 3278,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2851,  105, 1822,    9, 2580, 2264, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2742,  361, 2059,    1,    1, 2538,   32,  786,  187, 1749,   32,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  963,  446,    1, 1994,   10, 1234,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  361, 2275,  168,  582,   37,  582,   98, 2948,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147, 1009,  952, 3069,  764,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3092, 1360,  612,   44,  896,    1,    9,    1,   32, 1545,  386,\n",
      "         1090,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 2596,    1,    1, 1426,  447,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1824, 3116,  922,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  715, 2153, 1911,  183,  390,   32,    1, 1463,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2551,  321,  612, 1343,  220,  183, 1305, 1724,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  209,  112,  919, 1451,    1,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584,   12,  645,  354,   51,  576, 3301,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  191,  889, 2539,    1,  680,  861,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  365,  822, 2240,    9,  105,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151, 1341,   12, 1204,    1,    9,    1,  372,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,  296, 1250, 1960,    1,  131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3356,   90, 3357,   37, 1594,  297, 3346,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3381,  437,  267, 2414,  163,    1,   12,    1, 3102,   32,  531,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3359, 2024,    1,   98, 3375,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3342,   37, 1046, 1574,  297,    1, 3058, 2282,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1652,  794, 2355, 1718,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1629,    1,  926,   32,  286,  442,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  548,  537,   45, 1523,    1,  284,    1,    1,  777, 2165,  565,\n",
      "          707,  111,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700, 1000,    1,    1, 1204,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  884, 2267,    1,   98,    1, 1402,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3364, 1877,  590, 2338,  384, 2649, 1220,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1, 1285, 2029, 2024,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  156,  720,   98,  878,  477,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1, 1161,  953,  981,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  592,  536,    1,   93,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3173,  683,    1, 3174,  759,  395,   26, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2355, 1013,  384,  755,    1,  224, 1130,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  366,    1, 2519, 1218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  293, 1360,  612,  856,    1,  261,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  619,   39,  166,  741,   32,  584,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1560,  696,  104, 1272, 2454, 2523, 3325, 1654,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2998,  140,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1539,    9,  730, 1571,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  411, 2160,   28, 1140,    9, 3089,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294, 1456,  197,  418,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3151,  474,   37, 1195,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,  449,  726,  297,    1,    9, 2565,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1106, 1519, 1013,  220,    1,    1, 1028,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3147,    1, 1428, 1414,   32,    1, 3114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3101,    1,   51,  619, 1038,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1417,    1,    1,  466,  275,  224, 2355, 1013,  105,    1,\n",
      "         1160,    1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,  859,  182,   37,  208,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3279,   27,  531,   12, 2646, 2856,  249, 1386,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  696,  104,    1,   79, 2379,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3231,    1, 1110,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1003,   37,   16, 2789,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1486,   34,    1,   48,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1934,   37,    1, 3093,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715,   25,  276,    1, 1445,    1,    1, 1224,  720,  191,  137,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  405,    1,  729,    1,    9, 1110,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  376,  636, 2320,    1, 2101,   45,  159,    1,    9,  453,\n",
      "         1126,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 2957,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  329,  475, 2001,   98,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2822,   32, 1056,  356,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,    1,  104,  379,  907,   98,  164,  165,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1433,  166,  867,  321,    1,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3356, 3357,  729,    1,  531, 3346, 1142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1504, 1658,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115,  631, 3200,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  960,  200,  111,   33,   32, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  581,  294, 3102, 2772,    1,  187,   10,  146,    9,  764,   32,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  961,  398, 1707,    5,    1, 1991,  191, 2376, 2525,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,  379,    1,  112,    1,   98,    1,   45,  104,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094, 1086, 3038, 3339, 2731,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,   37,  168,  220, 2723, 2724, 1411,    1, 1935,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1109,    1,  325, 1273,   48,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3147,    8, 3148,  304,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1423,  113, 1468,  447,   32, 3275,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613, 1614, 1615,  259,  220, 1616,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1008,   37,  168, 1159, 1821,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  989, 1454, 1277,  132, 1010, 1379,  122,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  487, 3160,   61, 1231,  220,    1, 1147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1031,   61,  227,  187, 2523, 2850,   74,   12, 1509, 2277,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,    1,  187,    1, 1807,    1,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123, 1822, 1805,   28,  453,  100,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  460,  167, 1237,  455,  191,  465,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2279, 1454,  119,   32,  356,  439,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1602, 2539, 2800,   37,  815,   22,  211,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 1882,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 1997,    1,   32, 2142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  497,    1,  612, 2047,  486,  592,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1191, 1380,  105,    1, 1046,   98,    1, 1397,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3028, 2995,    1,  820,  191,  755,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3125,    1,  183,    1,   37,  764, 3025, 2816,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066,  884, 2800,  668,  808,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   69,    1,   27,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2036,    1, 3043,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37,    1,    9,    1,    1,    1, 1684,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2107,    1,   98, 1001,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2890, 2826, 2250,  119,  844,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2741,  361,  854,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  558,  315,   37,  151, 1697, 2606,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2149, 1173,  176, 1477, 1990,   12,    7, 2538,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2859, 3142,  167, 1154,  593,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1346,   32,  531,  166, 2673,    1,    1,  166,  593,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  557,  540, 2292,  447,  190,  100,    1,    9,  230,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56,  802, 1936,   79,   32,    1, 1126,   74,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  810,  112,   98,    1,   79, 1434,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3242,  590, 1178, 1179,    1, 1545,    1,   32, 3273,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1932,   37,  125,  541,   37, 1124,  244,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481,  140, 1445,  863,  187,  691,  446,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  228, 2572,  361,  547, 2249,  187, 3339,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159,  554,   98,  505,  195,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1744, 1079, 1232,  657,  302,  190,    1, 1260,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 1333, 1530,   32,    1,  187,    1, 1086,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3213,  997,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,  778,   45,  105, 1247, 2518,   32,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1497,  477,    1,    1,   32, 3155,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  321,  322,   79, 2713,  195, 1001,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2474, 2864,  453,  449,  356,   32, 1821,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  640,  339,  687,  951,    1,   94,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  497,  813, 1994,  926,   74,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  200,  365,    1,  361,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1386,  272,   98,    1,    9, 2924,  125,   32, 1256,  551, 2196,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   22,   95,  473, 1542,    9,  477,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3262, 1139,   45,    1,    9, 1460,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2880,   45,    1,    1,  176,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1625,   37,  504,    1, 1153,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2002,    1,  928, 1897, 1537, 1218,  427,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  744, 1251,  125,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   96, 2152, 1159,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2605,    1,  829,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1934, 1679, 1711,  384,  611,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1370,  199, 2548,    1, 2347,  202,  193, 1724,  754,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   79,  384,  119, 1653,   98,  430, 1259,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3343, 1002, 1512,    1,  187, 3363, 1443,   81,   79,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2576,  537,   45, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  342,  497,   37, 2192,  864, 2069,  916,   98, 2390, 1816,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  922, 2246,  449, 1023,   37, 1247, 1090,   37,  950,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,  61,  81,   9, 105,   1,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 829,  46, 861,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1, 3361, 1523,    1,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1024,    1,    9, 2615,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  733,  960,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 1387,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  166,  749,  400,    9,  885,  195,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978, 3138, 2651, 2764,  539,  366,  105,   12,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1408,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  609,   37, 1642,  257,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  574,    1,   32,    1,    1,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3345,  774, 2572, 1485, 3102,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  474,  759, 1845,    1, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1721,    1,  176, 2075,   32, 1151,   25,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  307,  125,  176,  104,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162, 2507,  726,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1726, 1947, 2271,  574,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424,  786,  967, 1292,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  378,   37, 1561,   28, 1720, 1191, 2264,    1,  608,    1, 1160,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2569,  622, 2414, 3357,  650,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 1169,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  730, 2918, 1897, 2300, 3048, 2923,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1178,   12,  844,    1,  853, 1746, 1294,    1,   75,    1, 1821,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2792, 3164, 3277,    1,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1218,    1,   98,  166,  260,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,  957,    6,   48,   32,   22,  447,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,   27,  187,  531, 2292,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  794,    1, 2969, 1766, 1767,    1,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  779, 3044, 2168,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,    1,    1,    9, 3173,  683,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2858, 1028, 3272,  551,  388,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3248, 1914, 1680,   48,   32, 3096,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  132,    7,   37, 2410,  626, 2054,   37, 1407, 1429,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,  446,   12, 1994,    1,    1,    1,  187,  310,  741,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  459, 2226, 2969,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783,  460, 1901,    1, 1228, 2323,  176,  215,  639,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1,  983,   93,   66,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,   32, 2138,    1, 2107,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,   81, 3018,  315,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  989,  475,    1,    1,   12,  469,   37,    1, 1277,  887,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3046,    1,  191,    1, 1675,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 1940,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,  782,  219, 2527, 2946, 1046,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  325,  849,   32, 1146,  332,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2710,    1,  193, 1018, 1816,   32, 1081,  741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,  672,  453,  259,  102,    1, 1307,  155,  453,  157,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  645,    1, 3005,    1,  818, 1117, 1525,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3310, 2386,    1,   45,    1,   98, 1404,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2004,    1,    1,  376,  570,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1794,    1,   98, 2931,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3058,  776,  891,    9, 1791, 2282,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  439,   45,    1, 1215,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2565,    1,  580,    1, 1034,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1900, 1604,   98,    1,    1,   37, 2446,  585,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428,  580,  365, 1355,   37, 2024,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3344, 3357,  155, 1057,    9, 3396,    1,   37, 3118,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  449,  221,  220,  166, 2685,   61,   37, 1805,  433,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1,    1,  674, 1107,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  633, 1564, 2024,   32, 2862,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299, 1680, 1661,  182, 2180, 1291,  191,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,    1, 1922, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3209,  799,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   89,    1, 1110,    1, 3319,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 3141, 1292,    1,    1, 2356,   45,    1,  966,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  439,  242,   69, 2109,  682,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2388,  634,   37,    1,    1,    1,    1,  506,   30,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3103, 1605,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  501, 2042,  140, 2376, 2024, 2223,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1023, 1204,  288,    9,  465, 1169,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  457, 1821, 2728, 1478,    1,    1,  431, 2223,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,   37,    1,  297, 2673, 1806,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1476,  977,    1, 1133,  705,  401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1333, 1530,  191,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  179,   37,  151,  180,   32,  131,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  366,    1,    1, 1290,  396, 1269,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2028,  884,  671, 3126,   32, 1123,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  574, 1900,   37,  138,   59,   37,  439,  290,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  940,  647,   26,   37, 1018,  148,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,   42, 1054,  663,  149,    1,  116,  823,  220,\n",
      "           12,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584, 1177,  672,  105, 1849,  996, 1438,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1604, 2191,  334, 1445,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   45,  443,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  927, 1159,    1,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  515,  957,  412,   37,  756, 2690,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1366, 2233,    1,  691, 1867,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 2577, 1495,    9, 1746,   45, 3015,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1449,    1,    1, 2000,  214,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437,  952,    1,    1,    1, 2706,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1658, 1778,  327,    1, 1370,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2448,  386, 1564,  581,  142,    9,    1, 3177,    1, 3187,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  718, 3224, 1333,   32,    1,   98, 2579,  336,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3339, 3352, 2833, 2696,   12,  756,   32, 1313,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   28,    1,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1527,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 1933,  159,   28,   98,  170,  943,    1,  202, 1721, 1820,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115,    1,  191,    1, 2446,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1861,  199,    9,    1,   98, 2170,   61,  297,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3298,  140,  449, 2760,  176, 2620,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1245,  548,  686,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3108, 2935,   72,   73, 1131, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 1708, 2606,  884,  105,    1,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2572,   32,    1, 2456,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  476, 1094,   37,    1,    1,   98, 2024,  226,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  531,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1625, 1218,  321,  335,    1,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1442,   37, 2929,    1,  150,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   26,  417,  395,   67,  423,  246,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3298,    1,  515, 3196, 1383, 2027,  176,  365,  649,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,  108,   45,    1,    9,  645,    1, 2558,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232,  759,   72,    1,   32,  228,  537,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1151,   15,  686,    1,   54,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,    1, 2024,   32, 3388,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  223, 2420, 1275,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  865,   37,    1, 1960, 1183,  713,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  848, 2914,  365, 1151,    9,  388,  311,  361,    1,  845,    1,\n",
      "         1089,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 3042,  161,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2, 189, 108,  45, 143,  15,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 105, 468,   1,  37,  52,  81,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  501,    1,    1,  951,    1, 3209,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1118,  484,   37, 1119, 1021,  408, 1120,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3101,  598,  548,    1,   85, 3065,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885,  726,    9,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2252, 2657,   32,    1,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  547, 2476,  332, 2376,    1, 2223,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    6, 1126,  636, 2320,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   65,   76,   37, 2654, 1524,  401,  402,   67,  423,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128, 1586,    1,    9,   72,  104,  250,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  382,  286,  125, 1658,  408,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  653,   81,   37,  147,  297, 1652,  399,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1645, 2789,   12,    1,   37,  342, 3037,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1926, 1927, 1928, 1082,   69, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3348, 3382,    1,   98,  776, 1114,   32, 1081,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460, 1132,  729,    1,    9, 2759,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1644, 1301, 2977,  172, 1294,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37, 1012, 1060,  388,   32,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1043, 1738,  418,  786,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,  404,   39,   45,    1,   12,  922,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2868,  891, 2237,   37, 3388,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1090,   12,  590,    1,    1,  202,  460,   12,  416,  105,\n",
      "         2692,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,  859,   37, 1403,    1,   85,   37,    1,  636,  402,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  120,   37,  331, 3295,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  463,    1,   28,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   39,  220, 3265, 1987,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  821,  230,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  163,    1,   12,    1, 2548, 2572,   32,  531, 1450,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,    1, 1656,   61,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118, 2751,    1,    1,   45,  241, 2292,    1,  469,   37, 1418,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   91,  361,  104, 1388,  297,  864,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  558,  835, 1056,  487, 1697,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,  197, 1660,  157,  921, 1944,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3084,   61,   76,   37, 1540,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035,  716,   37, 1038,   32,  717,    1, 1741,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2477,  944,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  398, 2008,  704,    1, 2226,    1, 1178,  384,    1, 2819,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 2767, 2105,    1,  535, 1153,  280,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1861, 1118,  869,  221, 2191,  548, 1002,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,    1,  488, 1539, 2462,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1095, 2418,   28,    1,    1,  150,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2094,  519,  284, 1925,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  160, 1278,  831,  995,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,  315,  395, 1273, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3141,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233, 1118,    1,    5,  625,  788,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3167, 2110,    1, 1022,    1, 2296,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363,  162,  449, 1526,   45,  645,   40,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,    1,  473,   32, 1845,  895,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 2170,    1,    1, 2158, 3158,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1773, 1680, 2510, 1828,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   79,   98, 3207, 3126, 2096,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 3022,    1,  187,  596,  506,  782,  786,   72,   45,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  182,  302,    9, 2890, 1675,   51, 1473,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  199,   37,  838, 1658, 1497,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  801,  187,  159,  698,  605,   32,  409,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1796,  624,    1,  616, 2071, 1074,  259,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  365, 2670,    1,  105, 2854,    1, 2854,  593,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1181,   30,    1, 2382,  259,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3204,  744, 2364,   98,    1, 2442, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,  325,  492,    1,  778,    9,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1, 1363,    1,   98, 1273, 2255,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671,   32,  105, 1101,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1178,  514,   32,  400,   45, 2095, 2471,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676,    1,  565, 2317,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  947,    1,    1, 1656,   37, 1911,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  428,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1079, 2802,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1398,  612, 1406,    1,  460, 2233,   52, 1824,   98,  844,    1,\n",
      "          267,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   10, 1484,    9,    1,  864, 2390,  396,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   34,  197,    1,  315,  388,  124,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  647, 1774,   39,  112, 2515,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   29,    1,  389,  218,  471, 1044,  128,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1778, 1450,    1,    1,    1,  725,    1,   55,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  761,  782,  985, 1260,  629,  220, 1646,    1,  315,   37, 1348,\n",
      "           37,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1147,  232, 1061,    9, 1610, 2471,   37, 1730,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1523,    1,   98,  166, 1412, 1107, 1030,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  758, 2035,   24,    9,  777,  378,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1343,  528,    1, 1857,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035, 2301,    1,  967,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096, 3116,  922,    1, 3181,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  709, 3060,   32,    1,  446, 2772, 2919,  928,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2473,    1,  591,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3174, 1249, 2347, 3178,    1, 1765,  449,  632, 1920,   37,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1672, 2771,  176,   48,   32, 2388,    1, 1090,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 112,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 326, 361, 657,  37,  26, 412,  37,   1,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  487,    1,  588,   37,  439, 2114, 2884, 1281,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  786,  915,    1,   37,  168,   63, 1444, 2872,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3297,    1,    1, 1675,  190,   52,    1,  187,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187,    1, 1512,    1,    1,  320,  544,  122,    9, 2517,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1613,  200,    1,  612,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647, 2407,  342,  432,   45,  148,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  344, 2596, 2414,  176, 2681, 2363,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1479,  671,  112,  214,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  299,    1, 2372,   45, 2834,   32,  121,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  366,    1,    1, 1290,  396, 1269,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  442,  448,  953,  417,   32,  871,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1427,   79,    1, 1401, 3271,  608, 3231,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  339,  891,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1936,  297, 1178,  163,    1,  742,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1584,   12, 1343, 1093,  574,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2737, 2770, 3118,   37, 1814, 1512,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1235,  102, 2084,  504,  452,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  991,  454,    9,  517, 2285,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,  777,  778, 2008, 2311,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  268,  353,  183,  354,    1,    1,  939,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  291, 2767,  792,    1,  792, 2232,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1, 1376,  220,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1128,  765, 1698,  128,  115,   32,  160,  623,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2576,  551,    1,  267,  449, 1023,  156, 1556,  187,  445,  187,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  573,  639, 1587,   45,  527,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964, 1082,  864,   37,    1,   37, 3385, 1004,  191,   88,    1,\n",
      "         2283,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3169, 3090,    1, 3253, 1774,  608,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213,   65,   28,  220,  245,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1186,  476, 2763,  220, 3345,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1661,  704,  222,  580,  133,   44,  297, 1405,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3241,    1,   81,   98, 2347, 1638,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1451,    1,  353,  242,  572,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3012,  176, 1795, 2279,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,  794, 1273, 1089, 2403,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  968, 2417,    1,    1,    1,   12,  915,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 3194, 3195,    1, 3305,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  350,    1, 1174,   32,  557,  540,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066, 1631,    1,  187, 2741,  921, 2846,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2016, 2753,  166, 3251,    1, 2757, 1301,  258,  142,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1827,    1,  388,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,   12, 1481,    1,  996,  119,   32, 1452,  863,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  681,  606,    1,   39,   32,   91, 2552,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1131,   61,  959,   32, 3132,  637,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178,    1,   37, 1096,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2268, 2214,    1, 1046,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3324, 1639,  384, 2804,   45,  810, 1593,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1435,    1,   82,  292, 1228,  226, 1499,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,  719,  388,    1,  172, 1294,  458,   45,  942,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3151, 2352,  474,    1,    9,   46,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2047, 1044,  858,  663,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1643,  794,  861, 1108,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 2962,    1, 1164,  764, 3263,  439, 1044, 1826,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  632,    1,  221,   37, 1947, 1839, 3037,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2752, 1583,  300,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2425,   37,  130, 1883,    9,    1,  182, 1160,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3226,    1,   39, 1700, 2119,  220, 1987,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1077, 1417,   59,    9,    1, 2049,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,  267, 2510, 1675,   37,  714,   32,  455,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  700,  837,   45, 3038, 2596, 1585,   32, 3376,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3218,    1, 2317,  191, 3141,    9,  547, 1675,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1361,   37, 2035, 2381, 2639,    1, 1085,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181, 1908,  220, 1545,    1,  787, 2503,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  360,  163,    1,   12,    1,  973,    9,  652,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  162,   92,  187,    7,  716,   18,   32, 1894,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  550, 1028,    1,   32,  166, 2499,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1784,  187,  567,  510,  431,  163,    1,   12,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,    1, 3107,   32,    1,   45, 1428,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  645, 1806,    1, 1017, 1297,  166,    1,    1, 1897, 1066,  581,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  123,   32,   98,    1, 3346,  187,  104,  794,  241, 1995,\n",
      "           98,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  397,    1,  454,    9,    1,    1,   98,  104,  643,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1779,  729,  967, 2398,   37, 2449, 3158,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230, 1654,  581,    1,  427,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  864, 2744,  955, 1461,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,   37, 1204,   98, 1965,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  391, 1329,   37,   47,   48,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3186, 1272,   32,    9,  105, 1633, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   74,   45, 2826, 2094,  671,    9,  284,    1, 1479, 3272,    9,\n",
      "         1130,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  437,  200,   15,   93,  469,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2388, 2726, 2206, 2207,  171,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314, 1692,   82,    1,  939,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,  166, 1779,  187, 1477, 1990, 2107,    1,   28,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  268,    1,   32, 1092,  524,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2926,    1,    1,  542, 2228,   79,   32, 1952, 1055,   45, 1204,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2932, 1835,    1,  617,  259,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,  606,  901, 1515,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 2734,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  761,  108,   45,    1,  985,  629,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   64,    1,    1,  167, 1641,  444,   10,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  602, 1353, 1690,  312,    1,  663,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1360,  612,   52,    1, 1159,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1, 2693,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,    1,   32, 2638, 2931,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  433, 2424,  581, 2650,  302,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1, 2192,  460, 2017,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1140,    9, 2490, 2705,  927,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75, 1273, 2819,  804,  833,  612,    1,  284,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,   32, 2069, 1958,   98, 1778, 2232, 2851,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  300, 1957,  608,  902,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3318, 1090,  183,    9, 3183,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885, 1631, 2523, 1001,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,  952, 2025,  987,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  244,    1,  983, 1473,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1156, 2708,  650, 1042,   39,   45, 2107,   37, 1504, 3358,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  140,   32,  865,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,    1,    1,  199,    9,  829,   12, 1718,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1361,    1,   32,    1, 1262, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1589,   12,  582,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3294,   76,   37,  877,    1,    1, 1247,   37,  698, 2675,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2712, 3322,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2213, 1241, 1507,  202, 1638,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2932, 1604,   37, 1021, 2910,  220,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  812, 1861,  187,    1,  650,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  199,  421,    1, 1200,   32,   46,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1, 2889,  384, 2841,   32,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  344, 2596, 2414,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75, 2167,  858,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1645,    1,   32, 2170,  580, 1665,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  112,  187,    1,    9,  104,  358,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  848,    1,    1,    1,  428, 1007, 1412, 1107, 1863,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3088, 2165,  608,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,   37,  125, 1446, 1612,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,  105,  829,   12, 1718,    1, 2279,    1,    1, 1370,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  579, 1481,    1, 1170,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  799, 2097,  584,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  814,  597,   82,   37,  619,  959,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,  954,   37, 1192,    1,  419,   32,  701,   32,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 105, 469, 182,   9, 647,  17,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  37, 151, 683, 781,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3177,    1,    9, 2936, 1616,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3241, 2368, 1826,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1024,  551, 1024,   37,  151, 1026,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1260, 2414, 1700,  388,   32,  854,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  563,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 1886,  384,  302, 1712, 1465, 2948,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1307, 2474,  618,  680, 1260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3320, 1210,    1,  132,    9, 3262,   12,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1585,  176, 2018, 3407, 3392, 2414,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1254,   85,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  410,  187,   69,  431, 1146,  106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426, 1707, 1715,  705,    1, 1417,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1,   37,  151, 2792,   12,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2594,  782,  166,    1,    9, 1523,  548,    1,  698,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,    1, 1749, 2287,   28,    9, 2229, 2232,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676,    1,  487,  947,  271, 2189, 1228, 1551,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  167,  429, 1215,  388,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089, 3047, 1527, 2664,  513,    9, 1204,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 2199,  547,   74, 1044, 1045,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 2272,   85, 2931,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  140, 2376, 2223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,  361,  479,    1,   37, 1289,  230, 2560,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2970, 2426,   32, 2646, 1258,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2628, 2970,    1, 1281,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  156,  245,    1,  225,   28,   98,  157,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1440,  171, 1650,    1,  176, 3283,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  351,   45, 1756,   30, 3151,   12, 2298,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,   45,  354,    1,  202, 2494,   45,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  597, 2977, 2664,  513,    1,   45, 1792,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2229,    1,   61, 1120,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3010, 3190, 2415,    1,   12, 1565,   61,  247,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   96,   28,  166, 1245,  187,  244,  554,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  245,   37,    1, 1443,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   98,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  864, 2177,    1,  813, 1260,   98,  163,    1,   12,    1, 3111,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2823,  736,  884,   98,  365,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  496,  258,  495,   37, 2449,  526,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2656, 1017,  936,  365,  132,  220,    1,   12, 1300,  538,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2193, 1441,  829, 1778, 2580, 2851,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1407, 2617, 1000, 3358,  967,  164,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275,  193,    1,   37, 1952,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  439,  242,    1,  374,   81,  530,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,  354,   98,  983,  720,    1,  134,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1591,    1, 1126,  102,  530,  308,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3266,    1,    9, 2202,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,    1,   45, 2931, 2678,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3257,  338,   37,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1704,    1,   26, 1039,  535, 1863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1257,   12, 1904,  112, 1536,    9,  467,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 2122,    1,  811,    9,  531, 2001,    1,  566, 1894,  627,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3129, 2885,   30, 2843, 1492,   12, 2101,  786,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2573,   12,    1,  190,  193, 1403, 3398,   81, 1159, 2789,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1443,   32, 3144,  498,   37,    1,  297,  741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504, 1065, 1190, 1216, 1583, 1532, 2958,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3119,  947, 1079, 1574,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1839, 3037,   37,   18, 1159, 1601,   98,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  215, 3143,    1, 2134,    1,  861,  231,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,  335, 2436,    1,  384, 1230,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1773,  551,  848,  494,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,  170,  837,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  854, 1463,  546,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3352,  114,   98,    1, 3150,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2, 425, 426, 376, 367,  15, 570,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 894, 334, 815,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,  958, 3347, 2572,   32, 1785, 1633,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  180,  476, 1488,   75,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3130,   96,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  625,  590,    1,  220, 2565,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1182,  477, 1663,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380,    9,    1,    1,    1,    1,   63,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  294, 1456,  246,   43,  951, 2180,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1625,  365,   16,   61,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  845,   32, 2342, 2458, 1638,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   85,    1,  202, 1745,   39,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2090, 2161, 2709,  449,  183, 1463, 2468,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1581,    1,  384,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  455, 1648,   37,    1, 1854, 2237,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   42,    1,   43,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1061,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596, 1565,    1,   69,  120,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1592, 1140,   98, 2977,   37, 1154, 3015,  220, 2978, 2699,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,  928,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  272,   37,    1,  384,  467,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,   51,  193,  606,  365,  475, 2191, 2020,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1317,  792,  704,  792,  104,    1,   37,  572,  197,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,    1,    1,   39,   45, 1352,  701,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    9, 1477, 1990,  872,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2718, 2833, 2432, 1499, 1516,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  167,    1,    1,    1,    1,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,   37,    1, 3358, 1351,   98,  740,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  867,    1,   85,   98, 1662, 2086,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388, 1574,    9,  584,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   61, 1782,   37,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1458,  156, 1470,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,  437,    1, 1300, 1412, 1107,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2275,  176, 1209,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  675,   50,   37,  151,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1257,    1,  588,  467, 1942,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2944,   37, 1418, 2924,  384,  531,  191,  439,   45, 1314,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   95, 1478,   32,  451,  548,  537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,   37,  489,  284, 2924,   39,   45, 1815,  424, 1034,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 1723,    1, 1409,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1879,    1,    1,   79,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230,    1,  191, 3169,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  891, 1958, 1778,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087,  433, 1082, 2862,   37, 1211, 3351,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  854,   12, 1354, 2556,    1, 2572,   32,    1, 3246,  548,  105,\n",
      "          356, 1844,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  903,    1,  464, 3397,  108,   45, 2673, 2108, 2107,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  715, 1228,    1,    1,  361,  247, 2742,    1,  619,  611,  199,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2701,  691,  726,  449, 1940,   12,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051,  564,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,   37, 1636,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  705, 2693, 1104,    1,  361,  105, 1465, 2693,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2895,    1,   30, 1433, 2966,   61,  363,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2, 275, 159,   1, 417,   1, 202, 218,   1,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  28,   1,  39,  98, 247, 248,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3141, 1090, 1829, 1214,  951,    1, 1717, 2920,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,    1, 2355, 1718,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98,  351,   45, 3361,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3009,    1,  220,   97,   98,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3345,    1,  487, 3102,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,    1,  104,  190,  907,    9, 1764, 1990, 1684,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  888,   45,    1,  548,    1,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2405,   37,    1,  922,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  310,   25, 1285,   28,  187,   60,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160,  102, 1269,   32,  871,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2800, 2764,  460,   12,  199,    1,    1,  810,  166,  454,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  558,   37,  559,   79,  560,   50,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141, 1949, 3268,   12,    1, 2784,   37, 2445,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  581, 2635,    1,    1,   32,  365,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,  108,   45,  909,   98,  104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1937, 1691,    1,   32,  365, 2445, 1563,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3018, 1494,   28, 1139, 2928,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  259,  681, 1882,   37,  619,  844,   98, 1273,  618,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  746,    1,  132,  220,  829,    9, 2348,  844,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3097,  855,  488,  365, 1002,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  671,    1,  861,    1,  775,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,    1, 2720, 2796,  894,    1, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1089, 1090,    1, 3039, 1887,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3196,    1,   32, 1742,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  228,  978,    1,  759, 1427, 1347,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447, 1585, 1389,    1,  202, 1744,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3365, 3338,  191, 3352,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  187, 1009,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  758,  200,  466, 1013,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,    1,  693,  365,  613,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1818,  147, 1579,    1,  370,  409,  172,  170,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  593,    1,    1, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  669,  495,   66,   28,  384,  356, 1490,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1830, 1610, 1066,    1,  159,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   10, 1261,    1,   45,  632, 1512,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2754, 1920, 1683,  191, 1147, 3365,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,  213,   37,  875, 1370,   45,  961,  573,   43,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1089, 1090,    1,  921,    1,   59,  449, 1034,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  786, 1048,    1,   37,    1,  220,  978, 3138,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2764,    1,  267,  190, 1343, 1926, 1927, 1928,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1502,   37,  125,    1,    4,  176, 1503,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1390,  267,  587,  498,   37,  469,   37, 1066,  669,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1417,  551,  717, 1258,  114,  333,    1,   79,    1,  455, 1131,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3279,  271,   39,   32, 2646,    1,  202,  957,  267,  460, 1625,\n",
      "           37,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296,   37,  588,  786,  131,    1,   32,  171,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  706, 1140,    9,  411,    1,   45,  654,  475,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2108,  469, 2070, 1789, 2357,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  547,  163,    1,  903,    1, 3365, 1683,    1,   32, 3360,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  857, 1567,  515,  903,    1, 1423, 2250,  220, 2637,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  477,  456,   85, 1744,  436,   45, 1815,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1823,  535,   12, 1824,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  311, 2936, 2864, 2457,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  361,  301,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1281, 1130,  187, 1103,  191,  166, 1690,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  455,    1,   85,    1,  285,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1231,   32, 1606, 2596,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848, 1572,    1,    1,  849,  349,  132,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1, 361,   1, 590,   1,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 397, 908, 909,  98, 104, 280,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3244,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3236, 1012, 2805,    1,  187,  512,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1748,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  498,   37,    1,  531,  734,  589,  592,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  137,  390,  288,  105,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,   12,    1, 1707, 3057,  142,  449,  571,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  361,    1,  105,    1,   32,  166,    1,  593,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  632, 1223, 1086, 3336,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1959,  700,    1,   32,   11,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,    1,    1,  166,    1, 2431,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2752,  388, 2292,   98,   74, 1700,   45, 2774, 2782,   45, 1633,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181,   37, 1539,  259,  220, 2543, 2177, 1027,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3358,   12, 3137, 1519,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,    1,    1,  630,  167,  631,   37,  613,    1,  132,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   75,  261,   32,    1,   45,  207,  259,  293,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3385,  267,  460, 2506,  163,    1,   12,    1,  600, 3373,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  750,  924,   32,    1,   86,    1,  776,    1,  583,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3191, 1249,    1,   37, 1124,  631,   37, 1700, 1394,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328, 3181,  168,  228, 1394, 1048,    1,  386,  726, 1114,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796,  623, 1091, 1083,  157,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  146,    9,  949,   45, 3025,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,  119,  293,  522,  444, 1182,   45, 2733,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  338,    1,  952, 1604,    1,  365, 1204, 1438,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230,    1,  105,  311, 1585,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1568,   38, 1337, 3300, 1045,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1536, 1312,  365, 2819, 2039,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,  550,  235,    1,   12,  477, 1627,  581,   74,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  729,  674,  121,  964,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  484, 1973,  877, 1515,  221,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3198,  726, 1380,   97,   98, 3257,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1797,  361,    1,   45,  460,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3115,    1,  460,    1,  726,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715, 1151,   13,  513,  514,   32,  636, 1336,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1211,  286,    1,  361,  764,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3352, 2856,    1,    1,  662,  650,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   74, 1921,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  251,  764,   32,    1,  163,    1,   12,    1, 2735,   37,\n",
      "          963,    1,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1276,  548,  458,  818,  271,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  347, 2748,    1,    1, 1340,  105,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  273, 1609, 1203,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3209,  606,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   61,  705,  182,   85,  361, 2961,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 1466,   42,  134,  597,   82, 2430,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  381, 2609,  367,  604,  333,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  463,    1, 2572,   32,  963,  851,  298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1711, 2449, 2198, 1021,   32,    1,  942,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2629,  741,    9, 2757,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1181,  623,  396,  593,  449,    1, 2382,  259,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3178,  162,  103, 1569,    1,    1,   37, 1046, 3174,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1433,    1,    1,   39,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3252,  140,    1,   32, 2941,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  203,   37,  877, 2048,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2102, 3049,  686,   59,  813,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  852,  198,   32,  800, 2498,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2806,    1, 2453,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1423, 1249,    1,   32, 3096, 1912,  691, 2471, 2046,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3296,  429,   98,   37,  688, 3233,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3363,    1,    1,  855,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  787,  336, 2711,   37,  741,   98,   24,   37,  439,  547,\n",
      "           74,  477,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  657, 1291, 1086, 1018, 1015,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  864, 1077,   37, 1413, 2673,  275, 1218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  844, 2495,  708, 2114, 1213,  187,   82,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   21,  388,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3187,  837,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,    1, 2325, 1281,   98,  597,  446,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2942,  967, 1030, 1559, 1311,    9,  119,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  794,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2275,    1,   10, 1523,    9, 1460,  622,  741,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,    1,   98, 2966,  444,  691,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  460, 1721,  712,    7,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  198,    1, 1884,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3221, 1908,   98,  608,  951,    1, 2689, 1717,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   21,  646,   93,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1256,  551, 1256, 1026,  167,  764,  273, 1609,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585, 2414,  176,  177,  176, 3407, 3392,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  664,    1, 2191, 1014,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2308,  474, 1355, 2967,   12,  949,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  326, 1441,    1, 1718, 1222, 2359,  934,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3161,  921,    1,    1, 1022,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 294,   1,   1, 158,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 147, 908,  22, 942, 283, 469,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  388,  763,    1,  961,  174,    5,    1,  127,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,   12,    1, 1201,    1,    1, 1513,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3066, 1380, 1092,   98,  429,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,  294, 2422,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  529,    1,    1, 1159, 2375,    1,  403,  396,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3254,    1, 3130,  321,  612,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   26, 2679, 2185,  572,  417,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  716,   92,   32, 1913,  401,  244,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2840,   61,    1,   98, 1345, 2834,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465,  249,    1, 2821, 2218, 2096,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1808, 1412,  614, 1824,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,   37,  588,  104, 1527,    9, 3375,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  632, 1497, 2421,  729,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1414,   84,   28,   97,   98, 2751,   32,\n",
      "         2646,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2519, 1564,  105, 1935,  712,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845, 1998, 2359,    1,   32,  166, 1811,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  592,  267,  395,    1,   37, 1121,  954,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  369, 1475,    4,   32,    1,  886,  221,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2227,  725,    1,    1,   98,  198,  983,   93,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,  386,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   25, 1173,   37,   26,  417, 1051,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  365, 1788,  681,  815,   80,   37, 1911, 1209,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1128,    6,  102,   98,  301,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,    1,    9, 1764, 1990, 2069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3103, 2222,  619,  105, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,   45,    1,  390,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962,    1, 1401, 1959,  608, 2307,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2316,  270,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  677,   94, 1380,   99,   32,  105, 2324,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363, 1625, 1443,  190,    1, 3343,  741,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2808, 2539,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 2965,    1, 1401,   32,    1,  186,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1661,  182, 2180, 1291,    1,   32,  786,   74,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,    9, 2557,    1,  187,    1, 2864,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  964,    1,   37, 3144,   37,    1,  446,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,    1,   50,    9,    1,  131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2994,   28,    1, 2997,   85,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1113,  396, 1253,  191,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  548, 1645,    1, 2552,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3251,    1, 1240,   18, 2283,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2130, 2971,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233, 2104,  256, 2977, 1001,   37, 1278,  302,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  463, 2571,    1, 1061,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    9,    1,  219, 2579,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  213,   37,  807, 2024,   23,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,   37, 1539, 1412, 1107, 1863,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 1353, 1228,    1,  210,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1109,    1,  697,    9,    1, 2187,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  876,    1, 1089, 1090, 1281,  321, 1878, 2559,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967, 1857,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  952,  388, 2341,  841,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  357,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1718,    1,  232,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  729, 1573, 2155,   28,  220, 1712,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2944,  446,  288,    9, 1918,  297,    1,  741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  176,  915,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,  387,    1, 1890,    9, 1718, 2366,  662,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  294,  716,  449,  156,  452,  170,  220,  182,  551,  717,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  294,  267,  204, 1924,   98, 1926, 1927,   12, 2290,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  951,    1,  792, 1951,  593,  443,  792,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,  163,    1,   12,    1, 2872,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  166, 2551,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2151, 1604,  176,   56, 2152,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1213, 2750,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1795,   37, 1539, 2328,   20,  162,  365, 2306,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,    1,  191, 1018,    1,  166,  104,  321,  612, 2712,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3407, 1900,    1,   37, 1844,   32,  531,  890, 1411,  339,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  232, 1117,    1,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 3111,    1, 3155, 1523,  297,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190,  334,   52,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  720,  187,  195,    1, 1151,    1,  817,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  474,   12,    1,   37, 1411,  922,  693,  113,    7,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  421, 1114,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102, 1150,   37,  105,  547,  339,  340,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1390,  140,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1898,  327,   37,  259,    1,   37, 1865,    1, 1153,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1924, 1018, 1691, 2193,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854, 1463,  546, 2673, 3085, 1461,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  326, 2094,    1,    1,  658, 1151,   37, 1021,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2030,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  119,  567,  390,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503,  159, 1374,   98,  749,    1,  550,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  387,  105,    1,  182, 1146,  356,    1,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  666,  868,    1, 2865,   39, 1021,   37,  331,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3025,  513,    9,  247, 1204,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1879,  913,    1,   98, 2347, 1482,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1120,   12,  166, 2376,    1,  920,    1,  460,   37, 1658,    1,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100, 1273,    1, 1396,  657,  660,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1994,   10,  777, 1708,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3364, 2726, 3339, 1939,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 1143,  267,  204, 1924,    1,  297,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2232,   15,    1,   32,  166, 1811,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  273,    1,  245, 2808,    9, 2073, 1090,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  452,  403,  464, 1585,  449,  898,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1185, 3120,    1,  153,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,    1, 2414,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2856,    1,    1,   32,  455,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978, 3138, 2225,    1,  512,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1138,   37,  125,    1,    4,    1,  123,  105,   72,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   12,  863, 1708,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1123,  892,  428,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12, 1481, 2864,  601, 1002,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  370,  325,  159,   32,    1,  371,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2767,    9,   59,  887,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  187, 2800, 2565,  176,    1, 1306,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   12,  301,    1, 2277,   61,  792,    1,    1,    1,  792,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  786,   45, 1700, 2812,   32, 1437, 2824,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3349, 2162, 1950,  640,  548,   64,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  136,    1,  613,  512,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,  140,   22,  395,   12, 1250,    9, 1312, 1202,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2292,    1,   32,  273,  548,  730, 2614,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   37,    1,    9,    1,    1,    1,    1,    1,    1,    1,\n",
      "           32,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2570, 1287,   37,    1,  511,  275,   32, 2138,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,   37,  151,  105,  265,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3013, 1437,  872,  708,    1,  187, 2565,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2197,  787,    1,    1,    1,   98, 1718,  221,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  224, 1770,  166,  454,   37, 1013,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  980, 2759,    1,  888,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 1353,  192, 2575,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3228,  517,    1,   39,    9,  914,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3384, 3149, 2774,  650,   37,  168,   98,  776,    9,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  176,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  491,  744,  182, 1429,  210,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,  294, 1107, 1624,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2383,  854,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  389,  167, 1344, 1590,  384, 2925,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  190, 1747, 1568, 1045,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  297,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 2640,   37, 1910,    9, 1821, 2190,   98, 1893,    1,    1,\n",
      "         2977,  267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1431, 1702,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 1011, 1196, 1473,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1708,  924,  796,  297, 2471,   37,  378,  437,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  786, 1965, 2550,    1,    1,  792,  836,    1,  792, 2337,    1,\n",
      "         1408,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 2178, 3382,    1,   12,  776, 2055, 1893,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 2388, 2540, 2451,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1583,    1, 2414,  547, 2729, 2548,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2959,  872,  420, 1169,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2893,  776,    1,    1,  204, 1822, 2192,   28,    1,  361, 1540,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  727,  613, 1564, 1018, 1377,   37,  413,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  200,  365,    1,    1, 2603, 2043,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    7, 1213,  190,    1, 2245, 1933,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3290,   84, 1159,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  818,  819,  335,   37,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 1414,    1,  191, 2476, 2625,    1,    1, 1444,  774,  254,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  415,    1,  612,  606,  166, 1001,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  897,    9,  107,    6,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  373,  496,   45,  574, 1132,  782, 2588,  388,    1,    1,  629,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  515, 2321,  105,  183, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,    1,  404, 1252, 1022,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,   44,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2317,    9, 1090,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  593,   12,    1,  826,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1427,  872, 1064, 1090,    9,  137,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2844,  187,    1, 1523,    1,   32,  854,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2311, 2308,    1,  104,  872,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  567,  799, 2151, 1568, 2885,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,  220, 3018,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2, 878,   1, 573, 574,   1, 647, 159,  37, 148,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 293,   1, 609,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 3160,    1, 1976,  514,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,  744, 2024, 1463,    9, 3375,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  691,    1, 2180,   37,  631, 2416,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178, 2399,    9,  215, 2280,   12, 2772,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,  437, 1679, 1147, 2548,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3316,    1,   32,  311,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3168, 2257,   39,   45, 2106, 1990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  603, 1159, 1630,  442,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3204,  140,    1, 1832,  271,   37,  759, 3329, 2069,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1933,  387, 1932,  187,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3314,  140, 1326, 1990,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2534,    1, 1004,  927, 1159,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  449, 1405, 2281,  776,  431,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2292,    1,  531, 1002, 1708,    1, 2343,  738,  924,    1, 3102,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   15, 2192,  169, 1018, 1893,    1, 2050,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1267,  105, 2457,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12,  572,  197,   28,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1542,   37,    1,  460,    1,  877, 2439,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1676,    1, 1292,  928,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,    1,    1,    1,    1,  517,    9,  259,  535, 3011,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  187, 3262,  664, 1394,  176,    1,    1, 1188,    9,  365,  580,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,  526,    1,  160,    1,  590, 1242,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  316, 1566,    1,  164,  165,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2264,  410,   98, 1577,   12, 2240, 1056,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  742, 1415,   37,  386,  214,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2877,  387, 1918,  297, 3045,   32, 3155,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3132,  542,    1,  354,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  665,  424,    1, 2072, 2349,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  602,   37,    1,  342,  673, 2010, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503,    1,  797,  469,    9,  103,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3331,    1, 1367,  220,  470,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  475, 1786,    1,   37, 1604, 1411, 1034,  420,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1337, 1645,    1,  701,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2268,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2328,  851, 1478,  331,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,  256, 1273, 2403,   37,    1, 2340,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,    1, 3256,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1680,  197,  897,  202,  307,  308,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1741,    1, 2176, 1822,  693,    1,  809,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  557,  540,  909,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  105, 2804,   12, 1727,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  891,  219,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  506,  861, 1553,    1,    1, 2500,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,  313,   37, 1198, 3081,   67,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  162,    1,    1,  384,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1127, 1550,    1,  102,   98,    1,    1,   15,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 2924,  856,  454, 1159,    1, 2827,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  816,    1,   79,  119,  340,  951,   94,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1879, 2565,    1, 3247,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  903, 1447, 1372,   37, 1463,  114, 1461,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,    1,  774, 3356,  213,   37,  439, 2646, 1512,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3389,  176, 1056,    1,    1,  217, 2856,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2658, 1040, 1178,   45,  166,  249,  357,  502,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1574, 2275,   12,  451, 2766,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3016, 1935, 1586,   28, 1092, 1876,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497,    1,   85, 1971,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2246, 1242,    1,   32,  142,   37, 1599, 1684,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,   63,   94,    1,  365,  340,  686,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3298,  140, 1684,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1694,  187, 2939,  571,    9, 1618,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  592,  267,    1,  996,  157,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1249,    1,    1,   37, 1758,   37, 3295,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1566, 1212, 1429,  220,    1,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2003,  114, 2414,   32,  403,  395,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   25, 1269,  187,   69, 1137,  224, 2781,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  529,  617,   12,  416,  166, 1021,    9,  517,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2235,   69, 1042,   37,  105,  106,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2497,    1,  411,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  683,   37, 1046, 3333,    9, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2451, 1178, 1231,  220,    1, 1159,  709,    1,   12,  675,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3176,  221, 2144, 1394,   32, 1030,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3167, 2722, 3074,    1, 1834,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1551,    1,    1,  259, 1675,   37,    1,  460,   32,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  566, 1089,    9,  112, 2492,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,   37,   26,  388,  124,    1,    1, 1130,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,  148,  361,  647,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  438,    1, 3081,    1,  917,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2321, 1110,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1585,    1, 1632,    1, 1633,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 2018, 3164,    1, 2889,    9, 1700,  257,  297, 1575,   39,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   56, 1061,   32, 3379, 2950, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 1228, 2718,    1, 2264,  176, 2413,  297, 2019,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 1654,    1,  460,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  325, 2943, 1416,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1652, 1718,   96,   28,  166, 1245,   98,  829,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   27,    1, 1390, 1579,    1,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 3184,    1,  837, 1527, 1900,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2920,    1, 1957,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   49,    1,  415,  166,  698,   45,  166, 1523,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1936,   98, 3356,  787,   32,  105,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3174, 1141,   37, 1758,   37, 2033,   32,  395,   26,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947, 2572,   32, 1378, 1002, 3367, 1450,  639,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  433,  993,  302, 1710, 1289,  947, 2005, 2295, 2302,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  396, 1422,  552,  552,  822, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1829, 1510,  221,   37,  470,    1,  261,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2080, 2341, 1074,  108,   45,   29, 2124,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   63,  166,  862,    1, 1137,  419,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,  267,  193,   37, 1155,  388, 2673, 1021,    1,   32,  105,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 1414, 2286,   37,    1, 3006,   32, 3155,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  119,    1, 1229,   37,   52, 1411,   98, 1629, 1638,    9,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1, 3358,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,  103, 2642,   37,  798, 3235, 1264,  841,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,    1,  227,    9,  112,    1,  299,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  768,   61,    1, 2443,    1,  202,  669, 1877,   37,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2551,   38, 3059,  449,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  170,  406,  640,  119,  845,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,  12, 105,   1,  39,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 163,   1,  12,   1, 305,  98, 700,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  755,  315,   37, 1539, 1697,  778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2620, 1380, 2153,   39, 1030,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2376,  855, 2645, 1922,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  331,   92,   37, 2147,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  550,  369,   12,  221,   37,  104,    1,  191,  615,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1614, 1778, 2232,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,  242,    1, 1946,  191,  496,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  361,   74,  332,  631,  548,  449, 1385,  176,\n",
      "            1,  628,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 726, 363,   9,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 829,  51, 544, 388, 834,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  744,  259, 1108,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1876,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  963, 2954, 1067, 1876,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1571,    1,   37,    1,  600, 2711,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1457,  782, 2738, 2508,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  150, 1484, 1593,   98, 1551,    1,  693,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 2759, 2232, 1396,    1,  441,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  302,  891,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1773, 1782, 1159,  111, 1387,   37,  537,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 2924, 2856, 3006,  176, 3339,  399,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2238, 1380,  105,    1,   98,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2744,    1,   37, 1127,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  411, 1178, 1827, 2290,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  675,  168,   32, 3013,    1,    1,   45, 2977,  927,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  597,  487, 3030,  315,  822,  522,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  198, 2164,    1, 1850,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3228,   38, 3115,  449,  354,    1, 2925, 1034,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,   12,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2153,  138,    1,   37, 3358,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3127, 3133,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   61, 1621, 1558,   32,  542,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2640, 1830,   37,  865,   37, 3024,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,   43,    1,   39,   45,  715,  147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758, 1525, 2996,  861, 2558,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  622,  851, 2421,    1, 2572,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3011, 1034,   32,  231,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1535,   45,    1,  861,    1, 2416,  384,    1,  166,  163,    1,\n",
      "           12,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213, 1041,    9, 1691,    1, 2001,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2596,   27, 2147,   32, 1081, 2414,  547,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162,   45,  166,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,  61, 786,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1,  98, 238,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  327, 2528, 2687, 1787,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75, 1579,  170,    1,  613,  633,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  921, 1638,   45, 2713,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107, 2216,  677,   69,  102,   98,  555,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1706,  182,   32,    1, 1021,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1957, 2584,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1821, 2190, 2640,  315,  365,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2144, 3043, 2710,    1, 1061,   32, 1791, 1050, 2596,  722,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1841,   32,    1,  372, 1448,  132,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   37, 1075,   98,  367,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3152,  576, 2967,   37, 1668,    9, 2308,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   61,    1, 1103,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  557,  540,    1,    1, 2396,  548,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1,    1, 1821,   95,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  744, 2364,   98, 2650,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3152, 2497, 3263,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2122, 1559,  105,    1, 2034,  247,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  706,  774,  302,  167,    1, 2785,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2391,   12,  166, 2010,    9, 3059,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,   51,  606,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3181,    1, 1545,  187,  166,  872,   37,  688,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2325,   45, 2047,  297, 1135,    1,   98,  487,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2551, 1398,  612,    1,   28, 3115, 1176,  445,    9, 1531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707,   12, 1375,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1497, 2449, 3158,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  686,  191,    1,  767,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2415,  204,    1,  220,  166, 1509,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  873,   45,    1, 1625,  361,  440,    1,  384, 2747,\n",
      "          657,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   65,   12,    1,  387,    1, 1437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   85,   37, 1515,  915,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1, 3115, 3228,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700, 1463,    1,    1, 1017,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1853,  456,    9,  885,  477,  297, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  200,    1,  361, 2686, 2687, 3004,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2541, 2001,   98, 1099, 1453,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1452,    1,  321,  612,  764, 1668,  726,   98, 2041,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2484,   37, 2728, 1766, 1767,    1,   32, 1352,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  531, 3006, 2856, 1056,    1, 3365,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    9,  166,  119, 1352,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,    1,  864, 1229,   32,   46,   98,  622, 2165,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,  617,  259, 1397,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  168,  539,    1, 1185, 1940, 1628,    1,    9,  424,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  892,   12, 1561, 3009,   32,  460,    9,  166,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 2693,    1,  193,    1,   37,   52,  105, 2505,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1326, 1660,    1, 1736, 1975,    9,  163,    1,   12,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  325,  674,   45,  978,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3194, 3195, 1822,  877,  917, 2309,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3091,    1,    1, 2249,   32,  531,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3352, 3353,  103, 3339,  232,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  792,  590, 1230,    1,  792, 1284,    1,   45,    1,\n",
      "            1,  361,    1,  105, 1530,  234,  182,  235,    1,    1,    1,  234,\n",
      "          182,  235,    1,    3,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32, 1364,    1, 1633,  176, 1537,    1, 1292,   16,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2006, 1530,   32, 2169, 3279,   32,  395,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1018,    1,    9,  166,  105,    1, 1417,    1, 1417,    1, 1765,\n",
      "          453, 3289,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2445,  147, 1707,   49, 1377,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  315,   37,  322,  131,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  213,   37,  104, 2099,   37,    1,  487, 2924,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  613,  815, 2072, 1694,   45,  593,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1841,  967, 1875, 2001,   98, 1683,  104, 3091,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  694,    1,    1,    1, 1056,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  474,  759, 1845, 1259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  597,  404,    1, 2696, 2356,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  220,    1,  423,   32,    1,  295,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   28,    1, 1821,  656,  548,  666,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1396,   49,  458,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   64,    1,  404,  395,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  411, 1567, 2070,  968,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,   27,  105, 1300,  693,    1, 1682,  774,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296,  154, 1947,  105,   37,    1,  220,   20,   12, 1117,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3029, 2094,  632,    1,  104, 3033,    1,   81,  384, 1821,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1610,    1, 2728,    1, 1976,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3207, 2745,   37,   52,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790,   37,  231,    1,    1,  761,  661,  195,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,    1,  947,  161, 1056, 1940,   32, 2811,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   46, 1195, 1813,  104,  358,    1,  359,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1, 1370, 1262,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3013, 2540,  365, 1212,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3222,    1, 3275,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  465, 1895, 1097,  568,  897,   32, 1837,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1172,   12,  671,  357, 2505,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2956, 1579,    1,  317,  361,    1, 1697,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056, 1335,  193,  514,   32,    1,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3276, 1838,   79, 1194,   73,  872,  220, 1918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1695, 1696,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374, 1949, 1952,  186,    1,    1, 3101,  477,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[  2, 793,   1, 359,  24,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 230,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1712,  162,   59, 1117,    1,  105,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  839,    1,  132,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1545,  162,   81,   37, 2315, 1262,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1,    1,   45,    1,  113,    1,  333,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,  640,  365,  340,  444,   94,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1363, 2222,  794,  517, 1273,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  398, 1337,  768,  767,  444,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2614,  774, 3238,   37, 1330,   32, 1090,    1, 1232, 1221,   61,\n",
      "          786,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  397,    1,  909,  444,  104,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2877, 1877,  992,   37,  856, 2834,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1477, 1990,  998,    1,  176,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585,   32, 2597,    1,  167,   52, 1656, 2596,  947,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2264,   29,    1,    1,  861,    8,  321,    1, 1897,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118, 1512,  190,  365, 2024,   46,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1883,   37,  151,   13,   45, 1117, 1525, 2759, 2043,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3328,   12,  244,  245,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  321,  631, 2792,  384,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3272,  386,   78, 1940,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  148, 2850,    9,  166, 1811,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  170,   37,    1,   14, 1031,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  506,  267,    1,    1,  193, 2879,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  686, 2482,   78, 2275, 1519,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1527, 1900, 1406,  600, 3155,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  266,  167, 1982,    1,    1, 1675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  424,    1,    1,   98, 1292,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 1466,   37,  151,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2163,   66,  816,  187,   69,  102,  670,  981,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  111, 1904,  986, 1938,    9,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1451, 1021, 3138,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  176, 1273, 1560,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  572,  354,  703,   98,   44,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106, 1107,  525,  256,   37, 2102, 2015,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1008,    1,   82,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1375,  103,  494, 1046,    1,  927,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2104,   37,  927, 3070,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,  256,  257,   37,  258,  259,  260,  261,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1962,  292,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1463,   37,    1,    1,  347,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   39,  220,    1,    1,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 3108,    1,    1,    1,  928,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1698,    1,   45, 1081,  139,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1450,  444,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1380,  105,    1,   98,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3003,    1,   85,  388,  912,  605,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  116, 1204, 1092,    1,  912,    1,  856,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  297, 2862,    1,    1,  176,  395,  442,  132,  187, 1725,\n",
      "            1,   28,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2497,  338,   98, 1112, 1167, 1184,  347,  606,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9, 1384,  616,    1,    1,   45,    1,   61, 2319,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1887,   45,    1,  685,    1,   32, 2499,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1971,  342,    1,  190,  764, 1590,   98,  754,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1488,    1,  166, 1831,  190,   52,    1,  247,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  686,  104, 1084,  841,  700,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2615, 1210,    1,    1,  202, 1444, 2233,  713,  361, 1937,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  155, 2326,   32, 1013,  443,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  729,  105, 1567,    9,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3364,  162,   92,   32,  142,    9, 2708,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,   24,    1,    1,    1,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2334,  744,  365,  846,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3167,  273,    1,    1,  827,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  326,  840,  453,  327,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  683,  919, 2615,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  619,   81,   32, 1126, 1090, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3086,  597, 1583,  655, 1550, 3148,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  813,    1,   37,  545,   12, 1746,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2862,  879, 3351,    1,  433, 2263, 1557,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758, 2355, 1013,  190,   52,  105, 2276,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  947,    1,  312, 1343,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3214,    1,  388,  640,    1,  765, 1387,   45,  119,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2523,    1,    1, 2579, 3154,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593, 1203, 3358,  166,    1,    1, 1625,    9, 2024,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3096,    1, 1837,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12,    1,  614,   39,  166, 2009,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,   37,    1,    1,  572,  689,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  267,  163,    1,  903,    1, 2673, 1281, 2189,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  204,  315,   37,  865,    9, 1090,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9, 2971,  625,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1423, 2272,   85,   98,  207, 2574,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2531, 1463,  546,    1, 2320, 1461,    1, 1917,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2619,   28, 1663,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1528,   32,   46,   37,  151,  215, 1093,  574,   87,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 1357,   98,  166, 1411, 1230, 1101,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1272,  176, 1157,    1,  548,    1,   56,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  649,  957,    1,    1,  384,    1, 1994,   10,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  146,  147,    1,  148,    1,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   36,  515, 2547, 2073,  916,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  267,  590,  132,    1,  590,    1,   98,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  388,  406,   66,  176,  903,    1, 1447, 1461,    1, 1603,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    7,    1,   37,    1,  317,  756,  548,  455,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2286,   37, 1154,    1,  548, 2844,   32,  350,    1,   79,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   32,    1,  220, 2147, 2950,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2227,  221,  665,   98,  429,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,   32,  531,  361, 3360,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,    1,  105,  671,    1, 1114,   32, 2601, 3282,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  459,  878, 1994, 2650,  302,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  215,  947, 2263,  786, 1178,  680, 1994, 2095, 1506,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,    1,    1,  615, 1587,  115,   45,  646,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2, 262, 263,  12, 264, 265,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 386, 781, 197, 418, 419,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2787,  729,  719,  105,  183, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2801,  387,   91,  187,    1,    9, 2226, 2969,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  237,    1, 1159, 1935,    1, 1160,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  361,   10,  442,  134,   98,  439,   45, 2375, 1281,    1,\n",
      "          361, 2502,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3359,  957,  580, 1512,  548, 1427, 1641,   32, 3101,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  397,  695,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361, 2114,   81, 2723, 2724, 1935, 2146,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1,  968,    1,  854,  361,  602,  588,  388,    1,  297,\n",
      "          596,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3282, 2627,  701,   32, 1660,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   39,  365,    1, 1228, 3004,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   26, 1218,   32, 1742,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37,    1,  131,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  344, 1656, 2596,   32, 2597,  163,    1,   12,    1, 2097, 3391,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1, 1130,  912,  388, 1994, 2819, 2039,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 1550, 2343,   12,   98, 3136,  477,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2797,   32,  632, 3071,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2287, 1735, 2536,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1930,    1,   32, 1313,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1,  191,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  388, 1772,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  261, 1031,    1, 1158,   37,    1,  809,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1248,  103,  147,   37, 1709,  552,  552,  400,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3101, 3372,  288,    9, 2507,  741,   98, 3339, 2271,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885,    1,   61, 1827,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  379, 1152,   45, 1479,  164, 1333,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  102, 2328,    1, 1124,   61,  166,  553,   32,  297,  537,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1325, 1585, 2803,  176,  177, 1056,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   69,  102,   97,  219,  159,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3172,  103, 1090, 1829, 1923,  176, 2388,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3010,  407, 1159,  601,   32,  365, 3278,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1061,   32, 2142,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   66,  187,  366, 2107,   37,  151,    1,    1, 1541,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,    1,    1,  187,  786, 1151,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  186,  608, 2615,   32, 2513,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2925, 1675,   98,  844,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3095, 1687,  365, 3339, 2625,  548,  477,   98, 3374,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  683, 3090,   37,  288,   28, 2779, 1388,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  168,   37,  166, 1928,   98, 3206,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2696,  459, 1689, 1109,  302,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  197,  202,  159,  245,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2004, 1577,  765, 1750, 2516,    1, 1228,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  232,    1,    6,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1298,    1, 2911,  193,    1, 2275,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  992,   85,  187, 1163,  475,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2005, 2087, 2614,  608, 3079,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  117,   61,  424,    1,    1, 1343,  220,  777,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   28,    1,  118,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1988, 3374,  650, 1550,  163,    1,   12,    1,  134,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3166, 2257,   39, 1918,  297, 3119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1591,    1,  159,   71,  187,  445,  187,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2288,  580, 1479, 2429,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2802, 1112, 1167,  204, 2233,  930,  548,  424,  914,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1877, 2140,  190,  193,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1502, 1008,    1,    1,  187, 1503,  129,  475,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  550,  369,  353,   71,   32,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,  938, 2032, 2867,  764,  384,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,  794,  365,  825, 1013, 2560,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2231,  373,    1,    1, 1405,  494,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  219, 2064,  498,   98,  864, 2390, 1757,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  565, 1395,    1,  105, 1048,  125, 2309,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  854,    1,    1,    1,   98, 1434,    9,  183, 2300,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  729,  387, 1332,    1,   15,   28,  419,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,    1,  167,    1,  275,  389,   93,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1025,    1,   37, 1911,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   47,    1,  118,   45,  159,   32,  502,  458,   45,\n",
      "         2792,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 3160, 2572,   32,  531,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1938, 3197,    1, 2107,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  195, 2054,   12,    1,    1, 2622,   25,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2977, 3027,  220, 2604,    1, 2421,   32, 3013,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843,   32,    1, 1569,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1523,  193,  297,  202, 3270,   98,  166,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2748,   37, 1523,  187,    1, 1443,    1,  424,  199,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  853,  538, 1049,  744, 1352,  714,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3286,    1,   39,  105,  198,  872,    9,  166, 1477, 1990,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  715,  532,    1,  528,  198,   94,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,   12,    1,    1, 1284,  105,  807,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  511,  952,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  267, 2275, 1924,  388,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1531, 2659,  878,  142,   37,   26, 1656,    1,    1,   37,  529,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1017,  361,  166, 1984,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2388,  750,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9, 2205,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    9,    1,    1, 2957, 1684, 1494,  191,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  580, 1044,  671, 3126,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2729,  947,  222,    1,  437,    1, 1527,   37, 3375,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  686,  885,  119,  845,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  463,  507,  307,  252,  442,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2227,    1, 1417,    1, 1417,    1,  991,  116,  412,  191, 1021,\n",
      "          847,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    9, 1526,   45, 1158,    1,  225,    1,   37, 1427,    1,\n",
      "          586,  267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777,   34, 2798, 1280, 1718, 1085,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  190,  405,   12, 1605,   37, 3235, 1232,  705,    1, 1417,    1,\n",
      "          162, 3251,    1,  428,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,   60,   61,    1, 2487,  689,  361,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  299,  272,   98, 2104,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537, 2924, 2856,  228, 3348, 2751,   32, 1815,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3369,  267, 2751, 2856,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1800, 2966,  798,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,   92,  568,  187,   69,  102,  686,  365, 1653,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 1009,  146,    9, 1527,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  326,   82,  812, 1239,  275, 1278,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1668,  581,   73,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2733,    1,   37,  119,  681,  600, 1107,    1,  147,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,   12, 1861, 1654,    7, 1190,  115,   45,  863,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,   28,  384, 1282,   12,    4,  701,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   79,  112,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  848, 1572,  437, 1564,  105,  857,  142,   37,    1,  849,  384,\n",
      "          199,  421,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004, 3034,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1557, 1707, 1457,   45,    1,  480,  741,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,   37,  319, 2741,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3152, 1124,  861,  548, 1665,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  108,  903,    1, 1447,  444, 1461, 1867,    1, 1082,  865,\n",
      "           37, 2673,   46,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1112,  176,    1, 1465,  315,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314,  551, 1692,   82, 1240,   52,  166,  449,   45,  105,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2582,    1,  460,    1,  267,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,   12, 3401,    1,   32,  365, 2224,  220,  284,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  338,   98,  244,  304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273,  259,  681,  345,    9,  365,  845,  846, 2146,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2391, 2555,  203, 2977,  190, 1403, 3012,   85,   37, 3024, 1821,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,  611,  199,    9,  878, 2852,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1041,    1,    9,  915, 1090,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1573,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 420,  98, 342, 996,   1, 680, 114,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 213,  37,  47, 131,  45,   1,  37,   1, 369,   1,  50, 328,\n",
      "           1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3177,   12,  457, 1204,  590, 1057,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226, 2370, 1658,  888,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1256,    1, 1751,  190,  698,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  193,  810,    1,   61,  166, 1690,   37,  166, 2925,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1070,  147,   37,    1,  326,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2926,    1,   37,  606, 1857,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2275,  267,   10,    1,  361,    1,  220,    1,   98,  531,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2838,  276, 1144,   98, 1183,  199,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3385,    1,  864,   12,  903, 1806,  104, 2167,   98, 1936,  522,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1004,    1,    9,    1,  287,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  422,   57, 1093,  977,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  162,  356, 2836,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1379,  833,  612, 1937, 2995,   32,  224,   12,  627,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213, 2411,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1861,  859,   37,  439, 1412,    1, 1232, 1445,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162, 1204, 1175,    9,    1, 2772,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 1473,  530,  105,  106,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105,  633,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1346,  474,  520,  590, 1161,    1,  444, 2183, 1428, 1499,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303,  884,  656, 1267,  424, 1034,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2833,  674,   45, 2078,    1,    1, 1499,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,    1, 2809,  311,   12, 1230, 1708,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2685,    1, 3231,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,    1,   32, 1239,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  961,    1,   61,  227,  550,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1256,    1, 1751,  513,  514,   32,  195,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  907, 2473,    1,  166,  259,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  147, 1566, 1983,    1,  400,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,   28,   98,   69,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1103,  115,   32, 2178, 2823, 2107,    1,  806,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2909,  357,    1,  590, 2259,   37,  864, 2390, 1665,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1,  193,   76,   81, 2191, 1657,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2922,   12, 1045, 1086,  187, 2672,  688,   28, 1879,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1086, 1034,  242,  202, 1293,  680,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  245,  187,  626,  159,    1, 1256, 1256,  817,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  856,   45,  247, 1204,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1206,    1, 2458,    1,    1, 1753,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,    1,  647,   12, 1046,   32,    1,  159,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  597, 1098,   45, 2275,  822,  872,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3069,    1,  121, 1207,   37,   92, 1994, 2095, 2532,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  388,    1,    9, 1407, 1149,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  680,  114,    1,  136,  859,   37,  917,  453, 2728,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1081,   12,    1,  190,  193,    1,    1,   32,   45, 1351,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  140,  297, 1131, 1443,   23,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2618, 1249,    1,   32, 2701,  593, 1990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  542, 1542,    9,  365, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1631,  168,    1,  454,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374,  108,  444, 1513, 1167,    1,  460,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,    1, 2109,   98, 2673,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56,    1, 1427, 2058,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1656, 3389,   32,  531, 2856,    1, 1744, 1763,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,  636, 1293,  530,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  191, 2275,  361,   10,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504, 2038, 2770, 2705, 1223,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1924,   98,  454,   37,    1, 2107,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1663, 1603,  733,   50,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,    1,    1,  166, 2084, 2226,    1,  552,    1,  405,\n",
      "            1,   12,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  667,    1,   32, 2124,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,   12,  449,  420,   61,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597, 2977, 2664, 1231,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1815, 2396, 2612, 2024, 1625,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967, 1018,  661,    9, 2659, 1167,  138,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1700, 3386, 1940, 1976,  514,   45,  312, 1450,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  152,   94, 1962,  109,  132,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2838,    1, 2017,  726,  297, 3132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  325,  963,  934,    1, 1499, 1873,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1988,  163,    1,   12,    1, 3400,   37, 1594, 3304,   32,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2480, 2910, 1527, 1209,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  319,  531,  957,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2528, 1613,   12, 1615,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  298,    1,    1,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 2024,   23,   37,  335,  297, 3069,    1,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   65,   12,    1,  267,  104, 1822,  125,  448,   37,   92,  745,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  191,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1117, 3058,    1,   37,    1, 3342,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,  376,  636,   45,   80,  259, 1108,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 3247, 1285, 3232,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  588,   37,   97,  163,    1,   12,    1,   37, 1121, 2822,\n",
      "            1,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1123, 2246,    1,  696,  665,  105,   12,   81,   98, 1171,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2924, 2172,    9,  531,   32, 1094, 1603,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2885, 1401, 2843,  176,    1,    1,  566,  590,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  854,  686, 1674,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 1477, 1990,  872,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   37,   44,  755,  220,  133,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  487,    1, 2593,  593,   12,  553, 1448,  669,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1185, 2562,    1, 1281,    9,  581, 3130,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1504,    1,  187, 1273, 1001,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1569, 2562,  105,  501,   92,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   13, 1670,    1,    1, 1942,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   26,  242,  548,    1,    1, 1087,  156,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2337,  334, 1604,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  880,  744,  119,    9,  846,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  873,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1407, 2153,    1,    1,   45,    1,    1,   12, 3081,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  352,  267,  399,   98, 1171,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2951,  103, 2334, 1638,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 1818,  147, 1392,    1,   98,    1, 2162, 1780,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37,  759,  166,  581, 1385,   45,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788, 1215,    1,  547,  440,  104,    1,    1, 2275,    9,\n",
      "         1009,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3252, 1401, 3059,  608, 3200,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1171,  872,   61,  921,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294, 1983,  861,  792,    1,    1,  792,  837,  636,  969,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  439,  166,    1,    1,  191, 2308,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  410,    1,    9,    1, 2565,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  296,  640,   81,  176,   20,  297, 1527,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  627,   45,  314,    1,   98, 1629,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   51,    1,   28,   37,    1,  182,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1956, 1822,  860,    1,  592,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  202, 1977,    1,  176,  215,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275,    1, 2021,  440,   32, 2482,   78,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1994,  229,  856,  921,   10, 2521,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  104,  872,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  293, 1489, 2623, 2624,  932,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  307, 2930,  400, 2322,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3117,  664,  885,    1,   37, 3296,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,   12,  822, 1523,  297,    1,    1, 1258,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  560,    9,  680,  339,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2855,    1,  460,   39,  297,  531,    1,    4,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,  338,    1,  218,    1,  395,   12,  221,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,    9,    1, 1958, 1563,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1355,  240, 1411, 2977,  475,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  221, 1836,   98,    1,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  314,  551, 1692, 1974,  218, 1085,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  123,    1,  525,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453,    1,    1, 1360,  612,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  366,  996,    1, 1121, 1114,   32,  385,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1658,  499,  275,  550, 1108,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1417,    1, 1458, 3380,   12,    1,   37, 1348,  187, 1583,  475,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32, 2597,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1050,  947,  877, 2095, 3109,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3369, 1550, 1188,    9, 2117, 3406,   32, 3118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,  611, 1991,   37,    1,  164, 1333,  261,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   95,    1, 1114,    9,  393, 2328,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   26, 1039, 1228, 1523,    1,  829,  444,  166,   26,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2280,    1, 2408,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2614,  506, 3232,  361, 1937,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,   45, 1361, 2579,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1929,  884,  913, 1897,    1,    1, 3011,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,  159,  720,    1,  647,   12,   71,  115,   45,  147,  856,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1629,  696,  209,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2802,    1,    1,    1,  802,  187, 1211, 2256,  218, 2361,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  493,  921,    1,    1,    1,    1,  384,  119,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1017,   24,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,    1,  572,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2963,  354,  408, 3301,  247,  389,  176,  584,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1260,   98,    1,  408, 3312,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1558,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,    1,  459,  259,  802,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1538,    1,    1, 2782,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,  715,    1, 2223,  614,   37,    1,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 2492,    1,    1,  884, 2505,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56,  249, 2347,   32, 2596,  216,   32, 2468,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,  967, 1846,    1,  176,    1, 2967,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,   37, 1124,  289,   98,  112,  993,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  513,  193,  514,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  207, 2683,   12, 2495,   37, 1778,  861,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1, 2835,  269, 3080,   32, 1479,   92,   37, 2471,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  656,   45,    1,  454,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3079, 1180, 1415,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1104, 2209, 2830,  753,    9,  187,  227,   45,  356,  187,  915,\n",
      "          356,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2475, 2651, 1779,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  108,   45, 2252, 1718,  767,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  475,    1,  548,    1, 2564,   98,  247, 1204,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1322,    9, 3046,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  176, 3127,  827,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092, 1070,  103,  147,   37,  817,  912,  605,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  221,   98,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1,    1, 1441, 1652, 1718, 2355, 2973, 1764,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2862, 1679,    1, 2179, 3080,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800, 2671,    1,  928,   45,    1,  505,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  251,    1,    1,   37, 2580,    1, 2264,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  295, 1949,  541,  187, 3121, 2405,   37,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3207,  671,  191,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  818, 2749,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  383,  187,  529,  408,  686,  954,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  301, 1228,   13,    1,  921,  689,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1658,    1,  384,  166,  478, 1361,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,  580,  342,  909,  297, 3118, 2292,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  103,  215, 1190,  614,    1,    1,    1,    1,  297, 1922,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035,   12, 1576,  912, 1377,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  727,  590, 1954,  469,    9,  179,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2224, 1464,   37,    1, 1021, 2139,  943,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  236, 1022,    1,   12,  183, 1034,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2487,    1,    1,  681, 1066,   98, 2103,  617,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361, 2820,    1, 1159, 1470,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,    1,   32,   59,    1,    1,    1, 3141, 1292,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  454,   51,  606, 2713,  440, 1294,   12, 3022,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790,    1,  952,  822,  764,  384, 1300, 1184,  437,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  187,  492, 1662, 1178,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  316,    1,  705,    1, 1417,    1, 1906,  765,   98, 1123, 1799,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1680,   37,  335,  297,  395, 1074,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  449, 1173, 1158,   12,    1,  365, 2452,  517,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,  606,    1,   85, 1601,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  636, 1042, 1315,  813,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 1034,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  917,    1,   51,   52, 1809,  105, 2457,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,    1,    1,   28,    9, 1539,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977,  792, 3054,  792, 1631,  846,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3349, 2817, 2200, 2130,  997,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  411,  176,  458,   45,  507,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1479, 1647,    1,   32, 1446,  652, 1852,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  714, 2071,    1,    1, 1935, 1736,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144,    1,  360,  863,  302,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   60, 1518,   32,   98,  687,  548,  800,   29,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1216,    1,    1,  664, 1515, 2405,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1174,   32,   22,  854, 2596,  776,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2427,  631,  191, 2202,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  961,    1, 1190,  267, 1221,  190,   52,  231,   45,    1,    1,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2469,    1,   32,  218,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,  418,  118,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3158, 3297,  162,    1,   39,   45, 2484,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1444,  565,    1, 1492,  817,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   45, 1698, 2943,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1739,  921, 2388,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  600, 1330,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2283,   12, 3141, 2246,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2768,    1,    1,  815,    1,   37,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  671,   32,    1, 3292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,  187, 1973, 2565, 2667,  167,  606,  258,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   51, 2022,  668,  112,    1,   47,   50,    1,  548,  390,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  775,    1,    1, 1049, 2670,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1036,    9, 1798,  220, 3358,   12, 1404,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1380, 1918,    1,   98, 2378,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2597,    1, 2696, 1333, 1530,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  176, 1178, 1179,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1070,   37,  211,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779,  801,   37, 1447,   26, 2069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1805,    1,   51,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  612,  302,  347,  686,  356,  845,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  147, 2621,  220,  171,   32,  400,  444,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2529, 3121,    1,  288,   37,  686, 2755,  455,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,    1,  304,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777, 1342,  365, 1644,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  437,   37, 1638,    1,   59, 1244,   98,  224,  942,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374,   37, 1860,  890,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  959,  526,   98,  197, 1936,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1,  163,    1,  903,    1, 1004,  187, 2189,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1128, 1419, 1230, 2543,  413,    1,  936, 1718,  662,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758, 1564,  105,  132,  220,  166, 2594,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2222,    1,  166, 3322,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564,  931,  105, 1479, 1665,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1958,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  476,  846,   98, 3402, 3408, 1534,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  496, 2415,   71,   32,  163,    1,   12,    1,  858, 2264,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   28, 3278,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,   34, 1994, 2095,    1,  220,  365,    1,  861, 2060,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,  861, 1414,   18,  680, 1260,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  156,   85,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1, 1447,    1,  903, 1463, 1801,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2246, 3250,  619, 2716, 1720,    1,  583,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  587, 2253,   37, 2035,  430,  477,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  321, 1481, 1349, 1403,    1,   37,  853,  538,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  698,   28,    1, 1908, 2242,    9, 1607, 1626,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1,    1, 1082, 1802,   37, 1124, 1054,  109, 2013,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,  936,    1,    1,    1,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  547, 1656, 2909,    1, 1316,  531,    1, 1887,  176,  177,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 2418,   28, 1412,    1,  669,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1178, 1061,   32,  215,   32, 1051, 2690, 2607,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  694,  845,  162,   81,   98, 1171,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  199,   61,  920,    9, 1718, 2718,   37, 1496, 2264, 2973, 1764,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2748, 3103, 1863,  513,    1,   37, 1325, 1995,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   20,  197,   28,  419,    1,    1,  155,  570,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433, 1458,   10,   98, 1951,  161,  931,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614, 1832,   28,  166, 2522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1582,  105,    1,   45,    1,  567,  914,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3369, 1583,    1, 3118,    1,    1, 1527,  639,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 2941,   32,    1,  628,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  597,  475,   45,    1, 2145,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  176,  166,  784,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  354,  703, 2216,  585,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310,  616,  410,   98,  395,   67,  423,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1399, 1094, 2446,    1, 1159, 3339,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2963,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3101, 2673,    1,    1, 1061,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1, 3015, 2699,  972,   37, 1980,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  593,   32,  870,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2496, 1976,   32,  437,    1,   32,  455,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  254,    1, 2698,    1, 2663, 1000, 1770,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 1592,    1,   32,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,  951,    1, 2615,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1211,   37,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2708,  446, 3067, 3101, 2625,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1290,  396,   85,  643,   57,  670,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2942,  190,  439, 2826,    1,    9,  872,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228,    1,   98, 2026,  134,   32,  602,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   32,  505,  195,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3060,  513,  514,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2045,    1, 1042,    1,    1, 1253,   98,  800,   60,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  267, 1732,  218,   37, 1121,    1,  332,   37,   71,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2103, 2727,   51,  693,    1,    1,    1,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3215,  477,  637, 2936, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2634,    1, 2957, 1539,    1,    1, 1651, 1597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375, 1982, 1204,  548, 3358,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2137, 2856,  228,   32, 2597,   12,  501, 2060,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,    1,    1,  284, 2746,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  510,   12,    1,  228, 1565,    1, 2028,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  879,  453, 2338,  384,  119, 1653,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  548,  105, 1183,  713,    1, 2533, 1293,  176, 2412,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1, 2615, 1173,    9,  105, 1253,  698,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3096,    1,  531,  759, 1286, 3179,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  204, 1360,  612,    1,  673,   37,  726, 3057, 1749,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1739,   46,  105, 1488, 1090,  763, 3010, 2489,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,    1,   98,    1, 1196,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  402,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2534,    1, 1242,  176,  104,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   49,  482, 2816,  121,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2161,   16, 2494,  872,  203,  460,   12,\n",
      "         2740,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2801,  708,   28, 1718,  361, 2894,    9,    1, 1003,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,   37,  130,  460, 1499,  700,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,   22,    1,  359,   37,    1,    1,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  865,  105,   54,   45, 1633,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962,    1,  456,   39, 3231,  187,  931,   77, 2315,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  195,  441,    1, 2466,    1,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1117,  442,  267, 1889,  605,    1,   32,  871,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1288, 3186,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2164, 2478, 1850, 1327,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,  617,  259, 1397,    1,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 2049,    1,  361, 2349,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  691,   12,    1, 1077,    9,  215,   12,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  732, 1346,   37,  619,  125,  636,  541,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1,    1,  674,   98, 1107,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  709,  457,   36,    1,   37, 1046, 2281,  134,   32,  147,  906,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2467,   45,  365,  163,    1,   12,    1,  342,  644, 1259,    1,\n",
      "          342,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  526,    1, 1256, 1256, 1026,  132,    1,  374,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1353,  138,  187,  334,  168, 2933,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1940,   12,    1,  104,  338,   37,  121,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  801,   37, 2196, 2069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1481,  729, 1762,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1176,  845,    9,  105,    1, 2810,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3129,  901,  873, 1308,  753,   45,   26,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  361,  968,  332,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    7,    1, 1413,    1, 2224,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  333,    1,    1,   32,  466, 1465, 2054,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1862,  297,    1, 1876,    9, 1715,    1,  872,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422, 1684,  810, 3079,  619,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    9,  166, 1925, 1583,    1, 1221,   12, 1298,  818,    1,  176,\n",
      "          424,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,   51, 1188,   37, 1083,  962,   37,  125,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1433,    1, 1459, 1360,  105,    1, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  775,  248,  777, 1013, 1017,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1448, 1749,  251,   37,  151,   28,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1712,    1,  191, 1718, 3004,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 324, 326, 132, 105, 638,   1,   9, 649, 441,  98, 166, 593, 234,\n",
      "         182, 235,   1,   1,   1, 234, 182, 235,   1,   3,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 189, 108,  45, 143,  15,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  968,   37, 2010, 1428,  412,   37, 3107,  250,  187, 2868, 2770,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  919,  163,    1,   12,    1,  909,    1,    1,  962,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  901,   32, 1821,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1687, 1022,    1, 3008,    1,   81,    1,  537,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3188,  162,    1, 2714,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  811,  267,  531,  443, 1532,  593,  388, 2342,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2505, 2050,    9,  104,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,    1,    9, 1841, 1953,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  531, 1929,   32, 2646, 2024,  142,   69, 1103,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,    1,    1,   45, 3358,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  400,    9,  238,   98, 1965,   61, 1239, 1032,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2238,   37,  665,  388,   23, 2072,  657,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2226,    1,  182,    1,  331,    1,  251,    1,   37,  154,   45,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422, 1025,  839,  225,    1,  176,  236,  237,  681,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  506, 1530,    1,  764,  166,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2295, 3117,  872,  420,  367,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1534,   98,  984,    1, 2126,    1,    1,  365,  231,  782,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463, 2170,   37,  335,    1,   45,  453,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3184,    1,  463, 2571,  442,  474,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 3185, 1655, 2052,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2546, 1107, 1108,    6,  278,    9, 2547,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1238,  295,  385, 1225, 1672,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2995,    1,    1,  104,  255,    1,    1,    1,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1971,    1, 1764,   39,    9,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3227,  726,  914, 3201,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  241,    1,  142,  191, 1861,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1007, 1090,  275,  353,  417,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  508,    1,    4,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1821, 2896,  928,  176,  754,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3141, 3009, 1285, 1617,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  294, 1035,   81,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1206,    1, 1579,    1,    1,  170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  590,   37, 2433,  863,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1557, 1025, 2257,   39,   45,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  606, 1515,   74,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548, 1675,   97,    1,  593, 1139, 1434,    1, 2267,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1364,    1, 1313,  176,  636,  418,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,   37,    1,  191, 1981,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,  884,  297,    1, 2699,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  105,    1,    1,  619,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2393,  851, 2361,  104,   95,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22, 2743,   37, 1250,  296,  105, 1202,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  409,   12,   25,  417,   98,  197, 1936,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2171, 2565,    1,   32, 3188,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   49,  321,  138, 1023,  453,    1,  372,    5,  302,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1009, 2682,  848,   12, 1892,  315,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  585,    1,  596, 1793,  361, 2700,  105,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144, 1818,  147,    1, 1844,   79,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2603,    1,    1,    1,  418,   32,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1,  908,  132,  220,  730, 2614,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1056,  487, 2548, 2572,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1296,   28, 2145,  548, 2970, 1388,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  116,    1,   37, 2176,    1,  187,  166, 2227,    1, 1417,    1,\n",
      "         1417,    1, 2369,  166,  261,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2212,  861,  105,    1,    9, 2087,  433,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  236,  237,  288,   37,  698, 1298, 1382,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3376,   32, 2589,  220, 3125,   45, 1428, 3404,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  636,  125, 2070,    1,  443,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994, 2095, 1506,   51,  168,  981,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977,  879, 1965,    1,    1, 2699,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092,  359, 1980,   37, 2155, 1361,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  597, 3053,    1, 1820,   98, 1821, 2057,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321,  105, 2873, 1154, 3015,    1,  388, 2700, 2898,  320,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  861, 2091,    9, 1856,   45,    1, 3389,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2003, 2162, 1950,  418,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2879, 2527,  928,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190, 1658,  259, 1752, 1658, 1084,  841,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  395, 1408, 2091,    1,   98, 1084,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1203, 2400, 1871,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092,   37,  764, 2977, 2155, 1821,  927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,  159,   66, 1782,   32,    1, 2320,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,   12,    1, 1178,  928,  548,  730, 2614, 2494, 1494, 2848,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1236,  829,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1774,   39,    1,    1, 2226,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1383,  384, 1684, 1443,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1138,    1,    1,    1, 1816,  937,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   74,    9,  105,  613,    1, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  228, 1493, 2579,  931,    1, 1764,  140, 3126,  176,  572,\n",
      "           36,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3016, 1935, 1586,   28, 1092, 1876,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  542, 1231,    9,    1,    1,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  190, 1377,  645, 3172,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2698, 1611,   36,   98, 1095,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  597,   20, 1644,  514,   32,  495,  126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2874,   45,  166, 1089, 1090,  378,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2175, 1371,    1,  284,    1,    1,    1, 2885,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1848,  353,  572,  197,  276,  387, 1151,  218,    1,  115,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1039, 1092,   37, 1753, 2232, 1182,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196,    1,  176,  551,  612,  875,    1,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1284, 1159,  224,  825, 1013,  224,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1474,  488,    1,    1, 1232,  403, 1447, 1450,  463,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,    1, 1572,   37,    1,   32,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  675,  156,   71,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  837, 1760, 1925, 1583,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  582,   45,    1,  442,  770,  108,   45,    1,  261,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  517,    1,  331,    1,    1,   46, 1980,   37, 1814,    1,  297,\n",
      "          956,  630,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314, 1692,   82,   51,   52,    1,   87,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056,  649,    1, 3340,   32, 2018,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1419, 2976,    9,  282, 2367, 2695, 3031,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1001,   61,    1, 2445,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 1450,   32, 2597, 2856,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2122, 1929,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,   12,  104,  382,   15,  245,   37,    1,   32, 1352,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3204,    1, 3230, 1388, 1114,  176,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,  197,   28,    1,  159,  245,   98,  157,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1183,    1,   61,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1841,    1, 2134, 1700,  482,   37,  319,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  551, 1340,  677,   60,  696,  159,  504,  528,  242,   69,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  584,    1,  220, 2941,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  472,    1, 1046,   79,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226,  331,  415,  599,  267, 1861,  548, 1857,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2160, 2049, 1625,   37, 2075,   81,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  325,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  376,  156,  570,  105,  581,  199,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  493,  260, 1553, 1812,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  531, 1070,  284,   45, 2343,   12, 2548,   37,  865,   37, 1604,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3238,  361,  730, 2614,   23,    1, 1090,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612, 1408,    1,  207,  259, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1312,  356, 1691, 2708, 3065, 1333,  191,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2321, 1027,  176,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2614,  361, 1340,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1334, 2080, 2810, 2198,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1419, 2183, 3374,  650,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2347,    1,    1,  321,  612, 1838,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3231,    1, 1110,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 1822,   52,    1,   37, 1814, 1815,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  428, 1771, 1635,    1,  187, 2800, 2565,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1932, 1566,    1,  221,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   42,  573,  149,    1,   37,  335,   44,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2158,   45, 2121,    1,  653, 1123,   32, 2016,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1046,    1,   32, 1645,   26,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,  810,   39,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3322,  665, 2110,   98, 2347, 1638,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,  325,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2778, 1980,   37,  498,   98,    1, 1165,  778,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094, 2414, 3006,   32, 2154, 3339, 2731,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  439,   37,  903,    1,  464, 1512, 2156,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  191,  917,   37,    1, 2673,  529,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3178,   12, 1918,  297,  683,   51,  193,   52, 2398,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  497, 1067, 1057,    9, 3358,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  177, 2572,   32, 1656, 2950,   27, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3096,  477, 1086,  202, 2778,    1,   37,    1,  132,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,  532, 1835,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,  170,   37, 1578,   32, 1875, 2706,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  750,  353, 1509,  339,  452,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  435, 3289, 1656,  865,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303, 1394,  458,    1,  187,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  335,    1,   32,  463, 2170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,  251,    1,   37,  105, 1013, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  245,  187,  109,  997,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1293,   98,  103,  176,  715, 3329,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  253, 2518,  105, 1298,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2571, 1223, 1358,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2835,  361, 1094, 1421,  104,    1,  442,  630,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1822,  138,    1,   32, 1662, 2086,  400,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,    1,    1,   37, 2472,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2018,   37, 1918,  297,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1040,  814,   37, 2123,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3158, 2828,  335,   98, 3191,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3232,    1, 1277,  498,   37,   24, 1145,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  338,   98,  570,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2962, 3188,  140, 3212, 1523,  187, 3244,  688, 2807,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 3057, 1512,   51,   23,  411,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  754,  756,   32,    1,  297, 2508,   12, 2235, 2232,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066, 2590,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3359,   39,   37, 1154, 3339, 2271,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  104,  233,  157,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  705, 2693,  105,  792,    1, 1104,  792, 2215,    1,\n",
      "            1,  612,  576,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  375,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1711, 1594,   39,   32,  183,  576,   79,    9, 2573,   12, 3398,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2342, 2988, 1396, 2987, 2762,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1766, 1767,    1,  488,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3342,  321,    1, 2394,  204, 1924,  193,    1,   32, 2282,  722,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  531, 2751,  288,   37,  946, 2108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  669,    1,    1,  369,  365,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3280, 2331,  297,  365, 1788,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,  613,  794,  111, 1107,  525,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   80,    1, 1737,    1,  528, 1251,  122,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  583,  320,  227,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147,  398,   37, 2303,   98,    1,  400,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1047,   37, 1753,  458,   45,  507,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1,    1, 1102,  931,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294, 3207,  396, 1940,   12, 3208,  810, 1385, 2545,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  342,    1,  297,  296,    1,   20,\n",
      "         1527,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,  972,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3187,   37,    1,   37,  386,   12, 3177,  693,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,    1, 2977,  562, 1821, 2190,   12, 1411, 2640,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1973,  565,  105,  888,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  551,    1,  353,  245,   32,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  686,  191,  195,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3226,    1, 3218,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  388,    1,    1, 1117, 1943,  361,  777, 2515,    1,  267, 2425,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374,  475, 1707, 2756,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1654,    7, 2730,  400,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  150, 2102,    1, 1230,  777,  778,  794, 3011,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1536,    9,    1,  131, 1126,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  195,  287, 2134,  304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3010, 1240,   52, 1036,  255,  454,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  698,  330,  892,   37,  194, 1658,    5,  302,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1017, 1592,  973,    9,  388,  104, 1465,  861, 1896,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3335,   98,  386, 2332,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  954,    1,    1,  202,  193,  187,  445,  187,   76,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118,   46,   98,    1, 2024, 1438,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 2342,  829, 2987, 2988,  820,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  776,   32, 1717,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  259, 1091, 1594,   98, 1273,  844,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303,  267,   69,  102,  193, 2537,    9,  954,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1052,  570,    9,  601,  401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3254, 1401,    1, 3329,  191,  786,  548,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  313,  176, 1230,  218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  409,   25,  317, 1595, 1376,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  776,   45, 1791, 2095,  475,    1,   37, 1348,  398,    1,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  964,  267, 1663, 2095,  176, 1604,   32,  121,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 2197, 1218,   37,  322,   79,   54,   45, 1147,  734,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1360,  612,  588,    1,   45,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  708,  219,    1,   32, 1116,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,    1,  832,    1,    1,  297,  395,  347,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1, 1100,    1,  848,   92, 1151,    1,  191,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3281,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649,  382,  700,  852, 2311,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3043, 2751, 2856, 1700,  115,   45, 1537, 2038,   12, 1815, 2237,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1056,  297, 2571, 2162,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1442, 2695, 2796,    1,    1,   12, 1046,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1951,    1,  744, 2364,   98,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   15,  245,  118,   32,  572,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1,  987,  220,  259,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  810,  288,    9,  166, 3135,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1,    1, 1046,    1,  663, 3061,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  506,  116,    1, 2179,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2222,   30, 1677,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2782,  191,    1,    1, 1366,  606,    1,   37,   52,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1953,   32, 1081,  313,   37,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  411, 2208,  891,  176, 2144,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2213,   32, 2148, 2498,    1, 2795,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1841,   45, 1700, 1976, 1530,   32, 1147,  754,  686,  191,  163,\n",
      "            1,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2236, 2908,    9,    1, 2263,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2266,    1,  297,  531,  443,  176,  163,    1,  903,\n",
      "            1,  428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  893, 2192, 2266,    1,    1,   32,  449,    1,  548,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  191,   20, 1749,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2640, 1830,    9, 1539,   37, 1663, 1821, 2190,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,   37,  288,   28,  116,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,   37,    1, 1998,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3327, 1408, 2204,  600,   12,    1, 2926,  389,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2906,  656,  839,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3155,   46,  729, 2317,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  251,   80, 1108, 3011,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  787,  967,  227,    1,   37,   77,    1,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1285,   28,   32, 2305,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  500,    1, 1191,  872,   28,   98,  858,    1,   37,  166,  754,\n",
      "         3011,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3256,  130,    1,  384, 3234,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  211, 2892,  221,   37, 1496,  247, 1569,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1484,    9, 3356, 3357,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1920,  967, 2214,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  379, 1982, 1821, 2190,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1366, 1445, 2740,  321,   52,    1,   63, 2226,  544,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2881,   12,   26, 1039, 1995,  515, 1718,  105, 3078,   28,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3381,  437,  267,  460, 2572,  487, 2924,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1617,  614,    1,  297,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,   42,  573,  149,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1904, 1149,   76,   37,    1, 1895,  787,  399,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1149,  548, 2174,  395,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 1218,  119, 2674,   32,  105, 1559,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2087, 2614,  442,    1, 1854,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2457,    1,    1, 2405,  220, 2990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  579, 1444, 1847,  600,  334,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1194,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  683,    1, 2744,  265,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1268, 2446,   98,  201,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3354, 1065, 1190,   37, 2237,  854, 1411,  339,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  566,  565,  166,    1,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,   25,  439,   28,  187,  479,  155,  739,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151, 1204,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   51, 1598,    1,  493,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1031, 1360,  612,  764, 3103,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2297,  582, 2565,  176, 3190,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1070,  535,   37,   52,    1,   32,    1, 2416, 1450,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2979, 1151,   98, 1171,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220,    1,   32,  913,    1,  166, 2615,  670,   28,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  153,    1,   39,    1, 3201,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1061,   32,    1,  927,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  715, 2404, 1189, 2673, 2108,    1, 1710,   52,  105,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  754,   15,  120,   32,  385,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2546, 1086, 2441,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  716, 3118,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1493, 1990,   45,  121,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1005, 2942,  140,  671,    1,   32,    1,   32, 2890,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  307,   94, 1388,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  619, 1658,    1,  683, 2324,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  260,  273,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1, 1031,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 1919,    1,    1,  915,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2160,   28, 1140,   98, 2834,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1361, 2744,    1,    1,  412,  949,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  125,  308,    1,   25,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  548,    1,  701,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,   51, 1937, 2224,    1, 1232, 1445,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   56, 1656, 2909,    1, 1450, 2856,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12,    1,   45,    1,   32, 1820,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  761,  197,   28,   98, 1220,    9,    7,  229,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3385,  744, 1757,    9,  231,   45, 1189, 2673,  210,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  636,   37,  865,  187, 1214,    1, 2565,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  459,   24,    9,  296, 1497,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2748,    1,  171,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1867, 1761,    1,    1,   32,  584,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  370,  371,    1,  373,    1, 1832,   28,  297,  104,  382,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715,  232, 1562,  104,  448,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  405,   98,  837,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1212,    1,  443, 2775, 1086,    1,    1, 2566, 1976,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  388, 2909,   32,  854,    1,  920, 1530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713, 3168,   32,  925, 2069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1443, 1542,    1,    9, 2708, 1002,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2347,    1,    1,  972,   37, 1306, 1090,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1039,  365,    1,    9,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  446,  267,  770,   45,  487, 1527, 2664, 1976,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  942,  102,  453,  159,  176, 2021,   32,  331,    1, 1300,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  119, 2242, 3133,  854, 3099,  427,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   51,   52,   98,  605,  222, 1176,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3064,  801,  176,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  698,   28,  217,   98, 2255,    1,   92,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2317,    9, 1056, 1867,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3398,  794,  142,   37, 1048,  247, 2225,    1,  865,   37, 2325,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1676, 2173,   76,   37,  804,   98, 1674, 1740,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  524,  525,   15, 1124,  699,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 3160, 1231,  220,    1, 1147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1100, 1000,  454,   37,  860, 1151, 1998,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  195,    1,    1,   32,    1, 2161,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  342,    1, 1906,    1, 2219,  116,  815,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   12,    1, 2918, 2699,  707,    1,  232,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,  26,  61,   1, 656,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 425, 426, 376, 367,  15, 570, 428,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1011,    1,  533,  817,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1875,    1,  357, 2383,  320, 1533,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,  766,    1,    1, 1183,  472,  468,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 1230, 2528,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 1310,   37,   62,    1,  548,    1, 2891,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  393,  359,  562,  125,   32,  138,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1507,    1,  920,    1,   37, 1000,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821,  550,    1,    9, 1657,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1019,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   88,    1, 2572,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  294, 1456,   37,    1,    1,    4,   32,  283,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  497,  903,    1, 1447, 1324, 2385,  612, 2390, 1585,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2543,  538,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1970, 2305,    1,   98, 1602,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2077,    1,  474,  759,  132,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 2707,   46,  288,    9, 1352,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,    1, 2590,    1,  176,  637,   45,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051, 2264, 1937,  284, 1402,  591,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3271,  288,   37, 1468,    1,   32, 2295,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1075,   39,    1,  460,   12,  810,  600, 1488,    1,  920,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  225,  226,  105,  227,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,    1, 3103,  590,    1,   37,    1,  872,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3022,  680, 1260,    1,  267, 2376, 2024,  855,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,    1,  207,  418,    1,  277,  191, 1084,  931,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1828,   37, 1124,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2023, 1619,  957,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  766,   61, 1936,   81, 1628, 1102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2157,    1,    1,   32, 2618,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  498,   37, 1145,  220,  449, 1385,  712,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,    1,  191,   65,  187,  491, 1464,   37, 2111,  787,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3245, 1610,    9, 1517,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2995,    1,    9, 1778, 1273,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 2472, 1178,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1104,  365,  356,   12, 1697,   37,  288,  119,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3254,    1,  967,  915,    1,   98,  825, 2633,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  218,    1,    1,    1,    1,  202, 1356,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2386,  104,   45,    1, 3118, 2751,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878, 1667,  140,  129, 2948, 2015,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1912, 1529,    1,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12, 3137, 2786,    1, 2153, 1248, 1945,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  997,  187,   69,    1,  897,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 3372,    1, 1065, 1190,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  567,  510,    1, 1750,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,   12,  792, 1056,    1,  792, 1999, 1997, 2572,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3219, 1188,    1,   37,   85,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1829, 2922,    1,   10,  606,  227,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  293, 2520, 2521,    9,   10,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1654, 2968,  853,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   12,  714, 2721,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1835,    1, 1273,  259,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1568,    1,  275,  441,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  171,    1, 1037,  275,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  884,  449,  992,   37, 1073,   85, 2650,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  266,    1,   37,  354, 2007,   37,  268,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2877,  108,   45,  340,    1,   98, 3155,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640,  813,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1363,  162,    1,  191,    1,   40, 1917,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310,   25,    1,   98,  119,   69,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2800, 3123, 2827,  176,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,    1,    1,    1, 1942,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  990, 1236,  681,    9,    1,    1,  354,  396,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1398,  612, 1575,   39,   98, 2846,  424,  199,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 1140,    1, 3173,    1, 3282,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2496,   98, 3024,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  982,  672,    1,    4,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  927,   45,    1, 1229,   37,  289,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1412, 2521,    1,  861,  105,  596, 1995,   98,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1206,    1,  112,    1, 1332,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  503, 2297,   32,  422,    1,    1,  839,  297,  749,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187,  940,  361,  655,   45, 2642,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  854, 3170, 1458,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3090,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  571,   37,  166, 2288,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3348,    1,    1, 1645, 1281,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2933, 1778,    1, 2336,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  244,   28,    1,  157,  969,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3276,    1, 3228,  804,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  437, 2677, 1617,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1018,    1, 1355,  486,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3176, 1917,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  611,  162,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1281,  562,  705,   98,  962,   98,  207,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  743,  786,   28,   98,    1, 3303,   32,  166,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2715,   51,  619, 1515,    1,  384,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1352,  382,   15,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  386,  497,  792,  193,  105,  721,   45,  482,  792,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2050,   71,   32,  215,   14,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1000, 1610,    1, 3022, 3024,   55,    1,    1, 1176,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 3165, 1388,  220,  947,   98,  531, 2128,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2006,  583,   32, 3101, 1461,  477,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  744,  105,  365, 1757,    9, 2580, 1108, 1779,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1082, 1850, 1423, 2024, 1896,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  590,    1,  193, 1114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  779,    1, 1907,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,  738,  220, 2860,   98,  903, 1447,  176, 1319,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1530,  384,  854, 2596, 2137,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  477,  456, 1853,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2067, 1488,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1542,   37, 2728, 2229, 2232,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1,    1, 1009,  267, 1386,  321,  590, 1400,    1,    1,\n",
      "         2774,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2843, 1380,  677, 3120,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1484,   60,   12,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1094,  134,  864,    1, 2343,  187, 2095,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2355, 1013,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32, 2597, 1585,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  121,    1,  395,  176,  166,  103,   45,  166, 2601,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  325,    1, 2552,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  743,   12,  862,  992,   85, 2007,   37,  505,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  313,  176,    1, 2264,  220,    1, 1708,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  370,  371,    1,  373,    1, 1832,   28,  297,  104,  382,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2004,    1, 1635,  924,    1, 1268,  395,  756,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   61, 1648,   37,  759,   39,   37, 2707,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3271, 1119, 1675,    1, 3251,   37,  104,    1, 2498,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   37, 1377,  397,    1,  695,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1042,    1,  932, 1980,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,   71,    9,  581,   74,   32,  105, 1559,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  203,    1,  321,  930,   98, 1658,  573,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596,   27, 2597,  947,    1, 2414,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  954,  897,  176,    1,  118, 1952,   67,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537,  446,  952,   37,  439, 2292,   32, 1815,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   98, 2380,  357,  191,  259,    1,  542, 1948, 1875,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2752,    1, 1140,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 1447, 1216,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  121,  288,    9,    1,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  393,    1,  359,  498,   37, 1698,  182,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  202,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  795,    1,    1,    1, 1618,   28,    1,    1,  159,  245,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280,    1,   37, 2107,   32,    1, 2472,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3172, 1090, 1829,  539, 1037,  176, 1037,  275,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2378, 2701,   46, 1980,   37,    1, 3151, 1384,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  506, 2334,    1,    1,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,    1,  608,    1,   32, 1600,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1568,    1,  686,  166, 2041,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  936,  449,  784, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  296,  193,   98,  829,   12,  175,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,  458, 1082,  594, 2064,   37,  860, 1429,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1972,    1, 1281,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  884,   85, 2851, 2852,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  166,  861,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,    1, 1187,  460,  544, 2330,  227,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  294, 2313,    1,    1, 2479,    1, 2505,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,   98,  260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1191,  156,    1, 1251,   45, 1889,  887,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  879, 1841, 1844,   32,  395,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  474,  387, 1647,   32,   46,    1,  960, 1398,  612,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 2962, 3188,    1,  547,    1,  187, 3244,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  284,    1, 1229,    1,   37, 2095,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2592,    1,  166,  777, 2191,  166,  777,   46,   81,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  795,   22,  267, 1949,  365, 2247,  278,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  353,  242,  581,  401,  197,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  104,  358,  580,  987,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777, 2368,   12, 1013,  361,  831,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  691,  863, 2306,  288,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1568,    1,  572,  156,  670,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3138, 2192,    1,  331,  297,  547,  537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  584,    1,    1,    1,  123,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  105, 1656,    1,    1,    1,   37, 1046, 1443,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,    1, 3204, 2963,   32,  581, 1385,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  286,  290,  703,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,    1,  365,  207,  259,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2278,  983,  361,  174,   71,  297,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  815,    1,    1,    1,   37, 1000,  454,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   16,  104, 1658, 1001,    1,  774,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175,  899,    1,    9, 1694,   45,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  647, 1800,   82,  648,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2136,    1, 2676,  288,   37,  907,   32, 1851,  736,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2768, 3228,  576, 1263,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  922, 1990,  729,  915,   98,    1,   12, 3217, 1638,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2249, 1014,  802, 1121,   37,  865,    9, 1228,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2489,  837, 3129,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3241,    1,   98,  333,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176, 1215,    1,  105,  856,  444,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  964,   57, 2678,  548,   36, 3071,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3337,    1, 2843,   12, 3023,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  409,   25,  439,  417,   60,   85,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2415, 3214, 2534,    1, 2493,  562,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1178,  386, 1454, 2878, 1469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1, 1222,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  444,   49, 1734,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2692,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 2024,  132,   61, 2011,   32, 2646,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1417, 2090,  379,  741,   98,  922, 1684, 1090,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1366, 1445,  227,    9,    1,    1,  267,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,  295,   37,   47,   48,   32,  700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2784,   37, 1212,  220,  447,   12,    1,  190,    1,  942,\n",
      "          706,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  716,  487, 3222, 2917,  384,    1, 1638,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2376, 2223, 2525,   37,   52, 2758,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1021, 1343, 1798,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  766,  872,   28,   98,  526, 2186,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230,  288,   37,  345,   28,  220,  340,    7, 2565,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2918, 1380,   98, 2300,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2235,    1, 2704, 1674, 2472,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  236,    1,  176,    1, 1325,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  721, 1360,  612,    1,  214,  220,  148,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 1125,  166, 2391,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 3045,    1,   85,  163,    1,   12,    1, 1583,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1396,    9, 1411, 1778,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,    1,    9,    1,    1,    1, 1856,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,    1,  342,   37, 1174, 2673,   46,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  912,    9, 1211,  639,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2909, 2856,    1,    1,  297,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  224,    1,  156,  554,    1,  361,  332,  636,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  230,    1,  267,  204,  580,  790,  791,   32,  792,    1,  792,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   27,  339, 2284,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   10, 1702,    9, 2532,    1, 1544, 1737,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  544,  227,    1,  726,  105, 2223,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  437, 2946,    1,    1, 1011,  777,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3389,    1, 2887, 1450,   32,  854, 2856,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,   21,  601,  401,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 2767, 1479, 2706, 2232, 1901, 3004,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1668,    1,    9, 2021,  698,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2476, 2160,   28,   98,   74,   45, 1477, 1990,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  435, 2102,    1,   79,  396,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652, 1419,    1, 1718, 2193,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  647,  721,  515,    1,   85,   37,  148,   12,  693,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,   12, 1016, 2660,  132,   37, 1413, 3359,   12, 3057,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2844,   32, 2490,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   54,   37, 1155,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1023, 1204,  949,  288,    9, 1169,  548,  211,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1423, 1249,  463, 2170,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1622,  947,  774, 3094, 2572,   32,  965, 1585,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  794, 2355, 1013,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 422, 476,  37,   1,   1, 176,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 884, 631, 176,   1, 628, 428,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  108,   98,  572,    1,  356,  197, 1470,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  132, 1380,  324,   98,  596, 1267, 2928,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  215, 3102, 2804,  146, 3125,   37,   16,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   51,  907,  453,  427,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  491,   42,   69, 1482,  400,    9,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 2077,  353,    1,  182,  207,  197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[  2, 409,  25,  26, 242,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 102,  45,  69, 720, 528,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  111,    1, 1211,   98,  604,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  743,  884,  786, 1333,  631,  176,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   69, 2865, 1547,    1,    1,   60,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  413,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  398,  908,    1,    1,  394,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,  361, 2615,    1,  166,    1, 1444, 2556,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  639, 1713,  149,  444, 1785, 2044,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   37, 1075,   98,  367,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1597,  191,  199,  421,  361,  829,    1,  342,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1451, 2021,  712,   28,  449, 2318,    1, 2577,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  777, 2168,  631,  103,  861, 2298, 1638,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  800,    4,   93,    1,   85,   60,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2523,   37, 1523,   98,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  694, 2161,  619,  581,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1802,  140,  449, 1674, 3126,  452,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,   37,    1, 2977,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2414, 1056,  176,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1343,   45,  284,    1, 2554,  105,    1,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2905,   37,    1,    1, 1009,    9,  166,  449,  199,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2153, 1539, 1027,   37, 1598,    1,   32, 2170,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3321, 1401, 2807,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  561,   37, 1982, 1942,    9,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  786,  388,   37,  671,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61, 1509,    1, 3242,   90, 2602, 3066,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  150,  267, 1952,  197,   37,   52,  176,  340,  439,\n",
      "           45,  739,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  889,  529,  509,   77,   69,  102,  530, 1714,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2006,  137,  565, 2297,   32,   43,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  561,   76,   37,  470,  207,  259,  261,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1536, 1377,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  580, 1610,  422,  521,  149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  531, 2751,  477,   63,  163,    1,   12,    1, 1260,   98, 3391,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   61, 2310,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  446, 1874,  342,   12, 2362,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  315, 1824,  844,    9, 1273,  618,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  971,   37,  698,    1,  297, 1144,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1419,    1,  659,   45,  777,    1, 1228,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  447,  361,  602,  836,  342,  448,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2449,  730, 1568,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  374,  375,    6,  570,    1,  225, 1308,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1502, 1542,   37, 2192,   28,    1,  721,  808,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3209,    1,  375,  640, 1194, 2907,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  927,  162,    1,  220, 1965, 2918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,  176, 3261,    1, 2322, 1517,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  281,  282,  936, 1064,   32, 1131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 688,   1, 428,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 1821,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596, 2414,   32, 2597,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  965, 1585, 2414,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2236,    1,    9,  581, 1463,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   32, 1259,  220,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147,  379, 1761, 3345,  820, 1056,   45, 2877,   12,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1762,  914,  297,    1, 3158, 1045,  729, 2793,    9, 1545,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  350,    1,  794,    1, 1983, 1536,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1701, 1539,  822, 2731,  951,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962, 3252,  696, 2633,   38, 3260,  105,  354,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 2401,    1,    9,  224,    1,  357,  193,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  771, 1690,  312,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2925, 2962,    1, 1401, 3115,   37, 1194,   73,  404, 1684,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3375,  429,  861,  907,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   80,    1, 1201,    1,   37,    1, 1842,  441,    9, 2229, 1108,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,  590,    1, 2220, 2234,   98,  912,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1928, 2524, 1926, 1927,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2798, 2206,    9,  282, 2367, 2695, 2232,    1, 1370,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,    1,   37, 1708,  186, 2083, 3376,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2878,  588,  807, 1067,   32, 1020,   12,  627,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3186, 2712, 3256,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1468,    1,  845,   63, 1685,  104,   32,    7,  593, 1990,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   49,  952,  822,    1,   32,  104,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2257,   39,   45,  863,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,  852,  288,    9,  105,  410,  698,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  927, 1921,  176, 2918,   12, 1870,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  405,  837,   45,    1,  966,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  447,   61,    1,  187,  166,    1,   32,  557,  540,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  828,  817, 1407, 1696,  187, 1009,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  777,  778,  267, 3381,  437, 2414,  294, 3102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  446,    1,    9,   56,   74,   12,    1,  310, 2579,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2108,    1,   32, 3392,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284, 1925, 1583,   12,  862,    1, 1936,    1, 1704,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  344, 3403,  868, 3343, 1633,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1829, 1510, 2425, 2418,   28, 1883,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3108,    1,  608,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,    1,  971,    1,  479,  573,  408,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2837, 1260,  104, 3036, 1281,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  113,   39,    1,   45,  439,   37,  395, 2108, 3368,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  460,  415, 2385,  612,    1,   12,  199,  951,    1,  694,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2629,  469,   43,   37,  222, 1117, 2208,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   12,  464, 1009, 2770, 2924,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1256,  551, 1256,   37,  151, 1026,    9,    1,  131,   32,  987,\n",
      "            1,  225,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2594,    1,    1,    1, 1821,   95,  940,    1,  928,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1594,  440,    1,  833,  612, 1604,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,  188,   37,  119,  340,  444,   94,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314,   82,  267, 1354,   45,    1,    1, 2007,  906,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1964,   67, 1784,    1, 2100,  220, 2101,    1,  223,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 3235, 3212,    1,  928,  176,  823,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  973,    9,  105, 1116,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  916,   45, 2620,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1623,   45, 3396, 1492,    1, 1796,   36,   32,  395,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1367,  825,  449,   81,   37,   81,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3375, 2462,  863,    9,  740,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  641,  631,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 1348,   37,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,   32, 2107,    9, 3177,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,  968, 2346, 1334,  176,  754,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1163,  197,   28,  419,    1,   98,    1,   92,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,  342,  475,  952,    1,  132,   32,  673,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   22,    1,  359,  474,   32, 1845, 1259,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2267, 2866,   98,  912, 2285,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1821,    1,    1, 2963,    1,   45, 3022,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1676, 2422,  319, 2826,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1013, 1522,    1,  191,    1,   98,  449,   74,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2214,    1,  967,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307, 1564,    1, 1871,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  773, 1332,    1, 1690,  525,   15,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  878, 2458,  361,    1, 1753,  829,    9, 1350,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878,  787,  879,  486,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,   25,  670,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 2514, 1218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2807,  750,    1, 2748,   32, 1445,    1, 1090,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,  830,    1, 1352,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1969,  468,    1,  148,  744, 2462,    9, 2976,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2302,  156,  245,  118,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  777,  778,    9,    1, 2070,   43,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9, 2217,   12, 1277,    1,    1,  187,    1,  431,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3152, 1173,   37,  838,   79, 3268,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2502,  902,  463, 2170,   12,    1,   37,  522,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  297, 3249,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1355,  565,  638,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 3361, 3340,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3342,  353, 1368,   37,  439,   12,    1, 2170,  433, 2263,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  562,    1, 1120,   12,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  104,  358,  162,    1,    9,  876,  612,  209,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3175,    1, 2720,   45,  105,  389,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  932,   71,   98,    1, 1220,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2077,  353,    1,  182,  737,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230, 1401,  104,   44,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2838, 1140,   28,    1,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358, 1841,   37,  619, 1983,  912,   98, 1389,   45, 2162,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3352,  335,  547, 3102,  176,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1625,    9, 2024,   46,  187, 2752, 2751, 1198, 2782,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  104,  573,  639,  475,  108,   45,    1,  629,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2755, 2571, 2657, 1659,  213,   98,  365,  863,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1009,  964, 1625,   37, 1348,  624, 2456,  220,  342,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,  105, 1133,  466,  484,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,    1,  572,  354,   98,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2413,  565,    1, 1556, 1159,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   99, 1761,    1,  187,  365,  475,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3111, 1976,  514,   45,    1, 3361,    1, 1536,   16,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1821, 2190, 3053,   37,  741,  384, 2818,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  827,  274,    1,    1,  191, 2300, 3048, 2923,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  439,   28,  185,  504,   98, 1125,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2284,   45,    1,   54,  190,  665,    1,   98,  395,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  311, 2936, 1258,  424,  914, 1166,  460, 1827,  915,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3116,  922,  437, 1417,  231,    1,  361, 3315,   32, 3055,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    1,  223, 1294,   24,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   40,  612,  361,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,    1,    9,  365,    1, 2696,   12,  317,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2871, 2922, 2781, 1114,   98, 1602, 2539,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  140,    1, 1523,   32,  447,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,    1, 1207,   37,  846,   28,  977,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  733,    1, 1102, 1151, 2456,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1771, 1236, 1099, 1453,    1,    1,    1,  133,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  463, 2170,  726,    1,  497, 1684,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2614, 1673, 2195,    1, 3252,    1,  456,   85,  273,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  199,   98,  105, 1151,  166,    1,    1, 3032,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  353,    1,  572,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  705, 1458, 1838,    1,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465,    1,    1,  166, 1592,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1, 1087,    1,  326, 2440,  384, 2254, 1228,  768,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1,   28,  548,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1488, 2301,  361,    1,    1, 1632,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,  251,  453,   17,  111,    1, 1211,   45,   44,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  112,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 2069,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1327,   12, 3105, 1413,    1,  444,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1288, 1428,  460,  190,  899, 3107, 3366,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  350,    1,  700,  251,    1,  259, 1108,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,    6, 1090, 1667, 1758,  636,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1484,   98, 1123,   37,    1,  166,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  245,  187,   69,  640,  845,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 2087,  433,   21,    1,    1,   37,    4,   29,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  105, 1204,    1,   37,  531, 1086,  220,  105, 2210,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,  105,    1, 1361,   32,  166,  404,    1,  111,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,   37,  930,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2690,  994,    1,  150,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1879,  729, 1059,    1,  166, 1217,  297,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2138, 1567,  300,  942,   37,  593, 1990, 2069,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   26, 1039,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,   45, 2292,    1,  531,    1, 1887,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  585,  583,  756,  757,   12,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654, 1458,  848, 1935, 1017,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  299, 1579, 2977,  673,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1245,   12, 2315, 1045,    1,   37, 1700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,  227,    1,   98,   74,  786,   45,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1,  515,    1, 2017,    1, 1211,    1, 2355,    1, 1013,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1449,  613, 1564,  142,    9,    1,  963,  413,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2226,  606,  105,    1,    1,  202, 2226,  331,  562,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   61, 1884,    9,  863,   32, 1759,  309,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004, 1870,  267,    1,  429,   98,   37, 1658, 2177, 1027,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  650, 2908,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,    1,   12,    1,   32, 3144,  822,  964,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  335,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3188,    1, 3189,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1651, 1973, 2708, 1377,    9,  949,   45, 3340, 1527,  475,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2171, 3134, 3161,  171, 1249, 3166,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1056,  163,    1,   12,    1,    1,  298,   32,  531,    1, 1887,\n",
      "         1056,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835,  361, 1094, 2392,  442,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  187, 1147, 1708,  891,    1,  105, 2596, 2414,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3238,    1,  361,  273, 1625,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2, 294,   1,   1,   1, 166, 671,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   6,   1, 156, 570,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 2261,  220,  365,    1,  279,  861, 1151,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  528,  516,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151, 1739,  458,    1,  129,    9,   59,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1084,    1,   12,  636,  423,    1,  972,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2128, 1397,   32,  531,   37,  686,  119,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,    1, 2266,   98,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 1675,    1,    1,    1,  984,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  455,    1,  297,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  982,   21,  198,   15,   93,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  133,    1,    1, 1457,  437,  267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   45, 1585,   51,   52, 2848,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  721, 1707,  148,   12,  214,  142,  528,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  612,  335, 1183,  326,    1, 2933, 2545,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,   45,  166, 2854,    1,  365,  809,    9,\n",
      "          166,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  198, 2164,  898,   32, 2140,  163,    1,   12,    1,  639,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,    1, 1228,    1,  210,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1965, 2982, 2365,   98,  220,  365, 1799,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790, 2976, 2538,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1528,  361,    1,    1, 2260,    9,  631,    1,    1,   56,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3371,    1, 2531,  446, 1010,    1, 1860,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  303,  954,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,  104,    1,   37,  693, 1994,    1, 1017,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2445,  147,    1,    1,  444,   49,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3323,    1,    1, 2590,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  640,    1, 1401,    1,  191,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   14,   15, 1269,  187,  382, 2054, 1071,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3075,   12,    1, 1638,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1, 2355,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  273,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    9,  885, 1797, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  215,  957, 1484,    9, 1032,  748,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,   13,   45,    1,  164,  165,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3093,    1,   32,  166, 1891,  593,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3167, 3175,  335,  786, 1090,  631,   32,  294,  539, 1131,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2275, 2682,   10,   12,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,  932,    1,  148,   12,  400,    9,   11,  647,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  581,  401,  646,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 2170,  872,   28,   37,  764, 3118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1645, 1836,    1,    1, 1713,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  642,  643,   57,   71,   98,  851, 1220,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1811,  404,  652,    1,   37,  429,  449,    1,   32,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,   72, 1385,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1327,    1, 1060,   45, 2189,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,    1,   28,  949,   45,  572,  156,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  654, 1831,   37,   84,   85,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1182, 2160,   28,   37, 1273, 2798,  719,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  195,   25,  245,  187,    1, 2137,  790,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  213,   37,  151,  849,    9, 1270,  372,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1194,  887,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  249, 2572,   32, 1656, 2950,   32, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  634,  382,  436,   13, 1996,    1,   37,    1, 1612,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  896,    1, 1427,  696,  492,  866,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    9, 3113,    1,  627,   61,  603,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   83,    1,    1,   37, 1066,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1231,  220, 1465,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2443,    1, 2023,   45,    1,  964,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,   60, 1563,    1,  232,  267,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,    1,  114, 3162,   98, 3339,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  227,   37,   52,  917,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  256, 1067,    1, 1089,   37, 2492,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,   37, 1463, 2355, 1013, 2560,   32, 2020,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2826,  439,  220,    1,    1,  591,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  196, 1426,  630,  220, 1786,   98,  176,  551,  612,  613,  132,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,   26, 1039, 1665, 2928,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2459,  580, 1766, 1767,  533,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1, 3018,    9,  829,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  761,  250,  580,    1,  290,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 2308,    1,  154,   37,  907,   32,  142,   37,    1,  914,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2511,  172, 1581,  105,    1,  384,  422,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   10, 1229,   37,   52, 1542,   37,   26,   69, 1482,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612, 1249, 1721,  689,  528,    1,  131,  354,   32,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 3185,  287,  176, 1675,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,  489,   39,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  288,   37,  114,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1734,  191, 1658, 1178, 2778, 1599, 2855,  548,   10, 2275,  736,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,  267, 1281,   98,  453, 3107, 3366,  210,  792, 2189,  792,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,  136,   82,  513,  193,  514,   37,  133,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428, 2104,  891,  927,   45, 3148,  396,   32, 3369,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2133,    1,    1, 2565,    1,  967,  915,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  657, 2182,    1, 1537,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  750,    1,  460,  441, 1505, 2461,  437,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1583,    1,    1,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3177,    1,  168,   37,  443, 1763,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2707, 1579,    1,   45,    1, 2690,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965, 2550,    1,   39,  459,   45,  238,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  742,  967,    1,  247,   48,    1,    1, 1748,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727, 2239,   98,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  668,  293, 1396,  166,  116,   32, 2086, 1523,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596,   32, 2597, 1396, 1190,    1, 1056, 2572,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  963,  750, 1190,    1,   37, 1186,  297,    1, 2949,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,  443,    1,    1,   12,  163,    1,  903,    1,    1,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  166,    1,   61, 1415,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  487,  626,    1,    1,  439,  822, 2096,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1338,   45,  987, 2572,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   28,   37, 2379,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1527,  353,  197,    1,  159,  720,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   76,   37,  423, 1184,  347,  892,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,    1, 2863,  872,   98, 1446,  861,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1326,    1,   61,  219, 1656,   45,  166,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3333,    1,    1,   45,  105, 1833,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2292,   37,  554, 3128,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2535,   98,  997,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006, 2035, 1757,   37, 2856,  786, 3102,  191,   56, 2074,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  424, 1981,   12, 1283,   98,  844,    1,  538,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,    1,   81, 3118, 1011, 1527,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  190, 3301,  619,  166, 2904,  548, 3239,  354,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203,  777, 2436,  321,    1, 1013, 1522,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2120,    1,   32,  104,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118, 1527, 1149,    1, 1010, 2292,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1334,   45, 3026,    9, 3264,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   79, 1515,   81,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2942,    1,  315, 2003, 1437,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 3146, 1484,    9,    1, 2129,   45,  810, 1407, 1414,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1414,   92, 1648,   37, 2199, 3118,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  458,    1,  453,  475,  822,  655,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2741,  140,  593, 1990,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2843, 2523,    1, 2017,  384, 2206,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401, 3260,    1, 2522, 2260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,   42, 2254,   12, 2255,  149,    9,   59,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,  224,  829,  443,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3126,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3213,    1,  220,  297,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3238,   12,    1, 3288,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1822,    1,  166,  365,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1181,    1,  848, 1421,    1,  768,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  447,  361,  121,  582,    9, 2069,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  104,  358, 1670,  591,  384,  474, 1495,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  782, 2249,   69,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   37,  129,    1,  361,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 1738,    1,    1,  636,  338,   37,    1,    1,    1,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   45,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1763,   12,  913,   37,  151,  654,  124,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2971,    1,  193,    1,    1, 1116, 2896,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  633,    1,   93,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1260,    1,   28,    1,    1,  207,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2,  25, 670, 187,  69, 407,  37, 119, 845,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1,   1,   1,  12, 674,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1619,  458, 2001,   98,  395,  945,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  476, 2383,   98,   69,    9, 1011,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3106,    1,  105,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213, 1086, 3335,  443,   45, 1886,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3001, 1991,   37,  877, 2500,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,  207,    9, 2501,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1018, 1158,    1,  105,   74,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2710, 2751,    1, 2073, 2504,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   32, 1228,  293,    1, 2293,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3206,  698, 1121,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,   1,  83,  32,   1, 149,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 190,   1, 973, 453,   1,   1,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3194, 3195, 1602, 2305, 3284,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,    1,  599,  260,   98, 1189, 2673, 1816,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2546, 1310,   37, 1331, 1158,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1, 1823,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  167,  240,    1, 2072,  166,  236,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  153,    1, 3206,    1, 2138,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  215, 1603,  765,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1761,    1, 2195,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,  155,  737,  983,  837,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2944, 1760,    1,  129,    1,  105,  223,  629,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1678, 1999, 2491,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1165, 1686,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  140,   72,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1366,  705,   55,   37,  288,  105, 1844,  837,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  361,    1,  875,  400,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1415, 1033,    1,   91,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  665, 1019, 1183,    1,    1,   32,  453,  913,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  582,   37,  531,   37, 1211, 3102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2672, 1670,   37, 1260, 3161,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,  531,  232, 1333, 1530,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  398,  261,   32,    1, 2171,   43,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2137,   32, 2707,    1,  249,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766,  936, 1230, 1542, 2627, 2543, 1027,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  882,  603,   37, 1155,    1, 1651, 1597,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2427,   37,    1, 1461,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3190,  361, 2748,    1,  449, 3278,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1228,  850,  166,    1,   98, 3002,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2335,   39,   45, 2954,  774, 1167, 3243,   61,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2917,  384,    1, 1638,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  345,   37, 2267,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   50,  891,    1,   54, 1126, 1299,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2652,  349,   45,    1,    1,  624,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220, 1530,    1,  510,    1,   79, 2732,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,  484, 2094,  273,  754,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1, 1401, 1364, 1365,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2379,    1, 2213, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,   37, 1551,   28,  182,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3132, 1247, 1183, 1333,   37, 1330, 1517,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1997,    1,   37, 1645,  611,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,  267, 2510, 1675,   37,  714,   32,  455,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147, 2924, 2625, 2597, 3392,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,    1,    1,  661,   98,  430,  109,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,  515,  562,   37, 1361, 2355, 2750,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3142,  712,   28, 1144,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,    1,  384,  422,    1, 1629,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  316,  317, 1458,  678, 2275,    9, 1009,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   51,    1, 1411, 2579,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,  460,  105,   74,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3181,  729,   98, 1434,  548, 1545, 2250,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3199,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2,  49,   1, 453, 856,   9,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   9, 861,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2620,    1,   39, 2882, 2018,  427,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  599,  220,  247,    1,  808,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1531,   12,  365, 2441,  606, 1230,    1,  190, 1697,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1554, 1443,    1,   37, 2935, 3077, 3126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   69, 1360,  612,    1,  163,    1,   12,    1, 1437,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1951,  171,    1,    1,   37,  856,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  176,    1,  171,    1,  122, 1192,  297,  105,    1, 2800, 2671,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485,  872, 2145,   37, 1343, 2198,  542,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  615,    1,    1,   17,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,  162,  562,   37,  588, 1983,  351,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3141, 1090, 1829, 2295,  176,  718,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2476,  726,  671,  176,  593, 2501, 1675,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,   32,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,  105,    1, 2616,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1686,   32,    1, 1417,   12,  245, 1979,  857,   32,  354,   37,\n",
      "         3259,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  258,  700,   32, 1259,   37, 1594,    1,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2106, 1396,  885,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  251,  597,    1, 3289, 3139,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  487, 3160, 1231,  220,    1, 1147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  225,  338,   98,  275, 1278,  122,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2565,    1,  928,   32, 1656, 2291,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1161,  113,   63,  863,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  547, 3361,  254, 2572,   32, 3391,    1, 2235,    1, 3102,   12,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1013, 1522,  251,    1,   37, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 1774,   39,  340,  439, 1456, 2168,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3206,  147,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  662,   61,    1,   32, 3155,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,   60,   12,  276,   61,  193, 1724, 1389,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3204, 1564, 2315,  865,  176, 3329, 1990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2161,  190, 1343,    9,  671,  548,    1,\n",
      "          602,   32, 1600,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2213, 2586,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800, 1178,  163, 1292, 1550,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  297,    1, 2464,  267,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183, 1272,    1,    1,  763, 2112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  848, 1566, 1234, 1876,   37,    1, 1230,  542,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3259, 1025,    1,  268,  442,    9, 2967,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  978,  769,  504,    1, 1572,  191,  735,   25,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,   24,   37,   47,   95,    1,   37,  395,    1,  295,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2345, 1123,  894,   18,   85, 2177,   98, 3283, 2292,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  491,    1,  191, 1625,    9,    1, 1279,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3387,  744,   79, 2909, 1316, 2468,    1,  176,  177,  583,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1046,   28,   37, 3315,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1603, 1170,    1,  528, 1481, 1349,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2071, 1935, 3016, 1935, 2636,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2494,   45, 1502,   32,  593,  103,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1170, 1008,    1,   82,    1,  159, 1253,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2197,  787,    1,    1,    1,   98, 1718,  221,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 2962,    1,    1,  914,  845,  187,  902,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,  378,  191, 2083, 1900,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1821, 2190, 2640,  967,  905, 1011,  109,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1087,   37, 1155, 1227,  269,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2529, 2565,  321,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  199,  421,  361, 1200, 2000,  142,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282,  103,    1,    1, 1426,    1,    1,  401, 3179,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   98, 1352, 1194,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,  103, 3233,   37, 1838, 2872,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,  499, 2747,  166,    1, 3260,   64,   81,   37,  335,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2498, 2701,  317,   61,  105,  227, 2810,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2206,    1,  902,  872,  420, 1169,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3326,   39,   37, 2394, 2080, 2771,  590,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2729, 3108,    1,  562,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1389,   45, 2162,    1,    1,  267, 3358,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  972,   37,  726,    1,  890,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,   37,  877,  769,  220,    1,  226, 1017,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2327, 1479,  922, 1123,  868,   39,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,  338,  187,  102,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  902, 1421,    1,   37,   24,  881,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671, 1078, 1654,  104,  142,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3128, 2770,  531,  187,    1,  614,   98,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878, 1458,  170,   45,  633,  978, 1731,  315,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1409,  790,    1,   45,    1,  230,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  593,   12,  553, 1222,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1889,  605,   28,  419,   32, 1332,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  537,    1,   63,    1,    1,   61,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,  365,  769,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  987,  507, 1353,   37,  878,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,   12,    1,   28,  365, 1230,  483,  124, 1412, 2945,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1185, 2887,    1, 1380, 3298,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718, 2146, 1967,  884,   98,  293,    1, 2973, 1764,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  220, 2474,    1, 2812,  892,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,   36, 1950,  418,   37,  388,  763,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   64, 2712,    1,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3029,    1,  548, 1821, 1747,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  256,    1,   37,  104, 1541,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 2673, 1063,  475,  476,    1,   37,   18, 1805,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  213,   37,    1,  636,  399,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1231,  220, 1995,  444, 3161, 2280,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2755, 2490,  167,   52,    1,    9,    1,   32, 1033,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1363,  200,  845,  846,  207, 1085,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1485, 3222,    1, 3275,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2500,  663,  652,   61,    7,   37, 2707,  342,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,  908,  596, 1793, 3037,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2965, 3021,  967,    1, 2895,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2504,  446,  108,   45,  388, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965,  853,  782,    1,   37, 1728,  323,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  593, 2352, 2178, 1578,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,   12,  446,  267, 2024,  220,  854,    1,   98, 1815,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  215,   12, 1861,    1,   37,    1,  531,  443, 1530,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964,  744,    1,    1,  176, 1694,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  548,    1,  938, 1282,    1,  819,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   39,  220,  166, 1691,  176, 1783,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2053, 2055, 1253,    1,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1354, 2556, 3384, 2644, 1159,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2302, 1360,  612,  907,  236, 1022,    1,  689,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 1567, 3328,    1, 1159,  915,   45, 3308, 1990,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   36, 1167,    1,    1,   37, 2534, 1205,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75, 1579,  196,   12,  176,  612,  613,  142,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  539,  458,  787,    1,   79,  548, 2137,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,  163,    1,   12,    1, 3148,    1,   51,  583,   46,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1147,  863, 2593,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2141,  229,   79, 1492, 1638,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  590,    1,    1,  415,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1292, 1277,    1,    1,  171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  759, 2707,  114, 1295,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  542,  187,  445,   37, 1096,  187, 2308,    9, 2811,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1117,  741, 2718,   38,  297, 1228,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  867, 1236, 2168, 1167, 2610,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1757,  424,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358, 1426,   95,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  664,   98,  302,   37,  698,  365, 2824, 2722,\n",
      "         3074, 1215,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   45,  453,  365, 1277,   45, 3129,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2265, 2224, 2591,   37, 2035, 1009,   12, 2113,   32,  756,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,   32,  365,  613, 1597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1147,    1, 2249,    1,  267, 1428, 2673,  639,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537, 2024,  221,    1,  753,    9, 1815, 2024,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1231,  220, 1300,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2841,  719,  104, 1984,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1860,    1,  890,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1564,  714,   98, 2158,   45, 2121, 2661,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3188,   37, 1046, 1531,    1,    1,   12,  119,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 3348, 2153,    1,   98, 2409,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  105, 1920, 2202,    9,  756,   32, 1785, 2044, 1160,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3218,    1, 2475,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051,   37, 1021, 1537,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2384, 1106,  844,  116,  361,  535, 1863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1087,   37,   47,    1,   12,    1, 1605,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3233,   77,    1, 1425,    9, 1056,  388,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,    1,  191, 1230,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2837,  335, 1994,  133,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2869, 2928,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2493,  395,   12,    1,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1092, 1458, 3016, 1935,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  737,  156,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   26, 1039, 2348,    1, 1475,  408,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3252, 1024, 1713,    1,   32,    1,  631,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  104,    1,  395,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  515, 2707,  501, 1125,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  582,   45,  463, 2571,    1,  700, 1231,  220, 2673,    1,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123,    1, 1066,   98, 2858,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1,  166,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,  361,    1,  973,   81, 1515,  915, 1651,  668, 1705,   37,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  506, 1718,  166,    1,   39, 1221,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  475,  190,  631,  502, 1296,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2974,  140,   59, 2695, 2223,  220, 1539,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2373, 1656,    1, 1230,    1, 3011,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,    1,  361,    1, 1515,  454,   37, 2522,  631,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,  949,  365, 1778, 2367,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  352,  267,    1,   51,  606, 1846, 1467,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1375,   22,  353,  354,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  590, 2764, 2765,   38,   32, 3393, 3389,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  792,  104,  954,   93,   37, 1121,   85, 1411,  356,  792,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 1173,  760,  453,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885,    1, 3371,   37,  943,  548,  854, 2018,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  455, 2176,    1, 2547,  191,  538,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,    1, 1998,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1704,  166,  116,   61,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2546,  111,    1,    1, 1158,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2275, 1396,   10,  996, 1563,  187,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,    9,  186,   37,  439, 1345,   32, 2646,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1157, 2785,  686,    1,    1, 3121,  431,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1377, 1668, 1281,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3369, 2331,   32,    1,  166, 1428,  861, 1906,   45, 1647,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1487,  794,  449,   45,  792, 1107, 2008,  792,    9,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3190,    1, 3194, 3195,  694,  361, 1923,  171, 1641, 2467, 2675,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388, 3307,    1,  885, 3229, 1144,    9,    1, 2321,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,    1, 2206, 2989,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3287,    1,    1, 1343, 1468,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  596, 1151,   15, 1036,    9, 1133, 1215,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151,  914,   98, 2378,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3177, 2753,    1,   32,    1,  714,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   66,   79,  316,  171,  540,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2130,  155,  997,    9, 2152,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885,    1,    1, 1310,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777,   37,  619, 3028,  861, 1541,    9,   59,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  477, 2414, 3361,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2615, 2872,   37,    1,  631,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  818,  157,    1,    9,  773,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1548, 1203,    1, 1975,  361,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  590, 1400, 3158,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  709,  104,    1,   37,  927,  273,  947,    1,  873, 1939,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1900,  907,   37, 2000,  651, 1031,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3059,  103, 2672,    1,  726,    1,  463, 1684,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1210, 1771,  741,  231,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1245,  429,   79, 3206,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1796,  147, 1800, 2099,   37, 2199,    1,   45,    1, 2671,\n",
      "            1, 3139,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2615,  130,  365,    1, 1178,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  403, 1447,    1, 1260,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066, 2693,    1,   98,  166,  207,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2451, 1635, 1583,   12,    1,  303,  187,  365,    1,  940,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,    9,    1, 1209,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2161,   12, 3096,  792,    1,  228,  792, 2555, 1674,  671,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,   52,    1,  191,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2890, 2826,  455,    1, 3077, 3126,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  155,  102,   98,    1,    1,  440,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1861,  952,   37,    1,  593,    1,   98, 2170,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741,   37,  168, 1698, 1565,  444, 2846,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2672, 2415,    1,  267,  204, 2233, 1306,   37, 2119,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1534,   45,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2546,  733,  152,    1,    1, 1086, 2610,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,    1, 1213, 1231,   32,    1,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  120,  187,   69,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1929,  721,  387,  593,  954,    1, 1232,   69,  102, 1334,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1215,  676,   37,   52,    1,   32,    1, 2293, 1851,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   61,   81,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  420, 1528,   27,  132,   98, 1405, 2039,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  538,  582, 2190,  170,  315, 2030,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  584,    1,  187,  510, 2344,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,   45,    1,   98, 1685,    1,    1,\n",
      "          928,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  395, 1137,   32,    1,    1,  884,    1,  671,    9, 1194,   73,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2807,  665,    1,   98, 1987,  420,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  725,   32,  105,    1,   45, 1017,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1084,    1,   37, 2123,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1497, 2286,   37,   77,    1,  361,  674, 1515, 1623,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2888,  640,  878, 1688,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1855,    1,    9,  104,  700, 2572,   32, 3360,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974,   37, 2286,    9,   59,    1, 2695, 2223,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,  812, 1194, 1856,   45, 3081,   45, 1833,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2620,    1, 1343,  176, 2957,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  215,    1, 1046, 1405, 2251,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  629,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  657,  835, 1151,    1,  384, 1087,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,  361, 2997,   32,  166,  645, 3028, 2995,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  449, 1068,    1,  155,  570,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,  338,   37,  339,  340,  951, 1547,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1555,    9,  166, 2491,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2862,  729,    1,  187, 1033,    1,   91, 2405,  907,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160,  102, 2084, 1253,  452,   51,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  511, 1287,  608,   12,    1, 2926,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  606, 1857, 2283,    1,   51, 1188,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3168,  140,  449,  427,  176,  590,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,    6,  367,  570,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 2196,  841,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1567, 2708, 1833,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  730, 2614, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2497,  256,   37,   97,   98,  375,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1236,  829,  297, 2229,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1426, 1567,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,  134,    1,   32, 2459,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1654,    1,    1,   42,    9, 3077,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,   25,   71,    1, 1572,  191, 1017,  441, 1162, 1226,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   98,    1,  204,   12, 2056,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3176,    1,  548, 2712,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,   12,  241,  698,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  114, 1159,  103, 1056, 1669,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  107,  386,   98,    1,  636,  837,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1108, 2054,   93, 1071,   37,  105,  340,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1007,    1,  105,    1,    1,    1,   37, 2035, 2074,   37,  470,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  545,   37,  398,  576, 2349,   37,  611,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,  726,  916,   37,    1,  957,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2692,  820,  411,  202,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1321,  157, 1876,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2578, 1408,    1,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3198, 2590, 2337,    1,    1, 3090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  882,    1, 1181, 2274,   98,    1, 1017,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766,  967,  183,  315,    9,  105,  803, 1027,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  105,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2103, 2727,  565,    1, 2083,  770,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2710,    1,  722,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,  688,  931,    1,  335,    1, 2522,  631,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1227, 1441, 1100,   12, 2381, 1331, 2019,  469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  230,  207,  994,    1,  150,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2503, 2494,  872,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2514,  105, 1989, 1990, 2250,   32, 1739,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2868,  859,  764,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,    1,   50,    9,    1,  131,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  190,  385,   52,  227,    9,   25,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  228,  142, 2458,  877,    1,   37,  219, 1674,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1128,  936,  453,  365,  260,   45,    1,  327,  361, 1901,    9,\n",
      "            1, 2695,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409, 1285,    1, 2094, 2691,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 1353,    1, 1699,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  297,  105,  365,    1,   32,  365, 1788,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 425, 426,  12,  86,   1,  15,  28,   1, 118,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   9, 105, 754,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,    1, 2071, 1331, 1151,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3140,   26,   37,    1,  220,  163,    1,   12,    1,   98,  531,\n",
      "         2868,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 305, 120,   1, 753,   9,  65,  67,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  81,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2018,  361,  854,  429,   46,   37,    1, 2673,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   26,  417,   32,    1,  605,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  171,  797,  286,  574, 1536, 1018, 1738,   67,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1384,  218,    1,  160, 1161,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,  361,  166, 2463,   45, 2798,  414, 1416, 3031,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2384, 1230, 2528,    1, 1412, 1510,  288,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2045,   69,  868,  365,  119,   98,  109,  997,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2264, 1046,  365, 2026, 2429,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1583,  267, 1417,    1, 2226,    1,  105,    1,    1,  388, 3361,\n",
      "          763,  460,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  615,    1,   37,  777,    1, 2165,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 2860, 1533, 1979,   98,  734,  591,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  506,   51,  764,  860, 2688, 1356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  603,  760,  166, 2196, 1357,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2546,   37,  693,    1, 1107,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3359,   12, 2129,  469,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  676, 1974, 1056,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    9,    1,    1,    1,  986,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  882, 2182,  798,   37,    1, 2545,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2076,   72,   45,  103,  327, 2718, 2626,   32,  547,  537,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192, 2158,  162,    1,  187, 1537,    1,    1, 2177,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   36,  433, 1242, 2928,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  839, 2077,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1622,  474, 1321,  477, 1665,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,  166, 2080, 2771,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1149, 1046,    1,    1,  187,  295,  588,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,  103, 1132,   32,    1, 1215,  619,  311,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  224, 2094, 1013, 1017,   37,  166, 2355,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861, 2932,  774, 2987, 2693, 1954,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  107, 2109,   69,  568,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2323,    1, 1095,   12, 2464, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  671, 1078, 1654, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783,    1,  829, 2797,    9,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  488,    1,   37, 1598,  229,   32, 1123,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1,    1, 2503,  590,    1,  584,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  645,  395, 2003, 1585, 2414,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  261, 1237, 1412,  823,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1445, 1421, 1836,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  315,  395,  250,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3316,    1,   37,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1983,    1, 1484,    9,  105,  365,  195, 1063,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,  387,  244,  120,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1, 1126,  636, 2320,  422,  432,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  439,  242,   98,  383,   69,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  884,   98, 1230,  220,  365, 2177,  988,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  314,   37, 1504,   82,    1, 2013,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  650,  315, 1296,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3351,    1, 2493,    1,    1,    9, 1033,   91, 2396,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2321, 2941, 1625,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1123,  203,   37, 1075,  166,  593, 2522,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  732,  733,   35,   48,   37,  138,  734,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    9,  119, 1524,  199,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3251,   79,   37,  316,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2826, 2942,   32,  671, 1882,    1, 3185,    1,    1,   98,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  381,  162,  119,  599,    9,  574,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  387,    1,    1, 1102, 1151, 1220,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1635, 1087,    1,   37,   47, 1228,    1, 1108,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1479,  922, 1123,  550,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2883, 2838,  186,    9, 2024,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2571,  474,   37,    1,  764, 2556, 1421,  176, 1964, 2396,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  324,  267,  460,  833,  612,  469,   37,  114,  326,   50, 1149,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  113,  700,  548,  183,  529,   25, 2250,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,    1,  645,  148,  693,    1,  267,  253,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,   85, 1270,  105,   60,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1127,   12,  207,  197,  418,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,  645,  395,   36, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  572,  207,   28,    1,  669,   34, 1470,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2526, 3181,    1, 3306, 2889,  257,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  967,  460, 2626, 2204,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3343, 3403, 2414, 3065,    1,    1,   32, 1260, 1167, 2766, 1130,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   66,  699,  417,  503,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1773,   37, 1403, 1107,    1, 1089,   37, 2510, 1090, 2402,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  819, 2785,  166,    1,    1,    1,  116,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2561,    1, 1056, 1612, 1969,  286,  287,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  721,  515,    1,   85,   37,  148,   12,  693, 3004,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612, 1096,    1,    1, 1724,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118, 2751,  774, 2024,   46, 1961,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1996, 1211,    1, 2043,    9,    1,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1514,  221,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3103,  631,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  381,   12,  455, 1831,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  463,    1,    1, 2107,   61,    1,  680,  105, 2849,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,    1,  832,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2995, 2026, 2762,  167, 2904, 2264,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1528,  162,   72,   73,  916,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  193, 2980,    1,    1,  267, 2425,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1702,    9,  388,  996,  652,   32, 3388,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3204,    1,   32, 2304,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  617,  259,  844,   61, 2175,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1570, 2384,  645,  659,   45, 2473, 2367,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  754,   15,  276,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,   91,  498,   98,  864, 3146,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707,   12, 2147,   32, 2597,    1,  716,   98, 1887,   45,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,    1,  104,  193,   37, 1237, 2342,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  397,  123,   37,  522,  444,  104,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3377,   12, 1841,    1,  548, 2772, 1089,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  756,  757,    6,    4,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2884,    9,  365,   82,  891,  187,  711,   12,    1,    1,  992,\n",
      "           85,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  314,  267,  927,   51,  583,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  475,  162,  104, 1943,  389,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1326,    1,  744,   28,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,    1,   98, 3118,  909,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1087, 1774,   39,    1,  340,    1,  327,   32,  395,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1841,  387,  105, 1665,   32, 1239,  301,  674,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1258,  104,    1,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103,    1,  162,  653,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3052,  588, 3021,   12,  671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3207, 1408, 1674,  671,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158, 2744, 2102,  942,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2672, 1980,   37,   77,   28,  220, 3318,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051,   37,  151,  552,    1,    9,  600,  331,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375, 1079, 1094,   37, 1418,   63,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3363,   66, 2315, 3343, 2241,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779,    1,   39,  547,  288,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1987, 2716,  361, 3204,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   37,    1, 1450,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2175,   32,  176,  612, 1273, 1704,  179,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885, 1798,    9, 2843,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   12, 1938, 2607,  297,  166,  116,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1818,  147, 2151, 3026,   45,    1,    1, 1178,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2914, 1362, 1480, 2873,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1792,    1,  777,  778,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  885,  838, 2994, 1013, 2549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1013, 1522, 1299,  116,    1, 1804,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  183,    5,  315,    1,  183,    5,  762,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390,  587,  360, 1746,  469,    1,  389,    6,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  393,  475,  108, 1167,  467,   61, 1610,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3038, 1388,   32,  557,  540,  187, 3405,  952, 2024,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2266, 1082,  183, 1124,   32, 2924,    9, 3118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  468, 1362,  251,  365, 1273,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1021, 2139,  483,   37, 1096,    9, 3369, 2292,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1405,  400, 2173,   19,    9,  105, 2210,  776,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1858,  361,    1,   45,  457, 2328,  851, 2331,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  919,  983,  837,    9,  215,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  738,    1,    1,  251,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  464,    1,    1,    1, 1647,  220,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  365, 3022,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1, 1363, 2274,   98, 1273, 1108,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  328, 1528,    1,  197,   28,  419,    1,  159,   71,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,  227,  550,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3069, 2924,    1,    1, 2263,    1,  443, 2938,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2148, 3161, 1710,   52,  562,  220,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2102,    1,    1, 2441,  791,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647, 2384, 1876,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1693, 2308,    1,  535,  548, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1309, 1009,    1,   39,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1676,    1, 2361,   95,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  763, 3361, 2572,   32,  608, 1056, 1890,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  365,    1, 1831,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  134, 1443,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  500,   82,  347,  268,    1,  306, 2429,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  842,  353,  198,   71,   32,  244,    1, 1862,  600,   15,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,    1,   79,  734,  361, 1573,  220,   69,  102,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  488,   69,  532,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1633,   37,  151,    1,   12,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2083, 1470,    1, 2266,  199,   37,  168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  597, 1405,    1,   37,    1,  176,  776,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  755,  315,  365,  777, 2995,  551,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1246, 2853,   28,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   32,  105,  129, 2578,    1,  166, 1140,   45,  166, 1264,   61,\n",
      "          460,    1,    1, 1160,    1,  150,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1752,  593,   12, 2084, 1448,  669,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  107, 1542,   37,  498,  568,  125,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1237, 1658, 1117, 1525,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1656,    1,  321, 1844, 1708,  378,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2101,   45, 3151, 2308,   32,   91,  640,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  306,    1,  150,    1,  829, 1753,  923,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2980, 2693,  640, 2894,  618,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2, 328,  82,   1,   1,  37, 271,  28, 669,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 474,   1, 960, 729,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1315,  105,    1, 1125,    1,  787,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,  571,   37,  389, 2337, 2749,  565,   39,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3112, 1380, 1545,   98, 2041,   37, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   12,  225,  884,   79,  548, 1858,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  632,    1,  114, 2414,  176,  177,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1,  342, 1388,  297, 1145,   45, 2673, 1806,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3161,   12,    1, 2087,  140,    1, 1624,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,   12,   83,   37, 1910,  669,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3172, 1090, 1829, 3161,  171,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3376, 3345, 1220, 1407, 2128, 2271,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2376, 2223, 2525,   37,   52, 2758,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  437,  952, 1377,   45,    1,  484,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3118, 2024,   46,    1, 2100, 1010,    1,    1,  297,  861,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1233, 2022, 1380,  440, 2954,   98,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2685, 1421, 3269,    9,  331,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1384,    1,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,    1,  150,    1, 2117,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  614,    1,   37,    1,  176, 2957,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1484,    9, 3339,  469, 1743,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2391,   61,  166, 2010,    1,  267, 2977,   12, 3054,  872,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,  361, 3276,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2042,    1,  191, 1277,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2112, 2289, 1924,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3348, 3382, 2556,   32,  104,   37,   52, 1231,   32, 1186,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3207,  321,   77, 1674,  810, 1385,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2244,   25,   26,  417,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,  183,    1, 1628,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,   82,   37,   84,   85,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1988,   45, 1185, 2392,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2827,   32, 2028,  865,  754,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158,   37,  138,  158,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2784,   37,  365, 1546, 1133,    9,  403, 1739,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  433,  517,    1,  405,    1,  552,    1,  650,  812,    1, 2104,\n",
      "           12,    1,   45,  247,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  409,   25,   26,  417,   98,   69,  120,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051,   96,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  915, 1140,    9,  615,   37,  142,   98,  224,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,  952, 1650,   98,    1,    1,    1,    1,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  484, 2644,  191, 3380,   98, 1583,  475,  317, 3354,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  755,   61, 1023,  105,  131, 2398,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  408, 1285,   28,   32,   72,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3128,  531, 1822, 1192,  248, 1386,    1, 1294,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1323, 1708, 1464,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,  267, 3107,    1,  959, 1864,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  929,    1, 1610,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   94,  418,   37,  365,  119,  845,    1, 1714,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  166, 3278,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1093,  574,   61,    1,  361, 2145,   37,  138,  962,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302,    1,  993,  580, 2353, 1623,   32,  233,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  375,  952,    1,    1,  104, 2489,  208,   32, 3134,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2844,   32, 2003, 2291,   32,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1019,    1, 2952,   32,  395,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  716,  120,   32, 1074, 1450,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1108,    9,    1, 3025,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967, 3358, 1983,  912,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  691,   12, 1481,  387,  792, 2312,  123,  792,  741,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3303, 1564,    1, 1048,    9, 1361,  787,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  297, 3043,  864, 2390,  778,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  747,  353,  417,  156,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1465, 1151,    9, 2979,   27, 1160,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1625,   32, 1094,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094, 2864, 2586,   45,  449,  671, 3126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,  217,  697,    9,  197, 1424,    1,  202,  729, 1807, 1427,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3272,  166, 2498,   37,  726,    1, 1575,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1043,  418,  191,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2658, 2269, 2424, 1583,    1, 1463,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1092, 1701,    1,  766,   12, 3016, 1935, 2146,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2487,  144,  145,    1,    1,   37, 1638,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  525,  884, 2407,  202,  193,   45,  453,  248,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  108, 3101,    1, 1240, 2286,   37,    1, 3359,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2510,  270,   30, 1300,  476, 2613,   37, 1343, 1089, 1675, 1773,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1013, 1522,    1, 1381,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  846,  361,    1,   32,  105, 2355, 1907,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1326,  868,  853,  538,  802,  220, 1443, 1122,    1, 1170,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   28,    9, 2479,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2178,  650, 2770,  778,   45,    1, 2299,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  967,    1,   37, 1496,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 2036,  184, 1940,   12,    1,   37,  798, 2507, 1427,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233, 2794, 3380,   37,  429,    1,  756,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2603, 1013, 1522,  256,    1, 1013,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,    1,    1,   32, 2332,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3292,  440,  294,  762, 1044, 1674,  671,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,    1,   37,  331,  207,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1477, 1990,  190,   52,  810,  297,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 1417,    1, 2800, 2565,    1, 1484,  460,  796,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1, 2189,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3160,  162,  547,  537,    9, 2772,   45, 1147,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1232,  166,  365,    1,    1,    1, 3238,   51,    1,  460,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1990, 2845,    1,  865,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  857,  591, 2903,   74,    9, 3186,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  863,    1,    1,  374,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1516, 2550,   37, 1779,   28,  361, 1910,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999,    1,  923,  442,  850,  297, 2186,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  366, 1695,    1,    1, 1683,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612,   37,  125,  600,    1,    4,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3238,  162, 3288,    1, 1114,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1536,  469,   37,    1,  214,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  446, 1564,    7,    1, 2237,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1448, 1235,    1,  387,  197,  554,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 2553,   39, 1708,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 2548, 2856, 1056,    1,  335, 3365,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,  42, 768,  43, 220, 874,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 140,   1, 562,   9,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3253, 1380,   32, 2876, 1998,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   62,  571,   37,    1,  548, 1981,   12, 2292,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1537,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1291,    1, 1465,   32,  365,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1810,    1, 2855,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  361,  104,  498,   37,  624,    1,   32, 1461, 1462, 1699,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1498,  289,   98,  259,    1,    9,  803, 1244,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,   37,   26,  885,  124,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  357, 3359,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  718,   65,  475,  267,  104,  719,  242,  347,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  787,  387,  788,  187,    1,   37,  333,    1,  380,  437,    1,\n",
      "           98,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 2520,  613,    1,  861,    1,  815,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1536,    9,  467,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3059, 1421,    1,    1,   37, 1700,  356,   24,  881,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  178, 2617, 3060, 3358,  967,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  501,  919, 3231,  608, 3209,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2546,  833,  612,  135,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 2104, 1082,   46,  220, 2707,  600,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  159,  245,  187,  669, 1114,  376,  157,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3236,  114,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1584, 1123,    1,  453,  248, 2298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  197,  338,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  877, 1515, 1394,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  729,  590, 2324,    9,  104, 1821, 2978,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  197,  417,    1,  320,  565,  159,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1850,  135,  577,  187,    1,  120,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3306,   81,  176,    1,  548,    1, 2878,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1877,  751,   37, 2328,  114,  384, 1430,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3094, 2572,   32,  531, 2292,  187, 2835,    1, 1186,  588,   37,\n",
      "         1211,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2391,  872,  967,  547,  365, 1098,  295,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1494,   37,  166, 1732,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2391, 1668,   56,  356,  132,   37,   22, 1824, 3192,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   56,  441,  469, 1437,   32, 1037,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283, 2438,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  348,  884,   81, 1311,  176,   81,  756,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2076, 1721,  943,  600,  166,  861,  441, 1398,  612, 1188,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  647,  353,  197,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2903,   74,    9, 2615, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  732,    1,    1, 2070,    1, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 1974,    1,  472,   81,    1, 1751,    9, 1056, 1675,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   51,  193,   52,  730, 2614, 2615,    1,  202, 1477, 1990,\n",
      "         1246,   61,  311,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2952, 1199, 2500,    1, 1976,   32, 1033,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   12,    1, 2170,   12, 3405,   98,    1, 2699,   37, 1814,  557,\n",
      "          540, 1512,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   81,   37,   36,  920,    1,  623,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  296, 1574,  342,   12,  484,   98,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  636,    1,  187, 1266,   42,  220,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  370,  371,   37,   47,  372,   45,    1,   37,  373,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1252,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  658,    1, 1494,  220, 1031,   98, 2283,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 2224, 2424, 3339,  302,   63,    7,  741,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1090,  460,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123,  593,    1,  361, 1340,    1, 1807,  388,  763,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  579,   12, 1411,    9,  647,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  520,    1, 1527, 1232,  590, 2024,  132,   32,   12,    1,\n",
      "         3369,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  138,   59, 1010,  133,  134,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  169, 1086,  630,   37,  151, 2105,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  296,   92,   37, 1462,  633,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3059, 1421,    1,   37,   24,  881,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,  418,    1,  102,   37,    1,   93,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2026,    9,    1, 2264,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1059,  615,  105,  774,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  640,  356,  845, 1230,   66,    1,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3305, 1036,   37,    1,    1,   45,  584,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2352, 2087, 2614,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3238,   12,    1, 3288,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2334,  396,  365,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  190, 1636,  760,   12, 2351,  631,   37,  365,    1,    1, 2973,\n",
      "         1764,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683, 1707, 1888,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  116,    1,    1,    1,  163,    1,   12,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  741,  288,   98, 1845,  132, 1813,    1,    1, 1016,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  522, 1648,  297, 2066,    1,  493,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   82,    1,   29,    1,  537,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  328, 1932,  251,  331,    9, 1933, 1541,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1470,  166,  636,   45, 1211,  442,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1952, 2015,    9, 1300, 1821,   95,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,    1, 1181,  498,   37,  332, 1317,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  677,   94,  509,  342,  518, 1726,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1852,  213, 1021,  636,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2047, 2580,  328,  190,    1,  725,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  266,   37,  693,  159,  176,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  393,  108,   45,  467,  187,  460,  765,   37,  125,    1,    4,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3167,    1,    1, 1214,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1, 2662,   12, 2918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  994,    1,  150,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1951, 2476, 2139,    9,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993,  682,  228, 1394,    1, 2997,  953,  228,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3344, 1940, 2833, 1072,    1,   32, 3339,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  197,  921,    1,  570,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  287,   37, 1251, 2302,  624,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,   37,  838,   68,    1,  220,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,    1,   37,  576, 1133, 1789, 1263,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1880,    1,    1,   32,   46,   98, 1610,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  925,  315,  593,   12,  553,    1, 1766, 1767,  207,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2960, 2668, 2597,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   45,  241,   22,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112, 1251,   45,  651,  674,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  325, 2241,   48,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,  474, 1974,    1,  477,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,  967,    1,    1,    1,    1,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2263,    1,    1,    9, 2985,   32,    1, 2772,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  793,  321,  815,    1,  987,    1,  398,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  678,   12, 2626,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3118,    1,    1,  187,  163,    1,  903,    1,    1, 1386, 2237,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219, 1619,  458, 1554,  347,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3285,    1,    1,  202, 1574,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,  147,   45, 1786,  695,    1,   37,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2965,    1, 2347,   32,  245,   37, 2378,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1707,    1,    1, 2867,  191, 1789,   12, 1009,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1555,   98,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  442,  910,    1,  388,  763,   76,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,    1,    1, 1865,  593,   12,  553,    1,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2081,    1,   98,    1,  187,  826,  408,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  584, 2619,   98,  444,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2563,    1, 1061,   98,    1,   44,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  519,  501,   76,   37,  698, 1517,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160,  102,   62,   85,   32, 1169,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  129, 2778,  661, 1817,    1,  233,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,  884,   79,    9, 1497,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3315, 1878,  715, 1990, 2716,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018, 1158,  105,   74,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  358, 1070,  147,   37,  439,  474, 1495,    1,  869,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  477,  515, 3328,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1,  166,  112,  218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159,  120,   98, 1583,   24, 1624,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1127,   26,   28, 1074,  412,  357, 1046, 2015,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  861, 1906,  213,   98, 3369, 3146,  187,    1,  543,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  749,  533,  665,  790,  226,  680,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2862,  446,  680,  433, 2263,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395, 1401,  593,   98,  858,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 544, 193, 544, 424, 176, 754,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 601, 401, 197, 418,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  420, 1186,  140,  163,    1,   12,    1, 1876,    9, 3388,   46,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  798, 1260,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1870,   37,  151,   81,  159,  384,  755,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,  474,  992,   28,  927,   45,  657,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  545,  967,  105,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2823,  736,    1,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1174, 2073,    1,   45, 1405,  373,    1,  776,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1586,    1,  297, 2236,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,  25,  28,  98,   1, 996, 716,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 148, 361,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,   37,    1, 3036, 3037,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962,    1,    1, 1056, 3299,  187, 3117, 2497, 2633,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,   37,  693, 1935,    1,    9,  282,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1684,    9,    1,    1,   37,   52,  365,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2800, 2335, 1178, 1545, 2250,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785, 1388, 2572,  103, 3384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  102, 1826,  187,  163,    1,   12,    1,  889, 1293,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2583,  459,  132,   37,    1, 3251,   32, 2016,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,    1,  331,  354,   32, 1913,  401,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2528,   45,  439, 2601, 1090,    9,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3198, 1249,    1,    9, 1913, 3329, 2545,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  114,  971,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1132,  361, 1149,    1,   37,  907,    1,    1,  288,   37,\n",
      "         1348,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999,  868,   81,  176,  923,  220, 3050,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   49,    1,    1,   37,   52,   53,   98, 1657,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,   12, 2511,  765, 1159, 1994, 2086, 1228,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  954,  256,    1,    4,   32,  367,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  920,    1,  105, 3050,   37,    1,  444, 2819,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2474,  618,   37, 1937, 2056,   93,  297, 1411,  228,  537,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1034, 2677, 3158, 3276,    1, 1497,    1,    9,    1,  404,  631,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  264,  442,  334,    1,  460, 1532,    1, 2191, 1227,    1,\n",
      "          460,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870, 1353,  327,    1,  809, 3004,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1778,   37,  619,  453,  915, 1479,  328,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   94,  953,    1, 1547,  816,   32,  698,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   98, 1180, 1208,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196,   12, 2204,  214,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2815, 2681,  696, 1668,  726,  404,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  395, 2003, 1585, 2162, 1950,  418,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  315, 2738,    1, 3339, 2456,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   20,  927,  703,   37,  372,   24,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  921, 2232,  846, 1463,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1043,  995,   28,   98,  198,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,  133,  798,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2932, 1000,  365,    1,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  515,    1,  105,   92,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2018,  812, 1537, 2128, 2271,  384, 1815,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   22,  359,  474,    1,  176,    1,  361,  362,    6,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  344, 2596, 2137,  501, 2060,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1114,  879,  647,  693,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2932,  506,  311, 3002,   37,    1, 2229,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,    1,    1,  132,  251,  809,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1389, 2156,    9,    1,    1,    1, 2579,  336,  298,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1304,   37,  138,  331,   37,  875,  422,  134,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  882, 1395, 2055,  350, 1069,   45, 1194, 2273,    1, 1395,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3065, 3156,   32,    1, 1656, 2536, 1530, 2164, 1950,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3096, 3112,    1,    1,  361,    1,    1,    9, 3302,   12,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2342, 1890,   98,  166,  593, 1264,  777,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1068,    1,  176,  971,   91,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,  102,  168,   98,  166,  832,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2235,  159,  123,  242,    1,  187,    1,    1,  491,    1,  105,\n",
      "          832,   32, 1295,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273, 1633, 1625,   37, 1083,  182,   32, 1126,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1292,    1,   32,  365, 2695, 2724, 1521, 1821,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2171, 3134, 2570,    1, 3161,  171,  726,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,    1,  453,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497, 1747,  581, 1023, 1456,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   65,  155, 1184,  347,    9, 1194,  199,  424,  356,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1401, 2695,  105,    1,   95, 1116,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  861,  700, 1635,    1,   45,    1, 3000,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,  188,    1,  307,  308,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1364, 1365,  957, 2867,    1, 2241,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  190, 1188,  987,    1,  990,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  592,  267,  616,    1,    1,   62,  548,   67,  418,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  645,  116,    1, 2501,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,  439, 1724,   37, 3144,    1,  528,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  645,    1,    1, 1744, 3361,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 1352, 1235,  102,   71,  166, 1354,  452,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2597, 1656, 2596, 2414,  228,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  551,  789,  197,   28,   98,   15,   93,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  127,   37, 1048,  445,  658,  187,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 1082,    1,    1,    1, 1281,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9, 1244,    1,  105,    1,   32,  878,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2970, 1089, 1675,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  870,   58,    1,   12,  794,  116,  279,    1,  809,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  878, 2321,    1,   45, 1809,  402, 1167,  460,   12, 3278,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2680, 2479,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  341,   29,    9,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3301, 1587,   45, 2904,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1, 1373,   37, 1496,    1, 2372,   45, 2299,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  503,    1,   45,  749,  223,  762,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  912,  424,  786,  187,  105, 2249,    1,  420,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  590,    1,   32,    1,   37,  424,  667,  872,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,  835, 1117, 1525, 1228,  700,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  737,  197,  418,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   30,  590,    1,    9, 3260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884, 1910,    9,    1,   98, 3265,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  155, 1931,  600, 1926, 1927, 1928,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,  236,   61,   32,    1, 1508,   37, 2314,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  487,    1, 1046, 2639, 2069,  176, 1675,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707,  967,  590,  388,    1,    9,  342, 2927,   46,  232,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,  37, 242, 572, 197,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 621, 325,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  225,  616,  242,  187,  286,  186,    1,    1,   32,   69,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  604,  685, 1348,   37,  973,  242,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1293,  220, 3117,   98,  183, 1757, 2539,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,    1,  476,   37, 2354,  334,   37, 1821,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  488, 1123,  297, 2901,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2779,  140,   32,  599, 2304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,  640,  339,  340,  951,    1, 1547,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  789,  817,   98,  978,  769,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2308,    1,  154,  360,  315,   37,  439, 3151, 1756,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3403, 2414,   32, 2531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,   91, 1388,  297,    1,    9,   20,  551,  296,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   37, 2303, 1371,   98,  909,  444,  104,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1411, 1778,   61, 1044,   29, 2759, 2549,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273,  618,  335,  297,   32,  854,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1785,  267,  107,    1,   69,  636,   97,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1485,    1, 1190,   32, 1140,   37,  587,  297, 1390, 1512,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2246, 2885, 1086, 2843,   12, 1844,   45,   32, 1559,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2197,  246, 1119,   37, 1718,  384,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  549, 2361,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2292,    1,  297,    1,  388,   32, 3118, 1428,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3181,    1,    1,   12,    1,  841,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  493,  102,  720,  187,   68,   69,  109,  418,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1419, 1479,  420,   98,  652,    1,  596, 2429,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  898,  132,  227,    9,  179,    1, 1488,    9,  180,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   20, 2331,  297,  573,  927,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260, 1539, 1159,    1,  631,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 163,   1,  12,   1,  25, 245, 995,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 107, 108,  69, 109,   6, 110,   9,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,   37,  130,  647,    9,    1,  131,    1, 2093,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,   12,   82,  162,  105, 1083,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   40,   32,    1,  220, 1158,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1251,    6,   92,  702,  737,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1668, 1914,    1,  105,    1, 1434,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1216,  460,   12,    1,   37,   52,   81,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  822, 1918,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1240, 1306, 2486, 1090, 2675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  388, 3068, 1289,    1,    1,   28,   98,  166,  116,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1973,  764,  219,  872,  176, 1477, 1990,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,   44,  176,    1,  787, 2800, 1218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2094,  388, 2258,   37, 2286,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2690,   37, 2988, 1778,    1, 2762,  920, 1300,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   12,  354,    1,  191, 1327,   12,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1711, 1314,   37, 3088, 3346,   32, 2646,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2386,  326,   45,    1, 2465,   32, 2086,  149,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 2842,   45, 2292,   32,  531, 2414,  228,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  666,    1, 2977, 1821,  656,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  166, 2505,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1829, 2028, 1187, 2017,  220, 1714,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  683,    1,  332,   59,   60,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  202,    1, 1710, 2449, 2191,  411, 1411,  356,    1,  267,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1019, 2214, 2527, 2663, 1976,   32,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307, 1353,    1,  361,  861,   45,    1,    1, 1996,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2929,  614,   37, 2659,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  592,  267, 2127, 2585,   32,  395,  193, 1724,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  189,  267, 1913, 1843,  983,  190,  245,  384, 2073, 1843,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2222,  794,  963, 2102, 1108,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  793, 1512,    1,  573,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169,    1,  105, 3204,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,   25,    1,   60,    1,   69,   71,    1, 1340,  670,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226,    1, 3220,   26,  220,  105, 1037,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1387, 1881,   45, 1056,  183, 2576,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2306, 2562,    9,  215, 1405,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2954, 2760,    9, 1913, 1463,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  818,   22, 1697,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3327, 1321, 2225,  384,  584,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 1447,   12,    1,    1,  455,   12,    1,   32,  443,\n",
      "          297, 1616, 2104,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1855,    1,    1, 3404, 2249,   32, 3360,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2765,  798,   37,    1,  337,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3101,  844,  267, 3358,  223,  967,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,   37, 1046, 1691,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  957,   37, 1776,    5,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 2954, 1758,  176, 3116,  922,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3099,  952, 2268, 2214,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,    1,  297,  211,   45,  301,    5,  302,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3356, 1484,   98, 3357,   37, 2446, 1345,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2494,  872,   39,   45,  671, 2107,  548,  354,   37,  208,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1789,   51,    1, 1560,    9,  163,    1,  903,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1, 1409, 1492, 1572, 2955,  656,    1,\n",
      "          928,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1000,    1, 2177,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,  922, 1090, 1829,  718,  176, 2307,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1159,  915, 2144,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3178, 1518,   98,  103, 1569,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3322,  670,  608, 2475,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    6,  746,    1,  747,    1,  361,  196,  748,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2779,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1212,  828, 1313, 1580, 1799,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  528,    1,   54,  354,    1, 1369,  267,  460,   61,   81,   98,\n",
      "         1171,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2912,    1,  191, 3066,   12, 1048,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 2682, 1312,  923,  220, 2039,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1987,  488, 3245, 1045,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  200,  201,    1,    1,  202,  193,  203,  204,  205,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1503, 1346,  354,  190,   52,  792,  680,    1,  792,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  361,    1,  439, 1559,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938, 1075, 2924,   81,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  186,  444, 3144,  741,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2476,    1,    1,    1, 1005, 2942,  726,  671,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2925, 1090, 1829,    1,  176,  718,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  927,    1,  225,  636,    1,    1,  389,    6, 2758,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3343, 2562, 2162,   32,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 1042,  315,   37,  665,    1, 1017, 1159, 1087,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1583,  475, 1271,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2660,   79,  531,   12, 3391,    1,   22, 2262, 2856,  547,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2631, 2460,   79,  914,  220,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  824, 1101, 1825,    1,    1, 2627,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  850, 1154,    1, 3117,  245, 2072,   32, 1264,  841, 2107,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2278,  884,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  903, 3085,    1, 1461, 1463, 1558,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  147, 1419,  663, 2042,   98, 1368,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  227,  550, 2026, 2574,  207, 1851,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1877,   37, 1348,    1, 3107,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3206,  439, 1826,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3337,   12, 2494,  698,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1572, 3406, 1670, 2416,    1,  187,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2864, 2507, 2927, 1159, 2158,   45, 2121,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   91,  927, 1921,  176,  166, 2918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1471, 1149, 1267,  365,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  691,   56,   81,  187, 1423,    1, 2637, 2428,  593, 3129,  631,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  459,  220,  632,  872,    1,  267,    1, 1036, 1221,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2738,    1,   45, 1821, 2978,    1, 1976,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  936,  365, 2452, 1167, 1631, 2436,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1585,  640, 1850,  531,  965,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683, 1707,  132,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,  191,  344, 3403,  176, 2190,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3199,  884,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  387,    1,  459,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2387,    1,    1,  784,  191,  784,  361,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  729,  105,    1, 1569,    9,  284,  148, 2264,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2073,   12,  221,  155, 1468,   45, 1574,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 492,   1,   9,   1,   1,   1,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1,  39,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2827,    9,  531, 3148,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2136,    1,   10,    9, 1600,  138,    6,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2702, 2421,   32,  403,  691,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  334,  321, 1096, 2977,    9,  166,    1,  341,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  521,    1,  741,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,    1,  114,   32, 2433, 3360,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1438,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12, 2245,    1,  435, 1670, 1527,  384,  957,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  871,  112,    1,   28,  388,  763,   76,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1977, 1443,  424,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  167,    1,   94, 2060,   93,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1996,  411,  861,  937,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1454,  484,   37,  114,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  352,   32,    1,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  498,  220,  837,   12, 1281,   45, 1925, 1583,  862,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  515, 2210, 1470,   45,    1, 2515,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1492,   12,   32,  260,   37,  335,  297,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2884,    9, 3379, 3035,    1,   98,  717,    1, 2255,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1162,  244,   28,  699,  528,  114,    1,  567,  361,  868,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1838,  242,   98,   14,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2851,  951,    1,  166,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106,    1, 1626,  449,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  373,    1,  571,   37,  626,  605,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398, 1392,    1,    1,  224,    1,  400,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 2334,  744,  593,  846,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2749,   71, 2444,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  381,   12,    1,  162,  590,    1,  317,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  338,   98, 1242, 1956,   67,  125,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1050,  693,  105,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  155,    1,   67,    9,  449,  199,   32, 1270,  105,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 1218,   21, 1176,  445,  384,  166,  872,    1, 2565,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  167,  439,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1186,  213,   37,  104, 2099,    9, 2128,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2477,    1,    7,  187, 1948, 1494,   37,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1668, 1188,   37, 2277,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585,  176, 1853, 1557, 1953, 2414,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1379,  437,  313,   37, 2199, 2187,  191, 2821, 1017,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1123, 1822,  100,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1099, 1453,  494,  288, 1515,  750,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  113,   39,    9,  166, 1001,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1786, 2358,    1, 2272,   85,  116, 2502,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   12,  649,  236,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   69, 1360,  612,    1,  104, 1437,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  639, 1874,  864,   12, 2836,   45, 2673,  210,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829, 1877,  856,   98,  768,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,  447,    1,   15,   71,    1,   98, 1168, 1124,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2832, 1210, 2757,   37, 1540,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2914,  593,   12, 1254, 2334,  716,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1433,    1,   61,  917, 1178,    9,  166,  389,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2277,    9,  104,  872,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1720,    1, 1721,  712,  994,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  678,    1,    1,    1,  872,   28,   37,  877, 2873,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,    8,  304,  600, 1718, 2039,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1419,  660,    1,    1,    1,    1,    1,    9,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2101,   45, 3151, 2308,   32,   91,  640,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12,  645, 2575,   37,  619,    1,  220,  844,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1951, 1656, 1149, 1267,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,  288,   37,   52, 3343, 1009,   32, 1551,   45, 1448,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2922, 2616, 1564,    1,  436, 2051,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2529, 3087,  640, 1850,  455,    1,    1, 2734,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1174, 2208,   32, 1422,  863,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 1070, 2673, 1063,   81,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  907, 1698,   69, 1588,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  579,  460,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  342,    1,  372,   45, 1495, 1897,  811, 2784,   37,\n",
      "          395,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   30,   15,  361,  156,   93,   32,  572,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3251,  221,  162, 1914, 1322,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,    1,  197,   28,  225,  407,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1761,    1,    1,  384,  537, 1490,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2620,   32, 2468,  833,  612,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,  971,   91,  859,   37, 1911,  389,    6,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118,  469,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2216,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273, 1609,   12,    1,   15,    1,   32,  367,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1287, 3059,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,  845,   36, 2800, 1292,    1,    9,    1, 2110, 1178,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  557,  540,   12, 1583, 1484,    9,   62,  548,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105, 2154,    1,   32, 2208, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1789, 2117,   12,  197,    1,  995,   32,   72,  401, 1010,    1,\n",
      "          157,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2880,   45,    1, 1207,   37, 1878,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2839,    1,    1, 1919,   32,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974,  967, 1532, 1821, 2218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  134,   76,  906,  384, 3141, 2811,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,  686, 1380, 3260,   32,   44,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,   26,  417,   29,    1,    1,  817,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  180,  476, 1488,   75,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  919,  455,   37, 1354,    1,  671, 2085,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    8, 2976,    9, 1312, 1228, 2558,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2162,   32,    1,   45, 3343, 3353, 3060,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,  446,    1, 2789,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2140,    1,    1,    1, 1662, 1292, 1492,    1,    9, 1009,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1749,  220,  326,   98, 1766, 1767, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 2473, 1294, 1396, 2474,  618,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3356, 1583,    1,    1, 2179,   23,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3213,   12,    1, 2001,   37,   52,    1,  191, 3092,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  858,  134,  729, 1176,  845,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3176, 2022,   91,  548, 2857, 2250,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2290, 3259, 2712,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3314,    1,   61,  590,    1,  267, 3181,   12, 3281,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3176, 2540,    1,   37,   77,    1,  922,  119, 1762,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,  455,   51,    1,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,  140, 2490,   26,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1739,    1,  315,  331, 1429,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1545,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  247,  608,  270,  220,    1,  444,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2222,  619,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3297, 1408,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 2051,    1,  600,  954,  496,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   10, 2424,  104,  993,  302,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247, 2257, 1427,    1,    9,  750,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  597,  381, 1682,   51, 1046,  422,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  792,    1,  220,    1, 1107,  792,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   69,   28,  419,  187,  679,   69,   25,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2499,    1,  267,  572,  354, 2420,  356,   45,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2627,    1, 1107, 1863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3339,  399,    1,  469,    1,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2176,    1, 1410,  116, 1527, 1961,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2384, 1069, 2750,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2944,   37,  489, 2924,  384,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1842,   12, 1443, 1344,   17,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,    1,   98,  425,  426,   15,  550,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358, 1025,    1,   98,  247,  248,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 2292,  640, 3339,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  354,  703,    1, 1635, 1429,  458,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2002,    1,   37,   52,    1,    1, 2689,    1, 3126,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  774, 2325,    1,  193,    1,    1, 2072,  163,    1,   12,\n",
      "            1,  221,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3305,  891,  365, 1015,   32,  584, 2800,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1123, 3108, 2935, 2764, 1619, 1131, 1684,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2500, 2126, 1976,   32, 3155,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3015,    1, 3062, 1521,   45,    1,   12,  661,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1585,  176, 1606,   32,  730, 2288,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  255,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  521,  945, 1190, 2659, 1407, 2326,   32, 1537,  295,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 1354, 2705,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2024,  571,   37, 2646,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128, 2612,  112, 1108,  656,   32,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2563,    1, 1061,   98,    1,   44,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 3350, 1564, 3343, 2237,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2701, 2308,  360, 3151,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,   37, 1758,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1447,   51,   52,    1, 1461, 1539, 1603,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2972,  475,    1,  939,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  971,  361, 2077,  872,   28,   98, 1736, 1522,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2307, 2161,  688, 2451,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  872,  190, 1604,   98,  453,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2584,    1, 1668,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1, 1260, 3006,   32,  531,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   28,  187,  889,  679, 1588,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1112,  176,  142, 2010,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   26,  242,  187,  615,    1,   79,   69,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2977,  880, 2598,  176, 1215,  846,   45, 1620,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 1542,   37, 1421, 2024,  132,  220,  463,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1537,    1,  487, 2700, 2567,   98,  195,   37,  856,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1, 2540,    1,  171,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,    1, 1442,    1,    1,  150,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  284, 1820,   25,  265,  187,  102,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,    1,  202, 2126,  105, 1665,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  104,   67,   70, 2139,  528,  340, 1275,   31,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2437,  220,  590,  671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,   37, 1539,  453,  248, 1107, 1863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 1509,  111,    1, 2165,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,  359, 1947,  131,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,    1,  191,    1, 1001,   32, 2028,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 1203, 1513,  220, 2566,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   25, 1285,   85,   98,  197, 1936,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2441,  361,    1,  187, 1054, 2003, 1953, 1268,   32, 3099,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   84, 1750,    1, 2359,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2669,  247,  913,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  657,   12, 1118,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,   12,  156,  103,  739,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  365,    1,   46,    1,  854,    1, 3128,   98, 2018, 2108,\n",
      "           15,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  891,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3339, 3352, 1211,  103,  861,  232, 3133,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  176,    1,  787, 2800, 1218,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2490,    1,  250, 1585, 2414,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  671,  191,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  510,  155,  493,  102, 1533,  384,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1808,  794, 1412, 1107, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105,    1, 1167,    1,  810, 2766,    1,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  474,    1, 1923,  250,   24,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,  267, 3118, 2751, 2587, 2500,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3399, 2605,    1,  163,    1,   12,    1, 1415,   37,  864, 2390,\n",
      "          132,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  275,   25,  670,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1228,    1,  912, 2285, 1108, 3000,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  150, 1353, 1140,  656, 1876,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   83,   37, 1910,  654,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1164,   37,  693,  864, 2673,  132,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1991,   37,  877,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,   12, 1471, 1149, 1267,  304,  868,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2838,    1,    1,    1,  356,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3378, 2137,  247,  776,  187,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1897,    1,  457, 1821,   95, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 3403, 2262,  947, 3150,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 104,   1, 397, 909,   9, 920,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 477, 297, 677, 529, 102,  32, 430,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1811,  404,  864, 2673,  132, 2260,   37,  104,  863,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1203,    1,    1,   32,  163,    1,   12,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3237, 1086, 1044,    1,  187,  730, 2614,  688, 3175,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1877,   37,  759,   39,   37, 2746,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3254, 1380, 2468,   32, 1881,   45,  593, 1990,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  315,   37, 1155,  649,  250,   32,    1,  267,  420,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  700,    1,  985,  629,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3403, 2414,   32, 1850,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1493, 1154,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  275,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  294, 1456, 1236, 2180,  361,    1,    1, 2738,  458,  841,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,   57, 2819, 1277,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  878,    1,  903,    1, 2926,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087, 2614,    1, 3233,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3198, 2963,  191, 1140,    1,    1,  176, 1022,    1,    1,\n",
      "           26,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  500,    1,   37,  564,   32,  111, 1935,    1,  856,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1809,  471, 1969, 2978,  139,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  113,   15, 1470,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,   37,  125,  102,  548,  594,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,   37, 1027,    1,  187,  627,  949,   45, 2255,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1033,    1,  166,  888,   45,   69,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1916,    1,   32, 1186,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3380,  387,  809,    9, 1815, 2389,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  195,  293, 2469,   37,   52,    1,   12,  365,   82,    1, 2126,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1683, 3365,  907, 3363,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3017, 1008,    9,    1, 2165,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2236,   76,   37,   52, 2030,  191, 2792,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3306,  891,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3233,   37,   77,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,  267,    1, 1952,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 2819,  149, 1396,    1,    1, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311,   12, 1107,  132, 1086,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2741,    1,  631, 1918,   44,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,    1, 1099, 1453,   37,    1,  156,   54,  176,   48,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 3028, 2995, 1441,  116, 2542,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3312,  865,   37, 1505,   32, 2304,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  196,  288,   37, 1864,  214,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  572,  156,   28,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2700,  469,   37, 2655,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1268, 1708,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  306,    1,  150,  912, 2026,    1,    1, 2039,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  365,  533,    9, 3351,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  669,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275, 1216,   37, 2127, 1569,    9,    1,  855,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  795,  359,    1,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,    1,  388, 2924,   37,  557,  540,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  462,  721, 1579,  469,    9,   49,  142,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  925, 1566,  613,  116,    9,  810,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  136,   37,  151,    1,    9,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,    1, 1831, 1082, 3369,   37, 2192, 3118,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  654,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1444,  254, 1573,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    6,  570,   98, 2859,  102,    1,    1,  408,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  365,  461, 2871,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1968,  768,  149,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  245,  995,  548,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,    1, 1530,   32,   22,  298,    1, 1574, 1389,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,  997, 1018,    1,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,   37,   26,    1,   94, 1107,  525,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,   12,   51,   52, 1036,    9,   79,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1723,  782,   86,    1, 1450,  565,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1492,  190,  631, 2588,  920,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,  166,    1, 1417,    1, 1117,    1,  405,    1,   12,\n",
      "         1492, 1399, 2588,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   12,  354, 1052,   32,  572,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  884,  411,  522,   98, 3332, 3311,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  852,   98,  187,    1,    1, 1386,  856,  460,   39,  176,\n",
      "            1,  147,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 2424,   98, 2336,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  952,    1,  384,  587,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3209, 2446, 1110,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652, 1536,    1,  149,  951,    1,  829,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   25, 1158,   12, 1986, 1702,  236,  237,  242,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,   69,  393, 2774,   32, 1194,    1, 2024,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1523, 2838,  424, 1054,   61,  255, 1054,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  761,  197,   28,    1,  108,   45,  768,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1603, 2715,   45, 2024, 2354,   37,    1, 2490,   12, 3105,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764,    1,    1, 3364,    1,    1,    1,  187, 2708,  650,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 2527, 2946, 1976,   32, 2140,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  590,    1,   32,  792,    1,  792,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1137,  548,    1,  296,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1564, 2812,    1,  861,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3096,  885, 2712,  167, 1937, 2741, 2565, 1383,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,    1,  829,   12, 2819,    1, 2146,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  162,  938,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  828,  562,  365,  261,   98, 1442, 1580,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,    1,  515,   28,  103,  317,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  177,    1,   12, 2315,   32,  424,  443,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 1658,    1,    1,  168,   37,  166, 1039,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  315,   37,  125,    1,    4,  187,  156,  276,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  391, 1713, 1117, 2208,  149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,   37,   47,   79,    1,  942,   48,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2768, 1128,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885,   37,  664,    4,  176, 1948,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1725,  379,    1,    9,  996,  895,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2191, 1893,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   91,  616,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 1458, 1839,    1, 3037,   51, 1237,   23, 1411,  356,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,   37, 1758,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  191, 1629,   32,  286,  218,  927,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  496,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3270, 1216, 2050,  176, 1684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  735,  681,    1, 1300,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640, 1938, 2809,    1, 3296, 2651, 3234,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1802,  159,  439,   27,    1,  845,   98,    1,    1,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  729,    1,    1,  454, 1176, 1744,    1,  227,    1, 2812,    9,\n",
      "         1340,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  680,  422,  927,    9,    1,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3310,  774,  405, 3291, 1467, 2161,    1, 1001,   37,   77, 2808,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  398, 1355,  342, 2027,   98,  829,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,  353,  242,  572,  156,    1,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2932,  332, 2376, 2223,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1579, 2649, 2791, 1858,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  111, 1013,    1,   61,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2823, 1002,  614, 1159, 1913, 1385,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1769,   37,  688,    1,  361,  183, 1510,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2801,   37,   18,   37,  215,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  921,   59,  847,  481,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123,  606,  105, 1311,    1,   32,  166,    1,   45, 2295, 3117,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32, 1260,   98,  163,    1,   12,    1, 2699,   32,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 1064,  220,  365,  673,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  395, 2122, 1742,  382,  315,  182, 1126,   32, 1802,    1,  365,\n",
      "         1788,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  702,    1,   37,  197,   32,  572,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1896,   37,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,  613,  213,   37,  151,    1,  728,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1422,  537,    9,    1,  825,   45, 2078,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1874,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  220, 2841,   16,    1, 2114, 1564, 2149,  221,    1,  202,  398,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481,  267,  764,  176,   38,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  108,   45, 1610, 2596, 1450,   32,    1, 1897,    1, 1725,\n",
      "         2396,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  397,    1,  909,  444,  104,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  702, 2418,   28,  169,    9,   54,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  658, 1151,    1, 1159,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3323,  664,    1,    1,   32,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  105,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428,  861, 1906,   37, 2000, 3369,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2043,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  352,  967,  388,  199,   37,    1,  408,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3296, 2303,  193,   37, 1445, 1421,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   12, 1046,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   26,  526,    1,  156,  550,  410,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,    1,   37,  649,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1589, 2225, 2385,  612,    1, 1488,  176,  177, 1720,  460, 1494,\n",
      "           37,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    9,  295,    1,  460,   12,  729,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20, 1117,  580, 2205,  384,  943,   45,  296,  413,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  938,  315,   37, 1753,  941,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3130,  105,    1,    9, 1668,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1537,  947,  927,    1, 3389, 1167, 2572,  249,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 1566,  909,  951,    1,  903,    1, 1447,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2993,  820, 3056,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 2732,    1,    1, 2868,   12,    1,    1,  220,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1009,  267,  107,  568,  562,  187,   61,    1,  104,  105,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  696, 3318, 1334,    1,    1,  539,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1079, 3063,  162,  466,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  327,   13,    1,   98,  466, 1021,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  123,  786,  118,  417,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596,  176, 2018, 3407, 3392, 2414,   56,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1968,  244,  554,   37,    1,  331,  104,   32,  572,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   37,  949, 2693,    1,    9, 1778,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2470, 1800,  403,   12, 2390,  396,  187,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510,    1, 1750, 1549,  540,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  830,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60, 1993,   28,    1,    1, 2156,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3238,  456,   85,  931,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  663, 2396,  812, 1695,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2028,    1,    1,  548, 1404,   12, 1313,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2188,    1,   45, 2764,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  776,    1, 1086,    1,   37,  865,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1701,    1,  197,  407,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2508, 1564, 2263,   32, 1778, 1039, 2690, 2607,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181, 2800, 1218,  661,   59, 3215,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,  25, 866,  98,  69, 102,   1, 485,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 326,  42, 573, 396,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2886,   12, 2234,  162,  365,  845,  275, 2524,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  823,  361,    1,    1, 2155,   28,  220, 1009, 1963,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  147, 1579,   22,  942,  283,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 2525,   32, 1096, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2178,  147, 1268,    1, 2095,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  389,  997,  187, 1062,    1,  519,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1993,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  273,   37,  221,   37,  999,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  572,  551,  105,  829,   12,  190,    1,   46,  600, 1412,  754,\n",
      "         2913,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3285,  750, 1042,  166,  873,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  814,   37,  125, 1354,  111,  442,    1,  191,  786,   72,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2310, 1944, 2175,   81, 1159,    1, 2658,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2275, 2682, 1514,  443,   32,  166, 1514,  913,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425,  190,  151, 1883,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1861, 1384,  190,  193,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1545, 2058,  228, 1394, 1048,  187, 3181,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3207,    1,    1,    1,   63, 1283,  147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,   56, 2577,  176,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1050, 2565, 1685,  522,   32, 2107, 1559,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    4,   98,  166,  222,  176,  196,  756,    4,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  766,  794,    1,  220,  365,    1, 1017,  361,  744,  119,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051, 1039, 2690,   28,    9,  333, 1851,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1821,    1,    1,    1,  928,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2062,    1,    1,  548, 2712,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3005,  952,   39, 1074,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1113,   85,  191,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  702,    1,  169, 1413, 1414,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1966, 1830,    9, 1663, 2396,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  666,  640,  584,    1,  187,  171, 1174,  471,  384,    1,  477,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  384,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   37, 1012, 1060,  388,   32,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,   81,   37,  112,  187,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2211, 1968,  497,  429,  442,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1157,  159,  439,   28,   98,  156, 1625,    1,   69,  102,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1257,  960, 1536,    9,  467,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  512, 1924,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1663, 1821, 2190, 3053,   37,  741,  384, 2818,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  384,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  420, 1530,    1,  583,   32,  864, 2291,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1940,   12, 3096,  872, 2489,    1,   37, 2250,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   95, 2361,    1,   37,  365, 1788,  548, 2596, 2393,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3178,   81,   98,  103,   45,  166,  593,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  497,   37,  856, 2822, 2378,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2919,   45,  593,   12,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3015, 1821,    1,    1,  105,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800, 1178,  163,  214, 1820,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  715, 1113,  418,   32, 1169,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1778,   45, 1516,   32,  829,   12,  535,  973,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  996,  157,    1,   98, 1166,  334, 1734,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 2246, 3228, 1737, 3115,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1657, 2820,    1,    1,   37, 2585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1167,    1,  786, 2762,  453, 1056,    1, 2558,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  190,  907,  453,  107,  125,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  446, 1458,    1,  361,    1, 1760,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1105,  787,  581,  401,  354, 1052,   37,    1,  105,  332,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1024,  551, 1024,   37,  130, 1026,  369,    1,    9,    1,  131,\n",
      "          104,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3404,  877,    1, 2237,   37,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3194, 3195,   12,    1,  415, 2582, 1176, 1744, 1628,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3066,    1,   37, 1343,  760,  593, 1990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2998, 1587,   45,  590,    1,  539, 1037,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  890, 1961,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  792, 1938, 2607,  382, 2206, 2989,  792,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  593,  772,    1,    9,  215,  872,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2137, 2856,   32,    1,  854,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37,  601,  401,  186,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1625,   45,    1,  165,  191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   28,  688,   98,  403,  464, 2673,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708, 2855,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3192, 2158, 2329,  854, 1260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 1583,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1164,   61, 2213,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3147, 1550, 1583,   32, 3114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2345,    1,  220,    1, 2372,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,   25, 1150,  548, 1151, 1091, 1152,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2393, 2134, 1676,  851,   37, 1054,   32, 2235,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  261,   59,  321,  612,   52,    1,  384,  597,  281,  282,\n",
      "          475,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  405,   12,    1,   37, 2155,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,    1,    1,  191,  672,    4,    1,  181, 1153,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1214, 3229,    1,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,    1,    1,  150,  716,    1,  120,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3227,  271,   39,   45,  701,    1, 2497, 2551,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296, 1321,  829, 1322, 1039,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193,  166, 1690,   32,    1, 2717,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,  267,  453, 1228,    1,   98,  413, 1643,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,    1,  986,  105,  331,    9,    1,   12,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 1194, 2350, 2114, 1713, 2723, 2724, 2636,    1,  437,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  653,   28,   37,  764,  730, 2614,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2516,    1,    1,   37,  759,  388,  249,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2301, 1211,  361, 2613,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1, 1178, 2162,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  927,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2178,  947,    1, 2679, 1263,  304,   45, 1585,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,  167,  741,   98, 2650,  302, 1411, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  632, 1223,    1,  187,  964, 1877,  856,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2147, 2596,  722,  776, 1268,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977, 2652, 1463,   95,   45, 2080, 2056,  880,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,    1, 2183, 1499,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 1173,  176, 2039,  115,   45,  863,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3317,  199,   37,  221,   28,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1149, 3047,   32, 3360,  259,  754,  187, 3006,  588,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  967, 2252,   37,   52,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 1463,    9,    1, 1312, 2512, 2227,  872,  176,\n",
      "         3243,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2975,   12,  792, 2692,  792, 1089, 1090,   76,   37,   52,  268,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3253,    1, 3064,  683,   32,  522,  892,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  505,    1,  344,    1, 2325,    1, 1167,   12,    1,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1211,   37,   52,  311, 1831,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  914,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,  199,   37, 1694,    9,  153,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523,   27,  103,   45,    1, 2957,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1233,  376,    1,   98, 1971,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,    1,    1, 3004,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2884,    9, 1938, 2607,  382, 2633,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   12, 1637,  147,  267, 1617,  321,    5,    1,  176,  417,\n",
      "           67,  763,  440,    1,  963, 2122,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1585, 2414,  176,  177,  176, 3407, 3392,   32,    1, 2018,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 1923, 3205,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,   37,  151, 2943, 1499, 2683,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2705,   32,  531,  103,    1, 1527, 1900,\n",
      "          661, 2022,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2984,  927, 2418,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1712,    1,    1,   98, 3018,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2504,  555,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1746, 2954, 1555,   37, 1237, 3155,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3089,    1,  511,  907,   32,    7,    1,   45,  422, 3154, 1090,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2095,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1000, 2056, 1171,  187, 2015,  891,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1854,   76,  442,  384, 2087, 2614,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1, 1022,    1,  140, 2073,   73, 1090,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2844,  680,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1875, 2476,  151,    1,  111,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  379,  360,    1,  808,    9, 2571,  474,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 997,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 224, 167, 877, 453, 218, 714,   1,   1,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2822,   12,    1,    1,    1, 2321,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  493,  114,    1,    1,  202,    1,    1,  321, 1334,\n",
      "           32,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  212,  213,  214,   45,  215,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1380,   97,   98,  829,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1875, 2613,    1,   98,  219, 3273,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,  245,  526,  187,    1,  588,  105, 2315, 1318,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  458,  108,   45,  245,   32,  433,  102,  187,  954, 1071,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2613,    9, 3328,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  863, 1442,   61, 2917,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  183,  647,  253, 1066,  741,   98,  148,  142,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3372,    1,   37,    1, 3358,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  921,    1,   32,  593, 1990, 2701,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  786,   85,    1,  786,   37,  168,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  710, 1484, 2638, 2931,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 1123,    1,   32,  316, 3251,   37, 1752,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  338,   37,  365,  340,  951,   94,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3096, 3181,  386,  166,    7,    9, 3281,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3327,   81,   32,  166, 1090,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  676,    1, 2565, 2352,    1,  693,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  709,    1, 1251,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051,  716,  119,  197,  202,  157,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1107, 2086, 2039,    1, 1632,  147,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  885, 1230,    1,  424,  786,  384, 1087,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12, 2812,   32,    1,    1,  202,  460,   12,  707,   37,\n",
      "         1251,  334,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   45, 2505,    1,    1,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3028,  313,  760, 2994,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  939,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   30, 1180,    1, 1616,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,  884,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1018,  294,   37,  151, 2448,  386,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1122,  853,   28,    1, 1170,   85,   63,  862,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 3212,    1,  928,   45,  985, 1260,  176,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1727,    9, 2024,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9, 1428, 3365,    1,  187,  997,   71,   45,  531,\n",
      "         2304,    1,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2054, 1391,  218,  471,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   56,   81,   32,    1,   45, 2809,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,  361, 2018, 1195, 1815,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359, 1004, 3140, 1598, 3006,   63,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2733,    1,    1, 1462,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777, 2432,  328,  105,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  928,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  341,  640, 1796, 1938, 3197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,    1,  105,    1, 1816,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3060,   32,    1, 2596,  776,  267, 2764, 2765,    1, 1450,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1718,  313,   37,    1,  361,    1,  166, 2355,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3101, 2404, 1301, 1645,  856,  444, 1994,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2419,  550, 2157,    1,    1, 1613,    1,    1,    1,  219, 1615,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2254,  566,  658, 1412,   93,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  952, 2149, 1428,  741,  304, 3140,   98,\n",
      "         1430,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  162,  885,  916,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   81,   37, 2276,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  162, 2468,   32, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  443,   32,  531, 1924,  917,  528,  590,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,   37, 1539,  365, 1013, 1522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3033, 1504,    1,   98, 1821, 2190,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  337,    1,  495,    1,  654,   82, 1013,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,   12,    1,  267,  590, 1442, 2915,    9, 2707,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1661,  182, 2180, 2010,    9, 1621, 2011,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,  476,   37,    1, 2390, 1806,    1,  342,  267,  590,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,   12,    1, 1009, 1458,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,   37, 1046, 2741,   32, 1912,  176,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,  200,  365,  526, 2105,    1,  313,   37,   92,  332,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  580,    1,  297,  531, 2128,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2942,    1,  105,  125,  530,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  612,   37, 1155,  182,    1, 1074,    9,  684, 2358,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  239,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1600,  261,  565,    1, 1628,  550,    9, 1612,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1583,   37,    1, 1370,   45,  531,   24,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3094,  388, 2572,   32,  365, 1345,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3010,   12,    1,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,  803, 2909,    1,   32, 2707,    1,  590, 3307,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,   56,  610,   37,  611,   32,  395,    9, 2931,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,    9,  550,  369,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1783,   51,  125,   28,   37,    1,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861,    1,    1,    9,    1,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  785,  786,   51,  619,  413,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3202,    1,    1, 1957,   32, 1742,    9, 3141,   12,  449, 1675,\n",
      "           32,  395,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1043,  953,    1,  419,   98,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2229, 1397, 2319,  810,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  820,   32,   91,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460, 1320,  269, 2264,   37,  619,  388, 2043,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   69, 1086,   28,  187,  430,  509,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   78,    1,  565,    1,    1,  202,  223,  408,    1,  471,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  419,   98,  195,  776, 1578,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  599,    1,    1,  420,   98, 2707,   12,    1,  142,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  342, 1625,    9, 1805,  439,   37, 3144,  863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,   37,  125, 1069,  548, 1700, 1034,  636,  276,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   12,    1, 1473,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,   37,  741,   98,  651, 1031,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  936,    1,  220, 1768,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2153,    1, 2018,  104, 2471, 2449,  198,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  550,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  410,  695,   32, 1968,  768,  149,  167,    1,    1,  613, 1117,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3296,  135,    1,   32, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   44, 2917,  444,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,    1,  547, 1821,    1,    1,  267,    1,  216, 1954, 1821,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2737, 2399,  202,    1,   37,  442,  105,    1, 3311,  420,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2972,  475,    1,  939,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  294, 1920,    1, 3343, 3065, 2844,  548, 3376, 1585,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162, 1950,   32, 2018, 3392, 2960, 1426,    1, 3094, 2347,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1, 2208,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2693, 1396,  784,  659,   45, 1778,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1535,  124,   84,   81,   37,  620,  627,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 1185,  582, 2158,   45, 2121,    1, 1638,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1363,  794,  517, 1085,   32,   91,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   26, 3289,  921, 3303,    1,    1,  191,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  487, 2924,  429,  915,    1, 1108,   32,  463,  531,   63,    1,\n",
      "          221,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,   51,  529,  344, 1259,   71,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   32,   37, 1349,   12, 1170,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2939,  696,  519,   37,  449, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275,  168,   98,  166, 1260,  548,  736,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  389,    6,    1, 1159,    1,   12,  572,  156,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1902, 2097, 3263,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 1756,  105, 2229,    1, 2283,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  632, 2751, 2582,    1,  469,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  245,   37,   56,  339,  340,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  361,    1,   32,  166,    1, 1821,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1212,  315,   37,    1,    1, 2049,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,  159,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1417,    1, 2226,    1,  105,    1,   32,  927,   45,\n",
      "         1147, 1038,  966,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2800, 1218, 1231,  297,    1, 1992,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  880,    1, 1159,  119, 1772,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  963,    1, 1194, 1843,  207,  338,   98, 1405,   44,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  675,  325,  552,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1095,   12, 2464,  686,  191,    1,   32,  111,  589,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2855,   98,    8, 1983,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3280,   12,    1,  471, 1560,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  301,    5,  302,  431, 2069,  432,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   25,   28,   98,  702,  169,  132,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1667,    1,   32, 2504, 2527,  164,  400,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3141, 1090, 1829, 3119,  176, 2307,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   45,    1,   32,    1,    1,   32,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  422,    1, 1370,   45, 2511,  172,   12,  993, 1108,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424,    1,    1,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1973,   46,    1,  220,  199,  472, 1139,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1118, 3036,  484,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  370, 1862,  528,    1,  832,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  391,  477,    1, 1327,   37, 1313, 2893,   12,  996,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  422,  134,    1,    1, 1902,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,  459, 1842,   80,  956,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  163,    1,   12,    1,  341,    1, 1159,   69,  102,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2834,  361,  861,  105,  499,  328,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  976,  884,   54,   32,    1,  977,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   85,   98,    1,  220,  354,   37,    1, 2337,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2835, 3109, 1791, 3393, 3035,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   64,  799, 2023,   32, 1895,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 1606, 1268,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12,    1,  838,   98,  411, 2550,  132,  943,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  140, 1194,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,   12,   35, 1484, 2199,   37,  170, 1377,  226,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1084,  841,  408,    1,   32,  166,  599,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2859, 2955, 2483,    1,    1,    9, 2715,  361,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3213, 1041,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,    9,  914,  220, 3078, 1987,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1264,  841, 3272,    1,  176, 2049,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810,  294, 3065,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1430,  952, 1891, 1876,   37,    1, 1428, 3146,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2881, 1366, 1188,  105,  327,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,  313,  176,  730, 1777,  220,  365, 2366, 1402,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  206,   12,  207,  174,   28,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   94,  927, 1494,   32, 1194,   32, 2918, 2107,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190,  665,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  361,    1, 1413,  632, 1218,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,    1, 2072,   32, 1472,   28,  220, 3145,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1087,   37,    1,  331,    1,  453,  538,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2942,    1,   39,   45,    1,  220,    1,   81,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401, 3097, 2823,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  921, 3260,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3151,    1, 1258,  187,  922,    1,  474, 2709,   98,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,    1, 1263, 3374, 1484,    9, 1945,  444, 1094,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2962,  479,    1,    1,  764, 3108, 2872, 3079,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1480,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1423, 2329,  116,  126,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136, 1268,  386, 1891,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   45,    1,  100,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  365, 3044,  754,    1,  357,  193,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1025, 1936, 2584,  389,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  125,    1, 1608, 1478,  220, 3115,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2789,   37,    1,  365,  650,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2226, 1210,  104,   37,    1,   79, 2017,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1861, 1082,  439,   45, 3118,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1, 1675,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2295, 2087, 2614,  872,  420,  367,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 3378,  776,  750, 1142,  653,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1,  51, 693,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 397, 261, 444, 104,   1, 342,  98,   1,   1,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  407, 1159, 1948,  220, 1918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1571, 2934, 1444,  321, 2192,    1,  140,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  691,   12,    1,  267,    1,  190,  764,   98, 1184,  347,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,  132, 2094, 1625,   98, 1189, 2673, 2109,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1705,   37, 1211, 3343, 3365,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2445, 1243,  453, 1674,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1767,    1,  105,    1,  173,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  180,   12,  197,  418,    1, 1680,  157,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1423,   12,    1,    1,  267,    1,  191,  487,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2801,   37,  693, 2226, 2969,   37,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  686,  191,  304,   45,    1,   97,  176,  487,  493,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  668,  293, 1236,  388,  763,  249,    9, 1148,  220,  111,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3281, 1707, 3181,  706,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868,  812, 2024, 1516,  115,   45, 2708,  741,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1277,    1,   12,    1, 2059, 1654,  798,   37, 3113,   12,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311, 2936,  190,    1, 3181,    1, 1545, 3066,  251,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 2107,    9, 2512,   37,  439,   45,  914,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2609,  342,  222,   98, 1527,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1744,    1,    1,  481,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,   32, 1430,  361, 3140,    1,    1,\n",
      "          267,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2693, 2393,    1, 2223,    1,  566,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2461,    9,    1, 1867,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  215, 1707,  403, 2288,    1,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1013, 1522,    1, 1381,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1159, 3220,   98, 2069,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  745,   32,  467,  176, 1816,  176,  147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,  119,  288,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2474,   42, 1159, 3048, 2818,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1725,   12,    1,  498,   37,    1,  996, 2532,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  865,   37,  608,   32,  121,    1,  964, 1288,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  291, 1877,   37,  856,   79,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1796, 1446,  437,    1,  716, 1269,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1204,  167,    1, 1315, 1965, 2481,    1, 1409,  267, 1120,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3111,    1,    1,   32,  531,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2137,   32, 2468,  548, 3387, 1665,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  696, 2611,  437,  125,    1,  408,    1, 1124,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  106,   37,  138,    1,   59,   37,  875, 2039,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282,    1,    1,    1,  361, 3257, 1758,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  511,   12,    1,    1,   37, 1844,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2355, 1718,  166, 2069,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2120,    1,   37,  726, 1684,   32,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  233,  476, 2079,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  315,    1, 1437,   32,   56,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374, 2153,    1,  319,    1,    1,  267, 1094,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   45,    1,  105,    1,  955,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2494,  872, 2257, 2017,   37,  688,  691,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  790, 1586, 2998,  669,    9,  460,    1,   24,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1056, 2267,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1157,    1,  650,    1,   32,    1, 3137,  548,  985, 1260,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1707, 3042,  161,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2459,   65,  883, 1279,  338,   37,    1,   32,  385,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3129,  873, 1118, 3271, 3251, 1090,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3358,   12, 2611,  912, 2644,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,  208,   37,    1,  955,  956,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3236,    1, 3266,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  849,    1,  387,  105,  787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  326, 2037, 1018,    1, 2789,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3372,    1,    1,  202,  590,  943,   45,  863,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1190,    1, 1665,   37,  319,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129, 3325,  640, 2463,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,    1,  365, 1461,  675,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2777,    1,  474,  297, 2901, 1816,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1574,   37, 1079,  600,  340,    1, 2261,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3198, 1426, 2069,   32, 2197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275,    1, 1523,  297,  443,   98, 2095,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  396, 1354, 2529, 2334, 2545,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,  744,  577,    1,   98,  236,  237,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,   37, 1876, 1234,   32,  627, 2308,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  387, 3065, 1021,   92,  220,    1,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2844,  187, 3121,    1,  640,  455,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1813, 1691, 2860,    1,  105,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  476,   39,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2868,    1,  590, 1031,   32,  104, 1731,    1, 1563,  548, 2357,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 1707,  163,    1,   12,    1, 2081,  342, 1713,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  572,  197, 1226,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2451, 1635, 2748,   45, 1771,   12,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3208,    1,    9, 3207,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2815, 1408,    1,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  931,    1,   37, 2553,   39, 2144, 1675,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1431,  338,   98, 2089,  550,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 741, 892,  51,  92,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 829, 861,  12, 800, 345,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 1958,  365, 1117, 1525,    1, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3059,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1545,  335,    1, 1992,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3188,  162,  916,   37,  698,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1704,  515,  105,    1, 1456,   92,   37, 1100,  279, 2910,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  931,    1, 3260,    1,  548,   56, 2799,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  650,   45,    1,  667, 1384, 2789,   37, 1734, 1114,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1393,  400,  614,   37,  845,  147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1266,  159,    1,  187,   82,  796,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2479,  631,  176, 2620,  686,  963,   26,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2940,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,  981,  231,    1, 1023,  105, 1684,   61, 1488,  763,  590,\n",
      "         1684,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3144,  650,    1,    1,  413,    1, 1360,  612, 2199,  741,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  716, 2299,  600, 3358,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1167,    1,   55,  105, 2527,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  884,   98, 2355, 1013,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  224, 3007, 2355, 1013, 2549,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3226,    1,  664,  857,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  422,    1,  132,    9,  111,    1,   45,  172,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  405, 3291, 2753, 1394,   32, 1245,    1,  714,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   10,   12, 1209,  921, 2275,   12,   32,    1,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   85,  361,   39,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2511,   37,    1, 3016, 1935, 2308,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,  967, 2432,   74,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  415,   32,  199,  166, 3117,  665,  460,  810, 2444,   32,  726,\n",
      "          297, 3296,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 1638, 1758,   37,  104,    1, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1004,   45,    1,    1,   98, 3309,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1744, 2264,  565,    1,  191,    1,   81, 3018,  469,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  715,  460,  639,  744,  119,   73,   98, 2997,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 3209,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1855,  446, 2405,    9,  342, 2396,   32, 2331,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1157, 2702,    1,  361,    1,   85,    1,    1,  176,  177, 1530,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  293,  420,  945,  104,  358,   37,  125,  138,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   97,  897,    9,  104,  673, 2324, 1010,   60,  720,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1830,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  883,    1,   28,  187,  575,    1, 2017,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,    1, 1552,   32, 1815,  187, 2885, 1086, 2237,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  522,   98, 3388,  894, 2014,  187,    1,  187,  166,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  430,  391,  477,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2308,   37,  907,  892,   32, 2184,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2415,    1,    1,  384, 1708,   32, 1923,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1195,   32,  584, 2176,  686, 2177,  191,   64,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2774,  650,  267, 3349, 1822,  907, 1004,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  176,    1,   12, 1815, 2362,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1413, 1841,   32, 1727,    9,  609,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  112,  854,   12,   93,  837,    1,    1, 1994,   31, 1553,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3343,   36, 2960, 2414,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1147, 1016,    1, 1564,  596,  714,  220, 1133, 2082,  115,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  284, 2375,  176,  121,   36,  254, 2713,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  726, 3201,  202,   51,  606,  901, 1764,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,    1,    1, 1505, 1331, 1718,  437,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1806,   61,    1,   98,   49,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  868,   37, 2192,  311, 2250,  176,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1815,    1,   32,  854, 2018,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1707, 1062,    1,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3091, 1631, 1159,    1,   45, 2736,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2476,    1,   32, 3376,  776,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 2827,  187, 2625,    1,  722,   37,  151,    1, 2596,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,  152,  572,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,   98,  112,  226, 1499,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1594,    1, 1159,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   12,    1, 1222, 1992, 1564,   29,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1147,  957,    1, 2764, 3356,  562, 2024,  132,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,    1,   15,  729,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  179,    1,  746,    1, 1766, 1767, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1477, 2773,    1, 1464,   37,  877,    1,  125,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2297,    1, 2731, 1863,   45,  166, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  337,    1,  876,    1,  952, 2970, 1089, 1090, 1281,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,   12,  156,  103,  689,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1151,   93,    1,   32,  367,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  947, 1343,   85,  997,   45,  317, 3070,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1009,  765,   37,    1, 3372,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  356, 1691,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  391, 1236,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  443,  997,   71,   32,  557,  540,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,   83,  267,  204,    1, 1143,  495,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282,    1, 2682, 1990,  261,  548, 2712,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  580, 1484,   37, 1540,  297,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  734,  591,  469,    1,  592,  437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2572,   32,    1, 2531, 2596, 1585,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  183, 2613, 1494, 1632,   98,  105, 1133,   74,   32, 1423,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,   37,  123,  896, 1097,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2360, 1281,   98, 1393,   15,  384,   39,   45,  171,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  102,  764,    1,    1,  354,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  574,   11,  662,    1,    9,  152,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2857,    1, 1327,  112,    1, 1837,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3151,    1,   46,  271,   85,   32, 2184,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,    1,    1,  504,  187, 2997, 1654,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  112,  830,    1,  367,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006,    1,  547,   32, 3343,  463,  232,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3122,    1,  150,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1442,  994,    1,  150,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,    1, 2071, 1331,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  328,  313,   37,    1,    1,   32,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  536,    1, 2608, 1512,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2747,  482,  319,  314,  721,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3363,   32, 2589,  220, 3370,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  559,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2741, 3192, 1863,    1,    1,  948,   37, 2579, 3184,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 1066,  297, 1117,    1, 2629,    1,   32,  806,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3261,   61,  603,  176,  375,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1883,  418,   98, 2425,  170,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  857,    1,  477,  515, 3181,  726,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  171,  190,  483, 1343,   32,    1,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  284,  163,    1,   12,    1,    1, 1046, 3343,  966, 1655,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   37,    1,  361,   81,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  903, 1447, 2386,  463,  297, 1593,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2406, 2784,  446,   37, 1083,    8,   45, 1428, 1511,    1, 2834,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  586, 1872,    1,  109,  524, 1228,   37,  631, 1278,  918,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2759,   98,  105, 1151,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1208,    9,    1, 1234, 1536,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   32, 1531,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  915,    1,  829, 2055,  166, 1107,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3345, 2035, 1757,    9, 1645, 3365,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2883,   37, 1211, 2751,   32, 3102,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1438,  650,  580,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  547,    1, 2572,   32, 1815, 2887, 1523,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3060,   37, 1734,  776,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  782,  388,    1,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800,  512, 2753,  183,  199,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2072,  166,  847,   32, 1523,    9, 2227,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106, 1713, 2355, 1013,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1089, 1675,    1,   32,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,  720,    1,    1, 1948,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  281,  282,  283,  284,  285,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358, 2312,    1,    1, 1407,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,  784, 2580,    1, 1288,  590,  636, 1500,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  400,  444,  672,   69,  568,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  104,  560,    1,   28,    1,    1,   85,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947, 2856, 1255,   12, 1354, 2556,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  892,   12,  103,    1,  176,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1034, 2175,   37,  439,  176, 3013,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  310,  159,  410,  187,   69,  816,   27,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363, 1800, 2529,  622, 2696,  115,   45, 3343,  806,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  332,    1, 1116,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1187, 1033, 1210,  384,  395,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2944, 1512,    1,  187, 1065, 1190,  796,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3121,    1, 1789,  456, 2176,    1, 1244,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,   37,   26,  388,  124,   32,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  365, 2741,    1,  460,   12, 1343,    1,  726,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1533,  917,  120,   32,  404,    1,    1,  602,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  103, 1283,  550,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  189, 1243,  315,   37,  508,   79,    1, 1612,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3329, 1641,   37, 3253,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,  197,   79,   32,  401, 1732,  636,    6,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25, 1473,   98, 1894,  646,    1,  550,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,  915,    1,  613,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1411, 1537,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1925, 1583,    1,  565,   85,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1177,  105,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1817,    1,    1,    8,    1,   37,  137,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,    1,   12,  775,  777,  279,    1,  809,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1479,    1,    1,    1, 1781,   32, 2170,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1398,  612,  665,  105,    1,   98, 2349,    1,  267, 3303,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  853,  538, 1228, 1908, 1122,  114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 1769,   37,  544,  460, 1488,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  315,   37,  335,  572,  134,   45,    1,  131,   37,    1,\n",
      "          131,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  160, 1900,  818, 1278,   37,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  172, 1270, 1660,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,  832,  187,  646, 1071,    1,  193,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328, 1050, 3116, 3313, 1980,   37,  114, 1114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1260,    1, 2821,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1789, 1557,  396, 1918,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  546,   82,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2759,    1,   16,    1,  365,  280,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3196, 1564,  411,  472,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  449,    1,    1,  678, 2275,   12, 2193, 2103,  617, 1058,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,    1,  647, 1889,    1,  210,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  507,  361,  342,    1,  442,  443,   98,  793, 1527,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977, 1830,   37, 2968,   98,  105,  853,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1022,    1,  202, 1130,    1, 1561, 2339,  726,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2073,  401,  197,  418,   98,  529, 1220,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1801,  600,  903,    1, 1447,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,    1,  388, 3387, 2985,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  942,    1, 3360,   98,  890,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,   78,    1,    1,   98,  164,  165,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  220,  365, 2367,    1,  829,  952,    1,    1,  566,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  636,   85,    9, 1034,  276,   66,   32, 1801,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1380,    1, 2913,  176, 2589,   45,  105, 2519,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2551, 2905,    9,    1,    1, 3059,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,  420,   37,   52,    1,   45,  460, 1278,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  315, 2355, 1013, 2549,    9, 1158, 2261,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094, 2794, 3358,   37, 1910,  247,    1,    9, 1983,  351,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   94, 2060, 1161,  972,   37,  832,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2171, 1675,   98,  844,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,  442,  448,  703,  187, 1196, 1124,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  301, 2972,    1,    1,  202,  590,  522,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3194, 3195, 1052,  453,  289,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  198, 2164,    1,    1,  686,  455,  176,  177, 1530,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1250,    1,  191, 2592, 1010,  289,   98,  258,  280,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  121,  765,   37,    1, 1839,  651,  895,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  501,  827,  951,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  758,    9,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  411,  819, 2155,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2971, 2896,    1,  928,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  764,  787,  947, 1013,    1, 1482,    9,    1,   32,    1,\n",
      "          400,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  896,    1, 1258,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  104, 3111, 2572, 1425, 2597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  166,    1,   45,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2845, 1056, 1034, 1334,   45, 3026,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2702,    1,    1, 2414,    1,    1,   32,  447,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2265, 1407,    1,  267,  460,   61, 1769,   37, 2341,  949,   45,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3240,   39,    9,  914,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  952, 1294,    1, 1876,    9, 2627, 2871, 1027,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3175, 1180, 1387,  105, 1090,   45, 3256,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  586,  163,    1,   12,    1, 2375, 1867,   32,  691,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2962, 2720, 2796,    1,  730, 2614,    1, 2615,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  582,   45,    1,  108,  112,   37, 2681,  444, 2834,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  455, 1550, 1996,    1,    9, 3102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783,    1,  987, 2014,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   14,   15,  670,   98,  382,    1,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,  292,   32,  754, 1085,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2764, 2962, 3238, 2781,  187,  730, 2614,    1,  608, 2615,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437, 2227, 3213,    1,   61,  255, 3177,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,    1,  844, 1151,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1,    1,  658, 1810, 2161,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1921,   32, 2018,    9,   46,   98,  531,    1, 2834,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1293,    1,   32,  411, 1970,  442,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1020, 1799, 1479,    1,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123,   12,  865,   37,  705,    1, 1417,    1, 1183,  199, 2175,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2932, 1604,   98,    1,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1481,    1,    1,  985, 1857,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2193, 3362, 2832,  877, 2429,   37, 2703,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  113,   27,   98,  889,  529,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1812,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3242, 1804,    1,  187, 2252, 3164,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  420, 1647,   32,  864,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1583, 2764, 3394, 2072, 2835, 2137,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2800,    1,  429, 1545,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089, 1090, 1091,  619,  105, 1417,    9, 1705,    1,  706,  774,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1595,   93,   66,    9, 1206,    1,  954,    1,  506,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3253,   98, 1171,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  579,  166, 1995,   96,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,   77, 1146, 1703,  119,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  716,    1,   72,  401,  354,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110, 1046, 3284, 1492,    1, 1515,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,  197,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  488,  443, 1232, 2024,   46, 1398,  612,  698,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3371,  140,    1,    1,  991,  454,   37, 1752, 2018,   12,\n",
      "         1065, 1190,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  612,    1,    1,   12,  999,    1, 1924,    1,  220,   85,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2746,    1,   10, 2001,   98, 2095,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,  721,    1, 2098,   28,  166,  669,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,   1, 176, 176, 551, 612,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 328, 592,   1,   1, 667, 996, 119,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  148,  162,   91,   12,  432,   37,  151,  647, 1160,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,    1,  328,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 2659, 2597, 3006,    1, 2572,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103,    1,    1,  967,    1, 1857,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  284, 2466, 3153,  663,    1,    1,  297,   10,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  348,   12,    1,   66,    1,   79,   32,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  458,   45,  507,  672,    1,    4,   32,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  195, 1091,    1, 2695, 2796,    1,    1,   37, 1545,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  657, 1620,   79,    9,  911,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   98, 1427,    1, 3175,  504,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1614,  453,  777,  279, 1117, 1525,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2949, 1401, 2160, 2049,   37,  726,  297,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  547,    1,  610,    9, 2649, 2162,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2634, 1713,  657,   32, 2177, 1027, 2146,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2890,    1, 2421,   39,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  474, 1707,  104,   22, 2362,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1465, 1466,  936,  283,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200,    1,  662,    1, 3356,  193,   98, 1638,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2762, 1976,   32,    1,  756,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  256,   32,   95,  412,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1766, 1767,  412,  402,    1,    1, 2210, 1151,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3365,  820,   32,  531,    1,  686,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3282, 3169, 1249,    1,   37,  759, 3329, 1990, 3295,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3167, 2633, 2728,    1,   37,  105,   12,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2368,   98,  387,  197, 1315,  308,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  755,   37, 1584,    1,   32,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1465, 1466,  932,  103, 1470,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  803,    1, 1669,  183, 3022,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  973,  854,   37,  166,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  387,    1,   32, 1147, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  171,   45, 1193,    1,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  148,  155,  647,  693,    1,  744, 1757,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  603,  388,   55,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  894,  477,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1266,   82,  796,    1,  159, 1374,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1110,    1, 3285,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178,  147,  261, 2834,  776,   37,  698, 1411, 1034,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2517,  864,  267,  219, 2027,  176,  903,   46,  729,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110, 1119, 1096,  384, 2565,   37,  166, 2308,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1829, 3363, 3390,   32,  187, 3343,  650,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   31,    1,   28,  128,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,   12,  365, 1107, 1597,  884, 1003,  176, 1158, 2102,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1366,    1, 1084,  841, 1469,  774,  217,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  361,    1,   98,  166,   71,   32,  602,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 1768,  161,   24,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  550,    1,  513,  514,  680, 1994, 2819,  625,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,  187, 2528,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1740,   45,  104,    1, 1758,   37, 3179,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  868, 2856,   32, 2764, 3155,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962,    1,  614,  323, 1114,  187, 3232, 3055,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2837, 2867,  311, 1778, 2580,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  136,   12,   59,    1,   37,    1, 1537,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375, 1260,  399,  548, 3358,  928,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2771, 1586,  590,    1,  584, 3239,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,  631,  297, 1477, 1990,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  116,    7,    1,   32,    1, 2502,  856,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,   12,    1,  267,    1,  132, 1372,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1813, 1094,    1,  864,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 3141, 1292, 2356,   45,    1,  966,  134,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1934,  456,   85,  622,  993,  756,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1380,   38,   28,    9,    1,  317,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1430, 1648,   37,  429, 1211,  890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741, 2783,  593, 1990,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3364,    1,  815,   45, 2108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2777, 2202, 1264,  187, 3115,    1, 3285,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,   27,  845,  951, 1547,   98,    4,   29,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1273,  681,  753,  575,  190, 1594,   98,   37,  844,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   47,   39, 2242,  190, 1075,  590,    1, 3190,  335,   98,  590,\n",
      "            1, 3010,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1788,   68,    1,  608, 1714,    9,  449,  199,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3116,  922,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1745,    1, 1973,  167,  688, 2388,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2590,  365, 2195,   32, 1539,   45,  268,    1,  229,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   10,   45, 3388, 2024,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,    9,  166,  356,  220,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  270,   32,  207, 2502, 2678,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 2924, 1753,  297,    1,   32,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3403, 2414, 2516,    1,    1,    1,    1,  384, 3069,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,  225, 1066,   92,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  156,   28,  118,   98, 1239, 1220,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  162,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 1251,    1,  884,  297,    1, 1589,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3292,  455,   12,    1, 2479, 1383,   32,  455, 3222,  220,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75, 1380,  429,   98,    1,  259,  347,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  388, 1574,  763, 2383,   32, 2425, 1883,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1726, 2000, 1815, 2096,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1957,  730,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,    1,    1,    1,   98, 2347, 1638,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  581,  872, 1042, 3135,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,    1,    1,    1,    1,  415,  187,    1,  187, 1886,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1718, 2718,  686,   81,  176, 2881,   12, 2215,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885,   12,  356,   37,    1,  190,   52, 2177,   37,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  443, 2493,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424,  414,  967, 1846,    1,  191,  166,  171,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2912,  765, 1159,  631,  548,    1,  449, 1385,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   29,  410,   98,  954,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3204,    1, 3169,   32, 2069,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  355,  267,  156,    1,   15,   93,   37, 1121,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  550,  132,    1,  454,    9,  221,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3398,   61,  105,    1,    1,    1,    1,    1,  650,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  982,   37,  130,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   93, 1568, 1126,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  683,    1,  191, 2062,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  261, 1432, 3207, 1408,  671, 3126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1502,  765,   37,  846, 1503,  887,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,    1, 2746,   37,    1, 1603,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2003,  114, 2414,   32, 2707,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  571,   37, 1957, 2340,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1187,  647,  132,  877,    1,    9,  148,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1147,  379, 1982,    1, 2208,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,   30,    1,  193,    1,  951,    1,  505,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 657, 197, 418,   1, 202,   1,   1,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,  79, 548, 330,  37,  47,   1,  50,   9, 331,  94,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  952,   37,    1, 1521,   32, 1206,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1897,  166, 2823,  736,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,  887,   45,  647, 2094,   17, 1159,  289,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  389,    1, 1696,   45,    1,  287,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 2750,   45,  192, 1085,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1641,  916,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  422,  267,  224, 1126,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  765,   28,  220,    1,    1,   85,  220, 2206,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  680,  114,    1,  314, 2151, 1936, 1469,  384,  137,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2107,   98,   37, 1155,    1,    1,  725,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  997, 2685,    1, 2483,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,    1, 2384,    1, 2639,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  626,   51,   52, 2867,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1285, 1823,   37,  759,    1, 3179,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2357,  297,  163,    1,   12,    1,  469,   37, 1806, 1541,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,    1,  568,  680,  898,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1842,  361,  613,  469, 1479,  283,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537,  446,   37,    1,    1,  115,   45,    1, 2237,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1017,  261,   32,  593,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  912,  605,  302,  765, 1836,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,  191, 3121,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384,    1,   37,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  765,  444, 2789, 1443,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,  251,   28,   37,    1,    9, 3144,  863,  963, 2122,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1965, 2550,  782,  388,    1,   45,  238,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2226,  933,  777, 1085,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1502,    6,  215,  458,   48,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2863,  292,    1,  111, 2608,    1,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2202,  984,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1454,  531, 2874,  361,  267, 1428,  894,  693,  388,  764,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1177, 1048,   45, 1443,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3163,  726,  162, 2942,   72,  671,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  702,    1,  169,   37, 2123,   32,  131,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1035,  162, 1757,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1981, 2420,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,    1,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2176, 1753,  297, 1442,    1, 1799,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 2292,   32, 3118,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1698,  147,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200, 1412,  844, 1151,    9,  617,  618,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2476,    1,    1, 2337,    1,  580, 1018,    1, 1473,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  212,  213,   37,  138,    1,  131,    9,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3206,    1, 2920,   32, 2138,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,    1, 3358,   12,    1,    1,   37, 2708, 1389,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   64, 2619,   98,   32,    1,  567,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  796,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3172, 1090, 1829,    1,  176,  511,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1433,   10,   61,   98,  166,    1,  220,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1089,   30, 3365, 3395,   32,  531,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2948,   12, 1411,  183, 2277,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,  109,  696,  816,   69,  636,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  171,   90,    1, 2547,   37,    1, 2997,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1802, 2122,   22,  395, 2344, 1126, 2306,   37, 1911,    1, 1388,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2841,    1,    1,    1,   37,  726,    1,  856,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,    1, 3037,  729,   98, 2378,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708,    1,  187, 2821,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3229,    1,  162,    1,  331,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   74,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,   27,    1,  109,  661,  430,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   12,  366, 3407, 3382,  852,   37, 1630,  132,  220, 2751,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   32, 1186,    1,  590,  388,    1, 2072,  166, 1215,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171,    1,   37, 1527,    1,  458,  515,    1, 2196,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2151, 1252,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   72,  401,    1,   28,  390,    9,  137,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614, 1594,   37, 3237,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,  698,  444, 3132,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 1230, 1917,    1,  166,    1, 1362,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,  108,   69,  109,    6,  110,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  790,   37,  761,  489, 1264, 1265,    1,  117,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1536, 2118,  444,  104,    1,  942,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  510,    1, 2028,  220,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12,  636, 1998, 2126,    1,    1,  267, 1619,  458,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2115,  574,  267,   37,  429,   49, 1611,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,  688, 2642,    1, 2341, 1264,  841, 1832,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1, 1363,  872,   28,   98, 2255, 1705,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  707,    1,    1,    1,    1,  833,  612, 2898,  166, 3089,\n",
      "         2565,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  614,    1, 1360,  612, 1343,   98,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2997, 1614,  590, 1400, 1211,    9,    1, 1778, 2264,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  233, 1392,   45,  286,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9, 2024,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  393,    6,   37, 1844,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2136, 2889,  384, 1675,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1366,  190, 1598, 2292,    1, 3375, 1399, 3355,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,   37,  804,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1398,  612, 2116,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1360,  612,    1,    1, 1988,   45, 2930,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  300, 3234,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1016, 2789, 1929,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   10,  361,  964,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  277,    1,  424, 1918,   85,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2606, 1089,   30,    1,   45, 1855, 2886,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327, 2864,  187, 2161,  168, 1211,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  972,  400,   45,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2227,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1816,  281,  282,  733,  131,   32, 1879,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380,  884, 1861, 1159, 1161,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98,  666, 2978, 1118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006,  114, 1957,  176, 2597, 1606,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  187, 3075,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  780, 1426, 1845,  132,  220,  587,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  242,   98,  198,  275,  156,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 2789,    1, 1479,  390,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2932,  588,   37,    1,  166, 1117, 1525,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 1475, 1126,  636,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1,   39,   45,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1744,  176, 2413,  220,   10, 1407, 1563,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  941, 2104,  267,  938,    1,  669,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,  391, 1081,   12,  365,  650,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2636, 1027,   13,    1,   12,  103,  710,  796,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2442,    1, 2253,    1, 1409,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  224, 1419,    1, 1013,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,  190,  843, 1876,   32, 3360,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  344, 1656, 2596,    1, 3279,  220, 3045, 1910,  176,  177, 1530,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2736, 2520, 2678,   98, 2095,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3144,   12,    1,  446,    1,  693,   37, 1557,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,  166,  298,    1,    1,    9, 2977,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2077,   12,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  374,  375,   11,    1,    9,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2887,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,   37,   26,  365,  327,  250,   32,  163,    1,   12,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  848, 1303,  551,  196,  613,    1,    1,  105,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,   30, 2822,  497, 1822,  125,  624, 1649,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151, 2511,  535,    9,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2823,  741,  680,  454,   32, 3367, 1010,  997,   45, 2292,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  864, 1707, 3385, 1140,    1,  488,   37,  222,  127,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1240,   52,  653,  187,    1, 1142,   32, 1405,  776,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2161, 1685, 1888, 1964,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,   80,   37,  103,  331, 1219,  191,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2779, 2032,    1,  356,  187,    1,   37,  683,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3097, 1557,  387,  133,    1, 1004, 1002,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  108,    1,    4,  176,  629, 1603,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,    1,  220,  534,    1,    1,  952,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  619,  365, 1994,    1,  261,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   71,   98,  720,   32,  160,  102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,  534,  251,   59,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  999,  321,   52, 1488,    1, 1720,  460,   12,  193,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   61,    1,  105,    1, 2814,    9,  163,    1,   12,    1,  535,\n",
      "            1,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,  186,   32, 1194,    1, 1452, 2522,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2753,    1,   32,  792, 1938,    1,  792, 1912,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,  476,    1, 1799,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1739,  700, 1396,    1,  220, 1907,   45, 1412, 2524,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  654,   32,  166,    1,  297,    1,    1,   37, 1213,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 2161,   12, 3096, 1632,   37, 3293,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  500,    1, 1191,  872,   28,   98,  858,  668, 2568,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  618, 1159,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,    1,  746, 1421, 1766, 1767,    1, 1259,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1973,  335,  183,   84,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  183,    1,  176,  405,    1,   37,  125,  541,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 193,   1, 600,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 341,   1, 105, 628,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  964,  300,    1,   37,  443, 2938,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  313,    9,  103,  220,  365, 1050, 2334,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  105,    1,   45,  593,   12,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 2998,  921,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  750, 1576,  774,    1,  220, 3378,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  927,  782, 1534,   45, 2938,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2950,   32, 1430, 2766, 2224, 1190,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1414, 2856, 3343, 3045,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2176, 1421,   28,    9,  822, 2441, 3049,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,   37,  741,   98, 1412,  844,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1432, 2272, 2690,   37,  168,   98, 2699,    9, 2741,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,    9,  105, 2280,  209,  210,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3198,  162, 1211, 1747,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1923,  171,  729, 1587,   45,    1, 2236,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  615,  335,  105,  818,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081, 1585, 2985,    1, 2555,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2934,   37, 1911, 1284,    1,   28,  191,  317,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1, 2672,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,  864, 2055,    1, 3107,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1369,  716,    1,  182,  354,  202,  267,  460,   12,   81,\n",
      "           98, 1171,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  460,   12, 1977,  202, 2205,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20, 1523,   61,    1,   12,  449, 1463,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1110, 2871, 1340, 1581,    1,    9,    1,   24,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2373,  593,   45,    1, 3011,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3184, 2405, 2827,  845,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1143,   83,    1, 2310,  315,    9,  654,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2881,  267, 1158, 1360,  612,  184, 1412, 1017,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  614,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,  884, 1003,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602, 1112,  176,    1, 1058,   98,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1862,  459,  115,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2777,   32, 1381,    1,  220, 3115,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1920,  515, 3081,  548,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1,  449, 1101, 2657,    1,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  429, 1617,   37,    1, 2250,   32,  593, 1990, 3275,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 1574, 1492, 3118, 2705, 1347,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,   26,  526,  187,   69,  102,  817,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1757,    9, 3340, 1428, 1149,   32, 3360, 2424, 2198,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3239,  565,  603,   37,  608,    9,  627,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3118, 3406, 1961,  105, 1034, 3147,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  561,    1,  503,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  475,  796,  548,  197, 2393,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2095, 1527,    1,  104,  980, 2108,   15, 1281,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  868,  671,    1,  197,   28,    1,  419,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  384,  166,    1,   45,    1,    1,  435,  829,   12, 2102,  525,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  936,  104,   59,  887,   45,    1,  369,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1447,  267, 2960, 1924,  205,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2617,  913,  753,   32, 2214,    1,   41,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  353,  197,    1,   15, 1269,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  474,  562, 1845, 1384, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  694,    1,  453,  454,   37,    1, 2771,   32,  903,    1, 1417,\n",
      "            1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   12,  156,  103,  689,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3287,  664,    1,    9,  166,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2648, 2801,    1,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  353, 1169,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3005, 2940,   37, 1778, 2264,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1236,  297,  808, 1573, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  534,  315, 1842,  413,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1417,   51,   52,  384, 1983, 1867,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,   85, 2642,   37, 1334, 1452,  220, 1110,   32, 3235, 1264,\n",
      "          841, 2107,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3343, 2649,  741, 1027,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220,  166,    1,   45, 1821, 2057,    1,  166,  880,    1,  571,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,  155, 1915,  529,  102,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213,    1,   37, 1545,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,    1,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  717,    1, 1741,    1,   37,    1, 1300, 2359, 1222,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  884, 1544,  444, 2819,    1,  909,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1366, 1360,  612,   52,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3096,  602,    1,  455,   32,  310, 2800, 2579, 3201,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,   66, 1472,  996,  872,    9,  920,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  325, 2725,  280,  260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3122,    1,  150,   12,    1,    1, 1631,   85,  166,  422, 3154,\n",
      "         1090,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  328, 1405,  369,    1,   12, 1644,  939,    1, 2297,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1635,  103,  314, 1213,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  487, 1384,  957,   37,   84,   28, 1994, 2095, 1506, 1232,  140,\n",
      "         1411,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,    1,    1,   37, 1910,  557,  540,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3318,    1,   37,    1, 1505,   98, 3130,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1459,  140, 1029, 1743,    1, 1578,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1567,    9, 1431,    1, 1998, 1379,   12,  112,  499,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1159,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 2188, 1877,   37,    1, 3004,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  218,  332,   45, 1718, 2261,   37, 1427,  191, 1716,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2156,  440,  802,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 1062,    1,   37,  151,   81,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2777, 1564, 2321, 2553,   28,  361,  335,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 1360,  612,  576,  365,    1,   37, 2646,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2844,   79,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  387,   59,  449,   74,    9, 2692, 1090,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  579, 2595,    1,    1,  384,  166,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1355, 1443,  220,  365,  111, 1107, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,    1,    1, 1204,    1,  384, 1341,    9,    1,\n",
      "          372,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196,  952,    1,   32,  176,  612,  613,  170,  918,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3120,  913,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2397,    1,   37,    1,    1,  202, 2945,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  186, 1260, 2414,    1, 2803, 1060,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2246, 3328,  386,  546,  453,  512,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  149,  396,  829,  583, 1652,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1640, 2774,  650,  251,   37,  946,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1543, 3358, 1351, 1492,  190, 1604,    9, 2024,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  288,   37,  726,    1,  372,  333,   45,  632,  141,   48,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1465, 1466, 3007,    1,  279, 1402,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,    1,  920, 1564,  579,  460,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  511, 1141,   37,  726,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  640, 3339,  787, 1396,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2932, 1835,    1,    1, 1463,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  387,  166,    1,   45,  885,  710,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   21,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,   12, 3118,  861,  105,  792,    1,  792,  267,  437,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3013,  105, 1805,   22,  100,    1,    1,  506,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2967,    1, 1632,    1,  914,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1092,    1, 1236,  829,  297,    1, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  914,   51,    1,   98, 2697,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  636,   45,  931,   37,   52,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1358,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  973,   98,  903, 1447,   46,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  935,  546,   28, 1821,   95,  469,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3021,   12,  671,  590, 1400,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1492,   12,  166, 3289,    1, 1492,    1,    1, 3076,  476,  844,\n",
      "          748,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2144,  638, 1804,    9,    1,   37,   26, 1039,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  381,   12,    1,  182,  399,  562,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  147, 1707,   49, 1727,   98,    5,  302,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  242,   69,  102,    1,   45, 1177,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2907,   32, 1194,  919, 2614,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12, 2086,    1,  693, 2739,  357,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  276,   51,    1,  439,   45,  284,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  553, 1313,   45, 1034,   76,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  261,   39,    1,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  220,    1,   45, 1019,  238,   98, 1965,    1, 2932, 1982, 1204,\n",
      "           12, 2467, 1821,    1,  150,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  197,   28,    1,  202, 2185,  157,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,  682,   32,  572, 1151,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   61, 1167,    1, 1228,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,   21,   69,  102,   37,    1, 1411, 1034,  187,    6,  565,\n",
      "         1532,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  179,  628,    1,    1,    1,  191,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129, 2246, 3324,    1, 2578,  191,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  528,  517,    1,  405,    1,  552,    1,  504,    1,  856,  297,\n",
      "         1930, 2126,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2967, 1401,    1, 1136,   32, 2890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1668,    1, 3336,  859,   37, 1343, 2177,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 2035,  631,   32, 2764,  404,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3360,   12, 3363,   32, 2018,    9, 2095,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  831,    1, 1111,   98,  163,    1,   12,    1,    4,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1472,    1, 1861,   12, 2339,  810,   32,  166, 1841,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  142,   37,  439,   46,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[  2, 510,  51, 415,  52, 105,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 233, 927, 110,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,  243,  682,  657,   34,  185,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1828,  554,  468,  972,   37, 1348,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1607,  231,    1, 1775,  918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171,   37,  698,  141,  142,  176,    1,  372,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1712,   45,    1,   32,  531,  187, 2844,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,  613, 2257,  259,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3356,    1,  693,   37, 1910, 3346,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1936, 1333,  176, 2316,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  311, 1064, 1242, 3215,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294, 3207,  396, 1940,   12, 3208,  810, 1385, 2545,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1043,  640, 1034,  181,  340,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123, 2246, 3260,    1, 1021,   32,  105, 1027,    9,  388,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 1517, 2581,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  183,  978,    1, 1221,  565,  590,  803,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  902, 1864,    1,  132,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  176, 2362, 1167, 3207,  865,  247,\n",
      "          671,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  273, 1249, 3132,   32, 2799,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  572,  197,  407,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  166, 1428,    1,  105,    1,  176, 3369,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1023, 1204,  288,    9, 1169,  949,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  321, 2935, 1569,   32, 2069, 1385,   45,    1, 3275,  220,\n",
      "          726,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   41,  376,  572,  157,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  144,  145,  353,  417,  572,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2171,    1, 1188,    1, 1031,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  410,  535, 1786,    9,  810,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  359,  429, 1193, 1953,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2522, 2493, 1123,   32, 1352,  967,  590,  413,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2409, 1042, 1860,   45, 3343,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,    1,   50,    9,  131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1433, 1366,    1,    1,  249,   79,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1,  166,  104,  361,  166,  823,   45, 2095,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2442, 1947, 2103,  617, 1116,  625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1811, 1499,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  204,   12, 2213, 1247,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  166,  112, 2876, 1167,   12,   37, 1096,    1,  193,\n",
      "          166,  912, 2285,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0],\n",
      "        [   2,   93,   67,   32,  223, 1251,   37,    1,    1,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  163,    1,   12,    1, 2548, 2572,  191, 2596,   32,  531,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783, 1666,  932,    1, 1458,  197, 1470,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2977, 2055, 2884,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 3005, 1634,   37,  463, 1447,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1062,  458,   34,  197, 1632,    6,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,  123,   37,  467,  669,   82,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  220, 1768,    1,   61,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  365,  633,    1, 1976,   32,    1, 3114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1741,    1,    1,    1, 2572,  176,  531, 1038,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2671,   45,  166,  245,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  597,  266, 1009,  162,    1,  191, 1170,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1474, 2330,  365,    1,  132, 1710,   52,    1,   37,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2245,  657,    1,    1,   98,  105,  365,    1,   45, 1151,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359,  361, 3358,    1, 2892,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,  311,    1, 2554,    1,   81,   37,  197,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,  914, 3135,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,  614,   28,  444,  306,  220,  825, 1013,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3013,  669,   37, 1835, 1488,  529,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  378,   32, 1089, 1675,  288,   37,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,  298,    1, 1334,  665,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  167, 1821,    1,   52,    1, 2763,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1484,   98,  342,   37,  652,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  449, 1778, 2580, 2851, 2432,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,  162,  103,    1,   32,  849,  104,   54,   16,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56, 2708,    1, 2572,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2602,  297,    1, 1263,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  865, 2615, 2941,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  232, 1484,  105,   10,  726,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1258,  247, 1844,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1585,    1,    1, 1324,  898,   32,  903,    1, 1447,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   83, 1550,    1, 1143,  187,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  766,  140, 3016, 1935, 1876,  384,   32, 1092,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,  794, 2366,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  463,  464,    1,  614,   37, 1020,  147,   37,  619,  671, 3126,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3319, 1334,   32,  166, 2884,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  441, 1947,  365,  845, 1208, 2636, 2294,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  602,  112,    1,   86,    1,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 1251,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3238,  190,  193,  698, 1090,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  439,   45,  166, 3358, 1015,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   93,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2292,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1019, 2826,  410,    1, 1283,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  785,  786,    1,    9,    1, 1938, 3197,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,   12, 1016, 2789,    1, 3359, 2431,   12,    1,   98, 2271,\n",
      "          469,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2126,    1,   45,  926,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 3397,    1, 3155, 1345,  220, 1147, 1009,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1463,  546, 2673, 3085, 1461,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  572,  105,  678,    1,    1,  136,   12,  365,   82,    1, 2182,\n",
      "           39,  247,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1723,  162, 1405,    1,  373,    1,  400,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1876,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1891,  922,  475, 1082,  949,   45, 1645, 3365,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1087,    1, 1361, 1362,    1, 1516,   32,  192,    1,\n",
      "         2498, 1379,   12,  112,  499,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   81,   37,   36,  220, 1729,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  409,   25, 1334,  700,   98,  954,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3010, 1822,  688, 2906,   37,  726,  183, 2771,  142,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1457,  782,  590,  133,   32,    1,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  742,  142,    1,   98,  674, 3137,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  590, 2181,   32, 2643, 1675,    9,  375,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,  166, 2525, 1232,  104,  358,  833,  612, 1878,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2827,   32, 1050, 2931,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105, 2823,    1,  696, 1963,   26, 2641,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  789,  986,   79,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1480,  845,    1,   55,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2924,   51, 1192,  163,    1,  903,    1,    1,   32,  531,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,    1,  166, 2814,   45,    1,  897,   27,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,   12,  365,    1, 2522,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1940,  921,   32, 1238,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,  393,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1971,    1, 3285, 2434,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  400,  444, 1486,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  734,   98,    1,    9,  932,    1,  592,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   57,  295,   37,  949,    1,   29, 2928,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,  166,  449,   32,  537,  790,  432,    9,  105,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  245, 1139,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1171,  361, 2498,  105,    1, 2709,  408,  104,   32, 3163,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  129, 1286,  737,  197,  418,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1878,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1087,  794, 2461,  279,    1,  973,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1039, 1304,   37,  875,  220,  422,    9,  331,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,    1, 1251,    6,  361, 1412,   93,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  819,  729,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1059, 2024,  105,  916,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2208, 2100, 2789,  847,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1534,   45, 1194, 2350, 1050,    1,   32,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   37,    1,  705,    1, 1153,    1,  125,    4,   37, 1154,\n",
      "          131,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1411,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3118, 1527, 1900, 2047,  241, 2292,    1,  221, 1346,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1312,    1,  403, 3165,  588,    1,   32, 2592, 1796,   36,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1249,    1,   32, 1018,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,    1,   32,  331,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2676,   12,  851,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  132,   98,    1,  983,    9,    1,    1,  361,  903,    1,   12,\n",
      "            1,  167,   18, 1411, 1034,  963, 2122,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  365, 1009, 3390,   32,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  794, 1228,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2325,    1,    1, 2769,   45,  166,    1,   61,  166, 2522,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,  315,  365,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2090,    1,  353,  242,  572,  197,    1,  155,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  395,  580,  365,    1,    1, 1650,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,  171,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1118,    1,    1,  484,    1,  267,  199,  193,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  463, 1447,   76,   37,  504,  384, 1053, 1108,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 1708, 1586,   28,  187, 3363, 2405,    9, 2743,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  166, 1675, 2871,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  418,  187,  163,    1,   12,    1, 1290,  396,  245,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  476,    1,    1,    1,    1,  480,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,  927, 2211,    1,    9, 1530,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  148,  325,  647,    9,  131,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1364, 1365,  876,  612,  682,    1, 2241,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2587,    1,    1,    1,   37,  860, 2606,    1,  347,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2087,  167, 1413,    1,   32, 3193, 1218,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1674, 2586,   32, 1676,    1,  649, 2122,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9,    1, 1945,    1, 3075,  300,    1,    1,   81,   37,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  234, 3041,  235,    1,  234, 3041,  235,    1,  117, 1108,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  244,  187,  613,   15, 1253,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2977, 3054, 1631,  945,  846,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  346,  347,    1,   98,  429,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1228,   37,    1, 2650,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056, 2119,  361,  331,   37,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1809,  105,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2871, 2685,  114,    1,    1,    1,  176,  439,   45,  166,\n",
      "          914,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3145,  454, 1159, 1948,  220,    1, 1918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2825,  105,  103,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  286,    1,  845,  493,  408,  583,    1,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  958, 1610,  170,   46,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  560, 1274,   71,   32, 1034,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390,  267,  587,  498,   37,  469,   37, 1066,  669,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2832,    1, 1319, 2396,   32, 1966,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,   12, 2984,  967,    1,    1,  220, 2820,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,  359,  474, 1707,  693,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,    1,    1,    1,   45,  443,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3194, 3195,  361,  163,    1,   12,    1, 1417,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1,   39, 1823,   37,  759,  717,    1,  903,    1,  182,\n",
      "            1,  105,    1, 3179,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1204,   32,  166, 2822,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1822, 2446,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3287,  726,   32, 1600,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   82,  108,   45,  388,  389,    6,  176,  294,  295,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  405,   12,  664, 1194,   73,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1902,  900,  190, 1306,  739,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2715,  661,    4, 1810,    1,   37,  168,   32, 1251,    6,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219,  379, 1248,  104,   37, 2199,   60,   12,  832,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612,  815,    1,  187,    1,    1,    1, 1841,   90,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3116,  922, 1385,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  223,  197,   28,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428, 1874, 1934, 1038, 1419,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  294, 2800, 3276, 2035, 2925, 2315, 1045,   37, 1675,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2227, 1463,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158, 2102, 1107,  525, 2352, 2464,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2676,    1, 2136, 1388,   98,  531,   32,  736,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  994,    1,  150,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  311,    1,    1, 2432,  861, 2558, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1090, 2677,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  519, 2939,    1,    9, 1517,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  147, 2959,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1204,   45,    1, 2890, 2304,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2, 266, 190, 142,   9,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 342,  37, 804,  98, 148,  12, 142,   9, 647, 428,   1,   3,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3174,  140,    1, 2579,    1, 3201,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  773,   66,    1, 1595, 1332,    1,   15,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  447, 2576,  166,  440,  705,   74,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,  421,  353,  197,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  848,   12,    1,    1,  844,   37,  335,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12, 2162,  105,    1,   45, 2708, 2139,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  249,  583,   32, 2596, 1585,  176, 1855,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1062,  458,  213,   37,   47,  457, 1429,    1,  112,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  600,  199,  166,    1, 1924,    1, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,   37,   52, 1683,  384, 2862,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2169, 1900, 1523,   32, 1619,  395,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1827,  361,    1, 1183,  894, 1343,    7,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  954,  388,    1,  763,  449, 2112,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861, 1484,    9, 1663, 1876,   45, 2170,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1285,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  155,   48,   32,    1,   37,  118,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  356,  560,  347,   71,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2753,  182,   32,    1, 1495,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1790,  692,  365,  912, 2146,    9, 1412, 2530,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,   32,  241,  531, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,    1, 1685,  467,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  151,    1, 1606,  524,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3141,    1, 2721,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2772, 1167,    1,    1,   12,    1, 2494,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   14,   15,  245,   32,  871,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200,  593,  449, 1766, 1767,  412,  402,   98,  105, 1151,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,  912, 1294,    1, 1615, 2759, 1208,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  162, 1217,    9, 3076, 1171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   12,    1, 2814,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  397, 1542,    9,  104,  909,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1068,  568,   93, 1270, 1271,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3140, 3067, 3040, 2564,  444,  709, 2265,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  903, 1447,   51,   52, 1411,   98, 2521,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2504, 2038, 2593, 2104,   37,  927, 2705,   32, 2755,  171,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  404,  395, 1097, 1149, 1313,  677,  102,    1,  340,  869,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2162,   45,    1,    1,    1,    1,   32, 1022, 1385,   45,  749,\n",
      "          767,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  932,  565,   32, 1444, 1445,  193, 1690, 1691, 2920,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2345,  619,  166, 3345,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   67,  423,  105, 1139, 2113,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  640,   81,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,  332,  756, 1228, 1039, 2690,  220,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1086,  356, 3106,  220,  726,  176,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  964,  546,  403,    1,    1, 1190,    1,    1,    1,  582,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2752,  446, 1877,   37,  856, 2751,    1,  854,   37, 2192, 2108,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1, 2497, 3155,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2642, 3224,    1,  223,    1,  193, 1123,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  286, 1682, 1558,   32,  142,  927,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3306,   81,   32, 2235,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,  355,  342, 1994, 2143,  400,  399, 1415,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1275,    1,    1,   57,   71,    1,  597,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   32,  166,    1,   45,  105, 1512,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2680, 1644, 1713,    1,  721,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  858,  815, 2424,    1,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,  389,    1,  202,    1,  967,   37,  544,  460,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  644,   77,   28, 3391, 2262,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096, 3277,  603,   37,    1,   37,  816,    1,  386, 2728,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,    1, 3177,  361,    1,   81,    9, 2741,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2596,   27, 3155, 2414, 3111,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  590,   37, 1407,    1,    1,   37,    1,   32, 3118,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1236,  777,    1,    1, 1130,  297, 2819,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   65, 1702, 1184,  347,   28, 1114,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3100,   81, 1764,  598,   37, 1343,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   95,  473, 2253,   37,  477,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    5,  652,    1, 1937,    1,  115,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  140,    1, 1624,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2345, 3214,  431,  119,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1283,  289,  538,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632, 2328, 2137,   79,    9, 2190,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,  633,  726,    9, 2563,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2187,  112,  967, 1382,    1,  361,  320,  967,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  251,   28,  192, 2351,    9, 1211,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    9, 2569, 2548,   32,  474,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  894,  647, 2842,  166, 2087,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1022,    1,    1, 1517,  932,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2546, 1288, 1230, 1756, 2324,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,  952, 2095, 3060,   12, 2251,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 325,  48,  32, 141,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 206,  12, 197,  28, 419,   1,   1, 921, 308,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  923, 2988, 1994, 2819,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  803, 1266,    1,  665,   22,  942,   32, 1134,   37,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1586,    1,  253,  115,   45, 1126,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2787,  288,   37,  698, 1517,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  393,   37,    1,   28,   37,    1,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1234, 1044,  128,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   25, 1269,  187,   60,  418,  361,   69, 1042,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  207,  354, 1052,   98,  198,  983,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  137,    1,  666, 1080, 1950,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 1133, 3201,  176, 1545,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,  879, 1376,  444,   94,    1, 1547,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  384,  166,    1,    1, 1019, 1796,    1,  920,    1,  191,\n",
      "         2057,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2483,    1,    1,   12,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2954,  741,    9, 2107, 2462,    1, 1463,    6,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  531,  839, 1610,  861,    1,  297,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3270,  744,  119,  199,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  455,    1, 1725,   37,    1,    1, 2532,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,  794,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3310,    1,    1,   45,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2591,  792,    9, 3144,   12,  627,  792,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2562,    1,  424,  199,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    1,   32, 1739,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1583, 2414, 2751,   32, 2755, 3369,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  297,  884, 2912,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3076,  872,  851, 2421,    1, 1530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095, 1268,    1,   32, 1447,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  654,  721,  614,  834,    9,  105,   82,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1656, 2596, 3060, 2572,    1, 2375, 1976,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3374,  650, 1564, 2050, 2784,   37, 2835,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,  565, 1587,   45,    1,    1,   98,  166, 1737,  357,   32,\n",
      "          166,   22,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,   32, 3369,  187, 1428, 1757, 1552,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3198,   45,  121,    1, 1249,    1,    1,  176, 2197, 3329,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1902,    1, 1367,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1717,    1,    1,    1,  606, 1841, 2471,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  952, 3358, 2162,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280, 1844,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  317,  948,   32,  449, 1023,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 2765, 2587, 3006,  444, 3380,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  842,  159,  245,   98,    1, 1406,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2463, 2243,  105,  365, 1173,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  756,   45,  464, 2147,   32, 2592, 1566,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115, 2712, 2563,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1264,    1,    1,    1, 1152,   98,  932,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  409,   25,   26,  417,   60,   85,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  160,  102,  276,    1, 2053,  831,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  885, 1718, 2355,  640,  218,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2821, 2547, 1159,  772,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1789,   12, 2193,    1, 2778,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  313,   37, 2392,  711,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   25, 1195,  186,    1, 1128,   34,  185,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1713, 2500, 1841, 2209,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1676,    1, 1867, 1894,    9,  229,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3268, 2784,   37, 2445,    1,    1,   45,  861,  122,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1398,  612,    1,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1951,  700,  566,   54,    1,  142,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  493,   29,  176, 2379,    1,  369,    1, 1572,   37,  134,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1720,  112,    1, 1401,   37,  139,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2820,  927,   37,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235, 2962, 1938, 2809,  696, 1110,  123,   98, 3231,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1772,    1,  887,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1566,   43,  297, 1156, 1682,  963, 2122,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  388,  116, 2264,    1, 2017,  384,  829,   12, 2542,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107, 2312,  803,  805,  384,  120,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  403, 1447,  744, 2915,   98,   46,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302, 1963,   37,    1,    1, 1857,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  777, 1085,    9, 1658, 1191,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  818,   15, 1539,    1,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,  995,  242,  197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,  220,  365, 2355, 2549,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2204,  449, 1023,  640,    1,  244,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1708,  518,  625,    1, 1753,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  500,    1,    9,  306, 1665,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 3065,  610,    9,    1,   12, 2162,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1480,  166, 1361,   37,  230,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  427,    1,  220,    1, 2275,   96,  166,    1,   98,   10,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1534,   45, 3102,    1, 2952,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  484,   98,    1, 1371,    1,  267,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1353, 1159,    1,    1, 2570,  616,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789, 2070,  455,  395, 1559,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1984, 1004,    1,  927,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,    1,  572,  983,  921,  131,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3052,    1,  600, 3208,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  523,  859,   37,  865,  331,   32, 1469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  245,   32,  215,   12, 1113, 2300,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2993, 1419, 3056,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  379,    1,  191,  691,    1,  438,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1993, 3173,   32,    1,  401, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2629, 1048,    1,   45,    1,  187,    1,    1,   32, 1850,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1398,  612,  544,  460,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  454,   37,  764, 1000, 2164, 2986,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2613,  707,    9, 3303,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  344,    1, 2803, 1312,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1492,   12, 1221,    1,  203, 2698,  321,   52, 2492,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1783,   37,  912,    9,  572,  420,  881,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,   51,   52, 1044,  453,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1498,  588,  414,  384,  681,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233,  765, 1836,  220,  301,    5,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  224, 2384, 1013,  210,    9, 2177, 1825,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  207,  197,  953,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1089,   30,  487, 1527, 2664,  361, 1922,    1,    1,    1,  105,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2864, 2050,  726,   32, 2826,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  743,   12,  737,  156,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  272,   39,  220,  103, 2132,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  879, 1376,  115,   45,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 2061, 2731,   32, 1850, 3339,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  542, 1594,   98,  179,  180,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2269,   12,    1,   98, 2539,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  942,  958,  581, 2623, 2624,  400,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  990, 1236, 2650, 2985, 2928,    1,  150,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1721,  774,  734,   61,  393,   12,  103,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2998,   61,    1,    9,  105,  354,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  242,  187,  197,  509,  470,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1861,   37, 2653,    1,   45, 2170, 2298,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328, 2049,  267,    1,   12,  195, 1464,   37,  907, 1567,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1349,  614,  853,    1,  202,  190,    1, 2535,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3263, 1957,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  179,  967, 1913, 1843,  354,   45,    1,  131,   98, 1074,  322,\n",
      "           85,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2536, 1670,   72, 2113,  176, 3385,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2488,    1,   37, 2641,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3006, 1439,   45, 2834,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  886,  835,    1,    9,  331,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1658,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2899, 2790,  292,  822,  912, 2285,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375, 1210, 2868,   37,  764,  949,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1625,    1,    9,  601, 1385,   45,   46,   98,    1,   12, 2673,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321,    1, 1154,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2903,  726,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2528,  326,   12,  552, 2232,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  617,    1, 2758,  191,  848,    1,  766,    1,  361,  326,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870,  884,    1,   37, 1212,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  930,  187,  582,   45,    1, 2498,   12,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   14,   15,  245,  388,  763,   76,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2912, 1401,  667, 3329,  191,   56,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1103,    1,    1,  241,  315,  384, 2719,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  166, 2475,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3250,    1, 1625,   37, 1343,   32, 3201,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,  613, 2168, 1403,  365, 2524,  551,    1,   37,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  659,    1,   45, 1718, 2146, 1967,    1,  920, 2812,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   30,    1, 1912,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1450,   98, 1147,  861, 1414,  452, 2343, 1556,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,  932,    1,    1,  150,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 1981,   98,  844,    1,  538,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  971,   91,   37,  125,    1,    4,   32,  132,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2523,   32,   61, 2146,   45,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1042, 2930,  134,  444,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  575, 1862,  600,  996,  157,  496,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    9,    1, 1204,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2051,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  102,  120, 1010,  720,   32,  104, 1915, 1588,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   68, 1631, 1632,  105,  106,    9,  449,  199,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  531,  879, 2375,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2946,   45,    1, 2952,   32,    1,  854,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1158, 1203,    1,    1, 1871,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1877,   37, 2122,    9, 1428,  142,  680, 1684,   45,  792,\n",
      "         1789,  792,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  593, 1990, 2871,    1,    1,  202,    1, 1360,  612, 1343, 2675,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  750,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  148,  200,    1,  112,  993, 1607,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1088,    1,  606,  590,  400, 3398,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2993,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1112,  600,  238,  354,   32,  166,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2413,   98, 2235,    1,  187, 1077,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2740,    9,  166,  914, 2321, 1594,   37,  166,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,  472,  593,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129,  787,   12,  572,  197, 1137,  118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  741,   98, 2169,    1,  804,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299, 2591,   37, 2035,    5,    6,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3300,    1,  190,   52, 1211, 2256,  548,  914,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  438, 2122, 1109, 1550,    1,  160,   50,   61,    9,  333,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  103, 1142,   32,    1,    1,  776, 1321,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1266,    1,    1,  885,    1,    4,  176,  629,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087, 2479,  750,  132,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  912, 2852, 1046,  365,    1,  973,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1924,  356,   45,    1, 3005,    1,  777,  700,    1,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2416,  997,    1,  297,  667,  863,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1809,  247,  221,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3285,  186,  608,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  492, 2263, 2343,   12, 3043,    1,  493,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  197,    1,  983,  418,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  952, 2730,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215, 3160, 2827,  297,  531, 2772,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  550,  166,    1, 2162,   45,  166,  350,    1, 2693,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49, 1489,  104,  695,   98,  271,   28, 1250,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2977,  794,  938, 2454,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3012,  298, 2797,   98,    1, 2485,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977,    1, 1821,  656,    9,    1,   45,  567,  510,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510,  134,    1, 1632,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  667,    1,    1,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,  140,   59,   24,    9, 1127, 2229, 1140,  656,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2573, 2774,    1, 3398, 1211,    1, 1082,  652,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  449,    1,  244,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  790,   37,  231,  317,  218,  230,  127,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  255, 1470, 2292,   32, 1283,  193,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  195,    1,  469,   37, 1978,    1,  361,  764,    1, 2170,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275, 1288,   37,    1,  163,    1,   12,    1,   98, 2095,  443,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  873,   32, 3257,   12,  147,    9, 2110,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1603,  581, 1181,  517,  260,   37,  226,    1,    1,  763,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1413, 1414,  220,  923,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1264, 1445, 1421,  705,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 232, 535, 716,   1,   1,   1, 187,   1, 234, 182, 235,   1,\n",
      "           1,   1, 234, 182, 235,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 293, 997, 861,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  386,  295,   37,  194,  104,  541,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3045,  686, 2597, 1606,  220, 1957,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  292, 1228,    1, 1499, 1992,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115,    1,  967,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  215,   32,  443,   45, 1886,  220, 1040,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  256,  331,   37, 1356,    9,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1409,  790,    1,   45,    1,  230,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2680,    1,   28,    1,  861,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2227,   61,    9,  912, 2285,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2708, 3352, 3353, 1072, 1235,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  754, 2261,   37,  619,    7, 1778, 2324,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  782, 1968,    1,  768,  400, 1258,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2868,    1,  455,   12,    1, 2000,  531,    1, 3360,    1,  403,\n",
      "         1447,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 2494,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  556,  397, 2927,   46,  220,  864,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1427,  477, 1308, 3186,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 2688, 1231,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766,   37,   47, 1411,    1, 1935,    1,  191,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,   37,    1,    1,  659,   45, 2366,  892,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  361,  755,  498,   37,  498,   98, 1994,    1, 3042,  161,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,    1,    1,    1, 2012, 2444,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   66,  220,  164,  165,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  502,  861, 1553,  680,  166, 1381,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121, 1874,   69,  681,   37,  142,    9,   49,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  380,  183,    1,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004,  179,   37,    1,   32,   40,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  116, 2264,  606,    1,    1,   45,  861,    1,  506,  782,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2268, 2214,  754, 2625,   32, 3099,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094, 2414, 3375,   32, 1479, 3339, 2625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1965,    1,  365,   29,  155,  241, 1574, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2977, 2984,    1,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  135, 2424, 3024,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2009, 2126,   26,    9, 2533,    1,  774, 2412,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2592,  288,   37,    1,  248,    1,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  215, 2128,  469,    9, 2597,    1,  997,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2826, 2962, 1628,   74,    9,  163,    1,   12,    1,    1,  365,\n",
      "            1,    9,  395,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2459,    1,  727,  477,  132,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649, 2684,   32, 3349,   37,  764,    1, 1250,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158,    1, 1158, 3007,    1, 1180,  517, 2452,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3227,  688, 3326,   32, 1602, 2539, 3201,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1774,   39, 1106, 1013, 1626,  327,  593,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1021,    1,    1,    1,    1,  963,    1, 2677,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3303,    1,    1, 1296,   79,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  279,    1,    1,  297, 2638,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  597, 3083, 1213,  610,    9,  133,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974, 1957,   37,    1,  331, 2223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1592,  973,    9,  388, 1465,  861, 1896,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,    1,  415, 1315,  105,  106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2550,    1,    1,   45,  238,   98, 1965, 2481,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3337,   12,  915, 1477, 1990, 1734,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  597, 2468,  446, 1082,  949,   45,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885, 3129,   61,  810, 2226, 1847,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  299,  288,   37, 2035, 1841,    5,    6,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  854,   12,    1,    1, 2572,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2238,  936,    1,  235,    9,  166,    1,  336,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  733,    1,   45,  761,  195,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1311,  102,  686,  356,  340,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,    1,   37,  230,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,   25, 1376,  187,   69,  102,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094, 2055,  434,    1,   32,  717,    1,  458,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 3358,   12,    1,  637,  297, 2708,  650,   12, 1983,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2459,  153,  914, 2677,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   37,    1,   45, 1656,    1,    1,  382,  675, 1620,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  330,    1, 2625,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3322,    1,   32, 3201,  176,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  190,  949,  166,    1,  466, 1465,   32,  166, 2090,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  632,  671, 3126,  855, 1867, 1894,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 2024,   46, 1195,  187, 1428, 1757,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  102,  103,  104,  105,  106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  792, 1328,    1,  792,   66,   32,  861,  176,  632, 2673,\n",
      "         2152,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3068,  614,    1,  220, 1962,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3147, 2924,   32, 3114,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1645,   26, 3289,    1,  188,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925,    1,   12, 2861,    9,  611,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3349, 2785, 2162, 1950, 2424,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1751,    1,   37, 1752,  929,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1687, 1022,    1, 3008, 2897,  548,  537,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  617,  259, 1140,    1, 2132,   32, 1619,  584,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1316,  507,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2345, 3102,    1,   16,  590,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2278,    1,  709,  326, 1222,    1,    9,    1, 2027,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,    1,    1,   81,   37, 2095,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2426, 1258,  220, 3384, 3382,   32, 2646,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275, 1112, 2466,   51,    1,  938, 2591,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  593,   12,  553, 1395,  844,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3092,    1, 2906,  826, 2242, 1803,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  140,  593, 2522, 3212,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1127, 1831,  288,   37,  221,   98,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1035,    1,  384, 1038,    1,  952,   37,  606,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  527,  353,   59,  354,    9,  401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,   63,   94,    1,  365,  340,  686,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,  852,   37,  863, 2329,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1174, 2172,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496,  163,    1,   12,    1,   37,    1,   32,  818, 1278,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  191, 3257,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  566,    5,  788,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  572,  156,   28,  419,    1,   37,    1,  331,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1457,  681, 1991, 1514, 2461,    1,  420,  267,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1181,  396,    1, 2436,  726,   32, 1100,  340, 1251,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  566,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2409,    1, 2789, 1278,  921,  131,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  506,    1,   37,    1,  469, 1710, 1251, 2051,  763, 2226,   93,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  463,  507,  566,  342, 2304, 1416,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,   12,    1, 1494, 2848,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2634,  779, 2759,  260,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  636,   79,    1,  557,  540, 1333,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  395, 1876,  903,    1, 1447,   46,  548,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  306,   12,  487, 2874,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  815,   45,    1, 2465,   61,    1,  176, 2028, 1967,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  200,  340,    1,  327,    9,  649,  218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  631, 1367,  297, 3241,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1811,    1,  652,   37,  688, 2834,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2694,  171,   45, 1193,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2006, 2572,   32, 2169, 3279,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3094,   45, 1147, 2924,    1,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3257,    1,  166,  753, 1167,  247,   81,  190, 1334,   98,  247,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2070,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  256,   37,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,   12, 1230, 1401, 1607, 1882,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  567,  799,    1,   39, 2796, 3138, 1090,    9, 1517,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  251,  105,    1,  131,    9,    1,   37, 1289,    1,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3343, 3345,  907,   98, 1623,   45,  163,    1,  903,    1, 3365,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1095,    1, 1086,  176,    1,    9,  356, 1691,    1,  220, 1521,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,  884, 1193,  992,   37, 1911,  734,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  754,  757,    1,  183,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   61, 2580,   12, 2324, 2440,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  950,  396, 1569,   32,    1, 1002,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  433, 1579,  881,   45, 1281,   98,    1,  166,  116,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56,   32, 1559,   37, 3178,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1062, 1682, 2338,   37, 1542,  105,  365, 1560,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3269, 1825,   48, 1159,  985,   45, 1739, 2561, 2554,  730, 2614,\n",
      "           37,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2802, 1488,   37,    1, 2017,  763,    1,   39,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1,  354,   45,  163,    1,   12,    1, 2924,   32,  531,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3250, 1289,    1,   12,    1, 2068,   37, 2760, 3273,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2255, 1416,    1,    1, 3004,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 1631, 3078,  444,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  361,    1,    1,  220,    1,    1, 1370,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1962,  744,  613,  846,  119,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614, 1918,    1,  166, 1021,   45,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2866,   32,   37, 1412,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  181,  574,   37,  365,  615,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  837,    1,    1,   42, 1600,  798,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2005, 3161,  297, 1739,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3263,    1,    1,   32, 1918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  837,    1, 3129,  645,    1, 2413,  550,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2728,  220,    1,    1, 1308,   79, 1855,  540,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785, 1877,   37,    1,   69, 1588,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1955,    1, 1427,  166,  104,   15,   45, 1736,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1, 2774, 2198,  105,    1, 2758,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2226,    1,  612, 2446,    1, 3328, 1831,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  794,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2922, 2158,  325,   93,   98,  166,  824, 1379,   12,  112,  499,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  572,  207,  354,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2266, 1145,  531,  443, 2189,  267,    1,  890, 1372,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3372, 1579,  342,    1, 1511,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1307,  259,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808, 1396, 1158,   12, 1230,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3141,  719,   37, 1173,   32,    1,    1,  193,  415,  176, 3240,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  197,   28,  202,  159,  245,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  245,   32,   69,  636, 2806, 2714,   92,    9,  236,  237,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  763,  415,  105,    1, 1046,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,  69, 102,  85,  37,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 996,  93,   1, 565, 700,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  344, 3043,   32, 3379, 2950,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1256,  361, 1256,   37,  151,  104,   12,  581, 2084,  985, 1671,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 2036,  688, 1853,  191, 2202,   32,  786,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  686,  105,  106,  187,  531, 2292,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3178,    1, 1159,  581, 1385,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343,  610,    9, 1887,   56, 3073,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  985,  223,    1,  384,    1,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 3224, 1631,   38,    1,  236,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2408, 1236,    9,    1, 1340, 1194,  754, 1844,  873,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190,    1,  423, 1184,  347,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2753,  187, 3191,  140, 3201,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,  531, 3006,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  912, 2285,  681,  119,  105,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1322,    1, 1121,  698,    1,  542,    1,   15,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  306,  197,  307,  308,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1038, 1140,    9,  455, 1213,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2304, 1228,  728, 1348,    1,  468, 3031,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 1481,  957,    1,    1,    1,   45, 1384,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2224,  908, 1197,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2752,    1,  340,   32,  535,    1, 1279,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1778, 1108, 1779, 1757,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  350, 1147,    1,  685,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  464,   22,  563,  564, 1812,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3151, 2308,   32,   91, 1897, 1756,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2252, 2657,   32,    1,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1317,  520,  181,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3045, 2833,  388, 3365,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    6,  102,   98, 2400, 1465,  769,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  166, 2821,   45, 2440,   64,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1583,   37,    1,  284,  589,  384,  352,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  451,  295,  884, 2568,   45,  365,   20,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1147, 1009,    1,  740,    1,  863,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1100,    1, 1128,    1,  657,    1,  829,    1,  361, 1361,  949,\n",
      "          777, 1085,    9,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0],\n",
      "        [   2, 2634,    1,    1,    1,  766,   37,    1,  877, 2738, 1395,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1355,  361,    1,   66,   32,  170,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  491,    1,  787,  220,  215,  492,  170,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  365,  116,    1,   32,  166,  272,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2836,  125,  191, 1056, 1675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 3149, 1009, 3390,   32,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   27,   98,    1,  531, 2292,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  224, 1660, 1013, 1279,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1214, 1993,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2681, 2572,   32, 2596, 1450,   98,  208,  217,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766,  140, 1092, 1701, 1876,    9, 3016, 1935, 2294,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1619,  458,    6,    7, 1184,   67,  191, 1023,  105,  402,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1229,    1,   37, 1046,  163,    1,   12,    1,    1,\n",
      "          535,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  251,  365,    1,   98,  166,    1, 2589,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162, 1328,  220,  163,    1,   12,    1,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3363,    1, 1010,    1, 2292,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181, 2712,    1, 3314,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1236, 2180,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1027,  199,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  709,   20,  232,   32, 1038,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1792,    1, 1484, 2205,  219,  295,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  538,   25,    1,   98,  586,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2801,    1,  982,   37, 1155,    1,    1, 1732,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  160, 1161,  884, 1150,   32,  602,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,   12, 1429,   32,  538,    1,    1,    1,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1312, 2844,   32, 1676,  336,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2672, 2871,  683,   37,  335,    1,   12,    1,    1, 1114,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,   15,    1,    1,    1,   25,  245,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  294,    1, 1130, 3340,    1,    1,   32, 2597,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  228, 2137,  898,   32, 2468,  548, 3387, 2429,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2822, 2715,  815,    1,   37, 1000, 1515,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  160, 1161,  640,  339,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,   15,  701, 1408,   25,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  777,    1,    1,   37, 1841,   12,   39,   45,  674,  818, 1616,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994, 2650,  669,   32,  147,   98,    1,  134,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  755,   37,  693,    1,  861,   12,    1, 1942,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  187, 1035, 1627, 1038,    1, 1922,  669,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2746,  877,    1,  682,   32, 1802,  890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2372,   45,    1, 3389,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 1100,  108,   45,  417,   15,    1,    1, 1101, 1102,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1580,  191, 2772,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1, 1456,    1,   28,   37, 1504,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3142,    1, 3263,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,   94,  640,  339,  845,  444,  166,   60,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3251,  688, 3271,   37, 2872,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2531,  267,  854,    1,   98, 2227,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  884,   98,  247, 1521,   32,  117,    9, 1013, 1522,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,  251,  825, 1013, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    6, 1952,  197,  570,  187,   15,    1,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2087,  433, 2681, 1745,    1,   10,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  507,  539,  353,  354,    1,  388,  390,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2977,    1,  894,    1,  510,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622,  233,   57,  491,   50,   37,  138,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  915, 1479,  793,    1,    1,   92,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567, 1080,   37,  583,    1,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,  166,   26, 1039,  226,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1388,   45,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 2352, 1029,  741, 1457,    1, 1484,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1430, 2095, 2985, 1634,   37, 2950,  722, 1061,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310,   25,  455,  682,    1, 1572,  191,    1,  463, 1447,  418,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2920, 3310, 1710,    1,   37, 3332,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455, 2164, 2414,    1,    1,  477, 2047,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    9, 3111,   98, 2262,    1, 1018,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1,  289,   45,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  758, 2937,    1,    1, 1176,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1917,    1,    1,  148,  140,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1206,    1, 2424,  617,  259,    1,  302,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2328,  140,  331, 2223,    9, 2784,   37, 1821,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,    1,  531, 1210,   37,    1,  166,  608,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1579,    1, 2635,    9,    1, 1316,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3168,    1,    1, 1758,   37,    1, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  183,  535, 1284,  807,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1159, 1689, 2821, 1282,  385,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3317,   61,  166, 1178,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1610, 1394,  354,  297, 2001,  122, 3199,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785, 2044,   37,   92,   69, 1069,  187,  636,  640,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   10, 1877,   37, 1604,   98,  397,    1, 2137,  296,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  921,    1,  176, 1742,   26,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1, 1021, 2110,   37, 1918,  297, 1022,    1, 2296,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   66,   28,  187,   69,  338,   65,   98, 1978,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  129,  922, 3209,  181,   32,   98,  885, 2545,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  515,    1, 2702,   24,   37,  455,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   98,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  877,  357,  271, 1832,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1349, 1058,    9,   91,   12,  365, 1350,  475,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2736, 2770, 2743,  443,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  220,  121,   12, 1217,    1, 3037,   98, 1649,  991,  915,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1354, 1465, 2264,    1,    1,  111,  861, 1553,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  187, 2565,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2737,  571,   37,  764,   64, 2368,  547, 1090, 1044, 1045,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  848,   37, 1174,  840,    1,    1, 2232,  220,  327,  361,  844,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,    1, 1580,  199,   51,  856,    1,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1779, 1136,    1, 2746,  335,  460,    1,    9,  920,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3320,  300, 3262,   37,  449,  354,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,  256, 1994, 2693, 1942,   37,  365, 2474,  259,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1908,  198,  275,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  625,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 3151, 1756,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1420,    1,  140,    1,  131,   60,  368,    1,  132,  220,  649,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,  136,   82,  162,    1,    1, 1907,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,    1, 2018,  493,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3355, 1542,   37,    1,   37, 3025, 3125,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2467,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2901,    1,    9,  582, 1987,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3095,  350, 2100, 3339,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  171,    1, 2388,  171,    1, 3135,    9,  166,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32,    1,   98, 1147, 1583,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2951, 3023,   45, 3116,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1536,    9, 1211,  639,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  267,  460,    1, 1443,   32,    7,    1, 1465, 1463,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2327,    1,   45,  166, 2880,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1405,  162,  168,  115,   37,   47,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1307,  259,  256, 2693, 1942,  327,  593,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1502, 2369,  453,    1,   98, 1503,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  483,  384,  424,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861, 1414,   98, 2393,  115,   45, 3343,  863,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1465, 2264, 1046,  365,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1414, 1260, 1147, 3045,   32, 3155,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1170, 1008,    1,   82,    1,  159, 1253,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  398,   37,  759,  484,   98,  829,   32, 1657,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1256,  551, 1256,  884,  985,  384,   54,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   42,    1,  134,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361, 1419, 2255,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2347,   32, 3367, 1656, 2950,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  777, 1085, 1228, 2718,  693,    1, 1907,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  621,  251,   37, 1066,  132,  220,   20,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2, 148, 572, 207,  28,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 315, 388,   4,  32, 854, 191,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2828,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1683, 1485, 3102,  267, 2289,  361,  581, 1920, 1999, 2162,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1140,   37,    1,  912, 2285,  220,  962,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3359, 1625, 3372,  741,  190,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  403,  464, 3396,  588,    1,   32,  963, 2147,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1228,   37,  764,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2751, 2891, 1147,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  334,  774,   47,    1, 2226,  774,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  315,   37, 1636,    1, 2200, 1755,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  651, 1031,    1, 2822, 2378,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1199,    1, 1360,  612,   52,    7,   37,  365,  327, 1998,\n",
      "          682,  327,  593,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2194, 1708,    1,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  424, 2385,  612, 1690,    1,  985,    1,    1,  267,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2379,    1,    1,    1,  631, 3228,   37,  726,  297,  634,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 2997,    1,   26,   28, 1452, 2580, 2851,   37, 1260,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1492, 1082,  388, 2527,  164,  165,   32, 2160,   45, 2162,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1181,  623,  213,  220,  848,   37,  332, 1354,  768,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  246,  388,  909,  951,    1, 2062,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1292, 2401,  361,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  882,  108,   98, 1151,   15,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   90,  453,  175,   45, 3020,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  299, 1542,   37,  328, 1442,    1,  625,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    9,   91,   12,  183,  564,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2715,    1,    1,    1,  345,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1158,   14,  525,   32,   91,   98,  453, 2576,  361,  288,\n",
      "           37,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2700, 2655,  166, 2624, 2955,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,  267, 1913, 1843,  983,  190,  245,  384, 2073, 1843,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2148, 1477,   12,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340,    1, 1110, 2286,   37, 1121,  730, 1568, 3260,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  365,  698,   28,    1, 1696,   32,  166, 2090,    1, 1532,   32,\n",
      "          854,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1536,  365,  149,   32,  142,   37, 2199,    1,    1,  370,\n",
      "          409,  170,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  148, 1680,  453,  693,  361,  325,  647,    9,    1,  131,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,    6,  102,  361, 1519,  280,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1617, 1924, 1090,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  220,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 1094,  516,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3215,   12,  416,  105,  311, 2537,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1087,   37,  949, 2693,    1,    9, 1778,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3279,   32, 2764,    1,    1, 3361, 2572,   32,    1,    1,  365,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,  342, 1116,  475,   26,   37, 2103,  617, 1116,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,  551,  105,  220,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  388, 3051, 2253,   37, 1731,   37,    1, 1428,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2565,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,  879,  682,  548,  996,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169, 1938,    1,    1,  202, 1862,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 640,   9,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 422,  51,  52,  27, 399, 220, 755,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2258, 1398,  612,  168, 1488,  187,  355,   12,  197,  304,  246,\n",
      "          374,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176, 2396,    1,  105,  132,   98,    1,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  342, 1974,  829,    1,  231,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  287,  396,  105,    1, 3084,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1092,   37, 2428,    1,    9, 2977,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  159,  504,   32, 1088,  714,   98,  365,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1309,  301,    1,  680,  114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  938, 2032, 1003,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 571,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 552, 552,   9, 617, 618, 759,  39, 361, 332,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1751, 2479, 1056, 1333,  631,  220,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  314, 1692,   82,    1,  939,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2962, 1340, 3299, 1114,  187, 1110, 2651, 3251,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2425,  680, 1260,  384,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056,  163,    1,   12,    1, 2548, 2844,   32, 3343, 1450,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   12,    1, 1117,    1, 1417,    1,   61,    1,    1,  297,   29,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2650,    1,  220,  829, 2432,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  267,  508,    1, 1405,  494, 1822, 1046,  776, 2444,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2275,  292,  389,    1,  315,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2697,   12,    1, 2748,  176,  365, 1788, 1497,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1072,    1,  597, 2374,  232,  187,  453,  163,    1,   12,    1,\n",
      "          475,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,    1, 1848,  872,   28,   37,    1,  192,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  200,    1, 1521,   45,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,   37,   81,  829, 2995,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1176,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   69,   92,   37, 1656,  627,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2994,    1, 2246,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1290,  396,  720,  528,  567,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   92,    9,  225,  218,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1749, 1822, 2709,    1,    1,   37,    1,  365,    1, 3031,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   49,  729,  123,   37,  467,    1, 1132, 1152,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1844, 1867,   98, 1117, 2208, 1294,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219, 1090,    1, 1621,   98,  105,  845,    1,  566, 1479,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  458,   45,  507,  207,   28,   98,  160,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2932, 2587, 2971,   37,  764, 2446,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  548,  547, 1090, 1826,    1,    1,  852,    9, 2383,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613, 3007, 1615, 1775,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 2188,  973, 1159, 2913,  280,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1976,   32, 1796,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,   57, 2219,    1, 1021,    1, 2239,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   84,   81,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,   82,  936, 1596,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 1680,  647,  693,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2615,    1,   32,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  671,    9, 2627,  179,   56,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3376,    1,  548,    1, 2950,   45,  104,  861,  700, 2414, 1312,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1966,  437,  315,   10, 2714,  220,  443, 2502,  149,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3116, 3262, 2540,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 3403, 2414,  176,  177,   32, 3354, 3392,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3358, 2617,  774,  204,  833,  612,  606,  505,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2114,    1, 1281,   32, 2741,    1, 2846, 1552,  548, 1358, 1464,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,  590,    1, 3079, 1159, 2069,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2377, 1559,  297,  754,  327,  412,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,   69, 2126,   27,  119,  636,   32, 1033,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,  515, 1110,  753,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3194, 3195,    1, 1794,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2725, 1867,   16,    1, 2409,  967,    1, 1215,  388,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614, 1403,    1,   37, 1938, 1267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2784,  891,  176,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1733,  108,  444,    1, 2433, 2325,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  733,    1,  159,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  297, 1061,   32,  163,    1,   12,    1, 2819, 2678,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181,    1,  105,    1,  904,    1,    1, 2689, 2038,  922,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1051, 2239, 1289,    1, 2524,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835,   12,    1,   18,    1,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,  331,  399,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2508,    1, 2042,   98,    1,  134,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  388,  763,    1, 1295, 2572,   32,  395, 1585,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384, 2819,   37,    1,    1,  105,   74,    9,  166, 1772,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  786,  595, 1572,   37,  885,   98, 3012,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1046, 2095, 1491,  134, 1411, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158, 2976,  282, 2367, 2695, 2558, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925, 2570,  787,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1333, 1530,   32, 1785, 2044,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3235,    1,    1,   32, 3117,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  621,  835,    1,    1,    9,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2264, 1173,   37,  470, 2206,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,  361,  166, 1688,   45, 1739, 1021,   28,  786,   45,  105,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,   12, 3355,  267,  531,  890, 1822,  168,  115,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  131,  141,   48,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    8, 2557,  297, 1743,   98,  890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  809,  606,  686,  135,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388,  763,    1,    1,    9,    1, 1717,    1,    4,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1991,   37, 1551,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  679,  529,  109,   66,    1,   69,   70,  245,  680,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  236,  237, 1034,  115,   29,   51, 2050,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 3344, 1414,    1,  449, 2085,    1,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  667, 1557, 2257,  115,   32,  123,  863, 2107,    1,  806,   16,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  686,  119,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3079,  664,    1,    1,    1,   98, 2041,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37, 1539,  365, 1013, 1522,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  342,  213,  132,   98,    1, 2728, 2150,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1067,  354, 1665,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  356, 2469,    1,   37,  619,    1,   45,  522,   32,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  947,  590,    1,    1,  229,   32,  597,    1,   12, 1294,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  215,   12,    1, 2414,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3298,  140, 1796, 1938, 3197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,  825,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 2137, 2275,    1,  459,    5,  302,   32, 1923,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1112,  176,  730, 1571,  221,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2640, 2684,  176, 1821, 2190,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  951,    1,    1, 1574,   37, 1463, 1658, 1821,    1, 1821,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  954, 1574,    1,   60,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  365, 2610,    1,    1, 1260,  640, 2492,  725,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  437, 2386, 1158,   45,    1, 2102,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2, 821, 819, 619,  28, 411,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 717, 551, 705,   1,  28, 214,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1420,    1,    1,  384,    1,    1,  510,  431,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1934,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  854, 1754,   37, 1778, 2580,    1, 2581,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117, 3058,   37, 2360, 3342,   32, 1956,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   69, 1782,    1,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1127,    1,  915,  853,   48,    9,  331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2232,    1,    1,  612,    1,  191,   26, 1039,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  420,   98, 3101, 2500,  663,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  852,   37,  439,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667,  996,   93, 1071,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  225,   70,  720,  548,  503,  550,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622, 2161,   37, 1377, 2162,  191,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1729,    1,  176,  455,   16,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12,  581,    1,    1,  779,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  670,   98,   69,    1,  374,  338, 1315,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1774,   39, 2366,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2206, 2435, 1606, 1149,   37,  865,   37, 1604,  548, 1756,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2612, 2873, 1167,    1,   98,  238,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1617, 1216,  460,    1,  261,   37, 1413,   94,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835,    1, 2985,   32,    1, 2137,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1498,    1,    1,  261,   98, 2089,    9,  225,  809,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1463,   45,  455,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   63, 2930, 2263,    1, 3310,    1, 2047,   37,  947,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1082, 2892,   37,  713,  176, 2646, 1712,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  865,   37,   95,   98, 1171,  528,    1, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  794, 1778,  279,    1, 2389,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  707,   37,   10,  186,    1, 2669,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2471,  220, 2018,  105,  845,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1537,    1, 2572,  191, 2702,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,   12, 2084, 1069,   50,  162,   59,    5,  302,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  730,    1,    1,  384,  787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3094, 2572,   32, 2596, 2137,  176, 3393,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2551, 1046,    1,  872,  220,  453,  248,  332,   45,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   98,  166,  221,  295,  707,  166, 2025,    1,    9,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3302, 1539,  469,   37,    1,  103,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3229,    1,    1,  220,    1, 3265,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1361, 2781,   98,    1, 1647,  220,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  171,  146, 1858,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2531,    1, 1364, 1365,    1,    1,   32,    1, 1463,  892,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  409,   25,  123,  242,    1,   60,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3045,  477, 1147,  947, 2190,    1, 3392,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,   37,   16,   79,  453,  248, 2071, 1331, 1017,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1377,   37, 3101, 2548,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596,  945,  861,   32,  105,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1112,  176, 1523,  297, 3358,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  375, 1159, 3179,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2018,   61,    1,   37,    1, 1437,    1,  267, 3380,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1536,    1,  469,  220,  147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  326, 1070,  845, 2442,  147,   37,  360,    1,  149,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  338,   37,  241,  340,  951,   94,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1247,    1,  872,   12, 1338,   45, 1705,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758, 1273,  251, 1013,   98,  166,  168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1097,   57,  276,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 2924,  865,   37, 2755,  531,  548, 2699,   27, 2597,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  130, 2681,    1,  683,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  548,    1, 2055,    1,  517, 1273, 1108,  288,    9,  335,   79,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1048, 1049,  156,    1,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   45, 2890,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  425,  426, 1579,  587,   32,  395,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2217,  765, 1415,   37,    1,  365,    1,  187,  233, 2424,    7,\n",
      "          302,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1870,   12, 2261,    1,    1, 2812,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2967,  361, 1497, 1542,   37,   84, 1159,  166,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,   37,  119,  340,  444,   94,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,   12,  954, 1353,  176, 2056, 1224,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   98,    1,  149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2084,    1,   32,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  213,   37,  875, 1370,   45,  633,  573,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1902,    1,    1,    1,  487,    1,    1,  928,  176,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  777,   29,  791,   37,    1, 1532,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  558,   37,  151,    1, 1697,    9,    1,  131,  987,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3260, 1473,   81, 1159, 2941, 2107,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,    1,  609,  162,  257, 1038,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 442, 448, 338,   1, 202, 183, 910,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 830,   1,  37,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3157,  774, 2205,    1,  202, 1360,  612, 2446,  741,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,   82,  880,  218,  471,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  654,   12,  721,    1,    1,   37, 1504,   83,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1, 2604,  675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  458,  605, 2199,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  492, 1000,    1, 1665,   37, 2990,  384, 2527,  164,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094,   12,    1, 1579, 3339, 2129,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1967,    1,    1,    1, 2596, 1976,   63,\n",
      "         3343,  741,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3153,    1,  535,  700,    1,  614, 1300,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1419,  183,   56,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,    1,    1,    1, 2683,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1215,  676,   37,  168,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1802,    1, 1002, 1394,   37,  166,  627,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140, 1537, 2348, 2287,   24,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2126, 2741, 2565,    1,  190, 1348,   46,   98,  627,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1123, 3231,  361, 3175,  606,  878,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962,    1,    1,  914,  845,  187,  902,  726,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  387,   71,   32, 1732,   15,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  275,  681,  588,   37,    1, 1715, 1994, 2086,  302,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,  695,    1, 1074,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2193, 2884,    1,  176,    1,   12,  754,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597, 1304,  710,  190,    1, 1727,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  692,    1,    1,  656,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1452,   32, 1918,    1,  104, 1654, 1046,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  487, 1973,  129, 3340,   32, 3360, 3355,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3280,   37,    1,    1,    1,  140, 3077,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  303,    1,  600, 1619,  458,    1,   98,    1,  616,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746,  868,    1,  630,  220,  479,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,    1,    1,  361,  829,   92,  911,    1,   37,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,  332,  756, 1039, 2690,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  617,  618,    1, 1991,   37, 2368,  166,  550,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2925,    1, 3318,    1,    9,  686,   98, 2158,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1808,  566, 1273,    1,   32,  395,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  997,    9, 3093,  187, 1583, 2120, 1934,   12,  446,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1492,  719,    1,    1,  918,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  267,  195, 1519,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2707, 1511,    1, 2690,  220,  661,   98,  342,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  545, 1035,   37, 1642,  199,  176,  539, 1037, 1038,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1008, 1902,    1, 1009,    1,   82,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  387,  567,  390,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  191, 2059,  571,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1018, 2613,  855,   32, 2592,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1810, 2572,   32, 1815, 2960,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,   82,  669,    1,  384,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3282, 3253,   61,    1,  191, 3198,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777,  325, 3028,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1786, 1535, 2272,   85,   98, 2285,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1489,  229,  134,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,  953, 1750,  687,  548,  800,   29,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   12, 1619,  458, 1500, 1184,   67,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   57, 2263,   45, 3402, 2153, 1634,   32,    1, 1585,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2298,    1,  393,   56, 1539,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  663,  437, 2682, 1147, 1916,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,  936, 1273,  132,  220,  180,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  311, 2936, 2565, 1366, 1445,   98,  917, 1171,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,  692,  119,    1,   59,  599,  444, 2114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  413, 1396, 1158,   12, 2102, 1107,   17,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 1386,    1, 2755, 2751,  543, 2024,  895,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  393,   37,  125,    1,    4,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3172, 1550,    1, 2099,    9, 2805,  683,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2543, 2522,  469,    9,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  429,   28, 2882, 1918,  973,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3058,    1, 2924,  865,   37,    1,    1, 1056,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  223,   37,  151,  449,  223,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,    1,  548, 3038, 2164,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2549,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  741,  590, 2463,    1,    9,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148, 3007,  112,  993,  517,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1212,   12,    1,   51,   47, 1056,  104, 2152,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1592,    1,  395,  945,   69, 1772,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1480,    1, 2562, 1056,  537,    9,    1, 1995,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,    1,  104,  186,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3268, 1421,    1,   37,   24,  881,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1373,   37, 1334, 2017,  187,    1,    1, 2493, 1176, 2947,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   22, 1450,   32, 3391, 2856,   32, 2074,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  501, 2682, 1133,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,  903,    1,   12, 2266,  531,  443, 2740, 1298,   37,\n",
      "         2199, 2834,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  453,    1, 2591,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,   62,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105,  551,  331, 2565,   61,   32, 1090,   45,  247, 1204,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1162,    1, 2732,  250,  202, 1974, 1495,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  439, 1034,   98,  845, 1318,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2498,   37,  619,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1484,  199,   98, 2213, 2318,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3157,  682, 1046,  183, 1665,   32,  195, 1225,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  982, 1586,  105, 2474,  856,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056, 1797,    1,    1,  565,    1, 2048,   45, 1125,  537,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  822,    1,   37,    1, 1085,    1,  357,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3161, 1287, 2072, 2087,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1258,   37, 1192,  658,  763,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  297,  411, 1282, 2305,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  105, 1338,   45, 1647,    1, 3194, 3195,  546,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2764,    1,  614,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1778,  877,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,   1, 345,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 550, 369,   1, 891,  32,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,    1,  297,    1,   15,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3149, 2774,  650,  884, 1096,    9, 2095, 1450,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1402,    1,   91,  817,   98,  971,  932,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  516, 2007,    9,  424, 2602, 1998,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3323,    1, 3227,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1390,    1,   95,  473,  498,  895,   98,  389,    6,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 221,  37,   1,  94, 673, 261,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 550, 251, 615, 388, 663,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  313,    9,   56, 2403,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424, 2306,   32, 1123, 1275,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1778, 2580, 2851,    1,   37,  439,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2662, 2483,  365, 1551,  361, 2918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    7,  365, 2741, 1675,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3092,  794,  549,  548,    1,  826, 2205,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3021, 1894,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204, 1310,    9,   72, 1479, 1684,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[  2,   1, 361,   1, 123,  37, 132,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 531,   1,   1, 891,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3029,  288,   37,  865, 2697,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  741,   98,  663,  625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2656,    1,  535, 1110,   32,   46,  297,  481,   50,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,  162,    1,  220,  215,  819,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2751,    1, 1803,   37, 3383,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  507,   12, 1338,   45,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,  498,   37,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2518, 1205,  191, 1717, 1697,  639,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2577,   24,    9, 1442,   22,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1151, 1091,  243,    1,   11,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  204,   12,  416, 1675,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  386,    1, 1554,  615,    1,  810,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  386,   37,  243,    1, 2293,    1, 1289, 1663,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  479,   34,  197,  157,    1, 1518,  250,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  460,   98,    1, 3132,  838,   79, 2614,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147,  358,   37,  865,   37,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1170,  159,  245,   98,  586,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,  132,  220, 2751,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1742, 1211, 2760, 1133,   37, 1399,    1,  707,   98,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2527,  164,  396,  453, 1194, 2500, 2566,   32, 1033,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 3101, 2729,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1327, 1484,  199,   98,  976, 3368,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  565, 2572,  187,  236,   32,    1,  338,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3214, 1401,    1,    1,   32,  331,   12,  726,  297, 3175,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3253, 3204,  427,  167, 1195,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1778, 1273,    1,  384,  612, 1273,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1359,  167,   52, 1634,   37, 2877, 1260,  722,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1439,    1,  162, 2335,  537,   32,  611,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2533, 2226, 1924, 1514,   37,  588,  683,  221,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3115,    1, 3227,    1,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567, 1666, 2486,    1, 1090, 2191, 1657,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  947, 2263,   32,    1, 1313,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,  951, 1361,  149,  765, 1836,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1661,  182, 2180, 1291,    9,    1, 1621, 2011,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310, 2064,  543, 1415, 2532,   32, 1345,  444,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1831, 2137,    1,  587,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  953, 1315,  187,  531, 2014,  418,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3198, 2489, 2347, 3267, 1411,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  381, 1414,    1,   45, 2183, 1682,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2578,    1, 2017,   37, 1434,  119,   32,    1,  628, 2630,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2099, 1908,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2843, 2523,  879,  631,  176,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1518,   32,   98,    1,  119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2290, 3259, 2368, 3331,  726, 1045,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2763,    1,  240, 1411, 2273, 1819,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  299,    1,  116,    5, 1281,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  218, 2596, 2414,   32, 2140,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  939,  187,   82,    1, 1009,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115,    1, 3250,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2551,    1,  132,  105,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2546,  251,    1,   37, 2547,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  245,  528,  107,  568,  125,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  967, 3078,   28,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3224, 1625,  193,   37, 1306,  837,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3382,   90, 3357,   37, 1594,  297, 3346,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2975, 1914, 1236,  297,    1,  988, 1825,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018, 1830, 2069,  973,   32,  463,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3142,    1,    1,  917, 3288,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,   45, 2249, 1407,  615,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  446,  531,  190,  741,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  182,  551,  517,  975,  338,  526,   32, 1300,  714,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  875, 1117, 2208,  149,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,  539,    1, 2540, 2018,    1,  801,   37, 3116,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2328,  640, 1619, 2597,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1105,  787,  354, 1315,  739,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1931,  969,  600,    1, 1336, 3015,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   98,  454,   37,  103, 2890,    1,  671, 2601,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1879, 2761, 3112,    1,   39,   32,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  993, 3160, 1156,    9, 3402, 3408,  966,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1424,   66,   32,    7,  293,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   37,   44,  755,  220,  133,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2980,    1, 2894,  618,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3250,  606,  590, 2259,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 2972,  475,  939,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1270,  118,  756, 2910,  606, 1846,    1,  191,  116,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  455,   12,    1,    1,    1,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  970,  125,   37,  395,   66,  187,    1, 1560,   98,   49,   12,\n",
      "         1370,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3355, 2940,   39,  297,  632,   36, 3071,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1557, 2682, 2018,  446,  741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,  105, 2365,  452,  354,   32, 3201,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  837,  572,   28,    1, 1946,  191,    1,   12,  333,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2922,    1,    1, 1897,  531,  443,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1527,    1, 2280,  210,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1559,  297, 3358,   12, 1983,  912,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963, 1920, 2249,    9, 2119,    1,   32, 1850,  531,  191,  163,\n",
      "            1,   12,    1, 1414,  963, 2122,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  593,  121, 1454, 1994, 2095,    1,  868,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  504,   32,    1,  602,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  848,  200,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   12,  936,  315,    9, 1658, 1412, 2301, 2012,  361,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2648, 2801,  498, 2226, 2969,  116,  132,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  796,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2909, 2856, 1763,   32,  531,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1166, 1221,   12,  105,  190,    1,    1,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  434, 1686,  176,    1, 1325, 1999, 1530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,   37,  224,  550,  395, 2795,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3359,  957,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    9,  270,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2751,    1,  557,  540,   46,  187,    1,  614,   98,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1759,  309,   32,  651,   45, 2047,  187,  890,   27,  420,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  892,   12,    1, 1037,  275,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  872, 1240,   52, 1488,   79, 2198, 2843,    1,   12, 1560,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3381,    1, 1061,   32, 3383,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2217, 1822,  846,   28,  652,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1147,  446,    1,  715, 2153,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1857,    1,    1,   22, 2611,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2841,    1,    1,  247,  593, 2841,  474, 1125,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1791,  104, 3400,  267,  204,  190,  946, 1371,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  272,   11, 1056,  861,  441,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1667, 2726,    1,   27,  942,   12,    1, 2578,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 733,   1, 112,   9,   1,  54,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1, 794, 111,   1, 776,   1,  88,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1576,  429,  845,    1,   32,    1, 2749,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1613, 2479,  829,  269, 2234,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1906,  520, 3369, 3146,    1,  104,   37,    1,   98, 3148,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2114,  967,  105, 2527,   12,  661, 1470,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1173,  176,    1,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1542,   37, 2000, 2673, 1816,  792, 2198, 2915,  792,  232,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2663, 1702,    1,    1,   81,   59,  537,    1,  506,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1867, 3262,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  487,  996,   93, 1071,   32,   72,  401,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1827,    1, 1625,   37,  698, 2675,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  326, 2334, 1114,  396,  119,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2677, 3262,    1,  787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2932, 1000, 2538,   32, 2580, 2851,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45,  229,    1, 1389,   45, 2162,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3230,   37,  631,  104, 1764, 1990, 3273,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3310, 1568,    1,  202, 2463,    1,   32,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,    1,  220,    1,   57,   98, 1778,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1497,    1, 1110, 3188,   32,  726,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  818, 1697,   81,   98,  166, 2655,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  942,  159,   28,   98,  214,  142,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  552,  517,   12,  156, 1473,    1,    1,  157,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1723,    1,   32, 3311, 3310,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 275,  25,   1,   1, 187, 978, 769,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 829,   1,   1,   9, 911,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1823, 1635,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141,    1, 2806, 1096,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  782,  460, 1133,  548, 1653,   45, 1477, 1990,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3340, 1527,  475,   61,    1,   98, 1089,    1,    1,  361,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  446,    1,    1, 1596,    1,  961, 2224,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  891,  840, 2031,  225,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  726,    9,    1,  650,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141,   37,    1,  220,  402,  261,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1770,    1, 2911,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2932, 1000, 2663, 2126,   45,  633,    1,   98,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  202, 2489,   85, 1990, 1625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  744, 3243, 1757,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1759,  309,    1,  187,    1,   23,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3302,    1,  593, 1863,   45,  166,  356, 1638,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,  692,  439,   37, 2084,  442, 2096,  220,  316,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3186, 3176,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  988,  682,  432,  384,  166, 2227,    1,  705,    1,\n",
      "          105,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  364,    1,    1,  590,    1,  884,  631,   32,  180, 1990,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  310,   25,  455,   12,    1,    1, 1789,   12,    1,    1,  424,\n",
      "         1034,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2339, 2945,  277,  469,    1,   12, 3143, 1313,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  848,    1, 1892,  297, 2371,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,  116,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 1236,  777,    1,    1, 1130,  297, 2819,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3194, 3195, 1654,    1,    1,  105,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  777,    1,  698,   28, 1668, 1799,    9, 1437,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2507, 2271, 1812,  191, 1094,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428,  391,    1, 2450,   37, 1982, 1789,   12, 1428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,  839, 1583,  966,  396,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977, 2407,    1,   28, 1167,    1, 3027,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,   12,  553, 2359, 1222,  614, 1824,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,  868,   39,  176,  657,  220,  365,    1, 1510,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,   12, 1021,   37,  907, 3169,   12,    1,   32,  163,    1,\n",
      "           12,    1,   26, 2069,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2967,   37, 1306, 1056, 1675,   37,  856,   43,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2070,    1,    1,    1,  572,  932,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  395,  945,   69,  475,  580,  947,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777,  920,  176,    1, 1722,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   32,    1,  231,  579, 1564, 2994,    1,  320,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  794,  112, 1116,  437,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3320,    1,    1, 2810,    9,  539,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 1831, 1877,  627,  104, 2954,   37, 1604,  388,   98,  596,\n",
      "          261,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3340, 3347, 2297,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  477,  488,  455, 1123,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1228,  696, 2264,  856,  923,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3058,  476, 3342,    1,  924,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  398,    1,    1,    1,  261,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  950,    1,  284, 2218,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  982,   21,  198,   15,   32, 2073, 1023,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2018,   12, 3380,  952, 2710,    1,  764,   32, 2095,  856,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,  794,    1,  361,    1,  853,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1,   98,  148,  647, 2552,    1,  150,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  848,   12,  844,  315,  335, 1134,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1656, 2950, 2414,   32, 2018,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3103,    1,  967,    1, 1857,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  852,   37,    1, 1560,    1, 3026,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  387,    1, 1450,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,   30,  365,  803,  112, 2168,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  243,  390,    1,  229,  361,   69,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1233, 1149,  741,  444,  477,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2764,    1, 1877,   37, 1937,    1,  298,    1, 1439,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3290,  729,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3140,    1, 3374, 1094, 2399,   37,    1,  105,    1,   12,    1,\n",
      "           32,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,    1,   98, 1093,  977,    1,    1,   98, 2204,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2305, 2581,  571,    1,   12, 1354, 2556,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1838,  260,    1, 1169,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1007, 1603,   37,   47,    1,    9,  331,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  613, 1929,    1,    1, 1085,  804,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1001,  573,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1, 3282,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1517, 2962, 2936, 2259,  166,  706,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3345,  774, 1444,  606, 2572, 1485, 3102,  844,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  344, 1260,   32, 3376,  741,    1,  431,  439,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  409, 2164,   76, 1387,  537,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1079, 3063,  794, 2355, 1013,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  909,    1,   59,   71,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1001,    1,  626, 1804,  384,  424, 1691,  433, 2193,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1883,   37,  151,    1, 1228,   32,  331,  132,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  166,  914,   37, 2446,    1,    1,  361, 2365,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   47, 2890,    1,  176, 1046,  265,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3066,   37,  100,   32,  105,  668,    1,   98, 2800,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3254,  884,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 353, 197, 951, 356,   1, 354,  88,   1,   3,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 197, 418, 118,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1206,    1,    1, 2843,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  695,   98, 3101,    1,   51,  631,   37,  909,    1,  391,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 1731, 2632,   32,  552,  552,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  430,  640,  491,  220,  331,  797,  798,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  978, 2953, 2334,  614,   98,  333,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3129,    1,   12,   37,  606,    1,  220,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  585,    1,  584,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 1834,    1, 3341,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  668, 1701,  335, 2621,   32,  856,  297, 1935,    1, 3000,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773, 2510,    1,  227,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1367,    1, 3241,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  729,  387, 1332,    1,   15,   28,  419,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  305,   71,    1,  218, 1867,  419,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2752,    1,  191, 3102,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2932, 3055,   32, 3110,   29,    1,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2317,    9, 1056, 1867,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  361, 1515,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1035, 1879, 1922,  669,    9,    1,  331,   45, 1462,  408,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  403, 2926,    1, 2451,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3066, 1550,  411, 1888,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  142,  140, 2511,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  964, 1398,  612,    1,   32, 3144,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  774,  947, 2572,   32, 2193, 3362,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  191,  984,    1,  193,    1,    1,  506,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2140,  345,   37,    1, 2172,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 2996, 2367, 2695,  861, 2558,  918,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1053,   22,  744,    1,  372,   20, 1250,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  407,  419,   98,  984,    1, 1926, 1927, 1665,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  219, 1107,    1, 1046,  822, 1260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2192,  163,   45,  612, 1628,    1,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,  972,  865,    9,  601, 1463,   37,   23,  872,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2136,  531,  443,    1, 2095,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37, 1096,  798,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1762, 1090,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,  491,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,  105,  365, 1015,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  741,    9,  258,    1,  361,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  601,  401,  156,  191,    1,    1,    1,  361, 3189,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2206, 2207,  172,  586, 1988,   45,    1, 2508,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1,   98,  132,   37, 1806,  810, 3107, 3366,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   61, 3166, 2800,   98,    1,  832,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  645,    1,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3068,  251, 1211,  613, 1067, 1484,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   51,  606,    1, 1204,   98, 3024,    1,  506,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  325, 1412,    1,  669,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3279,   32,    1,  187,  104, 2128,    1, 2684,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  430,  622,   57, 2199,   37,  393,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1709, 1655,   98,    1, 1393,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  754,  363,  754,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1, 2567, 1920,   32,  166,  844,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1816,  845,  275, 2886,   12,  728,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  937,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2493, 1477, 1990,    1,  220,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,   81,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3282, 3204, 1401, 3253,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1723,    1,  891,   32, 3311, 3310, 2930,  400,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3207, 1454,  671, 3126,   32,  147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1165,    1, 1735, 1607, 1220,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3235, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196, 1518,  372,    1,  613,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  870,  647, 2185,  572,  156,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2285,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3200, 2236,   39, 1056,  388, 2119,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  619, 1217,   28, 1030,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,    1,  138,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  600,  718,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  159, 1253,   98,  411,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1687, 1022,    1, 3008,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    7,    1,   32,    1, 3358,   12, 1204,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  864,  190,  360, 2330, 3146,   19,    9, 2836,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2189,    1, 2212,  861,  589,   39,   45,  759,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2970,  439,   37, 1204,   45, 2502,    9,  854,   12, 1354, 2556,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  671,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1707, 3385, 2673, 1004,    1,  267, 1542,    9,    1,  357,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2246,  683, 2963,   32, 2106, 1990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  297,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  267, 1060,   45, 1711,   45, 1117,    1, 1866,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  865,    9,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  698,    9,  163,    1,   12,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1441,  268, 1092,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,  359,  360,    1,  361,  362,    6,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3181, 1249,    1,   37, 1334,   98,  103,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   25,  439,   28,  503,  696,  374,   60,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1789,  251,   37,  125, 2924,  191,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,    1,    1,   12,  365, 1030,  260,  166, 2499,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1147, 3006,  774, 1444, 1683, 1855, 3365,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   19,    1,  218,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1622,  477,  288,   37,    1, 1159,  601,   74,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273,   21, 2048,  176,  730, 2614,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1268,  443,  220,  507,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  858, 2493, 2947,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  709,    1,    1,  513,    1,   37,  133,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,  967,    1,  595,    1,  379,  774,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  140,  183,   32,  963,    1,  400,  318,  361,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  709,    1, 2049, 2565,    1,  928,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  602,   12, 1354,    1, 1886,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,    1, 2275,  877,  915,    1,    1,    9,  764,  191, 1117,\n",
      "         1525,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  105, 2595,  183, 1090,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2070, 3175,  608,  105,   12,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1057,  297,  104,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3242,   37,   16,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  421,   37,  698,  176, 3229,    9, 1110,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  233, 2365, 1140,   98,  301,    5,  302,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   91, 2951,  163,    1,   12,    1,  176,  698,   45, 1477, 1990,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2505, 3126,    9,    1, 3046,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3369, 1707, 3118, 2024,   23,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3203, 1478,    1, 1918,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3188,   32,  661,   45,  166,   64,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  627, 1277,    1,    1,   32,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2319,  166,  454,  334,  825, 1697,  111,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3205,  602,   32,  593, 1990, 2701,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1293,   98,  103,   32,  602,  220,  726, 3315,    1,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,   12, 1194,  401,  197,  388,  763,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  422,  908, 1093,  574,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147, 2411,   37,  211,  574,  940,  804,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  215, 2702,  260,   37,   52,    1,    9, 1890,    1,  947,  774,\n",
      "          328,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  395, 2783,  103, 1569,    1,  163,    1,   12,    1,  580,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,   27,  187,  531, 2292,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3297, 3158,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1647, 1532,    1,  202,  445,   37,  544,   37,  759, 2003, 1211,\n",
      "          593,    1, 2396,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0],\n",
      "        [   2,    1, 2216,    1,    9,    1,  220,  404,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  328, 3168, 2257,   39,   45,   65, 1990, 3179,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  459,  132,    9,  864, 1273, 1074,    1,  729,   37,  138,\n",
      "            1,  278,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  924,  514,   32,    1,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3018, 2007,   32,  460,   12,  232,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1375,  353,   72,  401,  354,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  132,  431,  562,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  968,  306,    1,  407,    1,   29,   16,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1433, 1361,   12,    1,    1,  105, 2286,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,   91,  176, 2413,   98, 1649,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2206, 2989,    1,  772, 2577,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1632,  854,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1,    1,    1,    1,   37, 3331,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1000,   51,  764,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2225, 1167, 2866, 1608, 1000,  460,  220,    1, 3000,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,    1,  440, 2064, 1982, 2977,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3343, 3345,  288, 2069, 1757,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3363, 1103,  115,   32, 3343,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,   98,  166, 1611,  222,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  234, 3041,  235,    1,  234, 3041,  235,    1, 1581,  917,\n",
      "          502,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2707, 1268,  792,    1,   45, 1516,  792,  220,  652,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3188,   12,    1,   45,  119, 1908,  535,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1848,  494,   37,  619, 1038, 1145,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  428, 1002,   10,  113,  631,  297, 2275,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,    1,   27, 1727,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  665,    1,   98,    1, 1313,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  810, 2621, 2905,    9,  294, 1260,   98, 3391,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,   26, 1380, 1642,   32, 2232,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  438,    1, 3101,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3012, 2961, 3027,  113,  227, 2948, 2977,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  104,  684,   37,   47,  372, 1411,    1,  108,   98, 2010,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2507,  434,   51, 1724, 1937,  105,  365,   74,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  996,   93,    1,   37,    1,  118, 1224,   32,  581,  401,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 2058,   79,    1, 2274, 2041,   16,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  932,   16,    1,    1,  366,  968,  741,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1666, 3201,  297,  567,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  190,  224,  774,    1,   37, 2492,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,   22,  866,    1,  187,    1,    4,  565,  125,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2017,   98,  112,  429,  166,  259,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1310,   37,  504,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2442,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[  2, 683,   1, 207, 418, 159, 245,  98, 157, 328,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 596, 954,  37, 832,  32, 592,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  112,  187,    1,    1, 2631, 2905,    9, 1497,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,   79, 1619,    1, 1969, 2169, 3279,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2994,  361,  760, 2993, 1009,    1,  166,  627, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  790,  432,   98,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  171, 2358,    1,  232, 1061,   32,  290,   98, 1789, 2763,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1643,   37, 1155,  365, 2500,    1, 1294,    9,  104,    1, 1108,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  398,   32, 2235,  515,    1,   37, 1584,    1, 2214, 2844,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004, 1107,    1,  251,    1, 3049,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  572,  197,  418,  118,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2188,  453,  973, 1159,  844,  220, 1778, 2580,  535,  656,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2827,  191,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2499,    1,   37,   47,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1345, 1425, 1147,  787,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,   12,  737,  244, 1124, 1146, 1703,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1428,  312,  966,  927, 2954, 2684,   32,  166, 3114,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  635,  197, 1042, 1056,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 760, 166, 282,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 848, 437,  37, 151, 849,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  551,  217,  572,  156,  245,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  200,    1,    1, 2165,    9, 3293,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2764, 3381,  437,  267, 3340, 1796,   32,  531, 2606,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  163,    1,   12,    1, 2548, 2572,  191, 2597, 1656, 2596,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  585,  361,    1,   37, 1523,    9,  166,    1, 1684,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3334,    1, 1559,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  463, 1447, 1542,   37,  100,   32,  400,   45,    1, 1260,   98,\n",
      "         1360,  232,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  180,  132,  387,  179,  159,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1790,  692,  365, 2294,    9, 1748,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3010, 2871, 2919,    1,    1, 3229, 2253, 2321,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,  460,    1,    9, 2310, 1831,   37, 1079, 2349, 1232,\n",
      "         2226,  331,  603,    9,  885,  389,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  203,   37,  877,  105,    1,  173,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  388,    1, 2548, 2844,   32,  463,    1, 3279,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3191,  514,   45,  195,  966,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1428,    1, 2153,   37,  289,   98,  593, 1964, 1816,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3184,    1, 1791,    1,  650,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  365,    1,   37, 1758,    1, 1998,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,  929,    1,   32,  187,  545, 1035,  159,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  119,  293, 1396, 1107,   28,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2067,   97,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  978, 1178,  437,  571,   32,    1,    1, 3019, 1708,    1,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1818,  187,  460,  936,   71,   32,  244,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1247,    1,    1,  166, 2453,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1008,  365,  475, 1213,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1090, 1667, 1758, 2851,  636,  720,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2298,  470,  997,   45, 1395,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2468, 3109,   32, 3043, 2095,  469,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   35,  267,  460,   12,  199,   37,  221,   98,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  596, 1793,   12,  805,   98,  104, 2152,    1,    1,    1,  384,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1115,  166,  846,   45, 1125,   37,  860,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2246,    1,  459, 1056,  356,  132,  220, 3233,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  167,  429, 1215,  388,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  764,  856,    1,  505,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,  295,  190,  125,  388,    4,   32, 2139,   37,  836,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,   37, 1031,  332,  315,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1831,  338,   98,    1,  297,  460,  675,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1687, 1022,    1, 3008,    1,    1,  191, 3087,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275, 2438,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2518, 1550,    1, 1260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2569, 2751, 2156,   10, 3040,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1239,  459,   45,  105, 1115,   98,  236,  237,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,    1, 1444,  321, 1155, 1891,  593,   12,  449, 3093,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,   28,  115,   45, 1850,  889,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2163, 1215,    6,  197, 1396,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3397, 1261,  916,    9, 2024,   32, 3388,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  247, 1140,   28,    1,  267,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3149,    1,  488,  388, 1450,  548, 3070,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  868,  671,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1264, 1090,   32, 2916,    1,  191,    1,  220,  542,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  140,  845, 1253,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2528, 2165,  665,  105,    1,  289,   98,  102,    1,  280, 2928,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2838,  439,    1,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158,    1,    1,  846,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  142,    9, 1423,   12,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   11, 2701, 2287,  220,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2514,  968,   12,    1,  288,   37, 2935,    1, 1656, 2545,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1403,   81, 1691, 2294,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2594,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  565,    1, 1114,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,    1,  197,   28, 1270,  118,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1492,   12,  729,  166,    1, 1178,   32,  507,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1771,  845,  147, 1707,    1,   12, 1377,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3380,  267, 1360,  612,  319,  187, 1583,  475,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98, 1220, 2759,    1,  326,    1, 1228,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056,    9,  786,  132,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2468,  140, 1764, 1990,  187,    1,  921, 3230,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 3161,    1, 1739, 1022,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1929,  952,   37,    1, 2189,   15,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2333,    1, 1000,    1,  667, 2932,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  584,    1,    1,    1,  171,    1,  210,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,    1,  229,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,   37,  631,   46,   98, 2707,   12,  342, 2927,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1547,    1,   85,  191,  677, 1251,   45,   69,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,  224,   12, 2259,   37,  105,    1,  150,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,  37, 631, 183, 404, 428,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 105,   1,   1, 340,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   68,   69, 1298, 1382,  548,    1,   12,  863, 1572,  186,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  636,  120,  640,  236,  237,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103, 1090, 2052, 2007,   37,  567,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    9, 2423,    1,  424, 1832,  852,  227,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,    1,    1,    1,  892,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1363,  986,   39,   54,  202,  997, 1192,   98,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2546,  733,  152,    1,    1, 1086, 2610,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1032, 1547,    1, 1326,   12,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2929, 2800, 2277,   32, 2267, 1262,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  598,   37,  544,  284, 1604,   98,  147,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3310,    1,   79, 2737,   12, 2081,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   14,   15,    1,  187,  818,  914, 1268,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1,   32, 3376, 2596, 1585,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3124, 2660,    1,  726,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1985, 3375,    1, 3095, 2572,   32, 3339, 2292,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  666,    1, 2288,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  344, 2596, 1396,  947,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   60,  113,  530,  687,  187,   29, 1552,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2603, 1013,    1,    1,  150,  884,  365, 1992,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2065, 1117, 1603,    1,  633,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,    1, 1939,   45,  356, 1691, 2708, 3065,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  514,  202,  967,    1,  199,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1011, 1512,    1,   32,  403, 1447,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  306,  105, 1013, 1522,  251,  834,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,   59,   32,  584,  729,    1,  548,  799,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  171,  496, 1784,   37,    1,  384,  367,   12,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1127,  697,   37,  151,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  581, 2842,    9,  104, 1564,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 2419,  218,   32,  276,  918,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1199,    1, 1669,  365,    1,    1, 3022,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1086,  356,  909,  444,  976,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  861, 1906,   37,  907,   32,    1,   98, 3369,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2708,  861,   46, 1348, 1010,  997,   45,  555,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   77,   28,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  468, 1362,  515, 2017, 1273,    1, 2706,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,  744, 1757,    9,  864,   98, 2375,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2412,    1,    1,   12,  683, 1625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,    1,    1, 1006,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  668, 1701,  698,    1,  777,  912, 2852,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2345,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  147,  400,    1,  224,  361,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1341, 1500,  158,  959,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  815,  460,   32,  105, 1175,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2677,   74,    9, 1990,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  166, 1650,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  267, 1352,  104,   15,   71,    1,    1, 1387,  453,\n",
      "          570,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   33,  105,  628,  400,   45,  629,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32, 3402, 3408,  400,  513,  514,   37,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,  884,  118,   45,  647,  159,  202, 1090,   61,  193,  297,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  878,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  437,  929,   37,  930,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,   12,  688, 2838,   37,    1, 2764,  539,  631,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1928,   45, 3025,   12, 3040,    1,   98, 2606,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  199,  421, 1042,  849,  142,    1,  848,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1484,    9, 3339,  469, 1743,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1300,  379, 2360,  458,   45,  507,  389,    6,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2059, 1999, 1530,  548,  298,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65, 1500,    1,   67,  191,  105,  401,  402,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  311,    1,    1, 1086,    9,  104, 3397,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106,    1, 2750, 1626,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1464,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 3111,   32, 2140,   98,   64,  591, 2699,    1,  223,  997,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1968,   12,   40,    1,  103,  152,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 1173,   37,  123,   39,  730, 2614,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3363, 1443,    1, 2017,  176, 3343,  741,  631,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  726, 1445,  863, 1077,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2354, 2349,   37,  166, 2918, 2820, 1167,   61,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  857,  477, 1408,    1,   56, 1394, 1048,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  746,    1,  196,    1,  365, 2348,  279,    1, 2665, 1108,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1457,  958,    1, 1918,   32,  480,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2226, 1548,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3251,  709,  905, 1749,  588,  222,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  903,    1,  904,    1,   57, 1021, 2152,   37,  125, 1649,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2569,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  393,   22,  847,  387,  354,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2178,  947,  877, 1647,   32, 2147, 2596,  549,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  104,  476, 1415, 2471,  220, 2018,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2379,    1, 2652, 2333,    1, 1427,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  104, 2161,   12, 3273,  105, 2848, 2494,  872,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3190, 1993, 1741,    1,  275,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1087,   37,    1,  819,  220, 1412,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2278,  113,  453,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3375,    1, 1919, 3374, 1098,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  987,    1,   28,    9, 1611,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  506,    1, 1272,  166,  207,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  978,    1, 2549, 1396, 2650,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  104, 1114, 1877,   37, 2884, 1926, 1927,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870,  353, 1455,  197,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,   61, 1194, 1354,    1, 1833,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169, 1287,  608,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,    1, 1995,    1,    1, 2161,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,  993,  929, 2297,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   31,  953,   37,    1, 1146, 1703,  202,  284,  729,    1,  242,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,    1, 1094,  429,   39,    1,   45, 3388,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  149,  801,  444, 1379,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  746,  361,  829,  469, 2348,  844, 1108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  299, 1713,  912, 2285, 1523,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  829, 1070,  342,  147,   37,  899,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1, 2700, 1865,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3102,  949, 1027, 1258,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1028,  657,   12,  365,   82,  580,  183, 1355,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,   37, 1245,   28,    1,  218,  220,  365, 2168, 2973, 1764,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1317,  704,  104,  729,  840, 1317,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942,  801,   37,  593, 1990, 2701, 3293,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1771,  163,    1,    1, 1564,    1, 1007,  550,  220, 2275, 1435,\n",
      "          318,  361,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1099, 1453,   37,   77,  388,  987,   98,   38,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2957,  891, 1222, 2359,  776,  220,    1,  371,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   45, 1212,    1,    1,  928,  176,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   10, 1454,  531, 2874,    1,  104,  522,   98, 2429,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1199, 1821, 2668,  764,  875,    1,  736, 1821,    1,  150,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1634,   37,  596, 1793,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1474,  267,  460,  190,   26,    1,  132,   37, 2015,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    4,  420, 2951, 1378,  736,  559,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 2877,   44,  548, 2891,   45,    1,   32,  531,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,    1, 2742,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    9,  793, 1612,    1,  460,   12,  166,  439,   45,  105, 2213,\n",
      "          823,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3004,  936, 1017,   45,  166,  356, 2577,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    6,  734,  191,   59,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  741,    1,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283,  830,    9,  385,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   32, 1815,    1,    1,    1, 1625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006,    1, 2108,  384, 2646, 3346,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1791, 1158, 1101, 1230, 2274,  459,  220,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1227,  325, 1994, 2650,  633,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788, 2615,  872,  420,  385,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1674, 1292, 2942, 2668,    1,   55,  792,    1,    1,  792,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2236,  483, 2582,    1,   32,  247, 1294,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103,  588,  683, 1001,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  433, 1579,  104,  131, 2108,  302,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,    1,   55,   12,    1, 2771,   51,  606, 1846,    1,   32,\n",
      "            1, 1215,    1,  365,  506, 1770,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2623,    1,    1,  199,  220,    1,  940,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496,  267, 2179, 2778,   66,  187, 1354,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,    1,   69,  361,  493,  166, 1868, 1172,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  321, 2856,    1, 2203,    1,  506,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2963,  297, 2577,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,  952, 2089,  414,  384,  971,  361,  479,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3276, 1879,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3175,  221, 1090,  115,   32, 2764,  539,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  506,    1, 2636, 2668,   98,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  476, 1345,  916,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1100,   30,   79,    1, 2071, 1331,    1, 2232,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  794,  365, 2328,    9, 1022,  199,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2883,  566,  217,   32,  195, 1001, 2884,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  493,  677,  297,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  328,  455,  147, 1579,    1,  370,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1,    1, 2071,    1,    1, 1732,    1, 1114,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1039,  668,  293,   37, 1753, 1465, 2264,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  105, 1882,   37,  688,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1659, 2864,  537,   45,    1,   45, 3088,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1352,  495,  176,  105, 1312,  339, 2284,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  215,   67,  429,  221, 1924,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   51,    1, 3027,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2563,    1,    1,    1,  551,  730, 1508,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3005,    1,   98, 2372,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  947, 2884,    9,    1,    1,    1,   32,    1, 2821, 2607,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3344, 1940,   64,  632,   36,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2885,  140, 1194, 3258, 2579, 2630,   45,  914,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  361,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2868,    1, 1057,  297, 1610,  903,    1,  464, 1463,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 1051,  710, 1713,  730, 1777,  721,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  950,  315, 1479,    1, 1437,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1622, 1149, 1539,   56,   74,  391,  477,  297,  677,  529,  408,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  365, 1102,  931,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647,  765,  115,    1,    1, 1479,  326,  662,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,    1,  220,    1, 1831,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2077,    1,  971, 1413,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  107,    1, 1738,   69,  636,  338,   37,    1, 1714,  105,  106,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1123, 2896,    1,  928,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  215,   12, 1861,  267, 2375,  420,   30,  531,    1, 1428,  261,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  542,  321,    1,  172,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2491,    4, 1638, 1564,    1,   28,   37,  166, 1831, 1620, 2181,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2149,  712,   61, 2689, 1717,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3115,    1, 2777,    1, 3285,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2333, 2527,  338,   37,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  829, 1268,   28,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219, 2122,  231,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,   98,  166, 2041,   37,    1,    1,    1,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3359,  992,   28, 1896,   37, 1505,  129, 1945, 1386,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3330, 2489,  808,   45,    1, 2773,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1428,  864,   61, 1300,    1,  590,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1822,  860,    1,   45,    1,    1,    1,  420,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  219, 3399, 1079,   37,  907,    1, 3061,   32,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,  354,   96,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,    1,   37,  125, 1149,  138,  191,  118,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2292,    1,  298,   32,  531, 2856, 2924,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  215,    1,  162,   94,   92,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2592, 1458,   39,   45,  829,   24,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056,    1,  350, 2983, 1976,    1, 3024, 2293,    1, 1411, 1821,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178, 1179,  108,   45,  417,  844,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  166,    1,  105,   71,   32,  166, 2101,  236, 1022,    1,    1,\n",
      "          166, 1354,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1916, 2086,    1,   98, 2610, 2363,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2484, 1020,    1,    1, 1532,    9, 1797, 1090,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1064, 1434,   37,   81, 2266,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  149,  191, 2458,  267,  829,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  988, 2759,  157,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  227, 1215,  877, 1481,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  796,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32,  404, 3114,    1, 1887,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 622,   1, 197, 176, 750, 681,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 921,   1, 142,   9,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2005,  730, 2614,  608,  978, 3138,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  275,   25, 1285,  242,    1, 1946,  191, 1128,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2425,   37,  130, 1412,  861,  624,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  247, 1281,  365, 1788,  317,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3358, 3336,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  927,   29, 2704, 2820,   12,    1, 1046,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1420,    1,  356,   37, 1014,  197,   66,   28,  995,   98,  242,\n",
      "          102,    1, 1220,  101,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  527,    1,    1,  498,   37, 2035,    1, 1890,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2597, 2137,   32,  501, 2060, 2856,    1,    1,  622,  267,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3099, 1702,    9, 1281,   98,    1, 2551,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  680,  114,  548, 2018,    1, 3217,  354,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  267, 1428,  193, 1997, 1133, 2398,   98,\n",
      "         3369,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2018, 3372,    1,  365,  446,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1193,   46,   98,  531, 3365,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  487,  957, 1562, 1158,    9, 2610,  408,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   37,  221, 1750,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1360,  612,   52, 2175,   81,   37, 3296,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,    1,   39,    9,  356,  220, 1628,   81,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2396,   45, 1645,    1, 2064, 3067,  557,  540,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,   98,  103,   45, 1412, 1107,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3058, 1118, 2282,  776,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  223,  286,    9,  166, 2516,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  420, 2759,    1, 1499, 1825,  293,   93,  918,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  288,   37,   26,   69, 1482,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  294,  361,    1, 2517,    1,    9,  166, 1255, 2498,  176,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  386,    1,    1,   32,  147,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2700, 1313,    1, 1178,  302,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,    1,   98,  365,   38, 2827,    1,   37,    1,  115,   45,\n",
      "          848,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2924,    1,  548, 1537, 2095, 1450,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1593,  176,    1,    1, 3349,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  864,  108, 2673, 2836,    1,   37, 1647,   32,   46,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2229, 2641,  578,    1, 2423,  234,  182,  235,    1,    1,\n",
      "            1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   22,  854,  776, 1142,    1,  187,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  397, 1579,  104,  442,  909,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1431,   51, 1031, 2089,    1,  159,   79,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  624,    1, 1380,  105,  365,    1,   98,   26, 1039, 3031,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3189,    1, 3227,    1, 3247,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1539,    1,  517,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2292,   32,  531, 1825,   69,   37,  365,  845,   45,  297,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,   12, 1404,    1,   39,  176,  379,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2685, 1025,   37,  877, 3269, 3237,   24,  693,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  891,  176,  754,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  387, 2467,   45, 2343,  776,   32,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1183,    1,  967, 1590,   32, 1030,  176,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  311, 1204, 1746,    1,   39,   98,  844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190, 1413,  105,  198, 2498,   32,  628,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3335, 1366, 1822,  289,   98,    1,   63, 1545,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1985,  118,   45, 2527, 2946,   37,    1,  104,  506,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  420,  441, 1807, 2056,  460, 1278,   93,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187, 2885, 1401,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1610,    1, 3126,  916,    9, 2942,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  581,    1,    1, 1564, 2333,    1, 2237,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,    1,   90,  724,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,  773, 1937,    1,  698,   37, 1104,    1,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  707,    9,  501,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1, 2342,  829, 2987, 2988, 2690,  820,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2365,   39,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1433,  544,  334, 1706,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  294,  922,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1702,   39, 2786,  861, 2996,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3033,    1, 2083, 2875,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  645,   70,  550,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1838,  395,  442, 1259,  202, 1911,    1,    8,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2347,    1, 2270,   37,  930,  228, 1890,  411,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  326, 1478, 1067,    1,   29,  132, 1960, 1270,  131,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   98,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  815,  134,  576,   10,  825, 2066,   28,    1,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  775, 1626,  659,   45, 2355, 1013, 2549,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1273,  259, 2264, 1427,  452,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2822,    1, 2056,   51,    1,  163,    1,   12,    1,    1,  191,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  660, 1426,  166,  846, 2010,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2885,  140,   32,    1,   37,  271, 2523,   12, 3258,  156,  119,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2550,    1,    1,  187, 1965,    1,  384, 2072, 1361,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1228, 1408,    1,   39,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  657, 1949,  469,   37, 1237, 1412,  844, 1151,  218,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2603, 1354, 2947, 1357,   98,  777,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  254,  334, 1542,    9,  284, 2800,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1116,   61,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  295, 1413,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116, 2401,    9, 1055,  834,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  510,  902, 2732,    1,  584,    1, 1193,  274,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  963,    1, 2695, 2223,    1,  884,  166, 1374,   32, 1463, 1821,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  193,   14,    1, 1825,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3237, 1745,    1,   37,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3398,    1,   37,  588,  502,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1983,   25,   28,    1,  118,   98, 1034,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  565,   98,  166,  454,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3153, 2220, 1816,    1,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,  288,    9, 2227, 1938, 3197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1621, 1905,   37,   52,  677,   37,  103,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104, 1579,  845, 1480,  858,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  987, 1907,    1,  187,    1,  898,    1,   59,  354,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1307,    1,  882,  872,  220,  715,    1, 1074,    9,    1,  776,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2807,  123,   39,  914,   98,  105,  845,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2292,    1,   32, 2755, 3360,    1, 2572,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,    1,  581, 1097,   32,   91,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  446,    1, 2593, 2224,  317,    1,  708,  709,    1,  582,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2889,    1, 2789, 1484,    9, 2024,   46,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2217,    1,  132,   37, 2286,    1,    1, 2153,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2877,   37, 1734,   32,  531,  890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1186,   66, 1322,  104, 2099,   98, 2924,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232,    1, 1554, 1090,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147, 1656, 2596, 2414,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   96,   85,    1, 2565,  317,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2828,   12,    1,  387,  730,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1472,    1,   32, 1482,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1906, 1258,  736,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2107, 2524, 2886,  260,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  395, 2272,   85,   98, 2226,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  914, 1086,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3260, 1139,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1110,    1, 3260,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1244,   77,  572,  327,   93,   98, 1171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  696,  417,   31,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,  786,  915, 1102,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  891,  549, 1159,    1,  851,  298,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2376,    1, 1713, 2604,  617,  700,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  204,   12,  288,   28,   37, 1330,   32,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1089, 1675,  168, 1092,  176, 1824, 2577,   16,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  612,  297,    1,  460,   12,  297,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1435,  691,   12,    1,   12,  708,  632,    1,  218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1528,   51,  875,  297, 1405,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  646,    1,    1,   37, 1952,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,  163,    1,   12,    1,  719, 1407, 1696, 1149,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2224, 1579, 3339,  797,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 1488,  763, 1056,  784,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  669,  765,    1,   37, 1778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 2272,   85,   98,  116,  663, 1063,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  864,  267,  460,  967, 1061, 2673,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,    1,  746, 1413, 1414,   98, 1766, 1767,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[  2,   1,  28,   9,   1, 361,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 191, 166, 437,  45, 441,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  179,   37,  125,    4,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2017,   98,  112,   61, 1697, 2219,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1428,   37, 1539,  152, 1027,    9, 3349, 2785, 2372,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2557,  528,  244,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1070,    9,    1, 1311,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,    1,   85,   98,  996,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   41, 2250,   81,   37,   36, 2242,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1002,  932,   16, 2107,    9, 1009,   61, 1114,  105, 1530, 1245,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  567, 1582,    1, 1159,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   20,  927,  703,   37,  372,   24,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1652,  794, 2355, 1718,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,   22,  847,    6,    1,    4,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3192,  105, 1292,    1,    9,  388,  763,  415, 1397,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   65,  155,    1,  347,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  315,   37,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  140,  142,   37, 1598, 3140,   32, 1430,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  487, 2641,  162,  613,  207,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  744,    1,   98,    1,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 1624,  125,   37,  331,  384,  182,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  405,   12,  688,  978, 3138,  220, 2144, 1844,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  800,   60,    1,  388,  104,  615,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  782, 2181,  176,  103,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2427,  361,    1, 2428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247, 2321,    1,   37,  903,    1,  507,    1,  763, 2112,    1,\n",
      "         2663, 1770,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2656,  267,    1,  191,  374,    1,   98,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615, 1910, 3294,   79, 2941,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,   14,   15,   71,  105, 2050,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1290,  396,   28,    1,  567,  105,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2531,   46,  590,  199,    1,    9, 1815,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  427,    1,    1,  438, 3164,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2617, 1542,   37,    1, 1046,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1249, 3254,   32, 1343,   79,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2696,  476,    1,    9,  840, 2970, 1675,   37, 2332,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 3276,    1,  548, 2787,   12, 1183,   74,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  219,  159, 1298, 1382,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  374, 1086,   28,   98, 1009,   10, 1918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  459,  786,  356,   24,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1252,   12,    1,    1,  877,  227,  449,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3321,   37,  698, 2807, 2198, 1247,  444,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2772,   45,  492,    1, 2037, 1833, 1159, 1512,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3103,    1,    1,   39,    9, 1517,   12, 1090,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,    1,  224,  361,  777, 1013,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,    1, 2789, 2153, 2460,   79,    7,  907,  187, 1021,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1203,    1, 2686, 2687,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1095,  325,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2835,  290,    1,  191, 1338,   45, 1534,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,   12,  365, 2334, 1631,  166,  593,   12, 1254, 1465,   12,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,  361,    1,   45,  150,    1,    1,    1,  361,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  395,  945,  290, 1781,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273,    1, 1022,    1, 2296,  730, 2614,  786,  726,   37, 3098,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1290,  396,  720,    1, 1196,  686, 1653,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1408,  453,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  121,   12,  417,  433, 1579, 1839, 3037,   98, 1649,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1037,  275,    1,   28,  282, 2334,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  590,  388,   46,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  778,    1,   37, 2703,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2733, 2339,    1,    1,  191,  147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1294,    1,  105,  686,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3288, 1408, 3238,  384,  205,  698,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  441,  221,   37, 1994, 2086,  769,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  657, 2257,    1,   98,    1, 1151,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2569,  611,    9, 1973, 1164,   32, 2397, 2095,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2071, 1935,    1, 3016, 1935, 2636,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1060, 2844,   32,    1, 2625,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  104, 1290,  396,   71,  388,  763,   76,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,   24, 1903,   98,  429,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1755,  583,  166, 2920,    1, 2737,  267,   32,  105,  365,\n",
      "          825,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144,    1,  536,  350,    1,   32,  741,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  715, 2122,  231,    1,    9, 3359,  361, 2700,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,    1,   72, 2886,   32,    1, 1938, 3197,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3286,  614,  220,    1,    1, 1608,    1, 2594,    9,  166,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2627, 2871, 1825, 2684,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1867,   98, 3358, 2704,  590,  459,   45,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  305,  686,  191,  840,    9, 2073,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3175,    1,    1,  640,    9,  166,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1492,   61,   72, 1178,   32,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361, 3405,   32,  443,   45, 1886,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  369,    1,    1,  105,    1,  301, 2717,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  352, 1566,  840, 2245,   50,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  441, 1152,   45,  365,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  321, 1599, 3304,  202, 1822,  690,  147, 1576,    1, 1428,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  777,    1,  162,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2924,    1,   37, 2446, 3339, 1957,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2669,    1,   98,  166,  116,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  284,    1,   32, 1107, 2086, 2039,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  164,  165,  109,  125,   32, 1023,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3282,  366,    1,    1,    1,   37, 1758,   32, 2490,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2974, 1137,   37, 1821,    9,  331, 2223,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  531, 2705,  798,   37,   52,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,  166,  661,   45,  166, 1177,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   69,  571,   37,  187,  889,   25,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2897,   32, 2755, 2883,    1,    1,  546,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3310,  776, 1268,  220,    1,    9,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,   25,  686, 1637,    1,    9,  257,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1502,   37,  125,    1,    4,  176, 1503,  548,  214,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2634, 2767, 2627, 2871, 1825,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 3375, 2572,   32, 3339,  477,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  231,    1,    1,  844,   51,   52, 2261, 1529, 2706,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1346,  469,  590, 1161,  741,  444,  103, 1499,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   25,  526,  548,  646,    1,  160,   29,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3318,    1, 3182,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  161,  127,  167,  606,    1,    1, 2705,    1,  267, 3084,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1728, 1114,    1,    1,    1,  166, 1514,  260,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1454,    1,  115,   45,  741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 3227,   32, 1864,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166,    1,  741,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 3007, 2933,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2102,  680,  114,  297,  215, 1402,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,  622, 2389,   37,    1, 1512, 2266,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  476,  397,   46,   98,   20,  296,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2597,  344, 1656, 2596, 2414,  176,  177,  947,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1435, 1128,   12,    1, 2182,   39,  105, 2041, 2655,    1,  384,\n",
      "         1085,   37, 1100,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  198,  478,    9,  433,  102,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  817,  627,   45,    1,    1, 2107,   29,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1700,    1,  200, 1254,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1777, 2739, 1408,  104, 2579, 1762,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2, 455,  12, 572, 646,   1,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 661,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  574,  512,  566, 1796,  172,   25,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1537, 3397, 2582,    1,  836,   32,    1, 1585,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2375,    1,  531, 2582,  590,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,  420,  105,  857,   44,  191,  166, 2640,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2384,    1,    1,    1,    1,    1,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1841, 1727,    9,  487, 3102,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  531,  379,   37, 1211, 1920, 3082,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  593,   12, 2084,  671,  700,  463, 2571,  671, 1235,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   60,  640,  365,  340,  444,   94,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213, 2331,   45,   94, 1647,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3192, 2427,  729, 1587,   45,  854,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380,    1,  105,   74,  220, 3363,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  198, 3087,  640, 1850,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,    1,    1,   45,  425,  426, 1149, 1280,  522,  149,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   32, 2667,  260,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1421,  103,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1364, 1365,    1, 2751, 1004,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1116,   32,    1,  744, 1363,   40, 1259,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 340,   1,   1,   1, 640,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  12, 551, 552,   6, 503, 734, 748,   1, 157,   1,   3,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,  436,  197,  418,    1,  159,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  551,  612, 1867, 1718,   37, 1504,  829,   12, 1778,   98,\n",
      "            1, 2261,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,   37, 1636,   98, 1220,   29,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2981,   81,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  485,    1,  197, 1042,    1,  159,  245,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2373,  593,  449, 2627,  327,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1000, 2901,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 2308,    1,   37,  856,    1, 1291,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  647,  776,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100, 2393,   98,  983,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  579, 1232,  105,   15,    5,  254,  166, 1851,    5,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861, 1075,    1,  365,    1,    1,  388, 2342, 3005,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  581, 1211, 2760,    1,  105, 2056, 1224,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,  361,  104,   32,  644, 1527, 1559,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2963,   32, 3308, 1990,  437, 1267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2004, 1087,   37,   47,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1019,    1,    1, 1674, 1551, 1976,   32,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   32,  942,    1,    1,  958, 1876,    9,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  424,    1, 2385,  612, 2879,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321, 2170,    1, 2571, 2298,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  449, 1173,    1, 2695, 1917,    1,    1,  612,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2053,  218,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   60, 1308,  548,  303,    1,    1,  671,   28,   32,   91,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2929,   37, 1237,  104, 1273,  218,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   61,    1,   85,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  857, 2754,    1, 2034,  726,   32, 2846,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  245,    1,   51,   52,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1994, 2086,  872,  256, 1645,  700,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1625,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204, 1456,    1, 3169,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  928,  187,    1,  985, 1464,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69, 1298, 1382,  548,  383,   98,    1,  341,  570,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1279,  977,  105,  227,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  995,  242,  572,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3134, 2445,    1,  187, 3013, 3268, 2257,   39,   45, 3141, 2306,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  298,  927,    1,   98, 1656, 2886,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3250,  472,   81, 1751,  513,  193,  514,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101, 1957, 2856, 1056,   32, 3339, 2831, 2791,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  786, 2072,  650,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3375,  543,  741,   37, 1504, 3358,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,  837,  187, 2476, 2075,   81,   32,  593, 1990,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2389,    9,    1, 1416,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  204,  476,   37, 2192,  121,  105, 1333,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3250,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2018, 1187, 2073, 1463,   45, 2673, 3085, 1461,   32, 1890,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  551,  789,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2863, 1350,  798,  444, 2956,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3075, 1082,    1,    1, 1076,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2379,    1,    1,  850, 1568,    9, 3176,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  321,  612,  544,  445,  440,  763,  713,    1, 3209,  774,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2308,  693,  193,    1,  227, 2398,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  162,  166,  698,  176, 3284,    9,  166,  694, 2551,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,   60,  338,  444,  166, 1547,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  968,   36,  336, 2291, 2414,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   25,   26,  242,    1,    1,   79,   69,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12, 1792,    1,  105,  311,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,  365,    1,    9, 1718,    9, 1729,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    1,  657,   12, 2336,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1260,  600,  531,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,  903,    1, 2673,    1, 1542,   37,  865,   37,  531,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  398,  515,  386,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1232, 1515,    1,  606,  105,  627,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  592,  475, 1082,  208,   37, 1838,  734,  283,  469,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,   66,  972,   37, 1083, 1184,  347,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1414, 2856, 3375,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1173,    9, 2941, 2966,  951,    1, 1717,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1147,  947,   32,  674,   45, 2646, 3346,    1,    1,   37,  716,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  859,   37,  792,  335,   98,  792,  448,   32, 1625,   45,\n",
      "            1,   60,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  395,   12,  677,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  730, 2614, 1089,  593, 1280,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  224,  580,    1, 1126, 2041,    1, 1721,  774,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,   61,   85,    1,  671,   28,   32,   91,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,   10, 1297, 1900,  544,    1, 1604,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   28, 1872,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  816,  187,  889,  509, 2103,  276,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1128, 1268,  885, 1140,  656,   32,  854,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1,  884, 1056,    1, 1992,   37, 1412, 1107,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1249,    1,   32,  447,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,    1, 2992, 2670,  315,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1707, 1096,    9,  354,  528,  857,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158, 1203,    1, 1871,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1955,   39,   37, 2446,    1,   12,  683, 1463,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1623,   45, 1527, 2664,   32,  166,    1,  187, 2306,  220, 3381,\n",
      "         1552,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 1987,  686,  854,   32,   72, 1463,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3378,  924,  580,  776,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   71,   45, 2229,  613,  681, 1379,   12,  112,  499,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2185, 1428, 2824,   98, 3369,   32, 2813,\n",
      "           45, 2591,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  136,  256,    1,    1,    1,   37, 1051,    1,  210,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  682, 1334,  115,   45,   31,   32,  367,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3345, 1198, 2162, 1665,   98,  104, 3091,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  741,    9, 1009,   32, 2024,  142,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  166,  821,  443,  891,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,  200, 1230, 2528,  551,  163, 1230,   32,  854,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3266, 2497, 3079,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    5,    1,  610,   37, 1700,  257,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1063, 2489,   85, 1503,    1,  997,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2231,  952,  537,   32,  611,    9, 2893,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,    1,    1,  693,  365,  613,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1458,  619, 1515,   74,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2960,   27,  104, 1967,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  142,   37,  439, 3144, 1512,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2031, 2660,  132,    9,  822,    1, 1291,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1614,  453,  326,    1, 2232,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1090, 2889,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299,  879,   10,    5,    6,    9, 1811, 1280,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  172,  681,    1, 2415,   98,  139,  471,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1757, 1552,    9,  294,    1,  487,    1,   32,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2690,    9,  166,  671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3241,  429,   79,    1, 3268,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   58,  197,  407,    1,  157,  969,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   50,    1,  531, 2699,    1,  622,  267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  342,  729,   32,   46,  220,  148,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1107,  293, 1236,  388,    9,  912, 2285,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2479,  631,   32, 2468,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302, 1712,    1,   37, 2103,  617, 1708,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1051, 2384,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  459,  881,   37,  704,  705,    5, 1084,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,  437,   30, 1928,   45,    1,   45,  547,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,    1,    1,  193,  859,    1,    7,   32,  531,  907,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1484,    1,    9,   46, 1010, 1860,  191, 1557,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  140,    1, 3154,   32,    1, 2162,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2802,   12, 2315, 1045, 1086,  176,  547,  187,    1,  140, 2080,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,   49, 1644, 1118,  865,   37, 2445,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  148, 1012,  578,  289,   98,    1, 1085,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3280, 1924,  193, 2347,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  189,    1, 2425, 2274,   98, 1074,  861,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2880, 2444,  444, 2819,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1497,  619, 1515,    1,   85,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  523,   42,  134,    1,   37,  138,   59,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2079,  270,  696,  148, 1124,  197,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2279,  190,  125, 2462,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,  183,  156,   37,  184,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  424,  914,  388,    1,  220, 2941,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  465,  404,    1, 2029, 1803,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,  395,  155,    1,  182,  220,  845,  439,  636,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2286,   37,    1,   39,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3006,    1, 3364, 1302,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  741,  920,   37, 2225,    1,   12,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  773,   37, 2243,    1,   29,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2190, 2640,  571,   37, 3024,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2896,  326,   12, 2022,  384,  327,  112,   66,  187,    1,  402,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3121,    1, 1789,  220,    1,    1, 2620,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    7, 1778,  328,    1, 1774,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1095,   37,  130,  463,  464, 1611,  700,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,   51, 1348, 2836,   45, 3107, 3366,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  255,    1,  565,   32,  166, 1525,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,    1, 1107,  293,   98,  163, 2304,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1720,    1,  907,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1030,  361, 2363,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   83,   37,  930,  384,  654,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1777, 2418,   28, 3028,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  303,  108,   98, 2214,    1, 1639,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1711,  260,    1,    9,    1,    1,    1,    1,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  848,    1, 1808,  114,   28,    1,  315,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  236,  237,   25,  439,  410, 1010,  885,   71,   32,   69,  102,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3280, 1685,    1, 1250,  548, 2890,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1567,  515, 3181,    1,  726,  176,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  341,    1, 1013,    9, 2728,   12, 2640,  187,   69,    1,  703,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  303,  954,  682,   23,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,  476,    1,    1,  384, 3107, 3366, 1806,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2292, 2414,  249,   32, 2490,  297,  608, 1056, 1890,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,  729,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1401,  166,  454,  176,    1, 3329,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  347,  415,  416,  417,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 2467,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1128, 1203, 2400, 1021, 1129,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2433,  455,    1,  191, 1056,  198,    1,  583,    1,    1,  267,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3308, 1118,  484,   98, 3096,    1, 1010,  342,  822, 1057,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  135, 1394,   37,  388,    1,  238,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  305, 1298, 1382,   63,   29,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  455,   12, 2801,  200,  517,  618,  220,  705, 1620,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1529,    1, 1042,    1,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3337,    1,  187, 2773,   45,    1, 1477, 1918,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2, 845, 361,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 458,  45, 507,  37, 125,   1,   1,   4,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1712,    1, 1465, 2948,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116,  259, 1108,   66,  187,   93,  293,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  902,    1,   76,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1816,  550,    1,  424, 1034,   32,  772,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 387, 419,   1, 983,  71,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 682,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  967,  638,    1,    9,  594,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1283,    1,   39,  176,  177, 1700, 2119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3285,  565, 2175,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3340, 1485, 1683,   32, 2755, 2140,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   49, 1489,  104,  695,   98,  271,   28, 1250,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3330, 3078, 1987, 2385,  612, 1328,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1790,    1,  758,    1, 1413, 1414,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,  708,    1,    9,  117, 1708,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  267, 2315,   61,    1,  260,  176, 3194, 3195,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3323,    1,    1,    1,  951,    1,  153,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,    6,  116,  259, 1108,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  667, 1386,  267, 1378,  863,  996,  739, 1176, 1862,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  596,  954,  395,   67,  423,  167,    1,  596, 1424,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   14,   15, 1285,   28,  699,    1, 1975,   85,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  244, 1124,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3182,   16,    1,  166, 2276,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  487, 2924, 1941,  187, 2377, 1708,  444,  443,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3297,    1, 1449, 2497,  511,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1786,    1, 1625,    9,    1,  863,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1797,    1,  176, 2646, 3346,    1,  284, 2751,   38,   32, 2108,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2840,   45,    1, 2325,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  485, 1086,  326,    1,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  327, 1091,  661,  160,  623,  810,  297, 1114,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  666,   37,  606,  905,  258, 1601,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[  2, 424,  61, 105, 389,   9,   1,   1,   1,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2503,  590,    1, 2755, 1306,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1695, 2209,    1, 1782, 1750,   12,    1, 1417,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2596, 2414,   32, 2597,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  361,  166,  688,    1,  614,   98,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  349, 1924,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3141, 2246,  405, 3291, 2753,    1,  583,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1479,  409, 2164,   76, 1387,  537,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  716, 2066,   69, 1196,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  487, 2162, 1950,  384, 2734,  167, 1992, 1407, 2541,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   58, 1737,  992,   37,    1,  361,    1,  613, 2973, 1764,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  137,    1,   37,  138, 1689,  314, 1469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 1484,    1,   32, 3369,   12, 3118, 2517,\n",
      "         3148, 1484,    9, 1428,  909,  963, 2122,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1850, 1423,   46,    1,   98, 1632, 2539,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1, 3127,  827, 3347,   61, 1710,   52,  344, 3403,  420,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2192,    1,    1, 1435,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3151, 2308,  907,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3356,   61,    1,  763,  460,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  245, 1315,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  671, 1078,    1, 1735, 1998,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  648, 1216,    1,  148,  142,    1,   82,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  758, 1525,  256,    1,    1, 2759,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  315,   37,    1,  220,    1,    9,  920,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,   12, 1443,    1, 2017,  176,  453, 2995,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2821,   45,  166, 2408,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  776,   30,  203,  923,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  624, 1359,  796,   82,  317,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  649, 1603,  267,  811,   12,  395, 2579,    1,  956,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  302, 1712,  105, 2876,    9,  166,  627,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1479,    1,  498,   37,    1,   45,  531,  734,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,  356,  560,  347,   71,   32, 1034,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1808,  794,  111, 1107, 1108,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1713, 1307,    1, 2894,   37,  877, 2474,  259,  769, 1379,\n",
      "           12,  112,  499,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  868,  187, 2741, 3055,  608, 2846,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  168, 2758,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 2580,  779,  245, 1362, 1139,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  845,   69,  636, 2007,   37,  109,  997,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1072, 1635,  709, 2374,  710,   37,  104,  317,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2857, 1249,    1, 2828, 2827,   37, 2250,  191,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3303,  980,  115,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2567,   98,    1, 1151,    9,  618,    9,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   20,  267, 1117, 1997,    1, 2198, 1859,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  231, 1778, 2580,    1,   85,    1,   32,  645, 2432,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1043,  176, 1034,  181,  340,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  819,    1,   81,   37, 1204,   32,  385,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  567,  471,  300, 1290,  396,   85,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103,    1,    1,   39,    9, 1517,   12, 1090,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  468, 1362,   12, 1211, 1273, 1994, 2693,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1121,  389,  218,    1, 1149, 1384,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3256,  187,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  116,   12,  846,  641,  187,  460,   96,  537, 1691,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2423,  877,    1, 1929, 3179,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3359, 2386, 1533,  917,   45,    1,  521,  443,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,   52,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   32,    1,  611, 1554, 1530,    1, 2347,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2820,   12,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1447,  147, 1707,  469,    9, 1633,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  121, 2051, 2440,  361, 2051, 1211,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1230,  361, 1230, 2543,  726,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  396, 2933, 2545,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2660,    1,  132,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  678, 2275,    1,  443, 1799,  741,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  315,   37, 1289,  389, 2172, 1699,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1867,  955, 1461,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2993,  520, 2355, 1013, 2524,    9, 2994, 2995,  327,  593,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,  186,   37,  726, 1090,  297, 3108,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  572,  156,  388,  763, 1427,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  314,  991,  453,  721,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2885,  140,  628,    1, 1631, 2523,  119,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1458,  673,    1,    9,  365,  993,  317,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  105, 1054,    1,  340,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1173, 1108,    1,  613,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2904,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  519, 2939, 2471, 1880,  813,    1,    1, 3288,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  994, 3151,    1,  612,  664,  187,  445,  187,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087,    1,  657,    1, 2336,  956,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  413, 1396, 1158,   12, 2102,   17,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  116, 2082,   23, 1707,  829, 1117, 1525,  161,  469,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  233,   46, 1980,   98,  912, 2285, 1228,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  251,  365, 1021,    1, 2226,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2837, 2572,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1516, 2550,   37, 1779,   28,  361, 1910,    1, 1821,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  415,    1,   55,  105, 2114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3045, 1260,  531,  863,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1675,   96,   98,  166,  538,    1,    1, 1243,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340,  640, 2907,    1, 1110,  103,  705, 1458,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2959,  688, 1957,   32,    1, 2592, 1838,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  836,  384, 2769,   45,  166,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1965, 2982,  619, 2919, 1021,   92,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,  267,  590, 3118, 2516,  804,    1, 1574, 2774,   46,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2809,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   68,   69,  102,    1, 1146,  106,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  562,  548,  298,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  961, 1482,  919,  837,   67,   37,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  726,    1, 3309,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2761,    1, 2034, 1879,  979,  389,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  119, 2674, 1684,   32, 3303,  759,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 1053, 1865,  195, 2568, 2763,    1,   37,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2137,    1, 3279,   32, 1619, 2597, 2856,  176,  177,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  765,   98,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1090, 2677,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  438,   12, 2391, 1074,  844,    1,    1, 1237,  170,   46,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  854,   12, 1273,  259, 2264,    1, 1054,  260, 1967, 2013,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2512,   37, 1706,   59,   32,  463, 1447,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  810,    1,    1,  810,  166,  199,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657,  852,   37,  619,   81,   98, 1171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,    1,  187,   69,  980,  361,  185,  504,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683,  415, 1360,  612, 1584,  460,  168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2673, 1463,   32,  403, 1447,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1029,   34,  962,   98,    1,  802,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  964, 1268,  365,  622, 1967,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  204, 1745,    1, 1232,  117,  681,    1,    1, 1495,\n",
      "          963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 3121, 2162, 1950,  418, 2249,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98,    1,  420,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1818,  147, 1392,    1,   98,  116, 1393,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  726, 1611,    9, 1973,  217,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1774,   39,    1,    1, 1907,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   82, 1936,   79,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3025, 2270,   37, 1075,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3233,   77,    1, 1425,    9, 1056,  388,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3296,    1, 3117,    1, 1194,    1,    1,  915,   39,   32, 1194,\n",
      "            1, 3117,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0],\n",
      "        [   2, 1404,   45, 3160,  610,   32, 1038,  966,  287, 2940,   39,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  176,  612,  852, 1159,  181, 1778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2600,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2295, 1367,  872,  420, 1657,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1298, 1606, 1597,  920,  884, 2135,   45, 2048,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  894,  606,    1,  754,    1,    1,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1762, 1310,   37,    1,  187, 1989, 1990,  628,  855,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  554,  530,  105,  106,   32, 2163,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2567,    9,  949,   45, 3365,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1597, 1633,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  551,    1,  565,    1,    1,  267,  829,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  469, 1936,  429,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3302,  140, 1700,  356,  822, 1523,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  795,   37, 1636,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2918,   12, 2923,   55,  105,    1,  873,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   89,  361, 2378, 1674,    1,    9,    1, 2826,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1,  224,  794,  777, 1013, 1108,    9,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,    1,    1,   32,  630,  220,  342,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2308,    1,  157,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2885, 2297, 3258, 2579, 1863,   45,  356,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  588, 2179,    1,   32, 3369,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  387,  377, 1895,  585,   32,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2026, 1450, 1781,  384,    1,   45,  725,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2324,  342, 1213, 1512, 1082,  811,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  320, 1492,    1,  810,  166,    1,   32, 1821,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,  365,   82,    1,  187,    1,  992,   85,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2994,   61, 1568, 3056,   12,  193,    9,  227,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,    1,  395,  297,    1,  265,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1808,   37, 1539,  111, 1107,    1,  115,   45,  538,  786,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2645,    1,    9,    1, 1590,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  942,   37,  130,    1,   37, 1636,   32,  104,  463,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,   37,  693, 1410, 1772,   37, 1344,  777,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,    1, 1361,  875, 2255, 2096,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2779,   98, 1171,    9,   72,    1, 1684,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,    1,    1,  361, 2278,  289,   32,   98, 2759, 1228,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  726, 3292,  671,   32,  119, 1215,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,  725,   37,  125,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  645,  595,   30, 1247,  979,   37,  664,    1, 1523,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2266, 1822,  168,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2838,  498,   37,  786,  356,  132,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2614,    1, 1515, 2108,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  291,    1,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506, 1898, 1273,  618,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  487,  947, 2263, 1051,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    6,  739,   98,  822,  408,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,  446, 2767, 2224,    1,   37,    1,  706,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3200, 1289,    1,   32,    1, 1508,    1,  361, 1247,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1249,  689,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  845, 1625,  187,  597,  391,  884,  297,   32, 1081,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  476,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2691,  619, 1573, 1023, 1204,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219, 1110,    1,    1, 1625,  176,  166, 2162,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3403, 2414, 3101, 2735,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369, 3109,    1,    9,    1,  722,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  854,  580, 2081,   98, 2734,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  208,  688, 1327,    9,  913,   32, 2800, 2069,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  477,   37,    1,  691,   12, 1663,   22,  361, 2288,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2325, 1618, 3343,  741,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  232, 2771, 1077,    1,  191, 1164,   45,  183, 1985,\n",
      "         2954,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,    1, 1399,   45,    1,    1,    1,  361,  312,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3263, 1306,    1,    1,  202,   32,  227, 1134,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,   28,  187,  510,  488,  104,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  203, 2440,   61,  105,    1,    1,   32,  166, 2391,    1, 1821,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2472,    1,    1,   32,    1,  449,   32,  104,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  531,   37,  927, 1232, 1583, 2891, 1924, 2747,  389,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,    1,  903,  639,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428,    1, 3369,  297, 3118, 1512,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3104,  586, 1111,  600,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  726, 1045,  176,  220,  726,  297,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,   45,  365,    1,  641,    1,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1411,    9,  457,    1,    1, 2373,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  472,   81, 1765,    1, 2280,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564, 2149, 1604,   45,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3369,   12,    1,    1,  774, 2024,  132, 1954,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  164, 2952,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169, 2518,  427,  297,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  395,   37,    1,    1,  903,    1, 1447,   46,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2790,   45,    1,  166,    1,  313,   37,    1, 2500,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  275,   11, 2495, 1107,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,  162, 2871,  288,    9,  183, 2186,  714,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1454, 1684,  191, 2148,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  744,  636,    9, 2371,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  160, 1161,  338,   98,  389,  509,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1353, 2690, 2285,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   98,  166, 2918,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  150, 1749,  220,  613, 1605,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1211, 1084,  716,   37,    1,  378,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2950, 1965, 1539,   45, 2179, 1708,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1074,  412,    1,  674,    1, 1370,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  647,  879,  453, 1889,  210,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2620, 1380,    1,   98,  427, 1343,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  148, 1009,  267,  142,    9,  647,   51,   52,  125,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1713, 1923,  171,    1, 1346,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,  730, 2614,    1,  548, 1090,   45,  166,    1,    1,    1,\n",
      "            1,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  776, 2306,  288,    9, 1005, 2942,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3298,  140, 1796, 1938, 3197,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 1084, 1563,    1, 1408, 1184,   67,    1,  176,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,  267,  163,    1,  903,    1, 2673, 1281, 2189,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2737,   12,    1, 1333, 1249, 3202,   32,  395,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1543,  365,  650,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3238, 1949,    1,    1,    1,   10,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  342,  168,  115,    9,  148,  214,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3352, 2856,   56,   32, 2625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   15, 1556,   32,  385,    9,  166,  449,  199,   32,  257,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  196,  835,  176,  551,  612,  613,    1,  166,  311, 1604,  891,\n",
      "          920,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1485,    1,  162,    1,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1362,  313,   37,    1, 1446,   17,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1056, 1957,  686,    1, 2597,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   66,    1, 1282,   12,  682,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  602, 1579,  171,  526,  333,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  971,  353,    1,   72,  401,  156,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,  859,   37, 1527, 2883,   12,  195,  856,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1089, 1090,   13,    1, 1536,    9,  467,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1926, 1927,  103,    1, 1484,    9, 1450,   98,  104,    1,  215,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3364,  248, 3006,  360, 1140,   37,  439,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2948,    1,   37,  899,  285,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  213,   37,  151,  849,    9, 1270,  372,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  590, 1064,   37,  166,    1,  100, 2111,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10, 1822,  562, 1963,    1,  949,  469,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2163,    1,  391, 1629,   37, 1844,    9,  876,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,   23, 1710,  193, 1604,  444,  792, 2529,  792,  864,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1, 2493,  105, 1568,   38,    9,  772,  293, 2928,\n",
      "            1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3128,  566,  627,  104,    1,   32, 3097,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  973, 1689, 2591,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  850,   28, 3374, 3373, 2221,    1,    1,    9,  105,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  606, 2295, 2757,    1,  501,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3359,  762, 3040,    9, 3339,  469,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  593,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649,    1,   66,  187, 1665,   37, 2879,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  590,    1,    1,    1,  877, 2149, 1604,   45,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2069,    1, 2328, 1114, 1961,  191,  341,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 3109, 1056,   32, 3374,  394,  400,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700,  123,   32,   98, 1039,   45,    1, 2796,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2, 299,   1, 116,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 328,   1,   1, 840,   1,   9, 331,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1107,  681,  726, 2633,  695,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2310,    1,    1,  579, 1232,  166,  730, 2614, 2085, 1360,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   60,    1,  616,    1,   98,  303,  304,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1870, 2910,   37,   52,   53, 1632, 1362,  656,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2899,  215, 2954,  220, 1808,  538,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2659, 2597, 3006,    1, 2572,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  545,   12,    1,  260,  600,   37, 1192,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2075,   81,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1290, 1397, 1398,  612, 1399,  974,  724,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3078,  460,   39,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  691, 2447,   32, 2069,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1778, 1901, 2996,  861, 2558,    1,  202,  460,   12,  193, 1762,\n",
      "         1160,    1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3039, 3040, 1090,    1,  187,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1124,   32,  365, 1788,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 1656, 2717,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1759,  309, 2911,   76,   32,  119, 1397,    9,    1, 1002,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,    1,    9,   69,  162, 1159,  103, 2287,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,    1,   45,  722,   98, 1459,    1, 2488,   16,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   78,    1,   28,   98,  137,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447, 3145,  444,    1,   32,  531, 3102, 1512,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3149, 1009,   37,   52, 3390,   32,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  455,  187,    1, 1976,  193,   37,   52, 2126,   45,\n",
      "         3340, 3065,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2993, 3056, 2215,   61,  168,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  707,   81,    9,  166,  627,    1, 2685,   37, 1435,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  305,  417,   63,  228,  356, 1611,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103,    1,    1,   39,    9,  914,  220, 3265, 1987,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2790,    1,    9, 2500, 3036, 2234,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 1574,  627,    1,  176,    1,  442,  264,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1629,  927,   51, 2192,  973,   37,  129,  286,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1808,   32,   46,   37, 2341,  105,    1,   45,  395,   12, 1273,\n",
      "          218,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  369,    1,  162,  142,   37,  151,  810,   45,  453, 1541,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 2065,    1, 1074,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1290,   67, 1784,   32,  602,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  848,    1, 1773,  168,  582,   37,  582,  220, 1104, 1675,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1573,  166,    1, 1090,    1, 2510, 2304,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  302, 1396, 1576, 1492,  912,    1,  767,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,  600,   45, 2567, 2377,  245, 1315, 1964,  260,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  417,  187,   69,    1,  106,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  179,  936,  315,    9, 1613, 1615,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3276,  361,  519, 1822, 2277,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   75,  520,  613,  116,  412,   98, 1497,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3182,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  932,  973,   28,    1,   25,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  140, 2933, 2545,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186, 1993,  163,    1,   12,    1,    9,  331, 3163,  671,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  980,   37,  631,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,   74,    9,    1,   12, 1247,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  683, 1484,    9,    1,   32, 3153,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1151,   15,   71,    1,   66,   85,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   60,  113,  682,    1,   65, 2001,  764,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3285, 2553, 1632, 1021,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  224,  614, 1300,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  156,  125,  191,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  162,  166, 1217,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1327,    1,  187,  477,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  344, 3403,  928,    1, 2766, 1312,   32, 3376, 1260,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2919, 1585,  590, 2291,  903, 1447,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  233,   37,  817,  302,    1,  777, 2441,\n",
      "            1,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426, 1205,    9,    1,    1,  444,  938, 2711,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  674,   32, 1296,   28,   45, 1363, 1499,  872,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 1042, 2336,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  398, 1355,  342, 2027,   98,  829,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  103,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  649,  853, 1370,  640,  433,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  766,   12,    1, 1180, 2177,    1,  565,  449,   37,  815,    1,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   61,    1,  707,   37, 2565,  166,    1, 1720, 3151, 2361,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    6, 3044, 2168,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  220,    1,    1,    1,  187,    1,  865,  963,\n",
      "         2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,    1, 1211,  442,   46,    1, 1159,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1109,  251,  858,   37,  168,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,    1,   45, 1573,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  395, 2479, 1022, 1940,   12, 1674,  671,   32, 1171,  361, 2498,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  103,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1733,   12,   98,  449,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2857, 2540, 3176,   98,  857,  569,   32, 3116,  922,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2909,   32,  531, 1910, 1700, 1530,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691, 1107,  293,    1, 2733,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1531, 3263,  872,  420, 1657,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1773,  361,  848, 2228,   79,   32, 2480, 1090,  218,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  110,   37,  619,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  322,   79,  207, 1704,  853, 1705,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  455,   32, 1242,  548, 3087,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  583,   32, 1959, 3227, 1090,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  691, 1564,  816,  698,  176,    1,   12,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   39,   56,   37, 1700, 2119,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  957,  193,   37, 1083,  529,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  193, 2398,  187,    1, 1654,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 1147, 1414, 2392,   79,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1186,   12,  449,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3271,    1,  547, 3299,    1,    1,   37, 1918,  297, 3251,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3360,  267, 1625,   71,    9,  949,   45, 1428, 1149,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  425,  426, 1205,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   11,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  497, 1354,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  299, 2424, 2446,  910,    1,   37,  574,  957,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151,  386,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1433,  227, 1678, 1398,  612,    1,  877,  227, 2617,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  365,  459,   45,  238,   98,  166,  730, 3022,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    7,  545, 1142, 1976,  193,  514,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,   37,  168,  115,  220, 2390,  100, 2836,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  238,    1,  345,    1, 1204,   98, 1965,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9, 3328,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  790, 1566, 2305,  548,    1,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  215,    1,  876,  460,  460,   12,    1,    1,  203,  321, 1366,\n",
      "         2324,  460,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053,   12, 2814,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1046,    1, 1983,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  389,  157,   61,  800,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1776, 1888,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  571,    1,  696,  386,  688, 3262,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1128,    1,  220, 1100,   12,  784,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3378,  267,    1,  193,  514,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   37,  151, 1341,   12, 1204,    1,    9,    1,  372,  328,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3347, 1810,  547, 1940, 3338,  191,  531, 3352,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1725,    1,  395,  187,  218,  954,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2687,    1, 2105,    1, 1230,  176, 1331,   45, 1087, 1412,\n",
      "          973,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2999, 2194, 3050, 1908,  114,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2040,   45,  442,  132,  220,  395,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3272,  590,    1, 3100,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2706, 2232,   37,  619, 1087, 1876,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1414, 2341,  274,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12,  600,  166, 1509,  334,  321,  544,  220, 3278,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  115,   45,   76,  163,    1,   12,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  488, 3140,  548, 3374, 3389,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1586,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  191,    1,    1,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401, 3117,  608, 3234,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   61, 1221, 1001,   32, 1997,  501,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2826,    1,  104,  361, 2442,  439,  671, 3106,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,   28,    1,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275,    1,    1, 1789, 2360,   32,  806, 1844,   28,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 3185, 1063,   37, 2360,    1,   12,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3091, 3340,   32,  531,   61,  820,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  566,  999, 2690, 1967,    9, 3018,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2944,   37,    1,  453, 2924,  384,  531,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1523,   45,  166,  183, 1675,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  667, 2702,    1, 2803,  101,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,    1,  148,  279,    1, 1294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1060, 2827, 3102,   32,  121,   36,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2999,  251,   17,  210,   37, 1260, 2819, 2168,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2498,  569, 2192, 3182, 2138,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  168,  845,  275,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614,  542, 1000,    1,   32,  166,    1,   45,  166,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  109,    1,  384, 1081,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1948,  548, 2332,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   85,    1,  193,   39,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  454,   32,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649, 2789, 2153, 1140,    9,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1290,  396,  720,  388,  763,   76,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 1117, 1525,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  619, 1211,   45, 1658,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3264,    1,  191,  542,  548, 2250,  220,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  258, 2954, 2287,   28,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  917,    1, 1924,    7, 1370,   45,  593, 2522,  726,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2226, 2968,  220, 2310, 1298,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,    1,    1,    1,    1,    1,   32, 2468,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    6,  356,  439,  197,  157,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  104,  358,  474,  267, 1384,  132,   61,   27,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2520, 2235,  142,    9, 2826,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,  354,  548,  283,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  792,    1,  792,    1,    1, 3143,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129,  922, 1090, 1829, 2206, 2435,  176, 1440,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  275,    1,  876,    1,   37, 1211, 1766, 1767,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1090,   79,    1, 3151, 2591,   37,    1,   39, 2308,    1,    1,\n",
      "          606,   37,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158,  159,  245,   98,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  207,  338,    1,  583,  191,  584,  585,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  903,    1, 1447, 2081,  716, 1398,  612, 1719, 3203,  143, 1724,\n",
      "           88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,  952, 1938, 3135,   37,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  273,  730, 2614, 1421, 3224,    1,    1,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  715, 1149, 2370,    1,   45,  391,  371,  389,    6,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2640,    1, 1354,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2856,   79,  388,  259,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,   32,    1,  856,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   32, 2018,   12,    1,  274,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1101, 1102,  218,   37, 1348,   93,    1,    1,  782,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166, 2366,   98, 2336,    1, 1271, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,    1, 1213,   37,  582, 1943, 1535,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  961,  518, 1190,    1,    1, 1124,   32,    1,  963, 2122,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  729,  476,  342,  399,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  256, 1768,    1,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1284,  460, 2444,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1530,    1, 2335, 2347,   32, 1855, 2003,    1,  114,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  105, 1385,   28, 2857,   37,  877,    1,  142,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  839,  829,  199,  421,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2563,  321,  612,   77,   37,  384,    1,   32,  439, 2060,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1187,  193,  804,   39,  242,  693,    9,  129,  975,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  864,  515,    1, 2259,   37,  219, 2362,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1517,   12, 2925, 3210,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  272,   37, 1021, 2910,  220,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1964,    1,  388,   32, 1833,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,  305,    1,  187, 1331,   15,   71,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3101,    1, 1260, 2414,    1,   45,    1, 2328,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  497,   37, 2000,  579,   37,  544,  548, 1839, 3037,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3250,  713,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,    1,  182,  142,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  367,   15,    1, 1479,  773,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2885, 1631,  156,  119,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,  361,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   32,   98, 1551,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  334,  326,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3103,   98,    1,   45,  605,    1,   37, 2321,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358, 1536,    9,    1,    1,  467,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2826,  365, 3185,  287,    1,    1,    1,  176, 1675,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  811,  104, 1187,  193,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  449, 1173,    1,    1,   12,    1,  659,  327,  593,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3337,   12, 1625,   45, 2315,  565,    1,    1,   32,  166, 2391,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2227,  487, 3222,    1,  191,  132,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1213,   12,  225,  333,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  726,  726,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  296, 1392,  334,  920,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2692, 2405,   39,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3144, 1627,   72, 1034,   45, 1512,  220,  365,    1,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,  424,  105,  388,    1, 2107,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   71,  187,  615,    1,   79,   69,  102,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2931,   37,   92,  613,  777, 1085,  496,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  476,  388,  104, 1527,    9, 2883,  195,  856,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1545,    1, 3181,    1, 1178,    1,  386,  361, 3262,  810,  726,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709, 2972,    1, 2690,    1, 2043,  110,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  828,    1,  297,    5,  865,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2343,   12,    1,  442,  590, 2339,   37,  163,    1,   12,    1,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1337,  492,  922,  427,  297, 2242,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2634, 1027,   37,    1,  220,  160,   41,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  726,  951,    1,    1, 1710,  665,  104,   32, 2886,   12, 1311,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  865,    1,    1, 1240,  193,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3342, 2659, 1574,  191,    1, 3058,   98, 2282,  722,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69, 1672,  699,    1, 1588,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2158,    1, 1442,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169, 3205,    1,   37,  759, 3329, 3293,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  104,  361,  342,    1,    1, 1511,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162, 1198,  384,  469,   37, 1155,    1,   32, 1186,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  474, 1355,  903,    1, 2227,    1, 1007,    1,  983,  469,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496,  802, 1641,   37,  301,  455,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  907,    1,    1,    1,    1,  365,    1, 1292,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  663, 1075, 1082, 3363,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3325,    1, 2523,  872,   28,   37,  631,   79,  104,  176, 1477,\n",
      "         1990,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1213, 1204,  400,  924, 1574,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1031,   51,  764,  163,    1,   12,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437, 2424,   98,    1,  596, 1793,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,  288,    9,  526,   26,  187,   69,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1539, 2995,    9, 1778, 1273,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1312, 2827,   32,  492, 1994, 2095, 2262,    1,  947,  583,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   88, 1002,   10,  361, 2275,  729,   32, 1530, 1245,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3294,  571,   37, 2615, 2340,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342, 1579,  148,   12,  647,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  596,  616,  159,    1,   60,   71,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1785, 1877,   37, 1865, 2193,  112,    1,    1,    1, 1429,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  340,    1, 2277,   37,  726,  810, 1425,  671,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2275,  361,   10,    1,   98, 3373,    1,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  773,  420, 1595,  682,   32,  385,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    6,  176,    1, 1378, 1126,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  829,    8, 2851, 2432,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  442,    1,  190,    1,   10,   32,  942,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  590, 1400,  105,    1,    1,    1,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2474, 1921,  176,  166, 2918,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  326,   61,   81,   98,  103,  220,  978, 2953, 2334,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  108,    1,   37,    1,    1,    1, 1478,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  627,   45,    1,   12,    1,   12,  176,   38,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162, 1133,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  297, 1361,   12,   26, 1039,  315,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1451,    1,  884,  674,   45,  198,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  183, 1585,    1,    1, 1324,  898,   32,  903,    1, 1447,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  764, 2346, 1125,   98,  735,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1053,    1, 1364, 1365,    1,  630,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  936,    1,  361,  102,    9,  365,  772,   41,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  275, 1900,  973,    9,  704,  705, 1084,    1,  116,    5, 1281,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1527, 2156,    9,   64, 1080,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,   27, 1727,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1654,  247,    1,  297, 2107,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1158,    1, 1260, 2546,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  515, 3262,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1957,   85, 3219,   32, 2138,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  132,  919,   14,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1932,  251,   59,    9, 1933, 1541,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,    1, 1363,   37, 1027, 1273, 2255,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 2421,   32,  404,  854,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,   37, 1079,    9,  764,   32, 3360,  361,  531,    1,  178,\n",
      "          774,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2801,   96,   37,    1,    9,  105,  215, 2226, 2969,   29, 1108,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1360,  612,  168,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  550,    1,  150, 2025,  203,  166, 2122,  162,    1, 1159,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2387, 1942,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[  2,   1,   1,  32,   1,  32, 405,  12, 726,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 493, 102, 720, 187,  68,  69, 109, 641,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  776,  891,  297,    1,   12, 3020,    1,   32,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  446,    1,    1,    1,   98, 2041, 2655, 1806,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,   12,    1,  515,   28,  103,  622,  317,    1,    1,    1,\n",
      "           45, 1021,   37, 1733,  963, 2122,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3381,  437,  396, 1887,   45, 3361,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2275, 1523,  297,    4,  420,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  437, 2593,    1, 2472,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  121,   37,  771,  171,    1,  681,   37,  142,   98,   49, 1541,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176,  177, 1530,   32, 2140, 1177,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,   22,  868,  686, 3339, 2791,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081, 1002,    1,  615,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  597,    1,  519, 1041,    1,  331,    9,  977,  287,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2822, 1906,    1,  384, 1793,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094, 2414,  228,  548,    1, 3374, 1665,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2386, 1861,  297,  531,  443,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2560,  105,  365,    1,   32,   22,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  403, 1447,   51, 1463,  114, 1461, 2968,  853,   29,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1243,  135, 1283,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  572,  105,    1, 1854,    1,  220,  192,    1,  852,    9, 1639,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  432,   76,    9,  183, 1339,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,   51, 1598, 2390, 1604,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  814, 1633,  616,  112,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  936,  887,    1,  956,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  729,  967,  284,  856,   32, 1590,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  147,  920,  267,  253,  321, 1753,  148,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   11,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2064,   37, 2000,  261,   98,    1,  442,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  947, 1413,  927, 1159, 3263, 3226,  350, 2811,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   12,  569,  361, 2177, 1604, 1493,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2596, 2414, 3361,   27, 2597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  675,  156,   71,  118,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  273, 1609,  884,  297,    1,   12,  332,   45,  195,  663,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  484,  531,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1094,    1,    1,  548, 2950,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,  171,    1,   81,   32,  938,   32,  449, 1023,   45,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  772,  617,  259,  335, 1056,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3170,   12,  471,  300, 1537,  689, 2066,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 1811,    1, 2226, 2232,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1094,  442,  587, 1140,  391,  477,    9, 1970,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1537, 1538, 1140,   79,  477,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 3034, 1268,   28,   37, 1561,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,  777,    1,  335,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37, 1539,  365,  803,  112, 1228,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1661,  704,  222,  580,  133,  297, 1405, 1340,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2868, 1949, 2237,   37, 2890,    1,    1, 2462,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  403, 1447,  288,   37,  771,  865,    9,  487,  521,  663,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  353,    1, 1269,   32,  156,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3192,  691,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   10,    1, 1300,   98,  531,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428,  738,   98,  864, 2673,  315, 1010, 2596,  997,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 2764, 3394,    1, 3370,    1, 1450,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   45, 1434,  460, 1924,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103,    1,   37, 1306, 3201,  951,    1, 2807,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  163,    1, 2196,    1,    1,  620, 1521,    1,   32,  810,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  941, 1663,  162,  987,  384,    1,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  176, 2392, 2884, 2057,   61,    1, 2046,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,   37,   44,    9,    1,    1,  412,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,   37,  335, 2084,  686,  384,   12,  551,  552, 1279,\n",
      "         1119,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1934,    1,    1,  318,  267,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3172, 1090, 1829, 2628,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3213,  166, 1545,  537,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  455, 3087,    1,    1, 3102, 2162,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447,  200,  453,    1,   32,  166, 2599,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  502, 1525,  307, 1108,  837,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1810, 2572, 3006,   32, 3367,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1465,    1, 1665,   37, 1639,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  363, 2721,  565, 1532,   45,  424,    1,    1,    1,  606, 1366,\n",
      "            1,  166,    1,  234,  182,  235,    1,    1,    1,  234,  182,  235,\n",
      "            1,    3,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  558,   37,  138,    1,  131,    9,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1200,   82, 1484,    9, 1109, 1302,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2737,    1,   64,  288,    9, 1684, 1798,  101,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,    1,   45,    1,  647,  142,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3276, 1284,    1,   28,    9, 3220,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,    8, 2432, 1117, 1525,  161,  469, 2443,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  321,  424,    1,    1,    1,    1,   52,  166, 3059,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2881,    1,   98,  627,    1,    1,   98, 1718,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  104,  358,   37,  125, 1499,  138,    1,  362,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2578,  140,    1, 2335,    1,   32,  105, 2651,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2490,    1,  444, 2527,  164,  165,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363, 2694, 3360,  361, 2018,    1,   32, 1345, 2095,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1497,    1,   39,  220,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2652,    1,  471,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1861, 1702, 3118,  895,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3183,   98,  103,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  590,    1, 1252, 1993,    1,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1845,  132,   61, 2011,   98,    1,  903,    1,  904,    1,  195,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2834,  691,   32,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,  879,  631,   32, 2261,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   82,   37,  582, 1943, 1535,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3069,    1,    1,    9, 3343,  863,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3176,    1,  631,  220,  726,  297, 1178,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1106, 1107,  525,   37,  135,  166, 1107, 2610,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  352,  267,  197,   32,  531,   61,  800,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3132,   51,  606,   37,  138,   37,  576, 3294, 2017,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  190, 3215,  877, 2846,  427,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3363,  115,  548,  449,   59, 2591,    1,   32, 3343,  863,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2993,  794, 2994,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2963,  191,    1,  176,    1,   26,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,    8, 2432, 1117, 1525,  161,  469, 2443,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,   69,  102,  565,  816,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 2767,  228, 1778, 2996,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  286,  927, 1825,   85,   25,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  848,  437,  288,   37,  151,  849,  199,  421, 1042,  453,  142,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1536,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1194, 2132,  403, 2926,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  460,   12, 1628,  550,    1,    9, 1436,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  487,  147,   57,  949,   45, 1536,   32, 1186, 1081,  927,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   91,   12, 1298,    1, 1426, 2918,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1117,  834, 1720, 2258, 1398,  612,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102,  670,  548,    1,  163,    1,   12,    1,  626,  420,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   69, 1226,  885,   60,   37, 1034,  340,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3209,  103, 3233,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  476,  917,  636,    9, 3177,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3265, 1987, 1408, 3322, 2110,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1723,    1,   61,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  847,   28, 1762, 2093,   37,  914,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1005,    1,    1,   37, 2388, 2466,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2115,  663,  729,  105, 2537,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   98,    1, 1196,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,    1,    1,   98,  552, 1892,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  506,  858,    1,  608,    1,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3090, 3040,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1472,  674,   45,   31,   61,    7,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2535,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,   91,   12, 1354, 2529, 2334, 2030,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1645,  673,   37,  674,  448,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2343,   12,  776,   32, 1352,    1,    1,  939,  147,    1,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3124,    1,  754,   32,    1, 3329,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2523, 1494,   28,    1,    1,  202,  729,  590,    1,  428,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   79,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  231,    1,  590,  427,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885,  786, 1844, 1090, 1360,    1,  424,   61, 1176,  227,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1282, 2581,    1,  551, 1975,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2057,  729,  707,  198,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1, 2161,  688, 2468,   32,  449,  311, 1463,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2719, 2808,  444,  597,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3075, 3067,  531,    1, 1450,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433, 2104,  765,   37,    1, 2650,    1,  207, 2086,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  547, 2703, 3340,   32, 3360,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3109,  176, 1693, 3096,    1, 1556, 1146, 1703,  915,  914,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  952,   37,    1,    1,  681,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  947, 1000, 2249, 2313,  220,    1,    1,    1,  963, 2122,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  164,    1,   32, 2490,  187,  104, 2700, 1604,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  582,   37,  319,  716,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1431,   51, 1031,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  639, 1236,    1,  297,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  386,    1,  359,  759, 1845,   24,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487, 3105,    1, 3155,    1,  101,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3117,  193,   39,   45,  809,    9, 1415,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2899,   37, 1237, 1273,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  459,    9,  539,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37, 1209,   61,    1,   37, 2176,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,  476,  241,  863,   32, 2018,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,   12,  103, 3407,    1,  907,   32, 2646,    1,    1, 1333,\n",
      "         1530,   32,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614, 3132, 1018, 2858,  628,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  425,  426,  251, 2949, 2871,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[  2,  69, 415,   1,  45, 104,   1,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 657,  12,   1,   1,   3,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1481,   78,  601, 2113, 2521,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107,    1, 1595,   71,   32,   69,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  361, 2594,    1,    9, 1477, 1990,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3013,  267,    1,   37, 3305,  220,  726,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1077,  152,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1081,    1, 1056, 2095, 2985,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2614,  565, 1488,  857,  726,   32, 1194,  548,  206,    1,  411,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   32,  166,  931,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,   45,  241,    1,  176,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  592,  475,  387, 2252,    1,   32,  104,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1234, 2790,  108,   98, 2294, 1681,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  161,    1,  162,  163,    1,   12,    1,  164,  195,  132,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3363,  388, 2331,  600, 1918,   32, 2208,  548,  247,  581,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  619,    1,   37,    1,   37,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,    1,    1,  786,  199, 1228, 2234,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2729, 1976, 1530,   32, 1850,  531,  101,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   32, 2170,  817,  248,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2483,    1,  605,  400, 1243,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2954,    1, 1081,  851,  298,  778,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3335,   12, 1470,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1585, 2021,  440,   98, 2069,   74,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  306,   82,  536,  119,  818,  914,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2171, 1283,  844,  162, 1842,  802,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2616, 2864,  537,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3235, 2871,    1,  917, 2498,    1,    1,    1, 2347,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  227,   16,    1,  202,  193,  638,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2018,    1,    1,  365, 3380,  469,   98, 1815,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1166,  606,  810,  166,  475,  172,    1, 2626,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  420, 3358,    1,  247,  566,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  420,   98, 2571,    1, 1484,    9,   92,   37,  883,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1479,    1,    1,  191,  861,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  107, 1726,    1,  191,   69,  636,  720,  548,  568,  125,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3318,  688, 3244,    1, 1493, 1264,  841, 1569,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,   12,  103, 2673,  232,  267,    1,  967,  193,    1, 3107,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3340, 1189,    1,  820,   32,  531,  844,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,    1,  730, 1777,    1, 1361,  543, 1876,    9, 1100,   12,\n",
      "         2071, 1331,  769,  918,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1110, 1508,    1,   37,  547,  356,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  358,  162,  209,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,   94, 2060,   93, 1071,  995,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  682, 1737,   98, 1547,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  395, 2272,   85,   98,  116,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,    1,   37,  104, 2099,   37, 1119, 2924,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  420, 3067, 3339,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,   12,    1, 1821, 1563,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  853,  322, 2622,    1,    1,   12,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2900,  388, 2795,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3315,    1,    1, 1198,   94, 1625,  115,   45, 1388,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,    1,  150, 2025, 2208,    1,  680,  123, 1075,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  458,   45,  365, 1788,  325,    1,  112,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  786, 1249,  105,   32, 1447,    1, 1166,    1, 1401,    1,\n",
      "          191, 1056,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  463,  464, 2616,  267, 3107, 1463,    1, 1215,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,  267, 3051, 2774, 2153,    1, 2756,  630,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  897,  444,    1,  596,    1,  442, 2007,   32,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 2614,    1,   85,   98,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,  885, 1253, 2522,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602,  967,  590,  315,   37, 1031,  453,  531, 1563,    1,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1854,    1,    9,    1,  787,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1, 1708,   61,  297, 1123,   61,   81,   32,  316,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,    1,   61,  193,  415,  885, 2480, 1671,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2984,  288,    9, 2820,  865, 2709,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1046,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1000,  105,    1,   37,  726,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  326, 2094,  845,  439, 2759,    1,   37,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   63,  166,  862,    1,  418,    1,  118,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2051,    1,  229,  193,   66,  187,    1,    9,  163,    1,\n",
      "           12,    1,  533,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,  565,   66,   79,  105, 2589,  176,   26,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3297,  972,    1,    9,    1, 2771,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 1203,    1,    1, 1021, 1129, 2007,   37,  114,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3061,   64, 3372,   32, 2774,  511, 2517,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  267, 2275,    1,    1,   98,  901, 3373,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  353,  105,    1,  354,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  571,   37,    1, 1010,  214, 1801,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  729,  590, 2383,  384, 1965,   98,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590, 3151,    1,  590, 3151,    1,    1,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1056, 1940,    1,   32, 2018, 2950,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,   61, 1648,   37,    1, 3369, 2108, 3368,    1, 1289,  909,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,   93,   45,  596,  327,  218,  570,   37,  470,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1585,   32, 2597, 2774,    1, 2414,  176,  177,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,  726,  300,   69,   27,  105,  106,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1465, 1466,   37,  125,    4,  191,  419,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  716, 2173,    1,  136,  759,  895,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,    1,  331,  132,  220,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3229,  140,    1, 1624,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1326,    1,   61,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  892,   12, 2462,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2986,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1577,   37,  130,    1,    9,   59,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2106,  640,  365,   49,  220,  365, 1665,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  460,   12,  810,  600,  166, 1230,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   79,  166, 2880,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1340, 1194, 2907,  873,  162,    1,  176, 1611,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  713,    9, 2251,  550,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[  2, 121, 986, 331,  32,   1,  37, 592,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 310, 225, 616, 123,   1, 417,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  102,   27,  104, 1146,  106,   32,  365, 1788,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213,  459, 1114,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  306,  331,    1,  649,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117, 3058, 2162,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  671,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2518, 1205,  191, 1717, 1697,  639,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3115, 2651, 3326,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1940,   12, 3282,    1,    1, 3169, 1758,   37, 1183, 2921, 1990,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,   37, 1343,    9, 1110,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2226, 1937,  590,  753,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   12,    1,   61, 1960, 2048,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   65,   61,   76,   37,   92,  347, 1114,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1073,   85,  163,    1, 2196,    1,  279,  550,  777, 2165,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1543,  166,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  479,    1, 2077,  123,   32,   98,    1, 1711,   45,  365,  382,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2722, 3074, 1900,  498,   37, 1325,   93,    1,    9,  105,  636,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2972,  475,  939, 1010,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2700,   37,  506,    1,   45, 3055, 2728,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  190, 1046,    1,   32, 2936,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  387, 1488, 1998,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2264,    1,  414,  861,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  215,  433,  102,   28,    1,  327,   98,    1,   32,   86,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  627,   32, 2748, 2353,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1680,   82, 1713,  326,   12,  721,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  564,  454,   37,  331, 2545,  220,    1, 1844,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  829, 2994, 1187,  193, 2253, 2997,   12,  218,  332,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3332, 1401, 1245,  608,    1,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1861, 2520, 3369, 1004,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  365,    1,   37, 2518, 1292, 1681,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  548,    1, 2762,    1,    1,  580, 2039,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2357,  455,   12,  517,  617,  259,  218, 1563,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3266, 2651,    1,  202, 3079, 1376,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1295,  631,  219,   25,   85,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  348,  733,   32,    1,  886,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1, 1789,    1, 2024,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    9,    1,  356,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1158,   32, 1523,    9, 2102, 2653,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  758,  325, 1117, 1525, 1228,  700,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3115,    1,   28,    1, 1247,  220,  881,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,   69,  102,  729,  680,   97,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3169,   98, 3230,   12,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,  365,   24, 1277, 2437,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 3350,  388,    1,  110,   32,  531,  428,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2669, 1204,   98,  166,  730, 3022,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3299,   85,    1, 1940,   37,  168,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  282, 2334,    1,   28,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162,    1,  384, 1629,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  829, 1564,  453,   72,    1,   37,   26, 1039,  778,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  730, 1292, 1008,    1,  365, 2565,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  790,  908,    1,    1,  815,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2877,  146,    9,  593,  764,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2676,    1, 2081,   45, 2275,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2093,  190,   52, 1533,  384, 1762,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  316, 2190,  251,  493,    1,    1,  361,  201,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  342,  113,   39,    1,   45,  439,   37,  395, 2108, 3368,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  971,  132,    1,    1,  166, 1868, 1172,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2024, 2699, 1921,   32, 2646,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2427,  168,    9,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  172,  616,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  486,  782,  451,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3001,  361,    1, 1108, 1118,    1, 1942,  469,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3360,  640,    1, 1330,  187,    1, 1594,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  171,   12, 2583,    1,    9, 1090,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1018,   26, 1107, 2639,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  384,  166,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 2658,   37,    1, 1277,  193,   37,   84,   85,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   81,   37,   36,  187,    1, 2489,  105, 1555, 1090,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1741,    1,  275,    1, 1116,  437,   37,  872,   28,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  361,    1,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3167,    1,  705,    1, 1417,    1,  943,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  459,  132,  220,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1256,    1,  552,    1,  485, 1949,  326,  486,  132,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3186,    1,    1,  191,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1, 2161,  726,   72,    1, 3134,  671,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1401,    1,  548,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  150,  267,  829,    1, 1534,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  420, 2425,   32,   46,   37,  130, 1883, 1228,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  362,  384,  613,  207,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 3277,    1, 2448,  386,    9,  166, 1194,  199,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1380,    1,   32,    1,    1, 1194,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3117, 1066,    1,  220, 3271,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,    1, 1281,   61,  105,    1,    9,    1,  522,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  166,  855,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2162,  927, 1918,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  482,  483,  211,  484,   98,  449,  401,  158,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2260,    9, 1194,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   37,  218, 3014, 1718, 2079,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1013,    1,  794,  365,  778,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3108, 1185,  564,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  215,   93,    1,    1,  191, 2898,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1033, 2211,  577,   98,  996,  157,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1530,   32, 1168, 2702,    1,   32,  854,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  176,  365,  119,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,  147,  908, 1257,  960,  467, 1907,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  266,  353,  105,  354,   98,  134,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  910, 1813, 3141, 2308,    1,  542,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1570,    1, 1718,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3215,  311,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2692,   61, 1960,  166,  713,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1181, 2914,  593,   12,  449,  228,    1, 2382,  259,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,  456,   85,    1,  116,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788,    1, 1913, 1856,   45,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,    1,  647,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   45,    1, 2673, 2596, 1530,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162, 1938, 1723,    1,   98,  165,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3276, 1119, 1332,    1,  698,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1658,  327,   32,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3231,  130,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  695, 2443,  105,  829,  768,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2047,  361,    1,   98,    1,  836,  384, 2170,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  596,  433,  102,  729,  677,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  195,    1,    1, 1210,   37,    1,  503,   82,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32, 1739,    1,    1, 2547, 1463, 1018,  620,  661,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3101, 1891,  872, 1237,  183,  922,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,    1,  105,  131,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  487,  422,    1,   37, 2704, 2095,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 3244,    1, 3227,   32,  754, 3201,   98, 1565,   45, 3188,   12,\n",
      "          886,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1790,    1,    1,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2517,  864, 1809,  105,    1,   45, 2958,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,  614,  671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  328, 3112, 2753,   37,  764,  447,   37,  726,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  458, 1408, 1184,   67,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1661,  197,    1,   98, 1393,  134,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3028,   12,  232,  365, 2995,   61,   39,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,   37,  949,   72,   26, 1039,  934,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  167, 2200, 1691,    1,  221,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1674,    1,  619, 1894, 1578,    9, 2889,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  273, 2767,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1883,    1,   28,    1, 1228,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49,    6,   69,  532,   37,  395,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  625, 2483,    1,   32, 2707,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  709,  702,  494, 1231,  220,  133,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2178,  318, 1156, 1969,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2377, 1248, 3006,   32,  531,   37,    1, 3365,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  163,    1,   12,    1,    1,  691, 2161,   37, 1046,   79, 1114,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3282, 3204, 1249, 3257,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2026,    1,  116,  938,  616,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1538,  650, 1061,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  886,   12,  365, 1151,  313,  760,  617,  618,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224,    1,  630,  220, 1410,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3173, 1993,   39,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  727,  884,   98, 1842,    1,    1,  436,   45,  827,  171,  190,\n",
      "         1937, 1639,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,\n",
      "            3,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1178, 1988,   45, 1939,  176,  447,   12,  811,  580,  776,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3263, 2497, 3287,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2856,  915, 1247,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  156,  688,  308,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,   10,    1, 2676,    1,  531, 2582,  590,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  547,  681,   37,  142,    9,   49,   50,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  105,  826, 2317,   32, 2795,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    8,    1,  297, 2779,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2076, 2086,    1, 1718,  327, 1828,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1527, 1149, 3047,   32,    1, 2625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1710,    1,   37, 3101, 2673,  522,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3257, 1564,  460,   72,  199,    1,   32, 2936,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3259,  599,    1,    9, 2249,  872,   95,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  593,   69,  102,   71,   37,  885,  119,  845,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,    1,    1, 1450,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  345,    1,  361, 1013, 1522, 2788,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2278,    1, 1883, 2866, 1525,    1, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1138,  788,   37,  125,  297,    1,    4,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2427,  288, 1797, 2300,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  589,  804,   61,  786,  803,   84,   32,    1,  217,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  208,   37,    1,  734,    1, 2306,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  603,    9, 2843, 2523,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,    1, 1537,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  417,  810, 1658,    1, 1879,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,   47, 1549,   45, 1212,    1,    1,    9,    1,  182,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1783,  251,  411, 1888,   37,    1, 1149,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2871,    1, 2136,  195, 2836,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1053,   12, 1819,    1,    1,   37,    1,  663,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  952,    1,   32,  581, 1370,   45, 2031,  400,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  858,   37,  619, 1021,   92,   32,  183, 1158,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  777, 2165, 1642,   28,    1,   45,    1,  809,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1352, 1009, 1355,    1,   98,    1,  234,  182,  235,    1,\n",
      "            1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  551, 1658, 1084,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  864, 2673, 1559,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   37, 1776, 1539,   45,  365,  538,    1,  112,   50,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   98,  236,  237,    1,  105, 1415, 1173,  176, 1059,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   89,  590, 1188,   37,  125,  443, 1278,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2171, 3229,  431, 3172, 1880,  813,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3230, 1408,  754,    1, 1480,   32,  365, 1788,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  312,    1,  313,   37,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2459,   37, 1765,    1,    9,  810,  787,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   25,   26,  526,    1,   69,   28,    1,  180,  343,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   49, 1623,   61,    1,  187,  171, 1611, 1552,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3134,  163,    1,   12,    1, 2161,  726,  548,  105, 1133, 1463,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  557,  540,   37,  489,   81,  453, 1414,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  224, 2650,    1, 1628,    1,    1, 2587,  224, 2355, 1013,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1937,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  199,  421,  431,  132,  297,  755, 2089,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1028, 1092, 1701,  114, 1884,    1,   32, 1935, 2294,  443,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  344,  477, 2414,   32,  531,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1594,  444, 3342,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  199,  421,  744, 1483,  822, 1482,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2097,   45,    1,    1,   32,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  510,    1, 1594,    1, 2100,  404,  540,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1900,    1,   37,  907,  220,   10,    1, 2275,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2329,    9,  674, 2115,  633,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1899,   37,    1,   32,    1,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  493,  102, 1269,   37, 1738,    1,  105,    1,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2751,  288,   79, 1054, 2003,   32, 1537, 1815,    1, 1530,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1634,   37, 3012,  298,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 3009,  764,   37,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  503,  197,  338,    1,  583,  191,  749,  480,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2427,  184,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  539,  455,    1, 1372,   37,   52,    1, 2104,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  411,    1, 1924,    1,  105,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1839,   61, 1530, 1183, 1824,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,  761,  195,    1,  598,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2048,   45, 1714,  110,   37,    1, 2924,   32, 3118,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1117,  671,    1, 1051, 2690,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2705,  105, 1512,    1, 1428,  267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  535,  170,    1,    1,  267, 2183, 1190,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  971, 1346, 1313,  219,  389,    6,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  388, 1205,  191,  166, 3003,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  199,  421,   32, 1715,  399,  220,  422,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,    1, 1941,   32, 2842,   45, 1450,   32,  854,   12,\n",
      "         2245,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1428, 1906, 2405,   37, 3099,   32, 1013,   45, 3369, 2024,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  370,    1,  373,    1,   32, 1651, 1597,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,  160, 1161,  338,   32,  385,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3079, 2290,    1,  191,  415,   56, 1394,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  166,  296,   20,    1,   61,    1,    1, 1654,    1,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1874,  342,  469,   37, 1198,  442,  909,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   25,  670,  187,   69,  407,   37,  119,  845,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3310,   12,    1, 1079,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  202,  321, 1658,   80, 1108,  544,  424,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  550,   10,  777,  778, 2008, 2311,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  585,   51,    1,  584, 2325,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422,    1,    1,    1,   98, 1717,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3038,    1,    1,   32,  215,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  980,   37,   56, 1333,  726,  176, 2957,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  207, 1110,    1, 1994, 2819, 1294,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2967,   12,  416, 1977,   37,  774,  548,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3167, 1863, 1061,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1185,    1,  967, 1846,    1,   37, 2259, 1140,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2994,  162, 1542,    9,  117,    1, 2973, 1764,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  506,  852,  176,    1,    1, 1635,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  275,  681,  588,   37,    1, 1994, 2086,  302,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100, 1825,    1,  551,   37,    1,  461, 2871,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3359, 1862,  600, 2024,    1, 2337, 2292, 1258,  234,  182,  235,\n",
      "            1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1423,  288,  166,  411, 1224,  176,  593, 1990,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2737,  967,  105, 1133,  427,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2741, 1822,  544, 2198,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1370,   45,  166,    1,  550, 1074,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2256,    1,  147,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2800,  544,  166,    1,    1,  424,   61,  105,    1,  612,  726,\n",
      "         1090,    9,  104,    1, 1831,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,  565, 1827,  220, 1427, 1135,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  829,  162, 1159, 2603,  808,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  129,  922, 1090, 1829, 1834,  176,  365, 1788,    1, 1090, 1056,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  754,  757,    1,  982,   71,   63,  862,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1592,    1, 1117,  741,   29,  211,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 2298,  220, 2464,    1,    9, 1524,   74,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   60,  682,    1,   69,  102,  832,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1043, 1226,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310, 2700,   37, 1539,    1,  506,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1643,    1,  365,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  845,  147,    1,   98, 1842,  207,  412,  804, 2928,    1,  150,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  347,   98,  356,    1,  356,    1, 1269,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1564,  460,  547,    9,  810,   32, 1940,   12,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  399, 2867,   32,  195,  768,  400,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  163,    1,   12,    1, 3162,    1, 1794,  880,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  466,    1, 2327,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365,    1,    1,    1,   32,    1,   81,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1247,    1,  156,  720,  118,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2324,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,    1, 1941,   32,  547,    1, 1450,   32,  854,   12,\n",
      "            1,    1,  171,  963, 2122,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2628, 2696,  952,    1,   98, 1089, 1090,   15,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3367,   12,  365,  650,    1,  204,   12,  105, 2774,  837,   88,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  117, 1278,    1,   37,   71,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 3303, 1463,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1314,   96, 2970,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  395,  267, 1789,  443,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2957,  936,    1, 2334,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 3230,    1, 1103,   32, 1282,   12,  354,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  952, 2149, 1428,  741,  304, 3140,   98, 1430,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3322,  688, 1957, 1957,  220,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,    1, 3102,    1,    1, 1574, 1687,    9,  964,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 1682,  469,  111,    1,   37, 2372,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2254,    1,  326,   37,  872,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  225,  218,  143,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3103,    1,  162,  979, 1217,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  354,  703,   37,  104,    1,   59,    1,  311,    1,\n",
      "          983,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1053, 1974,  284,    1, 1196,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   96,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  255,    1, 2024,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1481,  952,  516,  297, 3262,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  305,    1,  417,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  224,   12, 1611,    1,  236,  237,   12,    1,   98,  845,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3374,  650, 2572,   32, 3101,   22,   23,  477,   27, 3339,  787,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  365, 2036,  147, 1707,   22,  438,   35,  662,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,  908,    1,  563,  564,    9,  284,  947,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2447,  729,  967,    1,    1,  733,    9,    1,   59,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  389,    1,   71,    1, 1635,  245,   32,  871,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,  566,    1,  613, 1671, 1499,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  511,    1,  512,  513,  514,  361,  515,  516,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  159,  701,   37,  339,  340,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1031,   28, 3079, 1421,  103, 2824,  712,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  328,    1,   12,  197,   28,   98,    1,  285,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  922,    1,    1,  694, 1578,  202,  859,    1, 1411,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  420,  797,    9, 2372,    1,    1,  131,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2677, 2468,  603,    9, 1797,    1,  444,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 2700,  774,  445,   45, 3012,    1,    1, 3013,  298,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104,  160,  102,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[  2,   1, 856, 356,  45,   1, 428,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 398, 556, 867,  12, 350, 767,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2787,    1,   37,   52,  166,  311,  132,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  341,    1,  105,    1,   55,    1,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1656, 2960,   32, 1537, 1815,    1,  228, 2572,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1366,  565,    1, 3118, 1512,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,  155, 1698,  356,  197,  157,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  828, 1807,   37, 2654,  302,   37,   10, 1371,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  112,    1,  774, 2095,  166, 2084,  629,   32,  104,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  658, 1100,    1,   12,   98,  166,  454,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1797,  132,    1, 1663, 1448,  437,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  374,    1, 2562,    1, 1103,  238,   37,  813,  350,    1, 2705,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1, 1138,  953,   32, 1378,  442,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   91,   61,  645,   37,  619,    1,  191,  460,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,   69, 1137,  530,   98,  104,  109,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  224, 2355, 1013,  967,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1646,  680,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  597,  391, 1408,  183, 1002,  631,   32, 1081, 1708,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1158,  200,    1,   45, 1700, 2543,  124, 3011,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1652,   37, 1599,   26, 1039, 1228,  220, 2351,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   60,  418,  444,   94,  361, 1547,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1534,   45,  312,  966,  191,  163,    1,  903,    1, 3114, 1346,\n",
      "            1, 2266,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,    1, 1056,    1, 2844,  176,  247,    1,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   24, 1151, 1091,    1,  657,   12,  533,    1,    9,  920,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   61,    1,   32, 2513,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1555,    9, 1069,    1,    1,  125,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   46,  289,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3192,    1, 2107,  927,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  102, 1146, 2403,    1,  193, 1146, 1331,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2154,  111,  161,  133, 1551,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2073, 2431,    1, 1922,  582,   37, 1876,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2252,  810,  294, 2494,  357,  810,  632,    1,    9,    1,  176,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  284, 1128,    1,    1,    1,    9,  230, 2298,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1648,   37,    1,  142,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1056, 1485, 2161, 3340,   32, 2597,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1340,  162,  885,    1,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3236, 1012,    1,  187,  512,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  885,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  987,    9,    1,    1,    1,  815, 2819,   37,  877, 1515,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2912, 1116,  656,   37, 1119,  289,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1094, 1288,   37, 1527, 2708,  741,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3213, 2745,   37, 1911,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 2676,    1, 1867,  176, 2611,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2722, 3074, 2920,  872,  420, 1657,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1307,   37,  665,    1,   98, 1871,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1699, 2558,  321,  612,    1, 1377,   45, 2968,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2206, 2989, 1090,  105,    1,   45,    1,   98,  166,    1,   32,\n",
      "         1717,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  996, 1034,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,   68,   69,  636,  640,  813,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  659,    1,    1,   29,   67, 2758,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  196,   37,  125,    1,    4,   37,  243,  408,  548, 2187,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2417, 3310,    1, 2556,   37, 1753,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2514,    1,  548,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  476, 2024,   46,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 3141, 2962, 1751,    1,    1,  608, 2920,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,   37,   26,  409,  704,  551,  705,  656,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2473,    1, 1775, 2367,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  912, 2285,  614,   37,  845,  147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  829,  775, 1106,    1,    9,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2796,   45,  753,   32,    1,  171,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  810, 1385, 1758,  176,  386,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1094,   37,  362,  384, 3393, 3389, 1592,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2157,   37,    1,    1, 1842,  207,   32,  166,  272,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  657,    1,  191,   81,   37,   36,  997,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2865,   85,    1, 3110,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2629,   45,  531,   12, 2646,  496,  166, 1080,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  691,  480,    1,  361,    1,    9,  449,  438, 1463,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  386,    1,   61,  837,   45,  163,    1,   12,    1,  290,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1428,    1,  249,    1,    1,   32, 3118,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2561, 1213,  513,  514,   32,  365, 1788,  927,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1033,   91, 1320,  897,    1, 2862,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,   10,    1,  400,    9,    1,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3124, 2587, 1017,   37, 2341,    1,   61,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  422,  113, 1737,   98,    1, 1787,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 2489,   85, 2851,  861,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2672,    1,  307, 2791,  220, 1987,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1230, 1443, 2228,   79,  444, 1158,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1056,    1,   45, 2971,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2278,  708,  326, 2469,    9,    1,  389,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1396,  463, 2170,  458,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   22,  854,  721, 1579,   20,  349,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  782, 1604,  123,   37,  754,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  709,    1, 1096, 2275,    9,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1, 1854,    1,  220,  192,    1,  852,    9, 1639,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  602, 3315,    1, 2827,   32,  569,    1, 1981,   32,  166,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  228, 1439,    1,  786, 2356,   32,    1,    1,  133,  776,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3096,    1,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  613,    1,   75,  515, 1217,   37,  196,  176,  551,  612,  613,\n",
      "          170,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189,  267,    1, 1398,  612,  335,    1,  522,  328,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  104, 1437,  167,  583, 1232,  745,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  447, 1086,    1,  541,  384,  557,  540,  187, 1994,    1,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3339, 2831,    1, 1260, 2803, 3101, 2548,  328,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  857, 1267,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2940,   39,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2596, 2137, 2856,   32,  854,   12,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 3290, 1031,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1230,    1,   67,  658,  763,  848,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  449,  199, 1479, 2525, 3325,    1, 3021, 2228,   79,   32, 1938,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1100,    1,  328,    9,    1, 2403,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1481,   12,  652, 2521,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2028,   60,    5, 1494, 1159,   23,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  942,  891,  927,   45,  189,   12, 2089,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2573,   12,    1,   37, 1421,    1,  132,  220, 1471,  424, 1034,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  593,   68,   69,  490,   98,  529,    1, 2095,  122,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2764, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  258, 2683,  325,   48,   32,    1,  716,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2963,  600, 1148,   10, 1911,  443,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 2573,    1,  453,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420, 1117, 2208, 2298, 1389,  354,   45, 2591,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2691,  753, 1089,    1,  220, 1185, 2911, 2928,    1,\n",
      "          150,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  150, 1702, 1416,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  709,    1,    1,    1, 2171, 2565, 2430,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3232, 1542,    9,  248, 2789,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1041,    1,  191, 3117,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531,    1, 1338,   45, 1428, 1149,   37,  764, 2905,  890,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    9, 2846,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1702, 2463,  608, 3083,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   32, 1629,   12,  756,    1, 2074,   45,    1,    1,    1,   45,\n",
      "            1,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37,  698, 3201,    9, 2563,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2813,    1,    1, 1243,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,    6, 1139,    1, 2784,    1, 2405,  754,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2694, 1743, 1918,    1,  202,   61, 1523,  297,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,  361, 1955,  872,   28,   37,  860, 1819,    1, 1294,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1428, 2682,  487,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  494,   37, 1335,  514,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  730, 2614, 1833, 1408,    1,  220, 3269,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  774,  460,    1,  612,  320,    1,    1, 2111,    1,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1481,  267,  531, 2128,    1, 1293,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2489,   85,  336,    1,  220,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 3192, 2741,  688,  691,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  500,    1, 1191, 1003,   37,  693,  111, 1108,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1963,  407, 1159, 1708,    1,  187, 2249, 3373,   23,   10,   98,\n",
      "         2125,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1056,  649,    1, 1999, 3340,   32, 3354,    1, 2517,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  220,    1, 1492, 2518,  166, 3216,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2800, 3308, 1990, 1385,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  405,    1,    1,   20, 1149,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   80,    1, 1201,    1, 1670,   37, 2274,  220, 1842,  681,  918,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2352, 1081,  741,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326, 2612,   32,  327,  861,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1708, 1464,   37, 1031,    1,   98,  531, 1002,  101,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   37,    1,  191,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  854,  140,    1,    1,    1,   37, 2447,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  912, 2852,   32,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  964, 2386,  539,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1185,  104, 3273,  288,   37, 1046, 2732,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[  2,   1, 176, 446,  98, 538,  32,   1,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  65,  37,  92,  67, 191, 105, 401, 402,   3,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 2170,  872,   28,   37,  764, 3118,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2217,   12, 1277,  967,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  630,   51,   52,   27,   98,  302,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3038, 2108,    1,    1, 2465,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  919,  395,  646,   93,  570,   37,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  104, 1169,  160,  102,   71,    1, 1331,   28,    1,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1214,    1, 3237,  140,    1,    1, 1624,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  148,   15,   29,   66, 1997,  820,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1484,    9, 1346,  138,    6,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162, 2335,  339, 1038, 1175,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  545, 1035, 1070,  147,   37,    1,  792,    1,    1,  792,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3271, 3117,    1,   39, 2675,  187, 1103,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    4,   37, 1850, 1037,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  502,  458,    1,   28,    1,  401,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  228, 1283,   98,    1,    9, 1610, 1674, 1675,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1087, 1308,    1,  934,    1, 2182,   79,  284, 1149,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  615,  325,  987,  112,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1492, 1082, 2948,   37,   77,  593, 2647,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  548, 2507,  863,  726,   32,  691,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  164,  165,    1,    6, 1944,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  365, 1102,  931,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   56,    7,  992,   32,  534,   12,  104, 1314,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1700, 1439,   32, 3386,  312, 1916,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  683, 1587,   45,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  651, 1031,    1, 1514,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 3189,    1,    1,   39,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[  2, 163,   1,  12,   1, 700, 325,  48,  32,   1,   1, 428,   1,   3,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2, 447, 400, 297, 758,   1,  98,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  350,    1,    1, 1301,  342,   98,  829,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,  267,  864,    1,   32, 2673, 2813,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 1023,  166,  593,   12, 1149, 1493, 2051,  763,  105,   74,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1784,   79,    1,   37,   77, 1684,  809,   26,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  746,  251,    1,  339,  858,   37,  365,   17,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   59,  388, 2261,   32,  854,  191,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  112, 1697,  437, 1082,  595,  469,    9,  104,  295,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  396,    1,    1,    9, 1059,   28,    1,   45,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  790,   37,  231,    1,    1,  761,  661,  195,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,   51,    1,  388,   32, 1802,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  393,  267, 1149,  335,  138,  125,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  388, 2924, 1910, 2379,    1,    9,  531, 1010, 2429,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2920, 2712, 3331,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  535,  716,  774, 2545,    1,    1, 1576,  123,   37, 1727,    1,\n",
      "           98,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2678, 1648,   98, 1662, 2086,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  585,  686,  756,  757,  197,   88,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 1589,   12,  367,   15,   28,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,  267,  204,   12, 1509, 1942,  384, 2824,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  326,   15,  710,    1,   37, 1752,  136,   82,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1247,  708,    1,  187,    1, 3164,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1110,    1, 3251,  428,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2615,  588,   37,   77, 3224,    1,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1327,   37, 2446,    1,  342,  909,  444,  976,    1, 1190,  101,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2285,   61, 1370,   45,  210,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,    1,   12, 1322,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829,  879,    1, 1876,    9,    1, 2232, 1632,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2356,   32, 2772,    9, 1012,  722,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  393,  313,   37,  125,    4,    1,  720,  105, 1153,  361,  194,\n",
      "          138,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 3375, 2099, 1645, 1983,  420,   98, 3358,   12, 2162,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1210,  652,    1,  202,  838,   37,  163,    1,   12,    1,\n",
      "          764, 1002,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  709,    1, 2565,    1,  928,  428,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2304, 2162,  427,    9, 1935,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  650,   45,    1,  233, 1061,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1,   28,    9,  332,   47,   79,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  755,   37,   47, 2341,  161,    1,   37,  856, 2964,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  531, 2216,  104,    9, 3038, 2625,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  813, 1018,  274,    1,    1,  460,    1, 2303,   98,    1,  357,\n",
      "         1651,  674,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2685,  693, 1025,  537,    1,  331,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 3161,  542,    1,  351,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  420,  810,   98, 3076,  872,  851, 2844,   32,  298,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2851, 1187,  193,    1, 1496, 2997,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,  802, 1641,   37,    1,   13,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 2614,  321,  612,    1, 3079,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  189, 1243,  453,  389,    6,    1,    1,    1,   32,  104,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 2104,    1, 1520,    6,   32, 3001,   25,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864,   37, 1348, 2673,  210,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  224,  159,  504,   32,  218,  714,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  657, 1770,    1,  116,   37,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3303, 1993, 2017,  384,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433,  556, 1600,  261,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2227, 3275,   37,  335,  913,   98, 2107,   74,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3207,  140,  810, 1425, 3208, 1684,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1024,  288,    9,  365, 1788, 2615,  442,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,   12,    1,    1,  168,  111,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2572,   32,  531, 2292,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  384, 1018, 1147,    1,    1,    1,  361, 2325,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  829,  765,  444, 2650,  220,  633,  887,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1079, 3063, 1627, 2355, 1013, 1090,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  384,  166,  736,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   10,   37, 2579, 1080, 1114,   63,  736,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  267,  204,  190, 1413, 3202,   98, 3141, 1957,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3358,    1, 1484,  199,   98, 3344, 2139,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,   82, 2022,  361,    1,  484, 1348,  647,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  167,  590,    1, 2192, 1340, 1018, 1521, 1198,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  882, 1395,  936,  228,  131,   60, 1429,  528,  568,    1,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2448,  787,  951,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 1786,  515, 1217,   37,  259,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1074, 1345, 1797,    1,  599,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  189, 2329,   81,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1122,  325, 1123,   12,  853,  538,  663,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1527, 3343, 2746,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2700, 2047, 1088, 2288,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[  2,   1, 470,   1,  98,   1,   3,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,   1, 986, 479,   1, 331,  37, 875,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,   37, 1096,    9, 2150,  985, 1080,  506,   88,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   69,  102, 1473, 2029, 1714,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 3235, 3223,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2328, 3330, 1478,  119, 1909,    1, 1185, 1624,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  176,  551,  612,    1,  176,  551,  612,  613,  439, 2096,    1,\n",
      "         1031, 1589, 1259,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361, 1051, 1505,  955,  662,    9,  723,  116,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  959, 2756,    1,   32, 3118,  384, 1352,  232,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,  458,  214,   32,  455, 1631,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  104,    1, 2213, 2589,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   37,    1,  978, 2953, 2334,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  121, 2216, 2834,    9,    1,  851,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,   95, 1273, 1484, 1812,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  425,  426,   15,    1,  471,  997,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1423, 2272,   85,   98,  116,  133,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 1933,    1,    9,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  187,  166,  365, 2441,   45,  854,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  176, 2107,   45, 3116,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2977,  475,    1,    9,  389,  176, 3089,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3083, 1764,   39,  220,   81, 1987,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3260,    1,  599, 1573,  581,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[  2, 457, 681,  37, 151,   1,   9, 372,   3,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0],\n",
      "        [  2,  69,   1,   1,  98, 236, 237,   3,   0,   0,   0,   0,   0,   0,\n",
      "           0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,\n",
      "           0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   37,   71,  119,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1122,  853,  538,  459, 1123,  132,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  455, 2185,   85,    1, 1014,  646,    1,    1,  225,  102,  417,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  829, 1702,   39, 1312, 2786,  861, 2996,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  592,  108,   98,  596,  433,  102,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  215,   12, 1247,   37, 1248,  163,    1,   12,    1,   37,  125,\n",
      "            1,   88,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2666,    9,    1,  632,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  162, 1300,  225,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2925, 1090, 1829, 1959,  176,  501,  827,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2171, 2800, 1675,   98,  844,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1833,   12,    1,   51,  664, 1123,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  121,  267,   37,  429,   49,  333,  528,  163,    1,   12,    1,\n",
      "          695,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2, 2573,   12,    1,  267, 2710,  497,  894,    1,  531,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  872,  140,    1, 1518,   32,   98,\n",
      "          671,  428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2, 1002,  515, 2275,  317,  736,  631,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1783,  475,  387,    1,   45,    1,    1,  389,    6,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  328,    1, 1052,  354,    1,   15,   28,  419,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   12,  166, 1357,    9,  203,  460,   61,  920,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  493,  965, 2870,   32, 2755,  121,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  422, 1648,   37,    1,    1,    1,  625,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  503,  225,    1,   98,  550,   45,  749,  480,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  398,   57, 1047,    1,   37,  776,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  220,  289,   98,  864,    1,  968,  162,  590,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  591,    9,   91,  187,  517,    1,  522,   37, 2199,   60,\n",
      "          832,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  619,    1, 2082,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  449, 1173, 1395,  256,  105,    1,   37,  166, 2355,  327,  593,\n",
      "            1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,   65,   66,    1,  347,  528,  509,   88,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   61,  729,    1,    9, 2383,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  941, 1201,    1,  940,    1,   51, 1910,  721,    1,  317,  716,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3152,    1,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1061,    9,    1,    1,    1, 2942, 1564, 1018,  516,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  207, 2323, 2952,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1361,    1, 2919, 2234,   37,   26, 1039,  437,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1977, 2644,   32, 3043,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2984, 1534,   30, 2662, 2918, 2793,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3172, 1090, 1829, 1440,  176,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1310,   37, 1125,  114,  680,    1, 2551,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  799, 2414, 1270,   32, 3349,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  592,  267,  616,  176, 1354,    1,   32,  537,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  395,    1, 2018, 1140,    9, 1415, 1583,   37, 1583, 2471,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2263, 1532,   32, 1051, 1039, 2690, 2607,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  176, 1687, 1022,    1, 3008,    1,  166,  183,    1,   61,   45,\n",
      "           29,    1,  193,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3190,   12,    1,    1,  140, 2171, 2800,   12, 3193, 3217,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  163,    1,   12,    1,    1,  182,   32,    1,  279,  977,   32,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   90,   45,    1, 1814,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361,   37,  288, 2366, 1211,    1,  548,  105,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 2347, 3323, 1863,  894,  619,   39,   45, 2611, 1602,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2442,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  403,  464,    1,    1, 1159, 1796,   36,   32, 2592,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2583,  812,    1,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,   21,   37,    1,   88,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3194, 3195,    1, 3190,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 3082,  966, 3060,  580,  715,  147,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   11,  105,    1,  220,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 2942,  256, 1724,  885,  671,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   32,    1,    1,   64, 2582,  810,  166,  917,  765,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,   58,  155,  157,   37,   37,    1, 1146,  332,    9,  401,    1,\n",
      "         1698,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1128,    1,    1,  361,    1, 2627,  820,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2, 3172, 2794,    1,   37,  726,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3204,   12, 1021,   37,  907, 3169,   12,    1,   32,  104,   26,\n",
      "         2069,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3359, 1112,  176, 3358, 3040,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2418,   28,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2004,  829,    1,   37,    1, 2442, 1463,  437,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  848,  200, 2419,  220, 1411, 2273,    1, 2379, 1616,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 1921,   32, 3369,    9,   46,   98, 3118, 1512,  101,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2879,    1,    1, 2684,   32, 1817,    1,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  276,  640,  403,  294, 2715,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1743, 2362,   61,  105,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1087,    1,  657, 2336,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2528, 1122,   12, 2869,  853,  538,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   58,  155,  449,  401,    1, 1698,  356,  157,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  963, 2949, 1426, 2792,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  843,    1,   37,    1, 2853,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  861, 1008,  365, 2501,  475,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 3101,  644, 1450, 3384,   12,  433,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  219, 2005,   37,  693,  864,    1,  187,  915,  916,   37,  720,\n",
      "          234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  197,    9,    1,   13,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1345,   32, 2597, 2414, 2144,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 3374,  650, 2572,   32, 3339,  187,    1, 1152,   45,  521,  443,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2202, 2017,  220,  746, 3154,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,  326,    1, 2043,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  550, 2455,    1,  176,  166,  449,    1,    1,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2977, 2932,    1,    1,  359, 2905,    9, 3012,  927,   12,  865,\n",
      "         1821,    1,  150,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3327,  193,    1,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    7, 1537,  171,   37,  168,   37,  806,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  268,  251,   37,  151, 1092,  524,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  326,  733,  327,   50,   37,  395,   12,  324,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1492,  125,   79,   38,  852,   81,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  613,    1, 2146,    1,  191,  356,   12,  439,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1861,  251,  247, 2789,  105,    1,  516,    9,  531,  443,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3369,   12, 2751,    1,  957,  907,    9,   46,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  326,   72,  401,  156,    1,  983,   71,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1963, 2641,    1,  453,    1,   12,    1, 1015,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  861, 2461,    1,   37,    1,  331, 1943,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 1190,    1,  191, 1346,  777, 2931,  815,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  229,   37,  619,  620,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2009,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  105,    1,  429,   98, 1811, 1280,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1361,   12,    1, 2520, 2366, 2041, 2655, 2973, 1764,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  275,   12, 1294, 2695, 2334,    1,    9,  846,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1140,    9,  522,   98,  116,  126,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  460,   28,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1204,    1, 1205,  191, 1206,    1,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2612,  443,    1,    9,  325,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,   81,   32,  166,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  743,  884,  786, 1333,  631,  297, 3303,   32,    1, 3154,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1,  361,    1,    1,    1, 2274,    9,    1, 2780,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   74, 1312, 2677, 3256,  891,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 3342,   81,   32,  147,  892,   37, 1787,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  198, 3087,    1, 1850,  455,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1095, 1831, 2297, 1354, 2529,    1,   32,  104,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1370,   45, 3093,    1,    1,  171,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  148,   37,    1,   56, 2855,    9,  647,  721,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1278, 1298,   98,  777,  378, 2928,    1,  150,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  334,    1, 1176,    1,  321,    1,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  567,  510,  640,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 2977, 1654, 1034,   45,    1, 1705,   37,  567,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1178, 1988,   45,    1, 2910,  220,  792, 2650,  792,  267,  204,\n",
      "           12,  234,  182,  235,    1,    1,    1,  234,  182,  235,    1,    3,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1106, 1107, 1108,   61, 1018, 1738, 2927,   32,  166,  111, 2326,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  557,  540,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,  202, 3243,    1,   81,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  103, 3210,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 2700,   16,   79, 2334,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3013, 3268,    1, 2784,   37,  121,  297,  861,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  854,   12, 1228,  532,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  491,  568,    1,  548, 1346,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  166,  249,   12, 2143,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1884,  140,    1,    1, 1250,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 1078,  565,    1,    9, 1989, 1990,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  354, 2177,   37, 1599,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1622,  477,  297,  529,  347,   37,  168,   98,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   37, 1418,  372,  384,    1,  977,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 2767, 1718,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  477, 2047,  548,  455, 2164, 2414,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1090, 2940,    1,    9,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3322, 2116,   98,  365,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 1564,  365,  142,    9,  691,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1, 1998,    1,  861,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   82,  256, 1056,  365, 1213,    1,   37, 1291,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  433, 1579,    1,    9,    1,  777, 2078,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   39,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  506,  256,   37, 1406,   98,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2, 1158,    1, 1158, 3007, 2452,  517, 3011,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2110,  967,  590, 2537, 2585, 1264,  841, 1832,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  365, 1788,    1,    1,  827, 1022, 1090,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1345, 2361,   32,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  744, 2322,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3380,  387, 1125,  176,  439,   45,    1,  220,  854,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  105, 1587,    1,   45,  591,   32, 2890,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,   45, 1222, 2359, 1505,  698,   28,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1336, 2514,   12, 2084, 2537,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2546, 1086,  453, 1023,   79,  111, 1107,  333,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2104,  802, 2195,   37,  829,   12, 2819, 2362,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3364,  267,    1, 1924,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  255, 1178,   32,    1,  744,   79,   98, 1585,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  864, 1707, 3385, 1220,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2,  487, 3102,   32,  531, 1530,  420,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2609,    1,   98,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 1122,  538,  111,    1,   32, 1352,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  361,    1,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  434, 1095, 1244,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1007,    1, 1457, 1458,    1, 1743,  932,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1326,    1, 2274,   37, 1706,  152,   32,  395, 1597,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307, 1732,   15,    1,  699,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2494,  872, 1380,  163,    1,   12,    1,  176, 1567,   45,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2, 1509,  151,  686,  220,   43,  297,    1,   45,  460, 1149,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1841,    1,    9, 2615, 3224,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2984, 2418, 2945,   45, 2662,   12, 2918,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  310,   25,  670,  187,   69,  765,  530,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,  160,  783,    1,   32,  385,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,    1, 3194, 3195, 2161,  688,  316,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2, 1316,  365, 1788,    1,  105, 2162, 1780,    1,   32,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,    1,  267,  147,  991,    1,   45,  761,  195,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2, 1106, 1107,    1,   28,   37, 1343,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   83,   37,   84,   85,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  479,  155,  197,  570,    1, 1564,    6,  176, 1233,  328,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  967,  505,    1, 1949, 2579,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,   79, 2476,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2576,  361,    1,  200, 1479, 1499, 1296,   28,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  941,  251,  938,  331,  132,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1051,  449,  401,  244,   28,  118,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  352,  353,  354,    1,    1,    1,   32,  531,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  942, 2061, 3349,   98,  808,    9, 3362,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,   79,  166, 2904,    9,    1,  948,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,  259,  920, 2812,  384,    1,  361,  275,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,  166,  454, 2226, 1937,  460,    1, 1917, 1545,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1674,  638,    1,  967,  590, 2609,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3113,   12, 1277,  531,  890,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2794,  388,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  195,  633,   37,  949,  776,  932,   98,  777,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  590,  707,   81,   98, 1511,  446,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2, 3363,    1,    1,   37, 1918,   32, 1002,    1,  859,   37,  690,\n",
      "         1578,  101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  647, 1707,  148,  142,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  640,  361, 2753,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,    1,    1,   79,    1,   50,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 3354, 1810, 2572,   32,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  903,    1,  904,    1,  700,  251,   37, 1806, 2161,   12,    1,\n",
      "          428,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2, 2909,    1,  176, 2752,    1, 1606,    1,  590,    1,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1600,  138,  190,  920,   52,    1,    9, 2048,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  865,   45,  166, 1277,    1, 1935,   51, 1306,  284,  818,\n",
      "          819, 1160,    1,  150,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1084,    1,   37,  788,  449,  273,  285,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 1465,  298,   37,  211,  573,  361,  362,  589,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 2748,   12, 2125,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 3117,    1, 2633,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  566,  219, 1463,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2,  730, 1777,   12,  755,  151,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  615, 1982,  996,  550,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,  399,  428,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  507,  986,  183,  636,    9,  803, 2958,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 2])\n",
      "x_data\n",
      "tensor([[   2,  284,  163,    1,   12,    1,    1,    1,    1,  157,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  626, 1535,    1, 1270, 1215,   32,  915,  356,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  132, 2011,   37,   77, 2193, 2771,   32,    1,  428,    1,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2759, 1228,  983, 1293,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,   12, 2447,  921,   59,  176, 1611,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2500, 2727,  877,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  657,  769,   32,    9,  365, 1870, 2261,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2292,   32, 1853,  548,  186, 1260,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  963,  872, 1713, 2328, 1539,    1,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1904,  986,    1,    9, 3088,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,  852,    1,  763,   63,    1,  267,  683,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3026, 1757, 2424,    9,  104,    1,  215, 3365,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  162,  916,   32, 1717,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3311, 3310,  521,   43,  288,   37, 1174,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 3012, 1821, 3027, 2421,   32, 3013,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  328,  386,  111,   37,  151,    1,  111,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1, 3067,    1,    1, 1260,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  166, 1301,   45,    1,   12, 2790,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  224,  515, 3034, 1561, 1876,    1,  315,    1, 2524,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2494,  872,  688,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2, 2918,    1,   98, 2662,   12,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1013, 1522, 1299, 2958,  773, 1188,   37, 1911,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 2993, 1419, 3056,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1307,  459,   59,  132,  220,  976,  428,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2, 1238,  398,   57,    1,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1361, 1227, 1302,  991,  454,   37,   26, 1039, 2366,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,    1,    1, 1564,    1,  714,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1444,  245,   32, 2518,  528, 2212,  910,    1,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 3])\n",
      "x_data\n",
      "tensor([[   2,  105,    1,  400,    3,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  758,    1,  224,   32, 1273, 1013, 2107,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2,  575,  529,  658,  996,   93,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  557,  540,   37,  489, 2924,   81,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2, 2031, 1536,    9, 1334,   45, 3026,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,   25,   16,  411, 1565,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2, 2197, 1988,  297,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  267,    1, 1232,  864, 2390,  315,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,  836,  548, 2074,   45,    1, 2329,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 2863,    1,   28,    1, 1614,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n",
      "x_data\n",
      "tensor([[   2,  709, 1405,  232,  513,  514,   37,    1,  133,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  496, 2931,   37,   92,  613,  777, 1085,   88,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 1])\n",
      "x_data\n",
      "tensor([[   2,  552,  552, 1523, 1426,  990,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1037,    1,  977,   37, 1344,  365,  326,    4,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,    1, 2137,  686, 2936,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  365, 2764, 3394, 1928,  972,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 3])\n",
      "x_data\n",
      "tensor([[   2, 2685,    1,    1,  877,  132,  232,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1, 1256,    1,    1, 2802,  928,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 0])\n",
      "x_data\n",
      "tensor([[   2,  647,  142, 1523, 1618,   28,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 2572,  187,    1,    1, 1741,    1,  220, 2620,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,  650, 1061,   32,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  632,  947, 1267,  365, 2625,   98,   49,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,  179,    1,  746,   32, 1139, 2320,  613,    1,  132,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  136, 1586, 1643,    9,    1,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 1])\n",
      "x_data\n",
      "tensor([[   2,   72,  199,   12,  105,    1,    3,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  592,  475,    1,  964,   98,  203,   37, 1427,  121,   12,   93,\n",
      "          101,    1,    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,  232,  361,  961,    1, 1388,   98, 2124,   37, 2527,    3,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 1185,    1, 1739, 2365,  608, 1739,  275,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([1, 2])\n",
      "x_data\n",
      "tensor([[   2,  667,  446,  162,  863,   92,  220, 2050,  720,   32,  234,  182,\n",
      "          235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,    1,   98, 2279,   12,    1,    1,   37, 1027, 2177,    1,\n",
      "           98,  223,  963, 2122,    1,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 3])\n",
      "x_data\n",
      "tensor([[   2,  294, 1456, 1241,   28,  119,  244,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1,  520,    1,  171,   45,    1, 1512,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([0, 0])\n",
      "x_data\n",
      "tensor([[   2,  424, 2446,    1,  202,  166,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  487,    1,  868,  132,  220,  829,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 1])\n",
      "x_data\n",
      "tensor([[   2, 1283, 1385,   28,    1,  162, 3052,   98, 1171,  548,  411, 1242,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  649, 3222,    1, 1282,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 2])\n",
      "x_data\n",
      "tensor([[   2, 1640,  476,    1,  147,   37,  335,   98,    1,  400,   88,    1,\n",
      "            3,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3332,   12,  221,   37, 2748, 1360,  612,    1,  539,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 2])\n",
      "x_data\n",
      "tensor([[   2,    1, 2942, 2781,    1,   98, 2084, 1267,    3,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,    1, 1670,  808,   32,  465,  404,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([2, 3])\n",
      "x_data\n",
      "tensor([[   2,  193,  885,    1,  474,    3,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2,  491,    1,  844, 2495,    1,   82,  220,    1,    1, 1025,  234,\n",
      "          182,  235,    1,    1,    1,  234,  182,  235,    1,    3,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 0])\n",
      "x_data\n",
      "tensor([[   2,    1,    1,    1,    1, 1413, 2275, 1708,  428,    1,    3,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0],\n",
      "        [   2, 3034,  162,   79,  453,  777,    1,    3,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,\n",
      "            0,    0,    0,    0,    0]])\n",
      "y_target\n",
      "tensor([3, 1])\n"
     ]
    }
   ],
   "source": [
    "for data_dict in dataloader:\n",
    "    for name, tensor in data_dict.items():\n",
    "        print(name)\n",
    "        print(data_dict[name])"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 22,
   "metadata": {},
   "outputs": [],
   "source": [
    "dataset.set_split('test')\n",
    "batch_generator = generate_batches(dataset, \n",
    "                                batch_size=args.batch_size, \n",
    "                                device=args.device)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 23,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "<generator object generate_batches at 0x000002C942A3FF90>"
      ]
     },
     "execution_count": 23,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "batch_generator"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## The Model: NewsClassifier\n",
    "\n",
    "In this example, we demonstrate how to use pretrained word embeddings with CNN. Specifically, we use the Embedding layer, which maps the input token indices to a vector representation. We use the\n",
    "pretrained embedding subset by replacing the Embedding layer's weight matrix. The embedding is then used in the forward() method to map from the indices to the vectors. \n",
    "\n",
    "The model uses a series of one-dimensional convolutions to compute incrementally more features that result in a single feature vector. \n",
    "\n",
    ":::{note}\n",
    "The `Sequential` module is a convenience wrapper that encapsulates a linear sequence of operations. In this case, we use it to encapsulate the application of the Conv1d sequence.\n",
    ":::\n",
    "\n",
    "ELU is a nonlinearity similar to the ReLU activation function, but rather than clipping values below 0, it exponentiates them. ELU has been shown to be a promising nonlinearity to use between convolutional layers (Clevert et al., 2015)."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### The ELU activation function\n",
    "\n",
    "ELU, Exponential Linear Unit, is a variation of the ReLU (Rectified Linear Unit) Actvation Function. ELU is very similiar to RELU except negative inputs. They are both in identity function form for non-negative inputs. On the other hand, ELU becomes smooth slowly until its output equal to -α whereas RELU sharply smoothes. It is based on the mathematical function:\n",
    "\n",
    "Once you see the shape it will become familar:\n",
    "\n",
    "```{list-table}\n",
    ":header-rows: 1\n",
    ":name: example-table\n",
    "\n",
    "* - ELU\n",
    "  - ELU Derivative\n",
    "* - \n",
    "    $$\n",
    "      ELU(x) =\n",
    "        \\begin{cases}\n",
    "          x & \\text{if $x > 0$}\\\\\n",
    "          \\alpha \\times (e^x -1) & \\text{if $x \\leq 0$}\\\\\n",
    "        \\end{cases}       \n",
    "    $$\n",
    "  - \n",
    "    $$\n",
    "      ELU(x) =\n",
    "        \\begin{cases}\n",
    "          1 & \\text{if $x > 0$}\\\\\n",
    "          \\alpha \\times e^x & \\text{if $x < 0$}\\\\\n",
    "        \\end{cases}       \n",
    "    $$\n",
    "* - ![The ELU Activation Function](../images/elu.png)\n",
    "  - ![The ELU Derivative](../images/elu_prime.png)\n",
    "```\n",
    "\n",
    "The ELU function tends to converge cost to zero faster and produce more accurate results. Different to other activation functions, ELU has a extra alpha constant which should be positive number.\n",
    "\n",
    "**Pros**\n",
    "\n",
    "- ELU becomes smooth slowly until its output equal to -α whereas RELU sharply smoothes.\n",
    "- ELU is a strong alternative to ReLU.\n",
    "- Unlike ReLU, ELU can produce negative outputs.\n",
    "\n",
    "**Cons**\n",
    "\n",
    "- For $x > 0$, same as ReLU it can blow up the activation with the output range of [0, inf].\n",
    "\n",
    "[A summary of pros and cons of Activation Functions](https://ml-cheatsheet.readthedocs.io/en/latest/activation_functions.html)\n",
    "\n",
    "[Torch Documentation on `torch.nn.ELU`](https://pytorch.org/docs/stable/generated/torch.nn.ELU.html)\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {},
   "outputs": [],
   "source": [
    "class NewsClassifier(nn.Module):\n",
    "    def __init__(self, embedding_size, num_embeddings, num_channels, \n",
    "                 hidden_dim, num_classes, dropout_p, \n",
    "                 pretrained_embeddings=None, padding_idx=0):\n",
    "        \"\"\"\n",
    "        Args:\n",
    "            embedding_size (int): size of the embedding vectors\n",
    "            num_embeddings (int): number of embedding vectors\n",
    "            filter_width (int): width of the convolutional kernels\n",
    "            num_channels (int): number of convolutional kernels per layer\n",
    "            hidden_dim (int): the size of the hidden dimension\n",
    "            num_classes (int): the number of classes in classification\n",
    "            dropout_p (float): a dropout parameter \n",
    "            pretrained_embeddings (numpy.array): previously trained word embeddings\n",
    "                default is None. If provided, \n",
    "            padding_idx (int): an index representing a null position\n",
    "        \"\"\"\n",
    "        super(NewsClassifier, self).__init__()\n",
    "\n",
    "        if pretrained_embeddings is None:\n",
    "\n",
    "            self.emb = nn.Embedding(embedding_dim=embedding_size,\n",
    "                                    num_embeddings=num_embeddings,\n",
    "                                    padding_idx=padding_idx)        \n",
    "        else:\n",
    "            pretrained_embeddings = torch.from_numpy(pretrained_embeddings).float()\n",
    "            self.emb = nn.Embedding(embedding_dim=embedding_size,\n",
    "                                    num_embeddings=num_embeddings,\n",
    "                                    padding_idx=padding_idx,\n",
    "                                    _weight=pretrained_embeddings)\n",
    "        \n",
    "            \n",
    "        self.convnet = nn.Sequential(\n",
    "            nn.Conv1d(in_channels=embedding_size, \n",
    "                   out_channels=num_channels, kernel_size=3),\n",
    "            nn.ELU(),\n",
    "            nn.Conv1d(in_channels=num_channels, out_channels=num_channels, \n",
    "                   kernel_size=3, stride=2),\n",
    "            nn.ELU(),\n",
    "            nn.Conv1d(in_channels=num_channels, out_channels=num_channels, \n",
    "                   kernel_size=3, stride=2),\n",
    "            nn.ELU(),\n",
    "            nn.Conv1d(in_channels=num_channels, out_channels=num_channels, \n",
    "                   kernel_size=3),\n",
    "            nn.ELU()\n",
    "        )\n",
    "\n",
    "        self._dropout_p = dropout_p\n",
    "        self.fc1 = nn.Linear(num_channels, hidden_dim)\n",
    "        self.fc2 = nn.Linear(hidden_dim, num_classes)\n",
    "\n",
    "    def forward(self, x_in, apply_softmax=False):\n",
    "        \"\"\"The forward pass of the classifier\n",
    "        \n",
    "        Args:\n",
    "            x_in (torch.Tensor): an input data tensor. \n",
    "                x_in.shape should be (batch, dataset._max_seq_length)\n",
    "            apply_softmax (bool): a flag for the softmax activation\n",
    "                should be false if used with the Cross Entropy losses\n",
    "        Returns:\n",
    "            the resulting tensor. tensor.shape should be (batch, num_classes)\n",
    "        \"\"\"\n",
    "        \n",
    "        # embed and permute so features are channels\n",
    "        x_embedded = self.emb(x_in).permute(0, 2, 1)\n",
    "\n",
    "        features = self.convnet(x_embedded)\n",
    "\n",
    "        # average and remove the extra dimension\n",
    "        remaining_size = features.size(dim=2)\n",
    "        features = F.avg_pool1d(features, remaining_size).squeeze(dim=2)\n",
    "        features = F.dropout(features, p=self._dropout_p)\n",
    "        \n",
    "        # mlp classifier\n",
    "        intermediate_vector = F.relu(F.dropout(self.fc1(features), p=self._dropout_p))\n",
    "        prediction_vector = self.fc2(intermediate_vector)\n",
    "\n",
    "        if apply_softmax:\n",
    "            prediction_vector = F.softmax(prediction_vector, dim=1)\n",
    "\n",
    "        return prediction_vector"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Training Routine"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Helper functions"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {},
   "outputs": [],
   "source": [
    "def make_train_state(args):\n",
    "    return {'stop_early': False,\n",
    "            'early_stopping_step': 0,\n",
    "            'early_stopping_best_val': 1e8,\n",
    "            'learning_rate': args.learning_rate,\n",
    "            'epoch_index': 0,\n",
    "            'train_loss': [],\n",
    "            'train_acc': [],\n",
    "            'val_loss': [],\n",
    "            'val_acc': [],\n",
    "            'test_loss': -1,\n",
    "            'test_acc': -1,\n",
    "            'model_filename': args.model_state_file}\n",
    "\n",
    "def update_train_state(args, model, train_state):\n",
    "    \"\"\"Handle the training state updates.\n",
    "\n",
    "    Components:\n",
    "     - Early Stopping: Prevent overfitting.\n",
    "     - Model Checkpoint: Model is saved if the model is better\n",
    "\n",
    "    :param args: main arguments\n",
    "    :param model: model to train\n",
    "    :param train_state: a dictionary representing the training state values\n",
    "    :returns:\n",
    "        a new train_state\n",
    "    \"\"\"\n",
    "\n",
    "    # Save one model at least\n",
    "    if train_state['epoch_index'] == 0:\n",
    "        torch.save(model.state_dict(), train_state['model_filename'])\n",
    "        train_state['stop_early'] = False\n",
    "\n",
    "    # Save model if performance improved\n",
    "    elif train_state['epoch_index'] >= 1:\n",
    "        loss_tm1, loss_t = train_state['val_loss'][-2:]\n",
    "\n",
    "        # If loss worsened\n",
    "        if loss_t >= train_state['early_stopping_best_val']:\n",
    "            # Update step\n",
    "            train_state['early_stopping_step'] += 1\n",
    "        # Loss decreased\n",
    "        else:\n",
    "            # Save the best model\n",
    "            if loss_t < train_state['early_stopping_best_val']:\n",
    "                torch.save(model.state_dict(), train_state['model_filename'])\n",
    "\n",
    "            # Reset early stopping step\n",
    "            train_state['early_stopping_step'] = 0\n",
    "\n",
    "        # Stop early ?\n",
    "        train_state['stop_early'] = \\\n",
    "            train_state['early_stopping_step'] >= args.early_stopping_criteria\n",
    "\n",
    "    return train_state\n",
    "\n",
    "def compute_accuracy(y_pred, y_target):\n",
    "    _, y_pred_indices = y_pred.max(dim=1)\n",
    "    n_correct = torch.eq(y_pred_indices, y_target).sum().item()\n",
    "    return n_correct / len(y_pred_indices) * 100"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "#### general utilities\n",
    "\n",
    "The process for using word embeddings as the initial embedding matrix involves first loading the embeddings from the disk (see the utlility function `load_glove_from_disk()` function), then selecting the correct subset of embeddings for the words that are actually present in the data, and finally setting the Embedding layer's weight matrix as the loaded subset.\n",
    "\n",
    ":::{important} How to deal with words that do not have pretrained word embeddings?\n",
    "One issue that commonly arises is the existence of words that are in the dataset but are not among the pretrained GloVe embeddings. One common method for handling this is to use an initialization method from the PyTorch library, such as the Xavier Uniform method (Glorot and Bengio, 2010). See the `make_embedding_matrix()` function.\n",
    ":::"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {},
   "outputs": [],
   "source": [
    "def set_seed_everywhere(seed, cuda):\n",
    "    np.random.seed(seed)\n",
    "    torch.manual_seed(seed)\n",
    "    if cuda:\n",
    "        torch.cuda.manual_seed_all(seed)\n",
    "\n",
    "def handle_dirs(dirpath):\n",
    "    if not os.path.exists(dirpath):\n",
    "        os.makedirs(dirpath)\n",
    "        \n",
    "def load_glove_from_file(glove_filepath):\n",
    "    \"\"\"\n",
    "    Load the GloVe embeddings \n",
    "    \n",
    "    Args:\n",
    "        glove_filepath (str): path to the glove embeddings file \n",
    "    Returns:\n",
    "        word_to_index (dict), embeddings (numpy.ndarary)\n",
    "    \"\"\"\n",
    "\n",
    "    word_to_index = {}\n",
    "    embeddings = []\n",
    "    with open(glove_filepath, encoding=\"utf8\") as fp:\n",
    "        for index, line in enumerate(fp):\n",
    "            line = line.split(\" \") # each line: word num1 num2 ...\n",
    "            word_to_index[line[0]] = index # word = line[0] \n",
    "            embedding_i = np.array([float(val) for val in line[1:]])\n",
    "            embeddings.append(embedding_i)\n",
    "    return word_to_index, np.stack(embeddings)\n",
    "\n",
    "def make_embedding_matrix(glove_filepath, words):\n",
    "    \"\"\"\n",
    "    Create embedding matrix for a specific set of words.\n",
    "    \n",
    "    Args:\n",
    "        glove_filepath (str): file path to the glove embeddigns\n",
    "        words (list): list of words in the dataset\n",
    "    \"\"\"\n",
    "    word_to_idx, glove_embeddings = load_glove_from_file(glove_filepath)\n",
    "    embedding_size = glove_embeddings.shape[1]\n",
    "    \n",
    "    final_embeddings = np.zeros((len(words), embedding_size))\n",
    "\n",
    "    for i, word in enumerate(words):\n",
    "        if word in word_to_idx:\n",
    "            final_embeddings[i, :] = glove_embeddings[word_to_idx[word]]\n",
    "        else:\n",
    "            embedding_i = torch.ones(1, embedding_size)\n",
    "            torch.nn.init.xavier_uniform_(embedding_i)\n",
    "            final_embeddings[i, :] = embedding_i\n",
    "\n",
    "    return final_embeddings"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Settings and some prep work"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "metadata": {},
   "outputs": [],
   "source": [
    "from argparse import Namespace"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Expanded filepaths: \n",
      "\tmodel_storage\\document_classification\\vectorizer.json\n",
      "\tmodel_storage\\document_classification\\model.pth\n",
      "Using CUDA: True\n"
     ]
    }
   ],
   "source": [
    "args = Namespace(\n",
    "    # Data and Path hyper parameters\n",
    "    news_csv=\"../data/ag_news/news_with_splits.csv\",\n",
    "    vectorizer_file=\"vectorizer.json\",\n",
    "    model_state_file=\"model.pth\",\n",
    "    save_dir=\"model_storage\\document_classification\",\n",
    "    # Model hyper parameters\n",
    "    glove_filepath='../data/glove.6B/glove.6B.100d.txt', \n",
    "    use_glove=False,\n",
    "    embedding_size=100, \n",
    "    hidden_dim=100, \n",
    "    num_channels=100, \n",
    "    # Training hyper parameter\n",
    "    seed=1337, \n",
    "    learning_rate=0.001, \n",
    "    dropout_p=0.1, \n",
    "    batch_size=128, \n",
    "    num_epochs=100, \n",
    "    early_stopping_criteria=5, \n",
    "    # Runtime option\n",
    "    cuda=True, \n",
    "    catch_keyboard_interrupt=True, \n",
    "    reload_from_files=False,\n",
    "    expand_filepaths_to_save_dir=True\n",
    ") \n",
    "\n",
    "if args.expand_filepaths_to_save_dir:\n",
    "    args.vectorizer_file = os.path.join(args.save_dir,\n",
    "                                        args.vectorizer_file)\n",
    "\n",
    "    args.model_state_file = os.path.join(args.save_dir,\n",
    "                                         args.model_state_file)\n",
    "    \n",
    "    print(\"Expanded filepaths: \")\n",
    "    print(\"\\t{}\".format(args.vectorizer_file))\n",
    "    print(\"\\t{}\".format(args.model_state_file))\n",
    "    \n",
    "# Check CUDA\n",
    "if not torch.cuda.is_available():\n",
    "    args.cuda = False\n",
    "    \n",
    "args.device = torch.device(\"cuda\" if args.cuda else \"cpu\")\n",
    "print(\"Using CUDA: {}\".format(args.cuda))\n",
    "\n",
    "# Set seed for reproducibility\n",
    "set_seed_everywhere(args.seed, args.cuda)\n",
    "\n",
    "# handle dirs\n",
    "handle_dirs(args.save_dir)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Initializations"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "metadata": {},
   "outputs": [],
   "source": [
    "args.use_glove = True"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 12,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Using pre-trained embeddings\n"
     ]
    }
   ],
   "source": [
    "if args.reload_from_files:\n",
    "    # training from a checkpoint\n",
    "    dataset = NewsDataset.load_dataset_and_load_vectorizer(args.news_csv,\n",
    "                                                           args.vectorizer_file)\n",
    "else:\n",
    "    # create dataset and vectorizer\n",
    "    dataset = NewsDataset.load_dataset_and_make_vectorizer(args.news_csv)\n",
    "    dataset.save_vectorizer(args.vectorizer_file)\n",
    "vectorizer = dataset.get_vectorizer()\n",
    "\n",
    "# Use GloVe or randomly initialized embeddings\n",
    "if args.use_glove:\n",
    "    words = vectorizer.title_vocab._token_to_idx.keys()\n",
    "    embeddings = make_embedding_matrix(glove_filepath=args.glove_filepath, \n",
    "                                       words=words)\n",
    "    print(\"Using pre-trained embeddings\")\n",
    "else:\n",
    "    print(\"Not using pre-trained embeddings\")\n",
    "    embeddings = None\n",
    "\n",
    "classifier = NewsClassifier(embedding_size=args.embedding_size, \n",
    "                            num_embeddings=len(vectorizer.title_vocab),\n",
    "                            num_channels=args.num_channels,\n",
    "                            hidden_dim=args.hidden_dim, \n",
    "                            num_classes=len(vectorizer.category_vocab), \n",
    "                            dropout_p=args.dropout_p,\n",
    "                            pretrained_embeddings=embeddings,\n",
    "                            padding_idx=0)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 13,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "4"
      ]
     },
     "execution_count": 13,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# Number of Classes\n",
    "len(vectorizer.category_vocab)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Training loop"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Training routines consist of the following now familiar sequence of operations: instantiate the dataset, instantiate the model, instantiate the loss function, instantiate the optimizer, iterate over the dataset's training partition and update the model parameters, iterate over the dataset's validation partition and measure the performance, and then repeat the dataset iterations a certain number of times."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "This takes 1008 seconds (around 17 mins). "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 14,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "8ef4f9e594244d5b8097a3c1d1f18de1",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "training routine:   0%|          | 0/100 [00:00<?, ?it/s]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "3210a87ecbc24944a8d84bb6bc9e517c",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "split=train:   0%|          | 0/656 [00:00<?, ?it/s]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "e2fab78016d9426b91c1d653bda03103",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "split=val:   0%|          | 0/140 [00:00<?, ?it/s]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "classifier = classifier.to(args.device)\n",
    "dataset.class_weights = dataset.class_weights.to(args.device)\n",
    "    \n",
    "loss_func = nn.CrossEntropyLoss(dataset.class_weights)\n",
    "optimizer = optim.Adam(classifier.parameters(), lr=args.learning_rate)\n",
    "scheduler = optim.lr_scheduler.ReduceLROnPlateau(optimizer=optimizer,\n",
    "                                           mode='min', factor=0.5,\n",
    "                                           patience=1)\n",
    "\n",
    "train_state = make_train_state(args)\n",
    "\n",
    "epoch_bar = tqdm(desc='training routine', \n",
    "                          total=args.num_epochs,\n",
    "                          position=0)\n",
    "\n",
    "dataset.set_split('train')\n",
    "train_bar = tqdm(desc='split=train',\n",
    "                          total=dataset.get_num_batches(args.batch_size), \n",
    "                          position=1, \n",
    "                          leave=True)\n",
    "dataset.set_split('val')\n",
    "val_bar = tqdm(desc='split=val',\n",
    "                        total=dataset.get_num_batches(args.batch_size), \n",
    "                        position=1, \n",
    "                        leave=True)\n",
    "\n",
    "try:\n",
    "    for epoch_index in range(args.num_epochs):\n",
    "        train_state['epoch_index'] = epoch_index\n",
    "\n",
    "        # Iterate over training dataset\n",
    "\n",
    "        # setup: batch generator, set loss and acc to 0, set train mode on\n",
    "\n",
    "        dataset.set_split('train')\n",
    "        batch_generator = generate_batches(dataset, \n",
    "                                           batch_size=args.batch_size, \n",
    "                                           device=args.device)\n",
    "        running_loss = 0.0\n",
    "        running_acc = 0.0\n",
    "        classifier.train()\n",
    "\n",
    "        for batch_index, batch_dict in enumerate(batch_generator):\n",
    "            # the training routine is these 5 steps:\n",
    "\n",
    "            # --------------------------------------\n",
    "            # step 1. zero the gradients\n",
    "            optimizer.zero_grad()\n",
    "\n",
    "            # step 2. compute the output\n",
    "            y_pred = classifier(batch_dict['x_data'])\n",
    "\n",
    "            # step 3. compute the loss\n",
    "            loss = loss_func(y_pred, batch_dict['y_target'])\n",
    "            loss_t = loss.item()\n",
    "            running_loss += (loss_t - running_loss) / (batch_index + 1)\n",
    "\n",
    "            # step 4. use loss to produce gradients\n",
    "            loss.backward()\n",
    "\n",
    "            # step 5. use optimizer to take gradient step\n",
    "            optimizer.step()\n",
    "            # -----------------------------------------\n",
    "            # compute the accuracy\n",
    "            acc_t = compute_accuracy(y_pred, batch_dict['y_target'])\n",
    "            running_acc += (acc_t - running_acc) / (batch_index + 1)\n",
    "\n",
    "            # update bar\n",
    "            train_bar.set_postfix(loss=running_loss, acc=running_acc, \n",
    "                                  epoch=epoch_index)\n",
    "            train_bar.update()\n",
    "\n",
    "        train_state['train_loss'].append(running_loss)\n",
    "        train_state['train_acc'].append(running_acc)\n",
    "\n",
    "        # Iterate over val dataset\n",
    "\n",
    "        # setup: batch generator, set loss and acc to 0; set eval mode on\n",
    "        dataset.set_split('val')\n",
    "        batch_generator = generate_batches(dataset, \n",
    "                                           batch_size=args.batch_size, \n",
    "                                           device=args.device)\n",
    "        running_loss = 0.\n",
    "        running_acc = 0.\n",
    "        classifier.eval()\n",
    "\n",
    "        for batch_index, batch_dict in enumerate(batch_generator):\n",
    "\n",
    "            # compute the output\n",
    "            y_pred =  classifier(batch_dict['x_data'])\n",
    "\n",
    "            # step 3. compute the loss\n",
    "            loss = loss_func(y_pred, batch_dict['y_target'])\n",
    "            loss_t = loss.item()\n",
    "            running_loss += (loss_t - running_loss) / (batch_index + 1)\n",
    "\n",
    "            # compute the accuracy\n",
    "            acc_t = compute_accuracy(y_pred, batch_dict['y_target'])\n",
    "            running_acc += (acc_t - running_acc) / (batch_index + 1)\n",
    "            val_bar.set_postfix(loss=running_loss, acc=running_acc, \n",
    "                            epoch=epoch_index)\n",
    "            val_bar.update()\n",
    "\n",
    "        train_state['val_loss'].append(running_loss)\n",
    "        train_state['val_acc'].append(running_acc)\n",
    "\n",
    "        train_state = update_train_state(args=args, model=classifier,\n",
    "                                         train_state=train_state)\n",
    "\n",
    "        scheduler.step(train_state['val_loss'][-1])\n",
    "\n",
    "        if train_state['stop_early']:\n",
    "            break\n",
    "\n",
    "        train_bar.n = 0\n",
    "        val_bar.n = 0\n",
    "        epoch_bar.update()\n",
    "except KeyboardInterrupt:\n",
    "    print(\"Exiting loop\")\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 15,
   "metadata": {},
   "outputs": [],
   "source": [
    "# compute the loss & accuracy on the test set using the best available model\n",
    "\n",
    "classifier.load_state_dict(torch.load(train_state['model_filename']))\n",
    "\n",
    "classifier = classifier.to(args.device)\n",
    "dataset.class_weights = dataset.class_weights.to(args.device)\n",
    "loss_func = nn.CrossEntropyLoss(dataset.class_weights)\n",
    "\n",
    "dataset.set_split('test')\n",
    "batch_generator = generate_batches(dataset, \n",
    "                                   batch_size=args.batch_size, \n",
    "                                   device=args.device)\n",
    "running_loss = 0.\n",
    "running_acc = 0.\n",
    "classifier.eval()\n",
    "\n",
    "for batch_index, batch_dict in enumerate(batch_generator):\n",
    "    # compute the output\n",
    "    y_pred =  classifier(batch_dict['x_data'])\n",
    "    \n",
    "    # compute the loss\n",
    "    loss = loss_func(y_pred, batch_dict['y_target'])\n",
    "    loss_t = loss.item()\n",
    "    running_loss += (loss_t - running_loss) / (batch_index + 1)\n",
    "\n",
    "    # compute the accuracy\n",
    "    acc_t = compute_accuracy(y_pred, batch_dict['y_target'])\n",
    "    running_acc += (acc_t - running_acc) / (batch_index + 1)\n",
    "\n",
    "train_state['test_loss'] = running_loss\n",
    "train_state['test_acc'] = running_acc\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 16,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Test loss: 0.5580926260777882;\n",
      "Test Accuracy: 83.09151785714283\n"
     ]
    }
   ],
   "source": [
    "print(\"Test loss: {};\".format(train_state['test_loss']))\n",
    "print(\"Test Accuracy: {}\".format(train_state['test_acc']))"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Inference"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 17,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Preprocess the reviews\n",
    "def preprocess_text(text):\n",
    "    text = ' '.join(word.lower() for word in text.split(\" \"))\n",
    "    text = re.sub(r\"([.,!?])\", r\" \\1 \", text)\n",
    "    text = re.sub(r\"[^a-zA-Z.,!?]+\", r\" \", text)\n",
    "    return text"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 18,
   "metadata": {},
   "outputs": [],
   "source": [
    "def predict_category(title, classifier, vectorizer, max_length):\n",
    "    \"\"\"Predict a News category for a new title\n",
    "    \n",
    "    Args:\n",
    "        title (str): a raw title string\n",
    "        classifier (NewsClassifier): an instance of the trained classifier\n",
    "        vectorizer (NewsVectorizer): the corresponding vectorizer\n",
    "        max_length (int): the max sequence length\n",
    "            Note: CNNs are sensitive to the input data tensor size. \n",
    "                  This ensures to keep it the same size as the training data\n",
    "    \"\"\"\n",
    "    title = preprocess_text(title)\n",
    "    vectorized_title = \\\n",
    "        torch.tensor(vectorizer.vectorize(title, vector_length=max_length))\n",
    "    result = classifier(vectorized_title.unsqueeze(0), apply_softmax=True)\n",
    "    probability_values, indices = result.max(dim=1)\n",
    "    predicted_category = vectorizer.category_vocab.lookup_index(indices.item())\n",
    "\n",
    "    return {'category': predicted_category, \n",
    "            'probability': probability_values.item()}"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 19,
   "metadata": {},
   "outputs": [],
   "source": [
    "def get_samples():\n",
    "    samples = {}\n",
    "    for cat in dataset.val_df.category.unique():\n",
    "        samples[cat] = dataset.val_df.title[dataset.val_df.category==cat].tolist()[:5]\n",
    "    return samples\n",
    "\n",
    "val_samples = get_samples()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 20,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "True Category: Business\n",
      "==============================\n",
      "Prediction: Business (p=0.93)\n",
      "\t + Sample: az suspends marketing of cancer drug\n",
      "Prediction: Business (p=0.63)\n",
      "\t + Sample: business world has mixed reaction to perez move\n",
      "Prediction: Sports (p=0.65)\n",
      "\t + Sample: betting against bombay\n",
      "Prediction: Business (p=0.94)\n",
      "\t + Sample: malpractice insurers face a tough market\n",
      "Prediction: Business (p=0.50)\n",
      "\t + Sample: nvidia is vindicated\n",
      "------------------------------\n",
      "\n",
      "True Category: Sci/Tech\n",
      "==============================\n",
      "Prediction: World (p=0.79)\n",
      "\t + Sample: spies prize webcam s eyes\n",
      "Prediction: Sci/Tech (p=1.00)\n",
      "\t + Sample: sober worm causes headaches\n",
      "Prediction: Sci/Tech (p=0.95)\n",
      "\t + Sample: local search missing pieces falling into place\n",
      "Prediction: Sci/Tech (p=1.00)\n",
      "\t + Sample: hackers baiting internet users with beckham pix\n",
      "Prediction: Sci/Tech (p=0.95)\n",
      "\t + Sample: nokia adds blackberry support to series handsets\n",
      "------------------------------\n",
      "\n",
      "True Category: Sports\n",
      "==============================\n",
      "Prediction: Sports (p=0.99)\n",
      "\t + Sample: is meyer the man to get irish up ? \n",
      "Prediction: Sports (p=0.99)\n",
      "\t + Sample: who ? who ? and clemens\n",
      "Prediction: Sports (p=0.99)\n",
      "\t + Sample: baseball today ap \n",
      "Prediction: Sports (p=1.00)\n",
      "\t + Sample: mark kreidler yao ming epitomizes the chinese athlete who is lt b gt . . . lt b gt \n",
      "Prediction: Sports (p=0.97)\n",
      "\t + Sample: no . miami rebounds to beat fsu in overtime\n",
      "------------------------------\n",
      "\n",
      "True Category: World\n",
      "==============================\n",
      "Prediction: World (p=1.00)\n",
      "\t + Sample: arafat in pain but expected to recover shaath\n",
      "Prediction: World (p=1.00)\n",
      "\t + Sample: maoist rebels bomb kathmandu building , no injuries reuters \n",
      "Prediction: World (p=1.00)\n",
      "\t + Sample: son running for ill . rep . s house seat ap \n",
      "Prediction: World (p=0.99)\n",
      "\t + Sample: strong quake hits in japan\n",
      "Prediction: World (p=1.00)\n",
      "\t + Sample: israel assassinates hamas militant in damascus\n",
      "------------------------------\n",
      "\n"
     ]
    }
   ],
   "source": [
    "#title = input(\"Enter a news title to classify: \")\n",
    "classifier = classifier.to(\"cpu\")\n",
    "\n",
    "for truth, sample_group in val_samples.items():\n",
    "    print(f\"True Category: {truth}\")\n",
    "    print(\"=\"*30)\n",
    "    for sample in sample_group:\n",
    "        prediction = predict_category(sample, classifier, \n",
    "                                      vectorizer, dataset._max_seq_length + 1)\n",
    "        print(\"Prediction: {} (p={:0.2f})\".format(prediction['category'],\n",
    "                                                  prediction['probability']))\n",
    "        print(\"\\t + Sample: {}\".format(sample))\n",
    "    print(\"-\"*30 + \"\\n\")"
   ]
  }
 ],
 "metadata": {
  "interpreter": {
   "hash": "d990147e05fc0cc60dd3871899a6233eb6a5324c1885ded43d013dc915f7e535"
  },
  "kernelspec": {
   "display_name": "Python 3.8.10 64-bit ('cits4012': conda)",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.8.10"
  },
  "toc": {
   "colors": {
    "hover_highlight": "#DAA520",
    "running_highlight": "#FF0000",
    "selected_highlight": "#FFD700"
   },
   "moveMenuLeft": true,
   "nav_menu": {
    "height": "138px",
    "width": "252px"
   },
   "navigate_menu": true,
   "number_sections": true,
   "sideBar": true,
   "skip_h1_title": false,
   "threshold": "5",
   "title_cell": "Table of Contents",
   "title_sidebar": "Contents",
   "toc_cell": false,
   "toc_position": {},
   "toc_section_display": "block",
   "toc_window_display": false
  }
 },
 "nbformat": 4,
 "nbformat_minor": 2
}
